(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     56418,       1667]*)
(*NotebookOutlinePosition[     57633,       1703]*)
(*  CellTagsIndexPosition[     57589,       1699]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Lineare Finite-Elemente Analyse einer \
Balkenstruktur", "Title",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
COPYRIGHT Prof. Dr. Oskar Wallrapp, Fachhochschule Muenchen. Juni \
2003\
\>", "Subsubtitle",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Probemstellung: Eigenwert-Analyse   (freie Struktur)", "Subtitle",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[1, 0.999985, 0.780011]],

Cell[TextData[{
  "Loese das Eigenwertproblem der ungedaempften DGL:   MFy . ddyF +  KFy . yF \
= 0.\nDie Abschnitte 1 und 2 muessen bereits durchgerechnet sein!\n\n",
  StyleBox["Aufgaben",
    FontWeight->"Bold"],
  ":\n4.1 Bestimmung der Minimalkoordinaten yF\n      Reduzierung auf \
Minimalform der lin. DGL:  MFy . ddyF +   KFy . yF = 0\n4.2 Berechne die \
Eigenfrequenzen fev in Hz und die Eigenvektoren zFev\n      Stelle die \
Eigenvektoren grafisch dar.\n"
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[1, 0.999985, 0.780011]],

Cell[CellGroupData[{

Cell["FEName", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[1, 0.999985, 0.780011]],

Cell[BoxData[
    \("Elast. Winkel mit 3 Elementen"\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Festlegung der Parameter", "Subtitle",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[0.833356, 1, 0.8]],

Cell[CellGroupData[{

Cell[TextData[{
  "Setzen von Lagerbedingungen: ",
  StyleBox["Lager = {{",
    FontFamily->"Courier"],
  "Nr. Knoten mit Lager",
  StyleBox[", Key-u1, Key-u2, Key-theta3}}, \n",
    FontFamily->"Courier"],
  "Key: 0=frei, 1=fest der drei Bewegungen u1, u2, theta3"
}], "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[0.833356, 1, 0.8]],

Cell[CellGroupData[{

Cell["Lager = {{1, 0,0,0}} ", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[0.833356, 1, 0.8]],

Cell[BoxData[
    \({{1, 0, 0, 0}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Setzen von Berechnungsschluesseln", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[0.833356, 1, 0.8]],

Cell["\<\
keyPrint = 1;         (* 0 = kein Print von System-Matrizen, 1 = \
Print                    *)\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[0.833356, 1, 0.8]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Loesung: 4 Eigenwert-Analyse", "Subtitle",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
4.1 Bestimmung der Minimalkoordinaten yF und der \
Mininal-Systemmatrizen\
\>", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
nKLager = Length[Lager];
nIndr   = Sum[Delete[Transpose[Lager],1][[j,i]],{i,nKLager},{j,nfk}];
Indr    = Table[0,{nIndr}];
nR=0;
If[Lager[[1,1]]===0,IndM = Table[n,{n,1,nF}]; nM   = nF;,   (* keine \
Randbedingungen *)
\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t(* mit Randbedingungen   *)
                    Do[If[Lager[[k,2]]===1,nR=nR+1;Indr[[nR]]=(Lager[[k,1]]-1)\
*nfk+1];
                       If[Lager[[k,3]]===1,nR=nR+1;Indr[[nR]]=(Lager[[k,1]]-1)\
*nfk+2];
                       If[Lager[[k,4]]===1,nR=nR+1;Indr[[nR]]=(Lager[[k,1]]-1)\
*nfk+3];
                      ,{k,1, nKLager}];];
nR\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t(* Zahl der gebundenen Koorditen *)
Indr                  \t\t\t\t\t\t\t\t\t\t(* gebundene Koordinaten         *) \
   \
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(0\)], "Output"],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
If[nR===0, IndM = Table[n,{n,1,nF}],
           IndM = Delete[Table[n,{n,1,nF}],Partition[Indr,1]]];
nM = nF - nR              \t\t\t\t\t\t\t\t    (* Zahl der (freien) \
Minimal-Koordinaten    *) 
IndM         \t\t\t\t\t\t\t\t\t        \t(* Liste der Minimal-Koordinaten     \
       *)\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(12\)], "Output"],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Reduzierung auf Minimalform der lin. DGL.:  MFy . ddyF +  DFy . dyF \
+ KFy . yF = hFy\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
KFy = Table[0,{nM},{nM}];
Do [ Do [KFy[[i,j]] = KF[[IndM[[i]],IndM[[j]]]], {j,1,nM}], {i,1,nM}]; 
If[keyPrint == 1, KFy//MatrixForm]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.26`*^8", "0", "0", \(-1.26`*^8\), "0", "0", "0", "0", "0", 
              "0", "0", "0"},
            {"0", "10206.000000000002`", "5103.000000000001`", 
              "0", \(-10206.000000000002`\), "5103.000000000001`", "0", "0", 
              "0", "0", "0", "0"},
            {"0", "5103.000000000001`", "3402.0000000000005`", 
              "0", \(-5103.000000000001`\), "1701.0000000000002`", "0", "0", 
              "0", "0", "0", "0"},
            {\(-1.26`*^8\), "0", "0", "2.52`*^8", "0", "0", \(-1.26`*^8\), 
              "0", "0", "0", "0", "0"},
            {"0", \(-10206.000000000002`\), \(-5103.000000000001`\), "0", 
              "20412.000000000004`", "0.`", "0", \(-10206.000000000002`\), 
              "5103.000000000001`", "0", "0", "0"},
            {"0", "5103.000000000001`", "1701.0000000000002`", "0", "0.`", 
              "6804.000000000001`", "0", \(-5103.000000000001`\), 
              "1701.0000000000002`", "0", "0", "0"},
            {"0", "0", "0", \(-1.26`*^8\), "0", "0", "1.2656266875`*^8", 
              "0", \(-112533.74999999999`\), \(-562668.7499999999`\), 
              "0", \(-112533.74999999999`\)},
            {"0", "0", "0", 
              "0", \(-10206.000000000002`\), \(-5103.000000000001`\), "0", 
              "9.97510206`*^8", \(-5103.000000000001`\), "0", \(-9.975`*^8\), 
              "0"},
            {"0", "0", "0", "0", "5103.000000000001`", 
              "1701.0000000000002`", \(-112533.74999999999`\), \
\(-5103.000000000001`\), "33411.`", "112533.74999999999`", "0", "15004.5`"},
            {"0", "0", "0", "0", "0", "0", \(-562668.7499999999`\), "0", 
              "112533.74999999999`", "562668.7499999999`", "0", 
              "112533.74999999999`"},
            {"0", "0", "0", "0", "0", "0", "0", \(-9.975`*^8\), "0", "0", 
              "9.975`*^8", "0"},
            {"0", "0", "0", "0", "0", "0", \(-112533.74999999999`\), "0", 
              "15004.5`", "112533.74999999999`", "0", "30009.`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
MFy = Table[0,{nM},{nM}];
Do [ Do [MFy[[i,j]] = MF[[IndM[[i]],IndM[[j]]]], {j,1,nM}], {i,1,nM}]; 
If[keyPrint == 1, MFy//MatrixForm]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.7999999999999998`", "0", "0", "0.8999999999999999`", "0", "0",
               "0", "0", "0", "0", "0", "0"},
            {"0", "2.0057142857142853`", "0.2828571428571428`", "0", 
              "0.6942857142857142`", \(-0.16714285714285712`\), "0", "0", "0",
               "0", "0", "0"},
            {"0", "0.2828571428571428`", "0.05142857142857142`", "0", 
              "0.16714285714285712`", \(-0.03857142857142857`\), "0", "0", 
              "0", "0", "0", "0"},
            {"0.8999999999999999`", "0", "0", "3.5999999999999996`", "0", "0",
               "0.8999999999999999`", "0", "0", "0", "0", "0"},
            {"0", "0.6942857142857142`", "0.16714285714285712`", "0", 
              "4.011428571428571`", "0.`", "0", 
              "0.6942857142857142`", \(-0.16714285714285712`\), "0", "0", 
              "0"},
            {"0", \(-0.16714285714285712`\), \(-0.03857142857142857`\), "0", 
              "0.`", "0.10285714285714284`", "0", 
              "0.16714285714285712`", \(-0.03857142857142857`\), "0", "0", 
              "0"},
            {"0", "0", "0", "0.8999999999999999`", "0", "0", 
              "4.028645714285714`", "0", \(-0.1257184761904762`\), 
              "0.7714542857142856`", "0", "0.0742881904761905`"},
            {"0", "0", "0", "0", "0.6942857142857142`", 
              "0.16714285714285712`", "0", 
              "4.005780952380952`", \(-0.2828571428571428`\), "0", 
              "1.0000333333333333`", "0"},
            {"0", "0", "0", 
              "0", \(-0.16714285714285712`\), \(-0.03857142857142857`\), \
\(-0.1257184761904762`\), \(-0.2828571428571428`\), 
              "0.06057173333333333`", \(-0.0742881904761905`\), 
              "0", \(-0.006857371428571431`\)},
            {"0", "0", "0", "0", "0", "0", "0.7714542857142856`", 
              "0", \(-0.0742881904761905`\), "2.2286457142857143`", "0", 
              "0.1257184761904762`"},
            {"0", "0", "0", "0", "0", "0", "0", "1.0000333333333333`", "0", 
              "0", "2.0000666666666667`", "0"},
            {"0", "0", "0", "0", "0", "0", "0.0742881904761905`", 
              "0", \(-0.006857371428571431`\), "0.1257184761904762`", "0", 
              "0.009143161904761906`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2 Eigenfrequenzen und Eigenvektoren", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Mat = MF-1 . KF;   vals = omega^2;   vecs = Eigenvektoren \
(kleinster Wert am Ende) , Zeilenweise gespeichert. Es liegen nM=nFy  Werte \
vor.\
\>", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Mat = Inverse[MFy] . KFy; {vals, vecs} = 
      Chop[Eigensystem[Mat], 0.000001];\), "\n", 
    \(\(fev = Reverse[N[\@vals\/\(2\ \[Pi]\)]];\)\), "\n", 
    \(\(Print["\<Eigenwert j |  Freq f (Hz) | omega (rad/s)  |\>"];\)\), "\n\
", 
    \(\(Print["\<--------------------------------------------------\>"];\)\), \
"\n", 
    \(\(Do[\(Print["\<  \>", j, "\<         |   \>", 
            fev[\([j]\)], "\<    |  \>", 
            fev[\([j]\)]*2*Pi, "\<  |   \>"];\)\[IndentingNewLine], {j, 
          nM}];\)\)}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[
    \("Eigenwert j |  Freq f (Hz) | omega (rad/s)  |"\)], "Print"],

Cell[BoxData[
    \("--------------------------------------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("  "\[InvisibleSpace]1\[InvisibleSpace]"         |   \
"\[InvisibleSpace]0.`\[InvisibleSpace]"    |  "\[InvisibleSpace]0.`\
\[InvisibleSpace]"  |   "\),
      SequenceForm[ "  ", 1, "         |   ", 0.0, "    |  ", 0.0, "  |   "],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("  "\[InvisibleSpace]2\[InvisibleSpace]"         |   \
"\[InvisibleSpace]0.`\[InvisibleSpace]"    |  "\[InvisibleSpace]0.`\
\[InvisibleSpace]"  |   "\),
      SequenceForm[ "  ", 2, "         |   ", 0.0, "    |  ", 0.0, "  |   "],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("  "\[InvisibleSpace]3\[InvisibleSpace]"         |   \
"\[InvisibleSpace]0.`\[InvisibleSpace]"    |  "\[InvisibleSpace]0.`\
\[InvisibleSpace]"  |   "\),
      SequenceForm[ "  ", 3, "         |   ", 0.0, "    |  ", 0.0, "  |   "],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("  "\[InvisibleSpace]4\[InvisibleSpace]"         |   \
"\[InvisibleSpace]7.526595418716641`\[InvisibleSpace]"    |  "\
\[InvisibleSpace]47.29099374796559`\[InvisibleSpace]"  |   "\),
      SequenceForm[ 
      "  ", 4, "         |   ", 7.5265954187166413, "    |  ", 
        47.290993747965587, "  |   "],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("  "\[InvisibleSpace]5\[InvisibleSpace]"         |   \
"\[InvisibleSpace]18.16034429234905`\[InvisibleSpace]"    |  "\
\[InvisibleSpace]114.1048084310102`\[InvisibleSpace]"  |   "\),
      SequenceForm[ 
      "  ", 5, "         |   ", 18.160344292349048, "    |  ", 
        114.1048084310102, "  |   "],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("  "\[InvisibleSpace]6\[InvisibleSpace]"         |   \
"\[InvisibleSpace]40.2463222236339`\[InvisibleSpace]"    |  \
"\[InvisibleSpace]252.8751004635518`\[InvisibleSpace]"  |   "\),
      SequenceForm[ 
      "  ", 6, "         |   ", 40.246322223633904, "    |  ", 
        252.8751004635518, "  |   "],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("  "\[InvisibleSpace]7\[InvisibleSpace]"         |   \
"\[InvisibleSpace]105.90599393920829`\[InvisibleSpace]"    |  "\
\[InvisibleSpace]665.4269850610838`\[InvisibleSpace]"  |   "\),
      SequenceForm[ 
      "  ", 7, "         |   ", 105.90599393920829, "    |  ", 
        665.42698506108377, "  |   "],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("  "\[InvisibleSpace]8\[InvisibleSpace]"         |   \
"\[InvisibleSpace]173.9350744263685`\[InvisibleSpace]"    |  "\
\[InvisibleSpace]1092.8663040389463`\[InvisibleSpace]"  |   "\),
      SequenceForm[ 
      "  ", 8, "         |   ", 173.93507442636849, "    |  ", 
        1092.8663040389463, "  |   "],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("  "\[InvisibleSpace]9\[InvisibleSpace]"         |   \
"\[InvisibleSpace]563.2168444693385`\[InvisibleSpace]"    |  "\
\[InvisibleSpace]3538.795801925798`\[InvisibleSpace]"  |   "\),
      SequenceForm[ 
      "  ", 9, "         |   ", 563.21684446933853, "    |  ", 
        3538.7958019257981, "  |   "],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("  "\[InvisibleSpace]10\[InvisibleSpace]"         |   \
"\[InvisibleSpace]1153.9471633467906`\[InvisibleSpace]"    |  "\
\[InvisibleSpace]7250.463862002117`\[InvisibleSpace]"  |   "\),
      SequenceForm[ 
      "  ", 10, "         |   ", 1153.9471633467906, "    |  ", 
        7250.4638620021169, "  |   "],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("  "\[InvisibleSpace]11\[InvisibleSpace]"         |   \
"\[InvisibleSpace]2406.3922004648243`\[InvisibleSpace]"    |  "\
\[InvisibleSpace]15119.808117272138`\[InvisibleSpace]"  |   "\),
      SequenceForm[ 
      "  ", 11, "         |   ", 2406.3922004648243, "    |  ", 
        15119.808117272138, "  |   "],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("  "\[InvisibleSpace]12\[InvisibleSpace]"         |   \
"\[InvisibleSpace]6450.294642377431`\[InvisibleSpace]"    |  "\
\[InvisibleSpace]40528.39652396508`\[InvisibleSpace]"  |   "\),
      SequenceForm[ 
      "  ", 12, "         |   ", 6450.294642377431, "    |  ", 
        40528.396523965079, "  |   "],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(vecs[\([nM]\)]\)\(\ \ \ \ \ \ \ \)\( (*\ \ Eigenvektor\ zur\ \
untersten\ Frquenz\ *) \)\)\)], "Input"],

Cell[BoxData[
    \({0.0019176079387064526`, \(-0.6572676368816269`\), 0.3338607740544409`, 
      0.0019176079387064544`, \(-0.3234068628278211`\), 0.3338607740533097`, 
      0.0019176079387064554`, 0.010453911225937643`, 
      0.3338607740539688`, \(-0.1316267016828803`\), 0.01045391122593764`, 
      0.33386077405396775`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Darstellung der Eigenformen", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
nevgraf = 2;         (* Zahl der darzustellenden Eigenformen *)
nevnicht = 3;         (* Zahl der ersten nicht darzustellenden Eigenformen *)

plotev = Table[0,{nevgraf},{nE}];
Ne3 = Join[Ne,{Table[0,{nFe}]}];    (*  Nullzeile anhaengen *)
Do[ ev = vecs[[nM-nevnicht+1-kk]];
    If [nR > 0, Do [ev = Insert[ev,0,Indr[[j]] ], {j,nR}]];
    Ue = Table[0,{nE},{3}]; 
    Do [      Ue[[e]] = \
Transpose[Gammae[[e]]].Ne3.Transpose[TeT[[e]]].(ev+ZF)/.{le->Edata[[e,5]]};
       plotev[[kk,e]] = ParametricPlot[{Ue[[e,1]],Ue[[e,2]]},{xi,0,1},
                          DisplayFunction->Identity,PlotStyle->{{RGBColor[kk/\
nevgraf,0,0]}}];
      ,{e,nE}];
  ,{kk,nevgraf}];
Show[PlStructure1,PlStructure2,PlStructure3,PlStructure4, plotev,
     DisplayFunction->$DisplayFunction,PlotRange->All, 
     PlotLabel->{nevgraf,\"Eigenwerte:\",FEName,\"mit Lager im Knoten \
1\"}];\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .36778 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.120927 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04156 -24 -4.5 ]
[-0.0125 .04156 0 4.5 ]
[-0.0125 .12093 -6 -4.5 ]
[-0.0125 .12093 0 4.5 ]
[-0.0125 .20029 -18 -4.5 ]
[-0.0125 .20029 0 4.5 ]
[-0.0125 .27966 -18 -4.5 ]
[-0.0125 .27966 0 4.5 ]
[-0.0125 .35902 -18 -4.5 ]
[-0.0125 .35902 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .36778 .125 0 ]
[ 1 0 .125 0 ]
[.5 .38028 -208.406 0 ]
[.5 .38028 208.406 12 ]
[.93651 .09447 -5 -6 ]
[.93651 .09447 5 6 ]
[.12963 .31934 -5 -6 ]
[.12963 .31934 5 6 ]
[.12963 .14738 -3 -4.5 ]
[.12963 .14738 3 4.5 ]
[.52646 .14738 -3 -4.5 ]
[.52646 .14738 3 4.5 ]
[.92328 .14738 -3 -4.5 ]
[.92328 .14738 3 4.5 ]
[.92328 .30611 -3 -4.5 ]
[.92328 .30611 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .36778 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04156 m
.00625 .04156 L
s
[(-0.2)] -0.0125 .04156 1 0 Mshowa
0 .12093 m
.00625 .12093 L
s
[(0)] -0.0125 .12093 1 0 Mshowa
0 .20029 m
.00625 .20029 L
s
[(0.2)] -0.0125 .20029 1 0 Mshowa
0 .27966 m
.00625 .27966 L
s
[(0.4)] -0.0125 .27966 1 0 Mshowa
0 .35902 m
.00625 .35902 L
s
[(0.6)] -0.0125 .35902 1 0 Mshowa
.125 Mabswid
0 .0614 m
.00375 .0614 L
s
0 .08124 m
.00375 .08124 L
s
0 .10109 m
.00375 .10109 L
s
0 .14077 m
.00375 .14077 L
s
0 .16061 m
.00375 .16061 L
s
0 .18045 m
.00375 .18045 L
s
0 .22013 m
.00375 .22013 L
s
0 .23998 m
.00375 .23998 L
s
0 .25982 m
.00375 .25982 L
s
0 .2995 m
.00375 .2995 L
s
0 .31934 m
.00375 .31934 L
s
0 .33918 m
.00375 .33918 L
s
0 .02172 m
.00375 .02172 L
s
0 .00188 m
.00375 .00188 L
s
.25 Mabswid
0 0 m
0 .36778 L
s
.10317 .36153 m
.10317 .36778 L
s
.30159 .36153 m
.30159 .36778 L
s
.5 .36153 m
.5 .36778 L
s
.69841 .36153 m
.69841 .36778 L
s
.89683 .36153 m
.89683 .36778 L
s
.125 Mabswid
.14286 .36403 m
.14286 .36778 L
s
.18254 .36403 m
.18254 .36778 L
s
.22222 .36403 m
.22222 .36778 L
s
.2619 .36403 m
.2619 .36778 L
s
.34127 .36403 m
.34127 .36778 L
s
.38095 .36403 m
.38095 .36778 L
s
.42063 .36403 m
.42063 .36778 L
s
.46032 .36403 m
.46032 .36778 L
s
.53968 .36403 m
.53968 .36778 L
s
.57937 .36403 m
.57937 .36778 L
s
.61905 .36403 m
.61905 .36778 L
s
.65873 .36403 m
.65873 .36778 L
s
.7381 .36403 m
.7381 .36778 L
s
.77778 .36403 m
.77778 .36778 L
s
.81746 .36403 m
.81746 .36778 L
s
.85714 .36403 m
.85714 .36778 L
s
.06349 .36403 m
.06349 .36778 L
s
.02381 .36403 m
.02381 .36778 L
s
.93651 .36403 m
.93651 .36778 L
s
.97619 .36403 m
.97619 .36778 L
s
.25 Mabswid
0 .36778 m
1 .36778 L
s
.99375 .04156 m
1 .04156 L
s
.99375 .12093 m
1 .12093 L
s
.99375 .20029 m
1 .20029 L
s
.99375 .27966 m
1 .27966 L
s
.99375 .35902 m
1 .35902 L
s
.125 Mabswid
.99625 .0614 m
1 .0614 L
s
.99625 .08124 m
1 .08124 L
s
.99625 .10109 m
1 .10109 L
s
.99625 .14077 m
1 .14077 L
s
.99625 .16061 m
1 .16061 L
s
.99625 .18045 m
1 .18045 L
s
.99625 .22013 m
1 .22013 L
s
.99625 .23998 m
1 .23998 L
s
.99625 .25982 m
1 .25982 L
s
.99625 .2995 m
1 .2995 L
s
.99625 .31934 m
1 .31934 L
s
.99625 .33918 m
1 .33918 L
s
.99625 .02172 m
1 .02172 L
s
.99625 .00188 m
1 .00188 L
s
.25 Mabswid
1 0 m
1 .36778 L
s
gsave
.5 .38028 -269.406 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
84.562 13.000 moveto
0.000 0.000 rmoveto
84.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigenwerte) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
150.562 13.000 moveto
0.000 0.000 rmoveto
150.562 13.000 moveto
(,) show
160.125 13.000 moveto
0.000 0.000 rmoveto
160.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Elast) show
190.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
202.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Winkel) show
244.125 13.000 moveto
(mit) show
268.125 13.000 moveto
(3) show
280.125 13.000 moveto
(Elementen) show
334.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
334.125 13.000 moveto
(,) show
343.688 13.000 moveto
0.000 0.000 rmoveto
343.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mit) show
367.688 13.000 moveto
(Lager) show
403.688 13.000 moveto
(im) show
421.812 13.000 moveto
(Knoten) show
463.812 13.000 moveto
(1) show
469.812 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
469.812 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .12093 m
.97619 .12093 L
s
.10317 .04156 m
.10317 .35902 L
s
.10317 .12093 m
.10317 .12093 .00794 0 365.73 arc
F
gsave
.93651 .09447 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .31934 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .14738 0 0 Mshowa
[(2)] .52646 .14738 0 0 Mshowa
[(3)] .92328 .14738 0 0 Mshowa
[(4)] .92328 .30611 0 0 Mshowa
newpath
.10317 .12093 .00794 0 365.73 arc
s
newpath
.5 .12093 .00794 0 365.73 arc
s
newpath
.89683 .12093 .00794 0 365.73 arc
s
newpath
.89683 .27966 .00794 0 365.73 arc
s
.10317 .12093 m
.5 .12093 L
s
.5 .12093 m
.89683 .12093 L
s
.89683 .12093 m
.89683 .27966 L
s
.5 0 0 r
.08847 .00876 m
.10456 .01743 L
.12212 .02692 L
.13861 .03585 L
.15447 .04442 L
.17134 .0535 L
.18759 .06218 L
.20486 .0713 L
.2215 .07997 L
.2375 .08817 L
.25453 .09672 L
.27093 .10475 L
.28669 .11227 L
.30348 .12003 L
.31963 .12724 L
.33681 .13458 L
.35336 .14133 L
.36927 .14748 L
.38621 .15366 L
.40251 .1592 L
.41984 .16463 L
.43653 .1694 L
.45259 .17352 L
.46968 .17739 L
.48529 .18042 L
s
.48529 .18042 m
.50139 .18299 L
.50977 .18409 L
.51895 .1851 L
.52758 .18588 L
.53544 .18645 L
.54359 .18689 L
.54808 .18706 L
.55009 .18713 L
.55231 .18719 L
.55426 .18724 L
.55635 .18728 L
.55751 .1873 L
.55857 .18731 L
.55964 .18732 L
.56064 .18733 L
.56155 .18734 L
.56206 .18734 L
.56252 .18734 L
.56303 .18734 L
.56358 .18735 L
.5641 .18735 L
.56458 .18735 L
.56502 .18735 L
.56544 .18734 L
.5659 .18734 L
.5664 .18734 L
.5674 .18734 L
.56832 .18733 L
.57032 .18731 L
.57245 .18728 L
.57627 .18719 L
.58038 .18707 L
.58492 .1869 L
.59298 .18648 L
.60167 .18588 L
.61882 .18426 L
.63533 .18216 L
.6512 .17965 L
.66811 .17646 L
.68437 .17292 L
.70166 .16864 L
.71832 .16405 L
.73435 .15921 L
.7514 .15361 L
.76782 .14781 L
.78361 .14186 L
.80041 .13513 L
.81659 .1283 L
.83379 .12067 L
Mistroke
.85036 .11297 L
.86629 .10525 L
.88212 .0973 L
Mfstroke
.88212 .0973 m
.88541 .10374 L
.88902 .11076 L
.89241 .11736 L
.89568 .1237 L
.89916 .13045 L
.90253 .13695 L
.90611 .14386 L
.90957 .15052 L
.9129 .15692 L
.91645 .16373 L
.91987 .17029 L
.92316 .17659 L
.92668 .18331 L
.93006 .18977 L
.93366 .19664 L
.93713 .20326 L
.94047 .20962 L
.94403 .2164 L
.94745 .22292 L
.95109 .22985 L
.9546 .23653 L
.95798 .24295 L
.96157 .24979 L
.96485 .25603 L
s
1 0 0 r
.08761 .18928 m
.10371 .18074 L
.12126 .1715 L
.13775 .16296 L
.15361 .15489 L
.17049 .1465 L
.18673 .13865 L
.204 .1306 L
.22064 .12318 L
.23665 .11637 L
.25367 .10953 L
.27007 .10338 L
.28584 .0979 L
.30262 .09257 L
.31878 .08797 L
.33595 .0837 L
.3525 .08022 L
.36841 .07749 L
.3773 .07625 L
.38535 .07531 L
.39384 .07451 L
.40165 .07394 L
.40555 .07373 L
.40967 .07354 L
.41167 .07347 L
.41381 .07341 L
.41504 .07338 L
.41616 .07336 L
.4172 .07334 L
.41835 .07332 L
.41938 .07331 L
.42035 .07331 L
.42089 .0733 L
.42137 .0733 L
.42191 .0733 L
.42218 .0733 L
.42248 .0733 L
.42298 .0733 L
.42344 .0733 L
.42396 .0733 L
.42446 .07331 L
.42534 .07331 L
.4263 .07332 L
.42734 .07334 L
.42849 .07335 L
.4308 .07341 L
.43294 .07347 L
.43495 .07354 L
.43929 .07373 L
.4434 .07398 L
Mistroke
.45113 .07458 L
.4594 .07543 L
.46706 .07643 L
.48339 .07924 L
.48444 .07945 L
Mfstroke
.48444 .07945 m
.50054 .08301 L
.51809 .08745 L
.53458 .09207 L
.55044 .09682 L
.56732 .10213 L
.58357 .10739 L
.60084 .11304 L
.61747 .11846 L
.63348 .12356 L
.65051 .12876 L
.6669 .13347 L
.68267 .13763 L
.69946 .14157 L
.71561 .1448 L
.73279 .14754 L
.74137 .14861 L
.74934 .14941 L
.75704 .14999 L
.76134 .15023 L
.76525 .1504 L
.76728 .15046 L
.76943 .15052 L
.77126 .15055 L
.7723 .15056 L
.77327 .15057 L
.77381 .15058 L
.77411 .15058 L
.77439 .15058 L
.77491 .15058 L
.77546 .15058 L
.77595 .15058 L
.77641 .15058 L
.77691 .15057 L
.77746 .15057 L
.778 .15057 L
.7786 .15056 L
.7798 .15054 L
.78091 .15052 L
.78194 .1505 L
.78405 .15044 L
.78633 .15035 L
.79047 .15015 L
.7945 .14989 L
.79821 .14959 L
.80603 .14877 L
.81463 .14756 L
.83144 .14425 L
.84762 .1398 L
.86482 .13359 L
Mistroke
.88128 .12614 L
Mfstroke
.88128 .12614 m
.88452 .13258 L
.88811 .1396 L
.89154 .1462 L
.89488 .15254 L
.89849 .15929 L
.902 .16579 L
.90578 .1727 L
.90946 .17936 L
.91304 .18576 L
.91688 .19257 L
.9206 .19913 L
.9242 .20543 L
.92807 .21215 L
.93181 .21861 L
.9358 .22548 L
.93967 .2321 L
.9434 .23846 L
.94738 .24524 L
.95122 .25176 L
.95531 .25869 L
.95924 .26537 L
.96303 .27179 L
.96706 .27863 L
.97074 .28487 L
s
0 0 m
1 0 L
1 .36778 L
0 .36778 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{546, 200.812},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{-0, 1}, {0, 1}},
  RenderingOptions->{"RenderThickness"->False},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008R0000b1000`40O003h00Oogooogoo97oo001Y
Ool2001BOol20004Ool00`00Oomoo`02Ool3001BOol3001AOol30004Ool00`00Oomoo`02Ool3001@
Ool5001=Ool006Qoo`04001oogoo001@Ool01000Oomoo`001goo00D007ooOomoo`00059oo`03001o
ogoo055oo`03001oogoo00Moo`05001oogooOol0001@Ool01000Oomoo`00CGoo001XOol01000Oomo
o`00D7oo00@007ooOol000]oo`03001oogoo051oo`03001oogoo055oo`03001oogoo00]oo`03001o
ogoo04moo`03001oogoo04eoo`00J7oo00@007ooOol0051oo`04001oogoo000;Ool00`00Oomoo`1@
Ool00`00Oomoo`1AOol00`00Oomoo`0;Ool00`00Oomoo`1@Ool00`00Oomoo`1<Ool006Qoo`04001o
ogoo001@Ool01000Oomoo`001goo1000Dgoo00<007ooOol0DGoo00<007ooOol01goo1000D7oo00D0
07ooOomoo`0004eoo`00J7oo00@007ooOol0051oo`04001oogoo0007Ool00`00Oomoo`1COol2001B
Ool20009Ool00`00Oomoo`1AOol01@00Oomoogoo0000CGoo001YOol2001BOol20008Ool5001BOol0
0`00Oomoo`1AOol00`00Oomoo`07Ool5001@Ool3001>Ool00?mooomoobAoo`00ogooogoo97oo003o
OoooOolTOol00?mooomoobAoo`00ogooogoo97oo003oOoooOolTOol003]oool00<T001moo`00>goo
0`0027oo00<007ooOol03goo00<007ooOol03goo00<007ooOol03goo00<007ooOol03goo00<007oo
Ool03goo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007oo
Ool03goo00<007ooOol03goo00<007ooOol03goo00<007ooOol03goo00<007ooOol03goo00<007oo
Ool03goo00<007ooOol03goo00<007ooOol03goo00<007ooOol03goo00<007ooOol03goo00<007oo
Ool03goo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007oo
Ool01Woo0P007goo000kOol00`00Oomoo`08Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomo
o`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomo
o`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomo
o`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomo
o`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomo
o`0@Ool00`00Oomoo`0?Ool00`00Oomoo`07Ool00`00Oomoo`0MOol003]oo`03001oogoo02aoo`03
001oogoo05Moo`03001oogoo05Qoo`03001oogoo05Moo`03001oogoo05Moo`03001oogoo02aoo`03
001oogoo01eoo`00>goo00<007ooOol09Goo0S`0ogooWWoo00<007ooOol07Goo000kOol00`00Oomo
o`0WOol2?03oOonLOol00`00Oomoo`0MOol003]oo`03001oogoo02Uoo`8l0?mooiYoo`03001oogoo
01eoo`00>goo00<007ooOol0:goo0S`0ogooV7oo00<007ooOol07Goo000kOol00`00Oomoo`0]Ool2
?03oOonFOol00`00Oomoo`0MOol003]oo`03001oogoo02moo`03?01oogoo0?mooi=oo`03001oogoo
01eoo`00>goo0`00<7oo0S`0ogooTWoo0P007goo000kOol00`00Oomoo`0bOol2?03oOonAOol00`00
Oomoo`0MOol003]oo`03001oogoo03Aoo`03?01oogoo0?moohioo`03001oogoo01eoo`00>goo00<0
07ooOol0=Goo0S`0ogooSWoo00<007ooOol07Goo000kOol00`00Oomoo`0gOol2?03oOon<Ool00`00
Oomoo`0MOol003]oo`03001oogoo03Uoo`03?01oogoo0?moohUoo`03001oogoo01eoo`00>goo00<0
07ooOol0>Woo0S`0ogooRGoo00<007ooOol07Goo000UOol20004Ool01000Oomoogoo1@001goo00<0
07ooOol0?7oo0S`0ogooQgoo00<007ooOol07Goo000TOol01000Oomoo`0027oo00@007ooOol000Mo
o`03001oogoo03ioo`8l0?moohEoo`03001oogoo01eoo`007Goo1@000Woo00@007ooOol000Uoo`03
001oogoo00Moo`@002]oo`0301moogoo015oo`03?01oogoo0?mooh1oo`<001moo`0097oo00@007oo
Ool000Yoo`03001oogoo00Ioo`03001oogoo02aoo`0301moogoo019oo`8l0?mooh9oo`03001oogoo
01eoo`0097oo00@007ooOol000Moo`05001oogooOol00007Ool00`00Oomoo`0/Ool00`0OOomoo`0D
Ool2?03oOon0Ool00`00Oomoo`0MOol002Aoo`04001oogoo0007Ool01@00Oomoogoo00001goo00<0
07ooOol0;7oo00<07gooOol05Woo0S`0ogooOWoo00<007ooOol07Goo000UOol20009Ool30008Ool0
0`00Oomoo`0/Ool00`0OOomoo`0HOol2?03oOomlOol00`00Oomoo`0MOol003]oo`03001oogoo02ao
o`0301moogoo01Yoo`8l0?moogYoo`03001oogoo01eoo`00>goo00<007ooOol0;7oo00<07gooOol0
77oo0S`0ogooN7oo00<007ooOol07Goo000kOol00`00Oomoo`0/Ool00`0OOomoo`0NOol2?03oOomf
Ool00`00Oomoo`0MOol003]oo`03001oogoo02aoo`0301moogoo021oo`8l0?moogAoo`03001oogoo
01eoo`00>goo0`00;7oo00<07gooOol08Woo0S`0ogooLGoo0P007goo000kOol00`00Oomoo`0/Ool0
0`0OOomoo`0TOol2?03oOom`Ool00`00Oomoo`0MOol003]oo`03001oogoo02aoo`0301moogoo02Io
o`8l0?moofioo`03001oogoo01eoo`00>goo00<007ooOol0;7oo00<07gooOol0:7oo00<l07ooOol0
ogooJgoo00<007ooOol07Goo000kOol00`00Oomoo`0/Ool00`0OOomoo`0YOol2?03oOom[Ool00`00
Oomoo`0MOol003]oo`03001oogoo02aoo`0301moogoo02]oo`8l0?moofUoo`03001oogoo01eoo`00
>goo00<007ooOol0;7oo00<07gooOol0;Goo0S`0DGoo7g`0mWoo00<007ooOol07Goo000kOol00`00
Oomoo`0/Ool00`0OOomoo`0_Ool2?017Ool8O00OOol9O03]Ool00`00Oomoo`0MOol003]oo`03001o
ogoo02aoo`0301moogoo035oo`8l041oo`El031oo`=l0>Yoo`03001oogoo01eoo`00>goo0`00;7oo
00<07gooOol0<goo0S`0=Woo27`0>7oo1G`0i7oo0P007goo000kOol00`00Oomoo`0/Ool00`0OOomo
o`0eOol2?00^Ool6O015Ool5O03POol00`00Oomoo`0MOol003]oo`03001oogoo02aoo`0301moogoo
03Moo`03?01oogoo02Moo`Al051oo`Al0=aoo`03001oogoo01eoo`00>goo00<007ooOol0;7oo00<0
7gooOol0>7oo0S`097oo0g`0F7oo17`0f7oo00<007ooOol07Goo000kOol00`00Oomoo`0/Ool00`0O
Oomoo`0jOol2?00OOol3O01OOol4O02eOol201l00goo01l07`0JOol00`00Oomoo`0MOol003]oo`03
001oogoo02aoo`0301moogoo03aoo`<l01Yoo`9l06Ioo`Al0;9oo`0301moo`0O01]oo`03001oogoo
01eoo`00>goo00<007ooOol0;7oo00<07gooOol0?goo0c`057oo0g`0K7oo0g`0/7oo00<07gooOol0
6Woo00<007ooOol07Goo000kOol00`00Oomoo`0/Ool00`0OOomoo`12Ool2?00>Ool4O01bOol3O02/
Ool00`0OOol07`0KOol00`00Oomoo`0MOol003]oo`03001oogoo02aoo`0301moogoo04Aoo`8l00Qo
o`Al07Uoo`=l095oo`8l01Eoo`807`03Ool07`0O01Yoo`03001oogoo01eoo`00>goo0`00;7oo00<0
7gooOol0AWoo0S`00goo0g`0P7oo0W`0S7oo0c`000=ooc`0Ool0<Woo0P007goo000kOol00`00Oomo
o`0/Ool00`0OOomoo`18Ool3O025Ool3O027Ool2?005Ool00c`0Oomoo`0aOol00`00Oomoo`0MOol0
03]oo`03001oogoo02aoo`0301moogoo04Eoo`=l009oo`8l08Moo`Al085oo`8l00Moo`03?01oogoo
035oo`03001oogoo01eoo`00>goo00<007ooOol0;7oo00<07gooOol0@goo0W`01goo0c`0R7oo0g`0
O7oo0S`02Goo00<l07ooOol0<Goo00<007ooOol07Goo000kOol00`00Oomoo`0/Ool00`0OOomoo`11
Ool2O00<Ool2?029Ool3O01gOol2?00<Ool00c`0Oomoo`0`Ool00`00Oomoo`0MOol003]oo`03001o
ogoo02aoo`0301moogoo03ioo`=l011oo`8l08Yoo`=l079oo`8l00moo`03?01oogoo02moo`03001o
ogoo01eoo`00>goo00<007ooOol0:goo1000>goo0g`05Goo0S`0G7oo1000:goo0g`0KGoo0S`04Goo
00<l07ooOol00`00;7oo00<007ooOol07Goo000aOol20008Ool00`00Oomoo`0ZOol00`0001l07`02
01l00`00Oomoo`0fOol2O00JOol00c`0Oomoo`1GOol20004Ool00`00Oomoo`0[Ool3O01WOol3?00D
Ool00c`0001oo`02Ool00`00Oomoo`0YOol00`00Oomoo`0MOol0031oo`04001oogoo0007Ool00`00
Oomoo`0ZOol00`0001l07`0201l00`00Oomoo`0cOol3O00MOol2?01GOol00`00Oomoo`03Ool00`00
Oomoo`0^Ool3O01ROol2?00GOol00c`0Oomoo`02Ool00`00Oomoo`0YOol00`00Oomoo`0MOol0031o
o`04001oogoo0007Ool40007OolQ01l00`0001l07`0g0002O00R0002?02?0003O01M0002?00I0000
0c`00000000301l00`0001l07`0O01l7Ool3000OOol0031oo`04001oogoo0007Ool00`00Oomoo`0Y
Ool00`0001l07`0401l00`00Oomoo`0^Ool2O00VOol3?01AOol00`00Oomoo`04Ool00`00Oomoo`0d
Ool3O01HOol2?00JOol01000Ooll00000goo00<007ooOol0:7oo00<007ooOol07Goo000`Ool01000
Oomoo`001goo00<007ooOol0:Goo00<0000O01l00`0O00<007ooOol0;Goo0W`0:goo0c`0Cgoo00<0
07ooOol00Woo00<007ooOol0>7oo0g`0Dgoo0S`07Goo00<007oo?0000Woo00<007ooOol0:Goo00<0
07ooOol07Goo000`Ool01000Oomoo`001goo00<007ooOol0:Goo0`000P0O0P00;Goo0W`0<7oo0S`0
CGoo0`0000=oo`000000?Goo0g`0CWoo0S`06Goo0W`017oo0P0000@l07oo000002]oo`03001oogoo
01eoo`00<Goo0P0027oo00<007ooOol0;7oo0P00;Goo0W`0=7oo0S`0CWoo00<007ooOol0@7oo17`0
B7oo0S`067oo0g`000=oog`0Ool01Goo00<003`0Ool0;7oo00<007ooOol07Goo000kOol00`00Oomo
o`0/Ool00`0OOomoo`0ZOol2O00hOol00c`0Oomoo`2BOol4O011Ool3?00HOol2O005Ool00g`0Oomo
o`03Ool00`00?01oo`0/Ool00`00Oomoo`0MOol003]oo`03001oogoo02aoo`0301moogoo02Moo`=l
03]oo`8l09Ioo`Al03]oo`8l01Uoo`9l00Qoo`03O01oogoo009oo`03000l07oo02aoo`03001oogoo
01eoo`00>goo00<007ooOol0;7oo00<07gooOol097oo0g`0@7oo0S`0V7oo0g`0=Woo0S`067oo0g`0
2Woo00=l07ooOol00Woo00<007oo?000;7oo00<007ooOol07Goo000kOol00`00Oomoo`0/Ool00`0O
Oomoo`0ROol2O015Ool3?02HOol4O00_Ool3?00GOol3O00>Ool01G`0Oomoogoo00000Woo00<l07oo
Ool0:Goo00<007ooOol07Goo000kOol3000/Ool00`0OOomoo`0POol2O01:Ool3?02IOol4O00XOol3
?00GOol3O00AOol01G`0Oomoogoo00000Woo00<l07ooOol0:7oo0P007goo000kOol00`00Oomoo`0/
Ool00`0OOomoo`07Ool3000EOol00g`0Oomoo`1=Ool2?01:Ool5001<Ool6O00POol2?00GOol3O00D
Ool01G`0Oomoogoo00000goo00<l07ooOol00goo0`008Woo00<007ooOol07Goo000kOol00`00Oomo
o`0/Ool00`0OOomoo`08Ool00`00Oomoo`0BOol2O01BOol3?018Ool01000Oomoo`00DWoo1G`067oo
0c`05Goo17`067oo00Al07ooOol000Aoo`05?01oogooOol00003Ool00`00Oomoo`0OOol00`00Oomo
o`0MOol003]oo`03001oogoo02aoo`0301moogoo00Qoo`03001oogoo011oo`9l05Moo`8l04Moo`03
001oogoo05Moo`Al019oo`8l01Aoo`Al01eoo`03O01oo`0000Aoo`03?01oogoo00Eoo`03001oogoo
01moo`03001oogoo01eoo`00>goo00<007ooOol0;7oo00<07gooOol027oo00<007ooOol03Woo0W`0
Fgoo0c`0AGoo00<007ooOol0FWoo2g`017oo0c`037oo2W`08Goo00=l07oo00001Goo00<l07ooOol0
0Woo0P008Woo00<007ooOol07Goo000kOol00`00Oomoo`0/Ool00`0OOomoo`08Ool00`00Oomoo`0<
Ool2O01POol4?00nOol01@00Oomoogoo0000IWoo4g`0;7oo00=l0000Ool017oo00<l07ooOol017oo
00<007ooOol07goo00<007ooOol07Goo000kOol00`00Oomoo`0/Ool00`0OOomoo`07Ool2000<Ool2
O01VOol3?00kOol01@00Oomoogoo0000Hgoo0c`0@7oo00=l07ooOol00goo00@l07ooOol000=oo`03
001oogoo01moo`03001oogoo01eoo`00>goo00<007ooOol0;7oo00<07gooOol027oo00<007ooOol0
27oo0W`0Jgoo0c`0>Goo0`00HGoo0c`0@goo00=l07ooOol017oo00<l07ooOol00`008Woo00<007oo
Ool07Goo000kOol00`00Oomoo`0/Ool00`0OOomoo`0AOol2O01`Ool2?02HOol3?016Ool00`00O01o
o`05Ool00c`0Oomoo`0TOol00`00Oomoo`0MOol003]oo`<002aoo`0301moogoo011oo`03O01oogoo
079oo`<l099oo`<l04Uoo`03001l07oo00Eoo`03?01oogoo02=oo`8001moo`00>goo00<007ooOol0
;7oo00<07gooOol03Woo0W`0N7oo13`0Rgoo0c`0C7oo00<007`0Ool01Woo00<l07ooOol08goo00<0
07ooOol07Goo000kOol00`00Oomoo`0/Ool00`0OOomoo`0<Ool2O01nOol4?023Ool4?01?Ool00`00
Ooml0006Ool00c`0Oomoo`0SOol00`00Oomoo`0MOol003]oo`03001oogoo02aoo`0301moogoo00Uo
o`=l08Aoo`@l07aoo`<l05=oo`04001oogooO005Ool00c`0Oomoo`0SOol00`00Oomoo`0MOol003]o
o`03001oogoo02aoo`0301moogoo00Ioo`=l08]oo`@l07Aoo`@l05Ioo`04001oogooO006Ool00c`0
Oomoo`0ROol00`00Oomoo`0MOol003]oo`03001oogoo02aoo`0301moogoo00Aoo`9l099oo`<l06eo
o`@l05Yoo`05001oogooOoml0006Ool00c`0Oomoo`0QOol00`00Oomoo`0MOol003]oo`03001oogoo
02aoo`0301moogoo00=oo`03O01oogoo09Eoo`@l06Eoo`@l05ioo`03001oogoo009oo`03O01oogoo
00=oo`03?01oogoo025oo`03001oogoo01eoo`00>goo00<007ooOol0;7oo00@07gooOomoo`9l09ao
o`@l05eoo`@l069oo`03001oogoo009oo`03O01oogoo00Aoo`03?01oogoo021oo`03001oogoo01eo
o`00>goo00<007ooOol0;7oo00@07gooO01l0:9oo`@l05Aoo`Dl06Ioo`03001oogoo00=oo`03O01o
ogoo00=oo`03?01oogoo021oo`03001oogoo01eoo`00>goo00<007ooOol0;7oo00<07g`0Ool0Ygoo
0c`0BGoo23`0Jgoo00<007ooOol00goo00=l07ooOol00goo00<l07ooOol087oo00<007ooOol07Goo
000kOol3000[Ool2O02/Ool6?00lOol7?01cOol00`00Oomoo`03Ool00g`0Oomoo`04Ool00c`0Oomo
o`0NOol2000OOol003]oo`03001oogoo02Uoo`9l0003Ool07goo0;5oo`Tl02]oo`Pl07Yoo`03001o
ogoo00Aoo`03O01oogoo00Aoo`03?01oogoo01ioo`03001oogoo01eoo`00>goo00<007ooOol0:7oo
00El07ooOomoo`0O0;]oo`ll00moo`dl089oo`03001oogoo00Eoo`03O01oogoo00=oo`03?01oogoo
01ioo`03001oogoo01eoo`00>goo00<007ooOol09Woo0W`017oo00<07gooOol0b7oo3c`0Sgoo00<0
07ooOol01Goo00=l07ooOol017oo00<l07ooOol07Goo00<007ooOol07Goo000kOol00`00Oomoo`0U
Ool00g`0Oomoo`04Ool00`0OOomoo`3oOomWOol00`00Oomoo`06Ool00g`0Oomoo`04Ool00c`0Oomo
o`0LOol00`00Oomoo`0MOol003]oo`03001oogoo02aoo`0301moogoo0?moofMoo`03001oogoo00Mo
o`03O01oogoo00=oo`03?01oogoo01aoo`03001oogoo01eoo`009Goo0P0017oo00@007ooOomoo`D0
00Moo`03001oogoo02aoo`0301moogoo0?moofMoo`03001oogoo00Moo`03O01oogoo00Aoo`03?01o
ogoo01]oo`03001oogoo01eoo`0097oo00@007ooOol000Qoo`04001oogoo0007Ool00`00Oomoo`0/
Ool00`0OOomoo`3oOomWOol00`00Oomoo`08Ool00g`0Oomoo`03Ool00c`0Oomoo`0KOol00`00Oomo
o`0MOol002Aoo`04001oogoo0009Ool00`00Oomoo`07Ool00`00Oomoo`0/Ool00`0OOomoo`3oOomW
Ool00`00Oomoo`08Ool00g`0Oomoo`03Ool00c`0Oomoo`0KOol00`00Oomoo`0MOol002Aoo`04001o
ogoo000:Ool00`00Oomoo`06Ool4000[Ool00`0OOomoo`3oOomWOol00`00Oomoo`08Ool00g`0Oomo
o`04Ool00c`0Oomoo`0HOol3000OOol002Aoo`04001oogoo0007Ool01@00Oomoogoo00001goo00<0
07ooOol0;7oo00<07gooOol0ogooIgoo00<007ooOol02Goo00=l07ooOol017oo00<l07ooOol06Goo
00<007ooOol07Goo000TOol01000Oomoo`001goo00D007ooOomoo`0000Moo`03001oogoo02aoo`03
01moogoo0?moofMoo`03001oogoo00Yoo`03O01oogoo00=oo`03?01oogoo01Uoo`03001oogoo01eo
o`009Goo0P002Goo0`0027oo00<007ooOol0;7oo00<07gooOol0ogooIgoo00<007ooOol02Woo00=l
07ooOol017oo00<l07ooOol067oo00<007ooOol07Goo000kOol00`00Oomoo`0/Ool00`0OOomoo`3o
OomWOol00`00Oomoo`0;Ool00g`0Oomoo`03Ool00c`0Oomoo`0HOol00`00Oomoo`0MOol003]oo`03
001oogoo02aoo`0301moogoo0?moofMoo`03001oogoo00aoo`03O01oogoo009oo`03?01oogoo01Qo
o`03001oogoo01eoo`00>goo00<007ooOol0;7oo00<07gooOol0ogooIgoo00<007ooOol037oo00=l
07ooOol00goo00<l07ooOol05goo00<007ooOol07Goo000kOol00`00Oomoo`0/Ool00`0OOomoo`3o
OomWOol00`00Oomoo`0=Ool00g`0Oomoo`03Ool00c`0Oomoo`0FOol00`00Oomoo`0MOol003]oo`03
001oogoo02aoo`0301moogoo0?moofMoo`03001oogoo00eoo`03O01oogoo00=oo`03?01oogoo01Io
o`03001oogoo01eoo`00>goo0`00;7oo00<07gooOol0ogooIgoo00<007ooOol03Goo00=l07ooOol0
17oo00<l07ooOol057oo0P007goo000kOol00`00Oomoo`0/Ool00`0OOomoo`3oOomWOol00`00Oomo
o`0>Ool00g`0Oomoo`03Ool00c`0Oomoo`0EOol00`00Oomoo`0MOol003]oo`03001oogoo02aoo`03
01moogoo0?moofMoo`03001oogoo00moo`03O01oogoo009oo`03?01oogoo01Eoo`03001oogoo01eo
o`00>goo00<007ooOol0;7oo00<07gooOol0ogooIgoo00<007ooOol03goo00=l07ooOol00goo00<l
07ooOol057oo00<007ooOol07Goo000kOol00`00Oomoo`0/Ool00`0OOomoo`3oOomWOol00`00Oomo
o`0@Ool00g`0Oomoo`03Ool00c`0Oomoo`0COol00`00Oomoo`0MOol003]oo`03001oogoo02aoo`03
01moogoo0?moofMoo`03001oogoo015oo`03O01oogoo009oo`03?01oogoo01=oo`03001oogoo01eo
o`00>goo00<007ooOol0;7oo00<07gooOol0ogooIgoo00<007ooOol04Goo00=l07ooOol00goo00<l
07ooOol04Woo00<007ooOol07Goo000kOol00`00Oomoo`0/Ool00`0OOomoo`3oOomWOol00`00Oomo
o`0BOol00g`0Oomoo`03Ool00c`0Oomoo`0AOol00`00Oomoo`0MOol003]oo`03001oogoo02aoo`03
01moogoo0?moofMoo`03001oogoo01=oo`03O01oogoo009oo`03?01oogoo015oo`03001oogoo01eo
o`00>goo0`00;7oo00<07gooOol0ogooIgoo00<007ooOol04goo00=l07ooOol00goo00<l07ooOol0
3goo0P007goo000kOol00`00Oomoo`0/Ool00`0OOomoo`3oOomWOol00`00Oomoo`0DOol00g`0Oomo
o`02Ool00c`0Oomoo`0@Ool00`00Oomoo`0MOol003]oo`03001oogoo02aoo`0301moogoo0?moofMo
o`03001oogoo01Aoo`03O01oogoo009oo`03?01oogoo011oo`03001oogoo01eoo`00>goo00<007oo
Ool0;7oo00<07gooOol0ogooIgoo00<007ooOol057oo00=l07ooOol00goo00<l07ooOol03goo00<0
07ooOol07Goo000kOol00`00Oomoo`0/Ool00`0OOomoo`3oOomWOol00`00Oomoo`0EOol00g`0Oomo
o`03Ool00c`0Oomoo`0>Ool00`00Oomoo`0MOol003]oo`03001oogoo02aoo`0301moogoo0?moofMo
o`03001oogoo01Ioo`03O01oogoo009oo`03?01oogoo00ioo`03001oogoo01eoo`00>goo00<007oo
Ool0;7oo00<07gooOol0ogooIgoo00<007ooOol05Woo00=l07ooOol00goo00<l07ooOol03Goo00<0
07ooOol07Goo000kOol00`00Oomoo`0/Ool00`0OOomoo`3oOomWOol00`00Oomoo`0GOol00g`0Oomo
o`02Ool00c`0Oomoo`0=Ool00`00Oomoo`0MOol003]oo`03001oogoo02aoo`0301moogoo0?moofMo
o`03001oogoo01Qoo`03O01oogoo015oo`03001oogoo01eoo`00>goo0`00;7oo00<07gooOol0ogoo
Igoo00<007ooOol067oo00=l07ooOol047oo0P007goo000kOol00`00Oomoo`0/Ool00`0OOomoo`3o
OomWOol00`00Oomoo`0IOol00g`0Oomoo`0@Ool00`00Oomoo`0MOol003]oo`03001oogoo02aoo`03
01moogoo0?moofMoo`03001oogoo01Yoo`03O01oogoo00moo`03001oogoo01eoo`00>goo00<007oo
Ool0;7oo00<07gooOol0ogooIgoo00<007ooOol06Woo00=l07ooOol03goo00<007ooOol07Goo000k
Ool00`00Oomoo`0/Ool00`0OOomoo`3oOomWOol00`00Oomoo`0KOol00g`0Oomoo`0>Ool00`00Oomo
o`0MOol003]oo`03001oogoo02aoo`0301moogoo0?moofMoo`<001aoo`03O01oogoo00eoo`03001o
ogoo01eoo`009Goo0P0017oo00<007ooOol00goo0`001goo00<007ooOol0;7oo00<07gooOol0ogoo
IGoo0`000Woo00<007ooOol06Goo00=l07ooOol03Goo00<007ooOol07Goo000TOol01000Oomoo`00
2Woo00<007ooOol01Woo00<007ooOol0;7oo00<07gooOol0ogooIGoo00<007oo00000Woo00<007oo
Ool06Woo00=l07ooOol037oo00<007ooOol07Goo000TOol01000Oomoo`001goo1@001goo00<007oo
Ool0;7oo00<07gooOol0ogooI7oo00@007ooOol000=oo`03001oogoo01Uoo`03O01oogoo00aoo`03
001oogoo01eoo`0097oo00@007ooOol000Moo`04001oogoo0008Ool4000[Ool00`0OOomoo`3oOomT
Ool01000Oomoo`000goo00<007ooOol06Goo00=l07ooOol02Woo0`007goo000TOol01000Oomoo`00
27oo00<007oo000027oo00<007ooOol0;7oo00<07gooOol0ogooI7oo00<007ooOol017oo00<007oo
Ool06Woo00=l07ooOol02goo00<007ooOol07Goo000TOol01000Oomoo`002Goo0P0027oo00<007oo
Ool0;7oo00<07gooOol0ogooIGoo0P000Woo0P007Woo00=l07ooOol02Woo00<007ooOol07Goo000U
Ool2000;Ool00`00Oomoo`06Ool00`00Oomoo`0/Ool00`0OOomoo`3oOomWOol2000]Ool00`00Oomo
o`0MOol003]oo`03001oogoo02aoo`0301moogoo0?mooiIoo`03001oogoo01eoo`00>goo00<007oo
Ool0;7oo00<07gooOol0ogooUWoo00<007ooOol07Goo000kOol00`00Oomoo`0/Ool00`0OOomoo`3o
OonFOol00`00Oomoo`0MOol003]oo`03001oogoo02aoo`0301moogoo0?mooiIoo`03001oogoo01eo
o`00>goo00<007ooOol0;7oo00<07gooOol0ogooUWoo00<007ooOol07Goo000kOol3000/Ool00`0O
Oomoo`3oOombOol3000POol2000OOol003]oo`03001oogoo02aoo`0301moogoo0?moog=oo`03001o
ogoo021oo`03001oogoo01eoo`00>goo00<007ooOol0;7oo00<07gooOol0ogooL7oo1@008Goo00<0
07ooOol07Goo000kOol00`00Oomoo`0/Ool00`0OOomoo`3oOom`Ool01000Oomoo`008Woo00<007oo
Ool07Goo000kOol00`00Oomoo`0/Ool00`0OOomoo`3oOomaOol00`00Ool0000ROol00`00Oomoo`0M
Ool003]oo`03001oogoo02aoo`0301moogoo00Ioo`<07omoofUoo`80029oo`03001oogoo01eoo`00
>goo00<007ooOol0;7oo00<07gooOol01goo00<07gooOol0ogooJGoo00<007ooOol087oo00<007oo
Ool07Goo000kOol00`00Oomoo`0/Ool00`0OOomoo`08Ool00`0OOomoo`3oOon;Ool00`00Oomoo`0M
Ool003]oo`03001oogoo02aoo`0301moogoo00Qoo`0301moogoo0?mooh]oo`03001oogoo01eoo`00
>goo0`00;7oo00<07gooOol01goo00<07goo01l0ogooRgoo0P007goo000kOol00`00Oomoo`0/Ool0
0`0OOomoo`07Ool00`0OOol07`3oOon<Ool00`00Oomoo`0MOol003]oo`03001oogoo02aoo`0301mo
ogoo00Ioo`807`03Ool07`0O0?mooh]oo`03001oogoo01eoo`00>goo00<007ooOol0;7oo00<07goo
Ool0ogooUWoo00<007ooOol07Goo000kOol00`00Oomoo`0/Ool00`0OOomoo`3oOonFOol00`00Oomo
o`0MOol003]oo`03001oogoo02aoo`0301moogoo0?mooiIoo`03001oogoo01eoo`00>goo00<007oo
Ool0;7oo00<07gooOol0ogooUWoo00<007ooOol07Goo000kOol00`00Oomoo`0/Ool00`0OOomoo`3o
OonFOol00`00Oomoo`0MOol003]oo`03001oogoo02aoo`0301moogoo0?mooiIoo`03001oogoo01eo
o`00>goo0`00;7oo00<07gooOol0ogooUGoo0P007goo000kOol00`00Oomoo`0/Ool00`0OOomoo`3o
OonFOol00`00Oomoo`0MOol003]oo`03001oogoo02aoo`0301moogoo0?mooiIoo`03001oogoo01eo
o`00>goo00<007ooOol0;7oo00<07gooOol0ogooUWoo00<007ooOol07Goo000kOol00`00Oomoo`0/
Ool00`0OOomoo`3oOonFOol00`00Oomoo`0MOol003]oo`03001oogoo02aoo`0301moogoo0?mooiIo
o`03001oogoo01eoo`009Goo0P0017oo00<007ooOol00Woo0`0027oo00<007ooOol0;7oo00<07goo
Ool0ogooUWoo00<007ooOol07Goo000TOol01000Oomoo`001goo00D007ooOomoo`0000Moo`03001o
ogoo02aoo`0301moogoo0?mooiIoo`03001oogoo01eoo`0097oo00@007ooOol000Moo`05001oogoo
Ool00007Ool00`00Oomoo`0/Ool00`0OOomoo`3oOonFOol00`00Oomoo`0MOol002Aoo`04001oogoo
0007Ool40008Ool4000[Ool00`0OOomoo`3oOonDOol3000OOol002Aoo`04001oogoo0007Ool00`00
Oomoo`09Ool00`00Oomoo`0/Ool00`00Oomoo`1GOol00`00Oomoo`1HOol00`00Oomoo`1GOol00`00
Oomoo`1GOol00`00Oomoo`0/Ool00`00Oomoo`0MOol002Aoo`04001oogoo0008Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?
Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?
Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?
Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?
Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?
Ool00`00Oomoo`07Ool00`00Oomoo`0MOol002Eoo`8000Yoo`8000Qoo`03001oogoo00Qoo`03001o
ogoo00moo`03001oogoo00moo`03001oogoo00moo`03001oogoo00moo`03001oogoo00moo`03001o
ogoo00moo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00moo`03001o
ogoo00moo`03001oogoo00moo`03001oogoo00moo`03001oogoo00moo`03001oogoo00moo`03001o
ogoo00moo`03001oogoo00moo`03001oogoo00moo`03001oogoo00moo`03001oogoo00moo`03001o
ogoo00moo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo00Moo`03001o
ogoo01eoo`00>gooo`00b@007goo003oOoooOolTOol00?mooomoobAoo`00ogooogoo97oo003oOooo
OolTOol00?mooomoobAoo`00ogooogoo97oo001DOol00`00Oomoo`07Ool00`00Oomoo`0BOol3000d
Ool00`00Oomoo`2eOol00`00Oomoo`0YOol3001GOol00`00Oomoo`0gOol005=oo`03001oogoo00Uo
o`03001oogoo01Aoo`03001oogoo039oo`03001oogoo0;Eoo`03001oogoo02]oo`03001oogoo05Eo
o`03001oogoo03Ioo`00Dgoo00<007ooOol01@0017oo00<007ooOol017oo1@0000=oo`0000000`00
0Woo10000Woo0`000Woo0`0000Moo`00001oo`00Ool00003Ool30002Ool30005Ool20003Ool30004
Ool00`00Oomoo`04Ool00`00Oomoo`04Ool500000goo000000030002Ool400000goo000000020004
Ool20004Ool00`00Oomoo`08Ool00`00Ool00002Ool500001Goo00000000Ool0100000=oo`000000
0Woo0`000Woo1@001goo00H007oo001oo`00Ool50003Ool20009Ool30008Ool500000goo00000003
0002Ool30002Ool01@00Ool007oo00000Woo0`000Woo0`0000=oo`0000000Woo0P000goo0`000Woo
0`0000=oo`0000000goo00<007ooOol00goo00H007oo001oo`00Ool50003Ool20008Ool50002Ool4
0002Ool40002Ool30002Ool30009Ool500001Woo001oo`00Ool000Moo`<00003Ool0000000<00004
Ool00000Ool30004Ool20003Ool30002Ool300000goo00000007Ool30004Ool00`00Oomoo`0fOol0
05=oo`05001oogooOol00002Ool00`00Oomoo`0:Ool01000Oomoo`000goo00D007ooOomoo`0000=o
o`03001oo`0000Ioo`04001oogoo0002Ool00`00Ool00002Ool00`00Oomoo`04Ool00`00Oomoo`03
Ool01P00Oomoo`00Ool001Ioo`04001oogoo0003Ool01@00Oomoogoo00000Woo00<007ooOol017oo
00@007ooOol0009oo`03001oogoo00aoo`03001oo`0000Aoo`03001oogoo009oo`04001oogoo0002
Ool00`00Ool00002Ool00`00Oomoo`05Ool00`00Oomoo`07Ool01@00Ool007oo00000goo00<007oo
Ool00Woo00@007ooOol000Moo`05001oogooOol00008Ool01000Oomoo`000goo00D007ooOomoo`00
00Eoo`07001oo`00Ool007oo00001Woo00@007ooOol0009oo`06001oogoo001oo`001Woo00@007oo
Ool000Yoo`05001oo`00Ool00003Ool00`00Oomoo`02Ool01000Oomoo`0027oo00H007ooOol007oo
0002Ool01000Oomoo`000goo00<007oo00001Woo00<007ooOol02Woo00T007ooOomoo`00Ool007oo
000027oo00@007ooOol0009oo`06001oogoo001oo`000goo00@007ooOol0009oo`03001oo`0000Io
o`04001oogoo0009Ool00`00Oomoo`03Ool00`00Oomoo`0fOol0059oo`03001oogoo00=oo`03001o
ogoo00aoo`03001oogoo00Aoo`05001oogooOol00003Ool00`00Ool000040002Ool02`00Oomoo`00
Ool007oo001oo`00Ool01@000Woo00<007ooOol00goo00<007ooOol00Woo1@004Woo00<007ooOol0
17oo00<007ooOol00Woo0`000goo0`000goo00<007ooOol03goo00<007oo000017oo00<007ooOol0
0Woo00@007ooOol0009oo`8000=oo`D000=oo`03001oogoo00Moo`05001oo`00Ool00003Ool00`00
Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`06Ool00`00Oomoo`04Ool01000Oomoogoo1@0000Mo
o`00Ool007oo001oo`050002Ool01000Oomoo`000Woo00<007ooOol00Woo1@000Woo00@007ooOol0
00Yoo`05001oo`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`03Ool30002
Ool01P00Oomoogoo001oo`D0009oo`03001oogoo00Yoo`09001oogooOol007oo001oo`0000Qoo`03
001oo`0000=oo`06001oogoo001oo`000goo00@007ooOol000Aoo`D0009oo`04001oogoo0009Ool0
0`00Oomoo`04Ool00`00Oomoo`0eOol005=oo`03001oogoo00=oo`03001oogoo00]oo`<000Aoo`05
001oogooOol00003Ool00`00Ool00003Ool01000Oomoo`000Woo00T007oo001oo`00Ool007oo0000
0goo00<007ooOol00P0017oo00<007ooOol00Woo00D007ooOomoo`00019oo`<000Aoo`05001oogoo
Ool00002Ool01000Oomoo`001Woo00<007ooOol03Woo00D007oo001oo`0000=oo`03001oogoo009o
o`04001oogoo0002Ool00`00Ool00002Ool01@00Oomoogoo00000goo00<007ooOol01goo00D007oo
001oo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`8000Uoo`<000Aoo`05001oogooOol00003
Ool02@00Ool007oo001oo`00Ool00003Ool01000Oomoo`000Woo00@007ooOol000Aoo`05001oogoo
Ool00002Ool01000Oomoo`002Woo00D007oo001oo`0000=oo`03001oogoo009oo`03001oogoo00Uo
o`03001oogoo009oo`04001oogoo0002Ool01`00Oomoogoo001oo`0000=oo`03001oogoo008000]o
o`09001oogooOol007oo001oo`0000Qoo`8000Aoo`06001oogoo001oo`000goo00@007ooOol000Ao
o`05001oogooOol00002Ool01000Oomoo`002Goo00<007ooOol00goo00<007ooOol0=Woo001COol0
1000Oomoo`000goo00<007ooOol02Woo00<007ooOol00Woo0`0017oo1@0000Aoo`000000009oo`@0
009oo`H00004Ool000000002Ool2000017oo000007oo10000goo0`0017oo00<007ooOol037oo00<0
07ooOol017oo00<007ooOol00Woo0P0017oo100000=oo`0000000P003Woo00H007oo001oo`00Ool3
0003Ool40003Ool01000Ool000000Woo0`0017oo00<007ooOol01goo0P0000Aoo`00Oomoo`<000=o
o`@000aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo009oo`<0009oo`800003Ool007oo
009oo`<0009oo`@0009oo`@000=oo`<0009oo`@000]oo`800004Ool007ooOol30003Ool40009Ool0
0`00Oomoo`03Ool20004Ool5000017oo000000000Woo0P0000=oo`0000001goo0`000goo0P0000=o
o`00Ool027oo00<007oo00000Woo10000goo0`000Woo10000goo0`000Woo10002Woo00<007ooOol0
0goo00<007ooOol0=Woo001DOol00`00Ool00003Ool00`00Oomoo`0:Ool01000Oomoo`00;7oo00<0
07ooOol06Goo00@007ooOol000=oo`03001oogoo00ioo`03001oogoo00ioo`05001oo`00Ool0000>
Ool00`00Oomoo`0:Ool00`00Oomoo`0DOol00`00Oomoo`08Ool01@00Oomoogoo000027oo00@007oo
Ool000=oo`03001oogoo01Yoo`03001oogoo02Aoo`03001oogoo00Uoo`03001oogoo03=oo`04001o
ogoo000>Ool00`00Oomoo`0EOol20004Ool00`00Oomoo`0gOol005Moo`<000aoo`D000=oo`03001o
ogoo02Ioo`03001oogoo01Qoo`D00004Ool00000000@Ool00`00Oomoo`0>Ool60002Ool00`00Oomo
o`07Ool2000:Ool3000AOol00`00Oomoo`02Ool00`00Oomoo`09Ool30008Ool5000017oo00000000
77oo00<007ooOol07goo00<007ooOol00Woo00<007ooOol027oo0`008goo00<007ooOol03Goo0`00
00=oo`0000003Goo00<007ooOol05Woo00<007ooOol0?7oo003oOoooOolTOol00?mooomoobAoo`00
\
\>"],
  ImageRangeCache->{{{0, 545}, {199.812, 0}} -> {-0.590254, -0.386061, \
0.0055355, 0.0055355}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowToolbars->{},
WindowSize->{1128, 379},
WindowMargins->{{Automatic, 5}, {31, Automatic}},
PageHeaders->{{Inherited, Inherited, Inherited}, {Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Cell[ 
      "Prof. Dr. O. Wallrapp, FHM FB06 "]}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->False,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
MacintoshSystemPageSetup->"\<\
00<0004/0B`000003_@:COm]og8?S0[G0fL5N`?P0080004/0B`000000]X2:001
0000E@0000400@410?l00BL?00400@00000000000000060801T1T0000000@000
00000000004000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 104, 2, 108, "Title"],
Cell[1883, 57, 136, 4, 53, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2044, 65, 152, 2, 78, "Subtitle"],
Cell[2199, 69, 558, 11, 176, "Text"],

Cell[CellGroupData[{
Cell[2782, 84, 103, 2, 43, "Input"],
Cell[2888, 88, 65, 1, 26, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3002, 95, 119, 2, 78, "Subtitle"],

Cell[CellGroupData[{
Cell[3146, 101, 361, 10, 74, "Subsubsection"],

Cell[CellGroupData[{
Cell[3532, 115, 113, 2, 43, "Input"],
Cell[3648, 119, 48, 1, 26, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3745, 126, 133, 2, 58, "Subsubsection"],
Cell[3881, 130, 194, 5, 43, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4124, 141, 81, 1, 62, "Subtitle"],

Cell[CellGroupData[{
Cell[4230, 146, 136, 4, 46, "Subsection"],

Cell[CellGroupData[{
Cell[4391, 154, 795, 19, 192, "Input"],
Cell[5189, 175, 35, 1, 70, "Output"],
Cell[5227, 178, 36, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5300, 184, 344, 8, 72, "Input"],
Cell[5647, 194, 36, 1, 70, "Output"],
Cell[5686, 197, 73, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5796, 203, 152, 4, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[5973, 211, 190, 5, 57, "Input"],
Cell[6166, 218, 2173, 38, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8376, 261, 190, 5, 57, "Input"],
Cell[8569, 268, 2414, 43, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[11044, 318, 93, 1, 30, "Subsection"],

Cell[CellGroupData[{
Cell[11162, 323, 209, 5, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[11396, 332, 576, 12, 131, "Input"],
Cell[11975, 346, 80, 1, 22, "Print"],
Cell[12058, 349, 85, 1, 22, "Print"],
Cell[12146, 352, 302, 5, 22, "Print"],
Cell[12451, 359, 302, 5, 22, "Print"],
Cell[12756, 366, 302, 5, 22, "Print"],
Cell[13061, 373, 378, 7, 22, "Print"],
Cell[13442, 382, 377, 7, 22, "Print"],
Cell[13822, 391, 376, 7, 22, "Print"],
Cell[14201, 400, 379, 7, 22, "Print"],
Cell[14583, 409, 379, 7, 22, "Print"],
Cell[14965, 418, 378, 7, 22, "Print"],
Cell[15346, 427, 381, 7, 22, "Print"],
Cell[15730, 436, 382, 7, 22, "Print"],
Cell[16115, 445, 379, 7, 22, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16531, 457, 127, 2, 27, "Input"],
Cell[16661, 461, 342, 5, 26, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17052, 472, 86, 1, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[17163, 477, 926, 21, 252, "Input"],
Cell[18092, 500, 38262, 1160, 209, 14236, 858, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

