(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     84098,       1717]*)
(*NotebookOutlinePosition[     85346,       1756]*)
(*  CellTagsIndexPosition[     85302,       1752]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Modules for 2D Beam Structures", "Subtitle"],

Cell[BoxData[
    \(Off[General::"\<spell\>", General::"\<spell1\>"]\)], "Input"],

Cell["Definition of date and time", "Text"],

Cell[BoxData[
    \(\(zeit\  := 
        StringJoin[ToString[\(Date[]\)[\([3]\)]], "\<.\>", 
          ToString[\(Date[]\)[\([2]\)]], "\<.\>", 
          ToString[\(Date[]\)[\([1]\)]], "\<;\>", 
          ToString[\(Date[]\)[\([4]\)]], "\<:\>", 
          ToString[\(Date[]\)[\([5]\)]]];\)\)], "Input"],

Cell["Definition of an n1,n2 zero matrix", "Text"],

Cell[BoxData[
    \(\(NullMatrix[n1_, n2_] := Table[0, {n1}, {n2}];\)\)], "Input"],

Cell["Evaluation of length of elements", "Text"],

Cell[BoxData[
    \(\(evalleData[nE_, nK_, RK_, Inde_, Edata_] := 
        Module[{le, Ak, Bk, dr}, \[IndentingNewLine]le = 
            Table[0, {nE}]; \[IndentingNewLine]Do[
            Ak = Inde\[LeftDoubleBracket]e, 1\[RightDoubleBracket]; 
            Bk = Inde\[LeftDoubleBracket]e, 2\[RightDoubleBracket]; 
            dr = RK\[LeftDoubleBracket]Bk\[RightDoubleBracket] - 
                RK\[LeftDoubleBracket]
                  Ak\[RightDoubleBracket]; \[IndentingNewLine]le\
\[LeftDoubleBracket]
                e\[RightDoubleBracket] = \@\(dr\[LeftDoubleBracket]1\
\[RightDoubleBracket]\^2 + dr\[LeftDoubleBracket]2\[RightDoubleBracket]\^2 + \
dr\[LeftDoubleBracket]3\[RightDoubleBracket]\^2\);, {e, 1, 
              nE}]; \[IndentingNewLine]le];\)\)], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Evaluation of mass of elements", "Text"],

Cell[BoxData[
    \(\(evalmeData[nE_, le_, Edata_] := 
        Module[{me}, \[IndentingNewLine]me = 
            Table[0, {nE}]; \[IndentingNewLine]Do[\(me\[LeftDoubleBracket]
                  e\[RightDoubleBracket] = 
                Edata\[LeftDoubleBracket]e, 
                    2\[RightDoubleBracket]\ le\[LeftDoubleBracket]
                    e\[RightDoubleBracket]\ Edata\[LeftDoubleBracket]e, 
                    4\[RightDoubleBracket];\), {e, 1, 
              nE}]; \[IndentingNewLine]me];\)\)], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Print of element data", "Text"],

Cell[BoxData[
    \(\(printElementData[nE_, nK_, FEname_, RK_, Inde_, Edata_] := 
        Module[{e, Lxma, Lxmi, Lyma, Lymi, Lzma, 
            Lzmi}, \[IndentingNewLine]mFE = \[Sum]\+\(e = 1\)\%nE 
                Edata\[LeftDoubleBracket]e, 
                6\[RightDoubleBracket]; \[IndentingNewLine]Lxma = 
            Max[Table[
                RK\[LeftDoubleBracket]k, 1\[RightDoubleBracket], {k, nK}]]; 
          Lxmi = Min[
              Table[RK\[LeftDoubleBracket]k, 1\[RightDoubleBracket], {k, 
                  nK}]]; \ \[IndentingNewLine]Lyma = 
            Max[Table[
                RK\[LeftDoubleBracket]k, 2\[RightDoubleBracket], {k, nK}]]; 
          Lymi = Min[
              Table[RK\[LeftDoubleBracket]k, 2\[RightDoubleBracket], {k, 
                  nK}]]; \[IndentingNewLine]Lzma = 
            Max[Table[
                RK\[LeftDoubleBracket]k, 3\[RightDoubleBracket], {k, nK}]]; 
          Lzmi = Min[
              Table[RK\[LeftDoubleBracket]k, 3\[RightDoubleBracket], {k, 
                  nK}]]; \[IndentingNewLine]lFE = {Lxma - Lxmi, Lyma - Lymi, 
              Lzma - Lzmi}; 
          Print["\<-----------------------------------------------------------\
-----------------------------------------\>"]; 
          Print[FEName, "\<: No nodes=\>", nK, "\<, No elements=\>", 
            nE, "\<, Tot.mass=\>", mFE, "\<, Tot.length=\>", 
            lFE\[LeftDoubleBracket]1\[RightDoubleBracket], "\<,\>", 
            lFE\[LeftDoubleBracket]2\[RightDoubleBracket], "\<,\>", 
            lFE\[LeftDoubleBracket]3\[RightDoubleBracket], "\<!\>"]; 
          Print["\<-----------------------------------------------------------\
-----------------------------------------\>"]; 
          Print["\<#el ! btw nodes ! length ! c.s.area !   Iz  ,  Iy   ,   It \
  ! density !  mass  !  E-  ,  G-modulus !  hy ,  hz  !\>"]; 
          Do[\(Print[PaddedForm[e, 2], "\< ! \>", 
                PaddedForm[Inde\[LeftDoubleBracket]e, 1\[RightDoubleBracket], 
                  2], PaddedForm[
                  Inde\[LeftDoubleBracket]e, 2\[RightDoubleBracket], 
                  3], "\<  !\>", 
                PaddedForm[
                  Edata\[LeftDoubleBracket]e, 5\[RightDoubleBracket], {4, 
                    3}], "\<  !\>", 
                PaddedForm[
                  Edata\[LeftDoubleBracket]e, 2\[RightDoubleBracket], {6, 
                    6}], "\<  !\>", 
                PaddedForm[
                  Edata\[LeftDoubleBracket]e, 3\[RightDoubleBracket], {4, 
                    3}], PaddedForm[
                  Edata\[LeftDoubleBracket]e, 8\[RightDoubleBracket], {4, 
                    3}], PaddedForm[
                  Edata\[LeftDoubleBracket]e, 10\[RightDoubleBracket], {4, 
                    3}], "\< !\>", 
                PaddedForm[
                  Edata\[LeftDoubleBracket]e, 4\[RightDoubleBracket], {4, 
                    2}], "\< !\>", 
                PaddedForm[
                  Edata\[LeftDoubleBracket]e, 6\[RightDoubleBracket], {4, 
                    4}], "\< !\>", 
                PaddedForm[
                  Edata\[LeftDoubleBracket]e, 1\[RightDoubleBracket], {4, 
                    3}], PaddedForm[
                  Edata\[LeftDoubleBracket]e, 11\[RightDoubleBracket], {5, 
                    3}], "\< !\>", 
                PaddedForm[
                  Edata\[LeftDoubleBracket]e, 7\[RightDoubleBracket], {3, 
                    3}], PaddedForm[
                  Edata\[LeftDoubleBracket]e, 9\[RightDoubleBracket], {4, 
                    3}], "\< !\>"];\), {e, 1, nE}]];\)\)], "Input"],

Cell["Print of node data", "Text"],

Cell[BoxData[
    \(\(printNodeData[nE_, nK_, FEname_, RK_] := 
        Module[{k}, 
          Print["\<-----------------------------------------------------------\
-----------------------------------------\>"]; 
          Print[FEName, "\<: No nodes=\>", nK, "\<, No elements=\>", 
            nE, "\<, Tot.mass=\>", mFE, "\<, Tot.length=\>", 
            lFE\[LeftDoubleBracket]1\[RightDoubleBracket], "\<,\>", 
            lFE\[LeftDoubleBracket]2\[RightDoubleBracket], "\<,\>", 
            lFE\[LeftDoubleBracket]3\[RightDoubleBracket], "\<!\>"]; 
          Print["\<-----------------------------------------------------------\
-----------------------------------------\>"]; 
          Print["\<#node! position Rx  ,  Ry   ,   Rz   ! \>"]; 
          Do[\(Print[PaddedForm[k, 3], "\< ! \>", 
                PaddedForm[
                  RK\[LeftDoubleBracket]k, 1\[RightDoubleBracket], {9, 4}], 
                PaddedForm[
                  RK\[LeftDoubleBracket]k, 2\[RightDoubleBracket], {7, 4}], 
                PaddedForm[
                  RK\[LeftDoubleBracket]k, 3\[RightDoubleBracket], {7, 
                    4}], "\<  !\>"];\), {k, 1, nK}];];\)\)], "Input"],

Cell["Plot of FE-structure (undeformed)", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(plotStructure[nE_, nK_, FEname_, RK_]\), ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({k, mFE, lmax, Lxma, Lxmi, Lyma, Lymi, Lzma, Lzmi, ie}\), 
            ",", "\[IndentingNewLine]", 
            
            RowBox[{\(Lxmi = Min[Table[RK[\([k, 1]\)], {k, nK}]]\), 
              ";", \(Lxma = Max[Table[RK[\([k, 1]\)], {k, nK}]]\), ";", 
              " ", \(Lymi = Min[Table[RK[\([k, 2]\)], {k, nK}]]\), 
              ";", \(Lyma = Max[Table[RK[\([k, 2]\)], {k, nK}]]\), ";", 
              " ", \(Lzmi = Min[Table[RK[\([k, 3]\)], {k, nK}]]\), 
              ";", \(Lzma = Max[Table[RK[\([k, 3]\)], {k, nK}]]\), ";", " ", 
              "\[IndentingNewLine]", \(lmax = 
                Max[Lxma - Lxmi, Lyma - Lymi, Lzma - Lzmi]\), ";", " ", 
              "\[IndentingNewLine]", \(PlStructure1 = 
                Graphics[{RGBColor[0, 0, 1], 
                    Line[Table[{{\(-lmax\)/10 + Lxmi, 0}, {Lxma + lmax/10, 
                            0}}]], 
                    Line[Table[{{0, \(-lmax\)/10 + Lymi}, {0, 
                            Lyma + lmax/10}}]], Disk[{0, 0}, lmax/100], 
                    Text[x, {Lxma + lmax/20, \(-lmax\)/30}], 
                    Text[y, {lmax/30, Lyma + lmax/20}]}, 
                  AspectRatio \[Rule] Automatic, Frame \[Rule] True, 
                  PlotLabel \[Rule] FEName]\), ";", 
              " ", \(PlStructure2 = 
                Table[Graphics[
                    Text[k, {RK[\([k, 1]\)] + lmax/30, 
                        RK[\([k, 2]\)] + lmax/30}]], {k, nK}]\), ";", 
              " ", \(PlStructure3 = 
                Table[Graphics[
                    Circle[{RK[\([k, 1]\)], RK[\([k, 2]\)]}, lmax/100]], {k, 
                    nK}]\), ";", " ", 
              RowBox[{"PlStructure4", "=", 
                RowBox[{"Table", 
                  StyleBox["[",
                    "Subsection"], \(Graphics[
                    Line[Table[{{RK[\([Inde[\([ie, 1]\)], 1]\)], 
                            RK[\([Inde[\([ie, 1]\)], 
                                2]\)]}, {RK[\([Inde[\([ie, 2]\)], 1]\)], 
                            RK[\([Inde[\([ie, 2]\)], 2]\)]}}]]], {ie, nE}\), 
                  "]"}]}], 
              ";", \(Show[PlStructure1, PlStructure2, PlStructure3, 
                PlStructure4, PlotRange \[Rule] All]\), ";"}]}], "]"}]}], 
      ";"}]], "Input"],

Cell["Setup interpolation matrix", "Text"],

Cell[BoxData[
    \(\(setNe2DBeam[] := 
        Transpose[{{1 - \[Xi], 0, 0}, {0, 1 - 3\ \[Xi]\^2 + 2\ \[Xi]\^3, 
              0}, {0, le\ \[Xi] - 2\ le\ \[Xi]\^2 + le\ \[Xi]\^3, 0}, {\[Xi], 
              0, 0}, {0, 3\ \[Xi]\^2 - 2\ \[Xi]\^3, 
              0}, {0, \(-\((le\ \[Xi]\^2)\)\) + le\ \[Xi]\^3, 
              0}}];\)\)], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Setup strain matrix", "Text"],

Cell[BoxData[
    \(\(setBe2DBeam[] := {{\(-\(1\/le\)\), \(-\(\(\((\(-6\) + 
                        12\ \[Xi])\)\ x2\)\/le\^2\)\), \(-\(\(\((\(-4\)\ le + 
                        6\ le\ \[Xi])\)\ x2\)\/le\^2\)\), 
            1\/le, \(-\(\(\((6 - 
                        12\ \[Xi])\)\ x2\)\/le\^2\)\), \(-\(\(\((\(-2\)\ le + 
                        6\ le\ \[Xi])\)\ x2\)\/le\^2\)\)}};\)\)], "Input"],

Cell["Setup mass matrix Me", "Text"],

Cell[BoxData[
    \(\(setMe2DBeam[] := 
        me\ {{1\/3, 0, 0, 1\/6, 0, 0}, {0, 13\/35, \(11\ le\)\/210, 0, 
              9\/70, \(-\(\(13\ le\)\/420\)\)}, {0, \(11\ le\)\/210, 
              le\^2\/105, 0, \(13\ le\)\/420, \(-\(le\^2\/140\)\)}, {1\/6, 0, 
              0, 1\/3, 0, 0}, {0, 9\/70, \(13\ le\)\/420, 0, 
              13\/35, \(-\(\(11\ le\)\/210\)\)}, {0, \(-\(\(13\ \
le\)\/420\)\), \(-\(le\^2\/140\)\), 0, \(-\(\(11\ le\)\/210\)\), 
              le\^2\/105}};\)\)], "Input"],

Cell["Setup mass matrix C1e", "Text"],

Cell[BoxData[
    \(\(setC1e2DBeam[] := 
        me\ {{1\/2, 0, 0, 1\/2, 0, 0}, {0, 1\/2, le\/12, 0, 
              1\/2, \(-\(le\/12\)\)}, {0, 0, 0, 0, 0, 0}};\)\)], "Input"],

Cell["Setup mass matrix C3e11", "Text"],

Cell[BoxData[
    \(\(setC3e112DBeam[] := 
        me\ {{1\/3, 0, 0, 1\/6, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 
              0}, {1\/6, 0, 0, 1\/3, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 
              0, 0}};\)\)], "Input"],

Cell["Setup mass matrix C3e22", "Text"],

Cell[BoxData[
    \(\(setC3e222DBeam[] := 
        me\ {{0, 0, 0, 0, 0, 0}, {0, 13\/35, \(11\ le\)\/210, 0, 
              9\/70, \(-\(\(13\ le\)\/420\)\)}, {0, \(11\ le\)\/210, 
              le\^2\/105, 0, \(13\ le\)\/420, \(-\(le\^2\/140\)\)}, {0, 0, 0, 
              0, 0, 0}, {0, 9\/70, \(13\ le\)\/420, 0, 
              13\/35, \(-\(\(11\ le\)\/210\)\)}, {0, \(-\(\(13\ \
le\)\/420\)\), \(-\(le\^2\/140\)\), 0, \(-\(\(11\ le\)\/210\)\), 
              le\^2\/105}};\)\)], "Input"],

Cell["Setup mass matrix C3e12", "Text"],

Cell[BoxData[
    \(\(setC3e122DBeam[] := 
        me\ {{0, 7\/20, le\/20, 0, 3\/20, \(-\(le\/30\)\)}, {0, 0, 0, 0, 0, 
              0}, {0, 0, 0, 0, 0, 0}, {0, 3\/20, le\/30, 0, 
              7\/20, \(-\(le\/20\)\)}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 
              0}};\)\)], "Input"],

Cell["Setup stiffness matrix Ke", "Text"],

Cell[BoxData[
    \(\(setKe2DBeam[] := 
        Ee\ {{Ae\/le, 0, 0, \(-\(Ae\/le\)\), 0, 
              0}, {0, \(12\ Ie\)\/le\^3, \(6\ Ie\)\/le\^2, 
              0, \(-\(\(12\ Ie\)\/le\^3\)\), \(6\ Ie\)\/le\^2}, {0, \(6\ Ie\)\
\/le\^2, \(4\ Ie\)\/le, 
              0, \(-\(\(6\ Ie\)\/le\^2\)\), \(2\ Ie\)\/le}, {\(-\(Ae\/le\)\), 
              0, 0, Ae\/le, 0, 
              0}, {0, \(-\(\(12\ Ie\)\/le\^3\)\), \(-\(\(6\ Ie\)\/le\^2\)\), 
              0, \(12\ Ie\)\/le\^3, \(-\(\(6\ Ie\)\/le\^2\)\)}, {0, \(6\ Ie\)\
\/le\^2, \(2\ Ie\)\/le, 
              0, \(-\(\(6\ Ie\)\/le\^2\)\), \(4\ Ie\)\/le}};\)\)], "Input"],

Cell["\<\
Setup stiffness matrix Ke\[Sigma]Bogen\
\>", "Text"],

Cell[BoxData[
    \(\(setKe\[Sigma]Bogen2DBeam[] := {{0, 0, 0, 0, 0, 
            0}, {0, \(6\ Ae\)\/\(5\ le\), Ae\/10, 
            0, \(-\(\(6\ Ae\)\/\(5\ le\)\)\), Ae\/10}, {0, 
            Ae\/10, \(2\ Ae\ le\)\/15, 
            0, \(-\(Ae\/10\)\), \(-\(1\/30\)\)\ \((Ae\ le)\)}, {0, 0, 0, 0, 
            0, 0}, {0, \(-\(\(6\ Ae\)\/\(5\ le\)\)\), \(-\(Ae\/10\)\), 
            0, \(6\ Ae\)\/\(5\ le\), \(-\(Ae\/10\)\)}, {0, 
            Ae\/10, \(-\(1\/30\)\)\ \((Ae\ le)\), 
            0, \(-\(Ae\/10\)\), \(2\ Ae\ le\)\/15}};\)\)], "Input"],

Cell["\<\
Evaluation of State vector in the reference configuration (position \
only)\
\>", "Text"],

Cell[BoxData[
    \(\(evalZF02DBeam[nF_, RK_, nfk_] := 
        Module[{k, mat}, \[IndentingNewLine]mat = Table[0, {nF}]; 
          Do[mat\[LeftDoubleBracket]nfk\ k - 2\[RightDoubleBracket] = 
              RK\[LeftDoubleBracket]k, 1\[RightDoubleBracket]; 
            mat\[LeftDoubleBracket]nfk\ k - 1\[RightDoubleBracket] = 
              RK\[LeftDoubleBracket]k, 2\[RightDoubleBracket], {k, 1, 
              nK}]; \[IndentingNewLine]mat];\)\)], "Input"],

Cell["\<\
Evaluation of Orientation matrices of elements \
\[CapitalGamma]e(e,(3,3))\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(evalGammae2DBeam[nE_, RK_, Inde_, Edata_, key_] := 
        Module[{e, Ak, Bk, dr, le, cg, sg, mat}, \[IndentingNewLine]mat = 
            Table[0, {nE}, {3}, {3}]; \[IndentingNewLine]Do[
            Ak = Inde\[LeftDoubleBracket]e, 1\[RightDoubleBracket]; 
            Bk = Inde\[LeftDoubleBracket]e, 2\[RightDoubleBracket]; 
            dr = RK\[LeftDoubleBracket]Bk\[RightDoubleBracket] - 
                RK\[LeftDoubleBracket]Ak\[RightDoubleBracket]; 
            le = Edata\[LeftDoubleBracket]e, 5\[RightDoubleBracket]; 
            cg = dr\[LeftDoubleBracket]1\[RightDoubleBracket]\/le; 
            sg = dr\[LeftDoubleBracket]2\[RightDoubleBracket]\/le; 
            mat\[LeftDoubleBracket]e, 1, 1\[RightDoubleBracket] = cg; 
            mat\[LeftDoubleBracket]e, 2, 2\[RightDoubleBracket] = cg; 
            mat\[LeftDoubleBracket]e, 1, 2\[RightDoubleBracket] = sg; 
            mat\[LeftDoubleBracket]e, 2, 1\[RightDoubleBracket] = \(-sg\); 
            mat\[LeftDoubleBracket]e, 3, 3\[RightDoubleBracket] = 1. ; 
            If[key \[GreaterEqual] 1, 
              Print["\<\[CapitalGamma]e_\>", e, "\< = \>", 
                MatrixForm[
                  mat\[LeftDoubleBracket]e\[RightDoubleBracket]]]];, {e, 
              nE}]; \[IndentingNewLine]mat];\)\)], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Evaluation of Index matrix Indufe(e,2) due to zF to tell 1: state \
index -1 for node A, 2: state index -1 for node B,\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(evalInduf2DBeam[nE_, Inde_] := 
        Module[{e, Ak, Bk, mat}, \[IndentingNewLine]mat = 
            Table[0, {nE}, {2}]; \[IndentingNewLine]Do[
            Ak = Inde\[LeftDoubleBracket]e, 1\[RightDoubleBracket]; 
            Bk = Inde\[LeftDoubleBracket]e, 2\[RightDoubleBracket]; 
            mat\[LeftDoubleBracket]e, 1\[RightDoubleBracket] = nfk\ Ak - 3; 
            mat\[LeftDoubleBracket]e, 2\[RightDoubleBracket] = 
              nfk\ Bk - 3;, {e, nE}]; \[IndentingNewLine]mat];\)\)], "Input"],

Cell["\<\
Evaluation of Transformation matrices of elements \
TeT(e,(nF,6))\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(evalTeT2DBeam[nF_, nE_, Ge_, Indufe_, key_] := 
        Module[{e, i, j, mat2}, \[IndentingNewLine]mat2 = 
            Table[0, {nE}, {nF}, {6}]; 
          Do[Do[Do[
                mat2\[LeftDoubleBracket]e, 
                    i + Indufe\[LeftDoubleBracket]e, 1\[RightDoubleBracket], 
                    j\[RightDoubleBracket] = 
                  Ge\[LeftDoubleBracket]e, j, i\[RightDoubleBracket]; 
                mat2\[LeftDoubleBracket]e, 
                    i + Indufe\[LeftDoubleBracket]e, 2\[RightDoubleBracket], 
                    j + 3\[RightDoubleBracket] = 
                  Ge\[LeftDoubleBracket]e, j, i\[RightDoubleBracket];, {i, 
                  3}], {j, 3}]; \[IndentingNewLine]If[key \[GreaterEqual] 1, 
              Print["\<Te_\>", e, "\< = \>", 
                MatrixForm[
                  Transpose[
                    mat2\[LeftDoubleBracket]e\[RightDoubleBracket]]]]];, {e, 
              nE}]; \[IndentingNewLine]mat2];\)\)], "Input"],

Cell["\<\
Evaluation of System mass matrix MF(nF,nF)\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(evalMF[nF_, Edata_, TeT_, Me_, key_] := 
        Module[{e, Memat, mat}, \[IndentingNewLine]mat = 
            Table[0, {nF}, {nF}]; 
          Do[Memat = 
              Me /. \[InvisibleSpace]{le \[Rule] 
                    Edata\[LeftDoubleBracket]e, 5\[RightDoubleBracket], 
                  me \[Rule] 
                    Edata\[LeftDoubleBracket]e, 6\[RightDoubleBracket], 
                  Ee \[Rule] 
                    Edata\[LeftDoubleBracket]e, 1\[RightDoubleBracket], 
                  Ae \[Rule] 
                    Edata\[LeftDoubleBracket]e, 2\[RightDoubleBracket], 
                  Ie \[Rule] 
                    Edata\[LeftDoubleBracket]e, 3\[RightDoubleBracket]}; 
            mat = mat + 
                TeT\[LeftDoubleBracket]e\[RightDoubleBracket] . Memat . 
                  Transpose[
                    TeT\[LeftDoubleBracket]e\[RightDoubleBracket]];, {e, 
              nE}]; If[key == 1, Print[mat]]; 
          If[key == 2, 
            Print[MatrixForm[mat]]]; \[IndentingNewLine]mat];\)\)], "Input"],

Cell["\<\
Evaluation to Compute CFt0 = TeT . Ce1T . \[CapitalGamma]e\
\>", \
"Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(evalCFt0[nF_, Edata_, TeT_, C1e_, Ge_, key_] := 
        Module[{e, mat}, \[IndentingNewLine]mat = Table[0, {nF}, {3}]; 
          Do[\(mat = 
                Chop[mat + 
                      TeT\[LeftDoubleBracket]e\[RightDoubleBracket] . 
                        Transpose[C1e] . 
                        Ge\[LeftDoubleBracket]
                          e\[RightDoubleBracket] /. \[InvisibleSpace]{le \
\[Rule] Edata\[LeftDoubleBracket]e, 5\[RightDoubleBracket], 
                      me \[Rule] 
                        Edata\[LeftDoubleBracket]e, 
                          6\[RightDoubleBracket]}];\), {e, 1, nE}]; 
          If[key == 1, Print[mat]]; 
          If[key == 2, 
            Print[MatrixForm[mat]]]; \[IndentingNewLine]mat];\)\)], "Input"],

Cell["\<\
Evaluation to Compute CFr3 == KFr3 =  -TeT . (C3e12 - C3e12T) . Te; \
 KFr3 is screw symmetric;  CFr1 = CFr2 = 0\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(evalCFr[nF_, Edata_, TeT_, C3e12_, key_] := 
        Module[{e, mat2, mat}, \[IndentingNewLine]mat = 
            Table[0, {3}, {nF}, {nF}]; 
          Do[mat2 = 
              C3e12 - Transpose[C3e12] /. \[InvisibleSpace]{le \[Rule] 
                    Edata\[LeftDoubleBracket]e, 5\[RightDoubleBracket], 
                  me \[Rule] 
                    Edata\[LeftDoubleBracket]e, 6\[RightDoubleBracket]}; 
            mat\[LeftDoubleBracket]3\[RightDoubleBracket] = 
              mat\[LeftDoubleBracket]3\[RightDoubleBracket] - 
                TeT\[LeftDoubleBracket]e\[RightDoubleBracket] . mat2 . 
                  Transpose[
                    TeT\[LeftDoubleBracket]e\[RightDoubleBracket]];, {e, 1, 
              nE}]; \[IndentingNewLine]Print["\<KFr1,2 = 0\>"]; \
\[IndentingNewLine]If[key == 1, 
            Print["\<KFr3=\>", 
              mat\[LeftDoubleBracket]3\[RightDoubleBracket]]]; 
          If[key == 2, 
            Print["\<KFr3=\>", 
              MatrixForm[
                mat\[LeftDoubleBracket]3\[RightDoubleBracket]]]]; \
\[IndentingNewLine]mat];\)\)], "Input"],

Cell["\<\
Evaluation to Compute OF-Matrices  OF3 == KF\[Omega]3 = TeT . \
(C3e11+C3e22) . Te;   KF\[Alpha]3 is  symmetric;  OF3 = - MF ; 
OF4 == KF\[Omega]3 = TeT . (C3e12+C3e12T) . The other matrices are zero\
\>", \
"Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(evalOF[nF_, Edata_, TeT_, C3e11_, C3e22_, C3e12_, key_] := 
        Module[{e, mat2, mat}, \[IndentingNewLine]mat = 
            Table[0, {6}, {nF}, {nF}]; \[IndentingNewLine]Do[
            mat2 = C3e11 + 
                  C3e22 /. \[InvisibleSpace]{le \[Rule] 
                    Edata\[LeftDoubleBracket]e, 5\[RightDoubleBracket], 
                  me \[Rule] 
                    Edata\[LeftDoubleBracket]e, 6\[RightDoubleBracket]}; 
            mat\[LeftDoubleBracket]3\[RightDoubleBracket] = 
              mat\[LeftDoubleBracket]3\[RightDoubleBracket] - 
                TeT\[LeftDoubleBracket]e\[RightDoubleBracket] . mat2 . 
                  Transpose[
                    TeT\[LeftDoubleBracket]e\[RightDoubleBracket]];, {e, 1, 
              nE}]; Do[
            mat2 = C3e12 + 
                  Transpose[C3e12] /. \[InvisibleSpace]{le \[Rule] 
                    Edata\[LeftDoubleBracket]e, 5\[RightDoubleBracket], 
                  me \[Rule] 
                    Edata\[LeftDoubleBracket]e, 6\[RightDoubleBracket]}; 
            mat\[LeftDoubleBracket]4\[RightDoubleBracket] = 
              mat\[LeftDoubleBracket]4\[RightDoubleBracket] + 
                TeT\[LeftDoubleBracket]e\[RightDoubleBracket] . mat2 . 
                  Transpose[
                    TeT\[LeftDoubleBracket]e\[RightDoubleBracket]];, {e, 1, 
              nE}]; \[IndentingNewLine]Print["\<KF\[Omega]1,2,5,6 = 0\>"]; \
\[IndentingNewLine]If[key == 1, 
            Print["\<KF\[Omega]3=\>", 
              mat\[LeftDoubleBracket]3\[RightDoubleBracket]]]; 
          If[key == 2, 
            Print["\<KF\[Omega]3=\>", 
              MatrixForm[
                mat\[LeftDoubleBracket]3\[RightDoubleBracket]]]]; \
\[IndentingNewLine]If[key == 1, 
            Print["\<KF\[Omega]4=\>", 
              mat\[LeftDoubleBracket]4\[RightDoubleBracket]]]; 
          If[key == 2, 
            Print["\<KF\[Omega]4=\>", 
              MatrixForm[
                mat\[LeftDoubleBracket]4\[RightDoubleBracket]]]]; \
\[IndentingNewLine]mat];\)\)], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Compute  CFr0 = CFr1...3 * ZF0 or OF0 = OF1..6 * ZF0", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(evalCF0T[nF_, ZF0_, CFr_, n_, key_] := 
        Module[{i, mat}, \[IndentingNewLine]mat = 
            Table[0, {n}, {nF}]; \[IndentingNewLine]Do[\(mat\
\[LeftDoubleBracket]i\[RightDoubleBracket] = 
                CFr\[LeftDoubleBracket]i\[RightDoubleBracket] . ZF0;\), {i, 
              n}]; \[IndentingNewLine]If[key == 1, Print[mat]]; 
          If[key == 2, 
            Print[MatrixForm[mat]]]; \[IndentingNewLine]mat];\)\)], "Input"],

Cell["Evaluation number of locked state variables nR and IndR", "Text"],

Cell[BoxData[
    \(\(evalIndr2D[nF_, nfk_, Lager_] := 
        Module[{nKLager, nIndr, k, indr}, \[IndentingNewLine]nKLager = 
            Length[Lager]; 
          nIndr = \[Sum]\+\(i = 1\)\%nKLager\(\[Sum]\+\(j = 1\)\%6\( Delete[
                    Transpose[Lager], 1]\)\[LeftDoubleBracket]j, 
                  i\[RightDoubleBracket]\); indr = Table[0, {nIndr}]; nR = 0; 
          If[Lager\[LeftDoubleBracket]1, 1\[RightDoubleBracket] == 0, 
            IndM = Table[n, {n, 1, nF}]; 
            nM = nF;, \(Do[
                If[Lager\[LeftDoubleBracket]k, 2\[RightDoubleBracket] == 1, 
                  nR = nR + 1; 
                  indr\[LeftDoubleBracket]
                      nR\[RightDoubleBracket] = \((Lager\[LeftDoubleBracket]
                              k, 1\[RightDoubleBracket] - 1)\)\ nfk + 1]; 
                If[Lager\[LeftDoubleBracket]k, 3\[RightDoubleBracket] == 1, 
                  nR = nR + 1; 
                  indr\[LeftDoubleBracket]
                      nR\[RightDoubleBracket] = \((Lager\[LeftDoubleBracket]
                              k, 1\[RightDoubleBracket] - 1)\)\ nfk + 2]; 
                If[Lager\[LeftDoubleBracket]k, 7\[RightDoubleBracket] == 1, 
                  nR = nR + 1; 
                  indr\[LeftDoubleBracket]
                      nR\[RightDoubleBracket] = \((Lager\[LeftDoubleBracket]
                              k, 1\[RightDoubleBracket] - 1)\)\ nfk + 
                      3];, {k, 1, nKLager}];\)]; 
          Print["\<nR = \>", nR, "\<, IndR = \>", indr]; indr];\)\)], "Input",\

  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Evaluate number of reduced state variables nM and IndM", "Text"],

Cell[BoxData[
    \(\(evalIndM[nF_, nR_, IndR_] := 
        Module[{nKLager, nIndr, k, indm}, 
          If[nR === 0, indm = Table[n, {n, 1, nF}], 
            indm = Delete[Table[n, {n, 1, nF}], Partition[IndR, 1]]]; 
          nM = nF - nR; 
          Print["\<nM = \>", nM, "\<, IndM = \>", 
            indm]; \[IndentingNewLine]indm];\)\)], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Evaluate load vector hF(nF)  due to nodal forces", "Text"],

Cell["\<\
evalhFnodal[nF_,nfk_,LastKnot_,key_] := 
  Module[{nKLast,k,mat},
  nKLast = Length[LastKnot];
  mat = Table[0, {nF}];
  Do[mat[[LastKnot[[k,1]]*nfk-nfk+1]] = mat[[LastKnot[[k,1]]*nfk-nfk+1]] + \
LastKnot[[k,2]];
     mat[[LastKnot[[k,1]]*nfk-nfk+2]] = mat[[LastKnot[[k,1]]*nfk-nfk+2]] + \
LastKnot[[k,3]];
     mat[[LastKnot[[k,1]]*nfk-nfk+3]] = mat[[LastKnot[[k,1]]*nfk-nfk+3]] + \
LastKnot[[k,7]];
  ,{k,nKLast}];
 If[key==1,Print[\"hF=\",mat]];
 If[key==2,Print[\"hF=\",MatrixForm[mat]]];
 mat]; \
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Evaluate load vector hFref due to reference motion, keya = 0 and \
key\[Omega] = 0 and keyd\[Omega] = 0 means no lin. accel. no angular vel. and \
no angular accel., respecitively\
\>", "Text"],

Cell[BoxData[
    \(\(evalhFref[nF_, LastRef_, CFt0_, CFr0T_, OF0T_, key_] := 
        Module[{omegaq, 
            mat}, \[IndentingNewLine]omegaq = {LastRef[\([7]\)]^2, 
              LastRef[\([8]\)]^2, LastRef[\([9]\)]^2, 
              LastRef[\([7]\)]*LastRef[\([8]\)], 
              LastRef[\([8]\)]*LastRef[\([9]\)], 
              LastRef[\([9]\)]*LastRef[\([7]\)]}; \[IndentingNewLine]keya = 
            Sum[LastRef[\([ll]\)], {ll, 3}]; 
          key\[Omega] = Sum[omegaq[\([ll]\)], {ll, 6}]; \ 
          keyd\[Omega] = 
            Sum[LastRef[\([3 + ll]\)], {ll, 3}]; \[IndentingNewLine]mat = 
            Table[0, {nF}]; \[IndentingNewLine]mat = \(-CFt0\  . 
                LastRef[\([Range[1, 3]]\)]\); \[IndentingNewLine]mat = 
            mat - Transpose[CFr0T] . LastRef[\([Range[4, 6]]\)] - 
              Transpose[OF0T] . 
                omegaq; \[IndentingNewLine]Print["\<keya = \>", 
            keya, "\<, key\[Omega] = \>", 
            key\[Omega], "\<, keyd\[Omega] = \>", 
            keyd\[Omega]]; \[IndentingNewLine]If[key == 1, 
            Print["\<hFRef=\>", mat]]; \[IndentingNewLine]If[key \[Equal] 2, 
            Print["\<hFref=\>", 
              MatrixForm[mat]]]; \[IndentingNewLine]mat];\)\)], "Input"],

Cell["\<\
Evaluate \[Omega]-part und d\[Omega]-part in KFRef =  \
KFr1*d\[Omega]1 + KFr2* d\[Omega]2 + KFr3*d\[Omega]3 + KF\[Omega]i \
*\[Omega]qi,   i=1,6 \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(evalKFref[nF_, LastRef_, KFr_, OF_, keyd\[Omega]_, key\[Omega]_, 
          key_] := Module[{k, omegaq, mat}, \[IndentingNewLine]mat = 
            Table[0, {nF}, {nF}]; \[IndentingNewLine]If[
            key\[Omega]\  > \ 
              0, \[IndentingNewLine]omegaq = {LastRef[\([7]\)]^2, 
                LastRef[\([8]\)]^2, LastRef[\([9]\)]^2, 
                LastRef[\([7]\)]*LastRef[\([8]\)], 
                LastRef[\([8]\)]*LastRef[\([9]\)], 
                LastRef[\([9]\)]*
                  LastRef[\([7]\)]}; \[IndentingNewLine]Do[\(mat = 
                  mat\  + \ omegaq[\([k]\)]*OF[\([k]\)];\), {k, 
                6}];]; \[IndentingNewLine]If[
            keyd\[Omega]\  > \ 
              0, \(Do[\(mat = 
                    mat\  + \ LastRef[\([3 + k]\)]*KFr[\([k]\)];\), {k, 
                  3}];\)]; \[IndentingNewLine]If[
            key == 1 && key\[Omega] + keyd\[Omega] > 0, 
            Print["\<KFRef=\>", mat], \[IndentingNewLine]If[
              key == 2 && key\[Omega] + keyd\[Omega] > 0, 
              Print["\<KFref=\>", MatrixForm[mat]], 
              Print["\<KFRef = 0\>"]]]; \[IndentingNewLine]mat];\)\)], "Input"],

Cell["\<\
Evaluate d\[Omega]-part in DFRef =  2 (KFr1 * \[Omega]1 + KFr2 * \
\[Omega]2 + KFr3 * \[Omega]3) \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(evalDFref[nF_, LastRef_, KFr_, key\[Omega]_, key_] := 
        Module[{k, mat}, \[IndentingNewLine]mat = 
            Table[0, {nF}, {nF}]; \[IndentingNewLine]If[
            key\[Omega]\  > \ 
              0, \[IndentingNewLine]\(Do[\(mat = 
                    mat\  + \ 2*LastRef[\([6 + k]\)]*KFr[\([k]\)];\), {k, 
                  3}];\)]; \[IndentingNewLine]If[key == 1 && key\[Omega] > 0, 
            Print["\<DFRef=\>", mat], \[IndentingNewLine]If[
              key == 2 && key\[Omega] > 0, 
              Print["\<DFref=\>", MatrixForm[mat]], 
              Print["\<DFRef = 0\>"]]]; \[IndentingNewLine]mat];\)\)], "Input"],

Cell["Generation of Minialform", "Text"],

Cell[BoxData[
    \(\(transMMin[nM_, IndM_, Mmat_, matname_, key_]\  := 
        Module[{i, j, mat}, \[IndentingNewLine]mat = 
            Table[0, {nM}, {nM}]; \[IndentingNewLine]Do[
            Do[mat[\([i, j]\)] = 
                Mmat[\([IndM[\([i]\)], IndM[\([j]\)]]\)], {j, 1, nM}], {i, 1, 
              nM}]; \[IndentingNewLine]If[key == 1, 
            Print[matname, "\<=\>", mat]]; \[IndentingNewLine]If[key == 2, 
            Print[matname, "\<=\>", 
              MatrixForm[mat]]]; \[IndentingNewLine]mat];\)\)], "Input"],

Cell[BoxData[
    \(\(transhMin[nM_, IndM_, hmat_, matname_, key_]\  := 
        Module[{i, mat}, \[IndentingNewLine]mat = 
            Table[0, {nM}]; \[IndentingNewLine]Do[
            mat[\([i]\)] = hmat[\([IndM[\([i]\)]]\)], {i, 1, 
              nM}]; \[IndentingNewLine]If[key == 1, 
            Print[matname, "\<=\>", mat]]; \[IndentingNewLine]If[key == 2, 
            Print[matname, "\<=\>", 
              MatrixForm[mat]]]; \[IndentingNewLine]mat];\)\)], "Input"],

Cell["Evaluate KF0 matrices ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"evalKF0", "[", 
          RowBox[{
          "nF_", ",", "nM_", ",", "nR_", ",", "IndM_", ",", "IndR_", ",", 
            "nE_", ",", "Edata_", ",", "TeT_", ",", 
            StyleBox["Ke\[Sigma]Bogen_",
              FontFamily->"Times"], 
            StyleBox[",",
              FontFamily->"Times"], "FECode_", ",", "Mmat_", ",", "hmat_", 
            ",", "matname_", ",", "key_"}], "]"}], ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({j, e, ze0A, ze0B, indB, KFM, hFM, zF0, nonzero, mat}\), 
            ",", "\[IndentingNewLine]", 
            
            RowBox[{\(mat = Table[0, {nF}, {nF}]\), ";", 
              "\[IndentingNewLine]", \(indB\  = 
                If[FECode \[Equal] 2  D, 4, 7]\), ";", " ", 
              "\[IndentingNewLine]", \(KFM = 
                transMMin[nM, IndM, Mmat, matname, 0]\), ";", 
              "\[IndentingNewLine]", \(hFM = 
                transhMin[nM, IndM, hmat, matname, 0]\), ";", 
              "\[IndentingNewLine]", \(zF0 = Chop[Inverse[KFM] . hFM]\), ";", 
              "\[IndentingNewLine]", \(If[nR > 0, 
                Do[zF0 = Chop[Insert[zF0, 0, IndR[\([j]\)]]], {j, nR}]]\), 
              ";", "\[IndentingNewLine]", 
              RowBox[{"Do", "[", "\[IndentingNewLine]", 
                RowBox[{
                  
                  RowBox[{\(ze0A = \(Transpose[TeT[\([e]\)]]\)[\([1]\)] . 
                        zF0\), ";", 
                    "\[IndentingNewLine]", \(ze0B = \(Transpose[
                            TeT[\([e]\)]]\)[\([indB]\)] . zF0\), ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"mat", "=", 
                      RowBox[{"mat", "+", 
                        RowBox[{"Chop", "[", 
                          RowBox[{
                            
                            RowBox[{\(Edata[\([e, 1]\)]\), "*", \(1/le\), 
                              "*", \((ze0B - ze0A)\), "*", 
                              RowBox[{\(TeT[\([e]\)]\), ".", 
                                StyleBox["Ke\[Sigma]Bogen",
                                  FontFamily->"Times"], " ", 
                                ".", \(Transpose[TeT[\([e]\)]]\)}]}], 
                            "/.", \({le \[Rule] Edata[\([e, 5]\)], 
                              Ae \[Rule] Edata[\([e, 2]\)]}\)}], "]"}]}]}], 
                    ";"}], ",", \({e, nE}\)}], "]"}], ";", 
              "\[IndentingNewLine]", \(nonzero\  = \ 
                Sum[Abs[mat[\([i, j]\)]], {i, nF}, {j, nF}]\), ";", 
              "\[IndentingNewLine]", \(If[key == 1 && nonzero \[NotEqual] 0, 
                Print[matname, "\<=\>", mat], \[IndentingNewLine]If[
                  key == 2 && nonzero \[NotEqual] 0, 
                  Print[matname, "\<=\>", MatrixForm[mat]], 
                  Print[matname, "\< = 0\>"]]]\), ";", "\[IndentingNewLine]", 
              "mat"}]}], "]"}]}], ";"}]], "Input"],

Cell["Compute the KFgeo matrix of alle KF0 matrices", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(evalgeost[nF_, keyGeo_, LastKnot_, LastRef_, KF0a1_, KF0a2_, 
          KF0\[Omega]3_, KF0d\[Omega]3_, KF0F1_, KF0F2_, KF0M3_, IndKF0node_, 
          key_] := Module[{nKLast, k, kkk, kkkk, nonzero, mat}, 
          mat = Table[0, {nF}, {nF}]; 
          If[keyGeo == 1, nKLast = Length[LastKnot]; 
            Do[kkk = LastKnot\[LeftDoubleBracket]k, 1\[RightDoubleBracket]; 
              kkkk = IndKF0node\[LeftDoubleBracket]kkk\[RightDoubleBracket]; 
              If[kkkk > 0, 
                mat = mat + 
                    KF0F1\[LeftDoubleBracket]
                        kkkk\[RightDoubleBracket]\ LastKnot\
\[LeftDoubleBracket]k, 2\[RightDoubleBracket] + 
                    KF0F2\[LeftDoubleBracket]
                        kkkk\[RightDoubleBracket]\ LastKnot\
\[LeftDoubleBracket]k, 3\[RightDoubleBracket] + 
                    KF0M3\[LeftDoubleBracket]
                        kkkk\[RightDoubleBracket]\ LastKnot\
\[LeftDoubleBracket]k, 7\[RightDoubleBracket]];, {k, nKLast}]; 
            mat = mat + 
                KF0a1\ LastRef\[LeftDoubleBracket]1\[RightDoubleBracket] + 
                KF0a2\ LastRef\[LeftDoubleBracket]2\[RightDoubleBracket] + 
                KF0\[Omega]3\ LastRef\[LeftDoubleBracket]9\
\[RightDoubleBracket]\^2 + 
                KF0d\[Omega]3\ LastRef\[LeftDoubleBracket]6\
\[RightDoubleBracket]; 
            If[key == 1, 
              Print["\<KFgeo=\>", 
                mat], \(If[
                  key == 2, \(Print["\<KFgeo=\>", 
                      MatrixForm[
                        mat]];\)];\)];, \(Print["\<KFgeo = 0\>"];\)]; \
\[IndentingNewLine]mat];\)\)], "Input"],

Cell["Compute the linear static solution of zF", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{\(evalzFLinStat[LoadName_, nF_, nR_, IndR_, KFM_, hFM_, nK_, 
            RK_, nfk_, key_]\), ":=", 
          RowBox[{"Module", "[", 
            RowBox[{\({k, j, zF}\), ",", "\[IndentingNewLine]", 
              RowBox[{
                RowBox[{"zF", "=", 
                  RowBox[{"Chop", "[", 
                    RowBox[{
                      StyleBox["LinearSolve",
                        "MR"], 
                      StyleBox["[",
                        "MR"], 
                      RowBox[{
                        StyleBox["KFM",
                          "TI"], 
                        StyleBox[",",
                          "MR"], " ", 
                        StyleBox["hFM",
                          "TI"]}], 
                      StyleBox["]",
                        "MR"]}], 
                    StyleBox["]",
                      "MR"]}]}], 
                StyleBox[";",
                  "MR"], 
                "\[IndentingNewLine]", \(If[nR > 0, 
                  Do[zF = Chop[Insert[zF, 0, IndR[\([j]\)]]], {j, nR}]]\), 
                ";", "\[IndentingNewLine]", \
\(Print["\<-------------------------------------------------------------------\
---------------------------------\>"]\), ";", \(Print[LoadName]\), 
                ";", \(Print["\<----------------------------------------------\
------------------------------------------------------\>"]\), 
                ";", \(Print["\<#node! position R1  ,  R2   ,   R3    ! \
displacement u1,  u2    ,   theta3  ! \>"]\), 
                ";", \(If[key \[Equal] 1, 
                  Do[\(Print[PaddedForm[k, 3], "\< ! \>", 
                        PaddedForm[
                          RK\[LeftDoubleBracket]k, 
                            1\[RightDoubleBracket], {9, 4}], 
                        PaddedForm[
                          RK\[LeftDoubleBracket]k, 
                            2\[RightDoubleBracket], {7, 4}], 
                        PaddedForm[
                          RK\[LeftDoubleBracket]k, 
                            3\[RightDoubleBracket], {7, 
                            4}], "\<  ! \>", \ \[IndentingNewLine]zF\
\[LeftDoubleBracket]\((k - 1)\)*nfk + 1\[RightDoubleBracket], "\< , \>", 
                        zF\[LeftDoubleBracket]\((k - 1)\)*nfk + 
                            2\[RightDoubleBracket], "\< , \>", 
                        zF\[LeftDoubleBracket]\((k - 1)\)*nfk + 
                            1\[RightDoubleBracket], "\<  !\>"];\), {k, 1, 
                      nK}]]\), ";", 
                "\[IndentingNewLine]", \(If[key \[Equal] 2, 
                  Do[\(Print[PaddedForm[k, 3], "\< ! \>", 
                        PaddedForm[
                          RK\[LeftDoubleBracket]k, 
                            1\[RightDoubleBracket], {9, 4}], 
                        PaddedForm[
                          RK\[LeftDoubleBracket]k, 
                            2\[RightDoubleBracket], {7, 4}], 
                        PaddedForm[
                          RK\[LeftDoubleBracket]k, 
                            3\[RightDoubleBracket], {7, 
                            4}], "\<  !\>", \ \[IndentingNewLine]PaddedForm[
                          zF\[LeftDoubleBracket]\((k - 1)\)*nfk + 
                              1\[RightDoubleBracket], {10, 6}], 
                        PaddedForm[
                          zF\[LeftDoubleBracket]\((k - 1)\)*nfk + 
                              2\[RightDoubleBracket], {10, 6}], 
                        PaddedForm[
                          zF\[LeftDoubleBracket]\((k - 1)\)*nfk + 
                              3\[RightDoubleBracket], {10, 
                            6}], "\< !\>"];\), {k, 1, nK}]]\), ";", 
                "\[IndentingNewLine]", "zF"}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}]], "Input"],

Cell["\<\
Compute the linear static solution of Constraint forces fbar due to \
boundary conditions\
\>", "Text"],

Cell[BoxData[
    \(\(evalfbarLinStat[LoadName_, IndM_, KF_, hF_, zF_, Lager_, key_] := 
        Module[{k, kk, nKLager, \ mat}, \[IndentingNewLine]mat = 
            Chop[Simplify[KF . zF - hF], 1*10^\(-6\)]; 
          nKLager\  = \ Length[Lager]; 
          Print["\<-----------------------------------------------------------\
-----------------------------------------\>"]; Print[LoadName]; 
          Print["\<-----------------------------------------------------------\
-----------------------------------------\>"]; 
          Print["\<#node! position R1  ,  R2   ,   R3    ! constr.force F1,  \
F2   ,   L3  ! \>"]; 
          If[key \[Equal] 
              1, \(Do[k = Lager[\([kk, 1]\)]; \ 
                Print[PaddedForm[k, 3], "\< ! \>", 
                  PaddedForm[
                    RK\[LeftDoubleBracket]k, 1\[RightDoubleBracket], {9, 4}], 
                  PaddedForm[
                    RK\[LeftDoubleBracket]k, 2\[RightDoubleBracket], {7, 4}], 
                  PaddedForm[
                    RK\[LeftDoubleBracket]k, 3\[RightDoubleBracket], {7, 
                      4}], "\<  ! \>", \ \[IndentingNewLine]mat\
\[LeftDoubleBracket]\((k - 1)\)*nfk + 1\[RightDoubleBracket], "\< , \>", 
                  mat\[LeftDoubleBracket]\((k - 1)\)*nfk + 
                      2\[RightDoubleBracket], "\< , \>", 
                  mat\[LeftDoubleBracket]\((k - 1)\)*nfk + 
                      1\[RightDoubleBracket], "\<  !\>"];, {kk, 1, 
                  nKLager}];\)]; \[IndentingNewLine]If[
            key \[Equal] 2, \[IndentingNewLine]Do[k = Lager[\([kk, 1]\)]; 
              Print[PaddedForm[k, 3], "\< ! \>", 
                PaddedForm[
                  RK\[LeftDoubleBracket]k, 1\[RightDoubleBracket], {9, 4}], 
                PaddedForm[
                  RK\[LeftDoubleBracket]k, 2\[RightDoubleBracket], {7, 4}], 
                PaddedForm[
                  RK\[LeftDoubleBracket]k, 3\[RightDoubleBracket], {7, 
                    4}], "\<  !\>", \ \[IndentingNewLine]PaddedForm[
                  mat\[LeftDoubleBracket]\((k - 1)\)*nfk + 
                      1\[RightDoubleBracket], {10, 6}], 
                PaddedForm[
                  mat\[LeftDoubleBracket]\((k - 1)\)*nfk + 
                      2\[RightDoubleBracket], {10, 6}], 
                PaddedForm[
                  mat\[LeftDoubleBracket]\((k - 1)\)*nfk + 
                      3\[RightDoubleBracket], {10, 6}], "\< !\>"];, {kk, 1, 
                nKLager}]]; \[IndentingNewLine]mat = 
            Chop[Expand[
                Delete[mat, 
                  Partition[IndM, 
                    1]]]]; \[IndentingNewLine]mat];\)\)], "Input"],

Cell["\<\
Normal stress for each element: SeN = Ee BeL(x2->0) Te.zFLin, \
normal force FeN = Ae * SeN\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(evalSeLinStat[LoadName_, BeL_, TeT_, Edata_, nE_, zF_, key_] := 
        Module[{e, mat}, \((\(mat = Table[0, {nE}, {7}];\))\); 
          Do[mat\[LeftDoubleBracket]e, 1\[RightDoubleBracket] = 
              Chop[Simplify[
                  Edata\[LeftDoubleBracket]e, 
                        1\[RightDoubleBracket]\ BeL\[LeftDoubleBracket]1\
\[RightDoubleBracket] . 
                        Transpose[
                          TeT\[LeftDoubleBracket]e\[RightDoubleBracket]] . 
                        zF /. \[InvisibleSpace]{le \[Rule] 
                        Edata\[LeftDoubleBracket]e, 5\[RightDoubleBracket], 
                      x2 \[Rule] 0}]]; 
            mat\[LeftDoubleBracket]e, 2\[RightDoubleBracket] = 
              Chop[Simplify[
                  Edata\[LeftDoubleBracket]e, 
                      2\[RightDoubleBracket]\ mat\[LeftDoubleBracket]e, 
                      1\[RightDoubleBracket]]];, {e, nE}]; 
          Do[mat\[LeftDoubleBracket]e, 6\[RightDoubleBracket] = 
              Chop[Simplify[
                  Edata\[LeftDoubleBracket]e, 
                          1\[RightDoubleBracket]\ BeL\[LeftDoubleBracket]1\
\[RightDoubleBracket] . Transpose[
                            TeT\[LeftDoubleBracket]e\[RightDoubleBracket]] . 
                          zF - mat\[LeftDoubleBracket]e, 
                        1\[RightDoubleBracket] /. \[InvisibleSpace]le \[Rule] 
                      Edata\[LeftDoubleBracket]e, 5\[RightDoubleBracket]]]; 
            mat\[LeftDoubleBracket]e, 
                5\[RightDoubleBracket] = \(-Chop[
                  Simplify[\(Edata\[LeftDoubleBracket]e, 3\
\[RightDoubleBracket]\ mat\[LeftDoubleBracket]e, 6\[RightDoubleBracket]\ \
2\)\/Edata\[LeftDoubleBracket]e, 7\[RightDoubleBracket] \
/. \[InvisibleSpace]x2 \[Rule] 
                        1\/2\ Edata\[LeftDoubleBracket]e, 
                            7\[RightDoubleBracket]]]\); 
            mat\[LeftDoubleBracket]e, 
                7\[RightDoubleBracket] = \[PartialD]\_\[Xi] 
                  mat\[LeftDoubleBracket]e, 5\[RightDoubleBracket]; 
            mat\[LeftDoubleBracket]e, 3\[RightDoubleBracket] = 
              Chop[mat\[LeftDoubleBracket]e, 
                    5\[RightDoubleBracket] /. \[InvisibleSpace]\[Xi] \[Rule] 
                    0]; mat\[LeftDoubleBracket]e, 4\[RightDoubleBracket] = 
              Chop[mat\[LeftDoubleBracket]e, 
                    5\[RightDoubleBracket] /. \[InvisibleSpace]\[Xi] \[Rule] 
                    1];, {e, nE}]; 
          Print["\<-----------------------------------------------------------\
-----------------------------------------\>"]; Print[LoadName]; 
          
          Print["\<-----------------------------------------------------------\
-----------------------------------------\>"]; 
          Print["\<#el ! norm.strain SeN ! norm.force FeN, vert.force FeQ ! \
bend.moment MeB(\[Xi]=0), MeB(\[Xi]=1) , MeB(\[Xi]) !\>"]; 
          If[key == 1, \(Do[\(Print[PaddedForm[e, 3], "\< ! \>", 
                    mat\[LeftDoubleBracket]e\[RightDoubleBracket]];\), {e, 
                  nE}];\), \(If[
                key == 2, \[IndentingNewLine]Do[\(Print[
                      PaddedForm[e, 2], "\< ! \>", 
                      PaddedForm[
                        mat\[LeftDoubleBracket]e, 
                          1\[RightDoubleBracket], {10, 2}], "\<    ! \>", 
                      PaddedForm[
                        mat\[LeftDoubleBracket]e, 
                          2\[RightDoubleBracket], {11, 4}], "\<  , \>", 
                      PaddedForm[
                        mat\[LeftDoubleBracket]e, 
                          7\[RightDoubleBracket], {11, 4}], "\< ! \>", 
                      PaddedForm[
                        mat\[LeftDoubleBracket]e, 
                          3\[RightDoubleBracket], {13, 4}], "\< ,\>", 
                      PaddedForm[
                        mat\[LeftDoubleBracket]e, 
                          4\[RightDoubleBracket], {10, 4}], "\< ,  \>", 
                      mat\[LeftDoubleBracket]e, 
                        5\[RightDoubleBracket], "\< ! \>"];\), {e, 1, nE}]; 
                Print["\<#el !  bending stress SeB !\>"]; 
                Do[\(Print[
                      PaddedForm[e, 
                        2], "\< ! \>"\ mat\[LeftDoubleBracket]e, 
                          6\[RightDoubleBracket], "\< !\>"];\), {e, 1, 
                    nE}];];\)]; \[IndentingNewLine]mat];\)\)], "Input"],

Cell["Plot of deformations zF+ZF0", "Text"],

Cell[BoxData[
    \(\(plotUeLin[LoadName_, Ne_, \[CapitalGamma]e_, TeT_, Edata_, nE_, zF_, 
          ZF0_, scaleUe_] := 
        Module[{e, Ue, plotUe, mat}, \[IndentingNewLine]Ue = 
            Table[0, {nE}, {3}]; \[IndentingNewLine]mat = 
            Table[0, {nE}, {3}]; \[IndentingNewLine]plotUe = 
            Table[0, {nE}]; \
\[IndentingNewLine]Do[\[IndentingNewLine]mat[\([e]\)] = 
              Transpose[\[CapitalGamma]e[\([e]\)]] . Ne . 
                  Transpose[TeT[\([e]\)]] . \((zF + ZF0)\) /. {le \[Rule] 
                    Edata[\([e, 5]\)]}; \[IndentingNewLine]Ue[\([e]\)] = 
              Transpose[\[CapitalGamma]e[\([e]\)]] . Ne . 
                  Transpose[
                    TeT[\([e]\)]] . \((zF/scaleUe + ZF0)\) /. {le \[Rule] 
                    Edata[\([e, 5]\)]}; \[IndentingNewLine]plotUe[\([e]\)] = 
              ParametricPlot[{Ue[\([e, 1]\)], Ue[\([e, 2]\)]}, {\[Xi], 0, 1}, 
                DisplayFunction \[Rule] Identity, 
                PlotStyle \[Rule] {{RGBColor[0, 1, 0]}}];, {e, 
              nE}]; \[IndentingNewLine]Show[PlStructure1, PlStructure2, 
            PlStructure3, PlStructure4, plotUe, 
            DisplayFunction \[Rule] $DisplayFunction, PlotRange \[Rule] All, 
            PlotLabel \[Rule] {"\<Durchbiegung *\>", scaleUe, "\<:\>", 
                LoadName}]; \[IndentingNewLine]mat];\)\)], "Input"],

Cell["Plot of bending moment MeB", "Text"],

Cell[BoxData[
    \(\(plotLeBLin[LoadName_, \[CapitalGamma]e_, Edata_, nE_, zF_, ZF0_, 
          SELin_, RK_, scaleMeB_] := 
        Module[{e, MeB, plotMe}, \[IndentingNewLine]MeB = 
            Table[0, {nE}, {3}]; 
          mat = Table[0, {nE}, {3}]; \[IndentingNewLine]plotMe = 
            Table[0, {nE}]; \
\[IndentingNewLine]Do[\[IndentingNewLine]MeB[\([e]\)] = 
              Transpose[\[CapitalGamma]e[\([e]\)]] . {\[Xi]*le, 
                      SeLin[\([e, 5]\)]/scaleMeB, 0} + 
                  RK[\([e]\)] /. {le \[Rule] 
                    Edata[\([e, 5]\)]}; \[IndentingNewLine]plotMe[\([e]\)] = 
              ParametricPlot[{MeB[\([e, 1]\)], MeB[\([e, 2]\)]}, {\[Xi], 0, 
                  1}, DisplayFunction \[Rule] Identity, 
                PlotStyle \[Rule] {{RGBColor[1, 0, 0]}}];, {e, 
              nE}]; \[IndentingNewLine]Show[PlStructure1, PlStructure2, 
            PlStructure3, PlStructure4, plotMe, 
            DisplayFunction \[Rule] $DisplayFunction, PlotRange \[Rule] All, 
            PlotLabel \[Rule] {"\<Biegemoment *\>", scaleMeB, "\<Nm:\>", 
                LoadName}];];\)\)], "Input"],

Cell["Plot of normal force FeN", "Text"],

Cell[BoxData[
    \(\(plotFeNLin[LoadName_, \[CapitalGamma]e_, Edata_, nE_, zF_, ZF0_, 
          SELin_, RK_, scaleFeN_] := 
        Module[{e, FeN, plotFe}, \[IndentingNewLine]FeN = 
            Table[0, {nE}, {3}]; \[IndentingNewLine]plotFe = 
            Table[0, {nE}]; \[IndentingNewLine]Do[
            FeN[\([e]\)] = 
              Transpose[\[CapitalGamma]e[\([e]\)]] . {\[Xi]*le, 
                      SeLin[\([e, 2]\)]/scaleFeN, 0} + 
                  RK[\([e]\)] /. {le \[Rule] 
                    Edata[\([e, 5]\)]}; \[IndentingNewLine]plotFe[\([e]\)] = 
              ParametricPlot[{FeN[\([e, 1]\)], FeN[\([e, 2]\)]}, {\[Xi], 0, 
                  1}, DisplayFunction \[Rule] Identity, 
                PlotStyle \[Rule] {{RGBColor[0, 1, 1]}}];, {e, 
              nE}]; \[IndentingNewLine]Show[PlStructure1, PlStructure2, 
            PlStructure3, PlStructure4, plotFe, 
            DisplayFunction \[Rule] $DisplayFunction, PlotRange \[Rule] All, 
            PlotLabel \[Rule] {"\<Normalkraft *\>", scaleFeN, "\<N:\>", 
                LoadName}];];\)\)], "Input"],

Cell["Evaluation of eigensystem", "Text"],

Cell[BoxData[
    \(\(evalEigennoD[keyOrtho_, epsmass_, MFM_, KFM_, nM_, key_] := 
        Module[{vals, vecs, j1, Me, mat}, \[IndentingNewLine]modalmass = 
            Table[0, {nM}]; {vals, vecs} = Eigensystem[Inverse[MFM] . KFM]; 
          freqEigen = Reverse[N[\@vals\/\(2\ \[Pi]\)]]; 
          mat = Reverse[vecs]; \[IndentingNewLine]If[
            keyOrtho == 
              1, \(Do[scal = \@\(mat\[LeftDoubleBracket]j1\
\[RightDoubleBracket] . MFM . \
mat\[LeftDoubleBracket]j1\[RightDoubleBracket]\); 
                mat\[LeftDoubleBracket]j1\[RightDoubleBracket] = 
                  Chop[mat\[LeftDoubleBracket]j1\[RightDoubleBracket]\/scal];,\
 {j1, nM}];\)]; Me = Chop[mat . MFM . Transpose[mat], epsmass]; 
          If[key > 0, Print["\<Me=\>", Me]]; 
          Do[\(modalmass\[LeftDoubleBracket]j1\[RightDoubleBracket] = 
                Me\[LeftDoubleBracket]j1, j1\[RightDoubleBracket];\), {j1, 
              nM}]; \[IndentingNewLine]mat];\)\)], "Input"],

Cell["Print of natural frequencies undamped system", "Text"],

Cell[BoxData[
    \(\(printEigen[LoadName_, nM_, matf_, modalmass_, keyGeo_] := 
        Module[{ome, 
            k}, \[IndentingNewLine]Print["\<----------------------------------\
------------------------------------------------------------------\>"]; 
          Print[LoadName, "\< with keyGeo = \>", keyGeo]; 
          Print["\<-----------------------------------------------------------\
-----------------------------------------\>"]; 
          Print["\<  No ! nat.frequ f(Hz) , angular frequ (rad/s) ! modal \
mass , modal stiffness !\>"]; 
          Do[\[IndentingNewLine]ome\  = \ 
              matf\[LeftDoubleBracket]k\[RightDoubleBracket]*2*
                Pi; \[IndentingNewLine]Print[PaddedForm[k, 3], "\< ! \>", 
              PaddedForm[
                matf\[LeftDoubleBracket]k\[RightDoubleBracket], {11, 
                  4}], "\<  ,\>", 
              PaddedForm[ome, {12, 3}], "\<          !\>", 
              PaddedForm[
                modalmass\[LeftDoubleBracket]k\[RightDoubleBracket], {9, 
                  3}], "\< , \>", 
              PaddedForm[
                modalmass\[LeftDoubleBracket]k\[RightDoubleBracket]*
                  ome^2, {12, 3}], "\<  !\>"];, {k, 1, nM}];];\)\)], "Input"],

Cell["Plot of eigenmodes", "Text"],

Cell[BoxData[
    \(\(plotUeEigen[LoadName_, Ne_, \[CapitalGamma]e_, TeT_, Edata_, nE_, 
          IndR_, nR_, vecs_, ZF0_, scaleUe_, noevgraf_] := 
        Module[{e, kk, ev, Ue, plotev, nevgraf, 
            mat}, \[IndentingNewLine]nevgraf = \ Length[noevgraf]; \ 
          plotev = Table[0, {nevgraf}, {nE}]; \[IndentingNewLine]Do[
            kk = \ noevgraf[\([k]\)]; \ 
            ev = vecs\[LeftDoubleBracket]kk\[RightDoubleBracket]; 
            If[nR > 0, 
              Do[ev = Insert[ev, 0, 
                    IndR\[LeftDoubleBracket]j\[RightDoubleBracket]], {j, 
                  nR}]]; \[IndentingNewLine]Ue = Table[0, {nE}, {3}]; 
            Do[Ue\[LeftDoubleBracket]e\[RightDoubleBracket] = 
                Transpose[\[CapitalGamma]e\[LeftDoubleBracket]
                        e\[RightDoubleBracket]] . Ne . 
                    Transpose[
                      TeT\[LeftDoubleBracket]
                        e\[RightDoubleBracket]] . \((ev\/scaleUe + 
                        ZF0)\) /. \[InvisibleSpace]{le \[Rule] 
                      Edata\[LeftDoubleBracket]e, 5\[RightDoubleBracket]}; \ 
              mat\  = \ Ue; 
              plotev\[LeftDoubleBracket]k, e\[RightDoubleBracket] = 
                ParametricPlot[{Ue\[LeftDoubleBracket]e, 
                      1\[RightDoubleBracket], 
                    Ue\[LeftDoubleBracket]e, 2\[RightDoubleBracket]}, {\[Xi], 
                    0, 1}, DisplayFunction \[Rule] Identity, 
                  PlotStyle \[Rule] {{RGBColor[k\/nevgraf, 0, 0]}}];, {e, 
                nE}];, {k, nevgraf}]; 
          Show[PlStructure1, PlStructure2, PlStructure3, PlStructure4, 
            plotev, DisplayFunction \[Rule] $DisplayFunction, 
            PlotRange \[Rule] All, 
            PlotLabel \[Rule] {nevgraf, "\<Eigen modes:\>", 
                LoadName}];];\)\)], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Animation  of an eigenmode", "Text"],

Cell[BoxData[
    \(\(animatUeEigen[kk_, Ne_, \[CapitalGamma]e_, TeT_, Edata_, nE_, IndR_, 
          nR_, vecs_, ZF0_, scaleUe_] := 
        Module[{e, t, ev, Ue, plotev}, \[IndentingNewLine]plotev = 
            Table[0, {nE}]; \[IndentingNewLine]ev = 
            vecs\[LeftDoubleBracket]kk\[RightDoubleBracket]; 
          If[nR > 0, 
            Do[ev = Insert[ev, 0, 
                  IndR\[LeftDoubleBracket]j\[RightDoubleBracket]], {j, 
                nR}]]; \[IndentingNewLine]Ue = Table[0, {nE}, {3}]; 
          Do[Do[Ue\[LeftDoubleBracket]e\[RightDoubleBracket] = 
                Transpose[\[CapitalGamma]e\[LeftDoubleBracket]
                        e\[RightDoubleBracket]] . Ne . 
                    Transpose[
                      TeT\[LeftDoubleBracket]
                        e\[RightDoubleBracket]] . \((\(ev*Cos[t]\)\/scaleUe + 
                        ZF0)\) /. \[InvisibleSpace]{le \[Rule] 
                      Edata\[LeftDoubleBracket]e, 5\[RightDoubleBracket]}; 
              plotev\[LeftDoubleBracket]e\[RightDoubleBracket] = 
                ParametricPlot[{Ue\[LeftDoubleBracket]e, 
                      1\[RightDoubleBracket], 
                    Ue\[LeftDoubleBracket]e, 2\[RightDoubleBracket]}, {\[Xi], 
                    0, 1}, DisplayFunction \[Rule] Identity, 
                  PlotStyle \[Rule] {{RGBColor[1, 0, 0]}}];, {e, 
                nE}]; \[IndentingNewLine]Show[PlStructure1, PlStructure2, 
              PlStructure3, PlStructure4, plotev, 
              DisplayFunction \[Rule] $DisplayFunction, 
              PlotRange \[Rule] All, 
              PlotLabel \[Rule] {"\<Eigen mode\>", kk, LoadName}];, {t, 0, 
              2*Pi, Pi/5}];\[IndentingNewLine]];\)\)], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(freqEigen\)], "Input"],

Cell[BoxData[
    \(freqEigen\)], "Output"]
}, Open  ]],

Cell["\<\
Generate of the mode matrix SeT(nF,nqSID), matrix phi0(3,nqSID) und \
psi0(3,nqSID), nqSID from eigenmodes zFEigen\
\>", "Text"],

Cell[BoxData[
    \(\(evalSETmatrixeigen[nF_, nR_, IndR_, zFEigen_, IndModeSID_, 
          freqEigen_, nK_, nfk_, key_] := 
        Module[{mat, ev, k, kk, i}, \[IndentingNewLine]nqSID = 
            Length[IndModeSID]; \[IndentingNewLine]Print["\<nqelast = \>", 
            nqSID]; \[IndentingNewLine]ielastq = 
            Table[StringJoin["\<eigenmode : \>", 
                ToString[
                  freqEigen[\([IndModeSID[\([i]\)]]\)]], "\< Hz\>"], {i, 
                nqSID}]; \[IndentingNewLine]phi0 = 
            Table[0, {nK}, {3}, {nqSID}]; 
          psi0 = Table[0, {nK}, {3}, {nqSID}]; mat = Table[0, {nqSID}, {nF}]; 
          Do[kk\  = IndModeSID[\([i]\)]; 
            ev = zFEigen\[LeftDoubleBracket]kk\[RightDoubleBracket]; 
            If[nR > 0, 
              Do[ev = Insert[ev, 0, 
                    IndR\[LeftDoubleBracket]j\[RightDoubleBracket]], {j, 
                  nR}]]; \[IndentingNewLine]Do[\[IndentingNewLine]phi0\
\[LeftDoubleBracket]k, 1, i\[RightDoubleBracket] = 
                ev\[LeftDoubleBracket]\((k - 1)\)\ nfk + 
                    1\[RightDoubleBracket]; 
              phi0\[LeftDoubleBracket]k, 2, i\[RightDoubleBracket] = 
                ev\[LeftDoubleBracket]\((k - 1)\)\ nfk + 
                    2\[RightDoubleBracket]; 
              phi0\[LeftDoubleBracket]k, 3, i\[RightDoubleBracket] = 
                0; \[IndentingNewLine]psi0\[LeftDoubleBracket]k, 1, 
                  i\[RightDoubleBracket] = 
                0; \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ psi0\[LeftDoubleBracket]k, 2, i\[RightDoubleBracket] = 
                0; \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ psi0\[LeftDoubleBracket]k, 3, i\[RightDoubleBracket] = 
                ev\[LeftDoubleBracket]\((k - 1)\)\ nfk + 
                    3\[RightDoubleBracket];, {k, 
                nK}]; \[IndentingNewLine]mat[\([i]\)] = 
              ev;\[IndentingNewLine], {i, nqSID}]; \[IndentingNewLine]If[
            key \[Equal] 
              1, \(Print["\<SeT=\>", mat];\), \(If[
                key \[Equal] 
                  2, \(Print["\<SeT=\>", 
                    MatrixForm[
                      mat]];\)];\)]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(If[
                key \[Equal] 
                  1, \(Print["\<phi0_k\>", k, "\<=\>", 
                    phi0[\([k]\)]];\), \(If[key \[Equal] 2, 
                    Print["\<phi0_k\>", k, "\<=\>", 
                      MatrixForm[
                        phi0[\([k]\)]]]];\)];\)\[IndentingNewLine], {k, 
              nK}]; \[IndentingNewLine]Do[\[IndentingNewLine]\(If[
                key \[Equal] 
                  1, \(Print["\<psi0_k\>", k, "\<=\>", 
                    psi0[\([k]\)]];\), \(If[key \[Equal] 2, 
                    Print["\<psi0_k\>", k, "\<=\>", 
                      MatrixForm[
                        psi0[\([k]\)]]]];\)];\)\[IndentingNewLine], {k, 
              nK}]; \[IndentingNewLine]mat];\)\)], "Input"],

Cell["\<\
Generate of the mode matrix SeT(nF,nqSID), matrix phi0(3,nqSID) und \
psi0(3,nqSID), nqSID from nodal coodinates\
\>", "Text"],

Cell[BoxData[
    \(\(evalSETmatrixnodal[nF_, nR_, IndR_, nM_, IndM_, nK_, nfk_, KF_, MF_, 
          keyOrtho_, key_] := 
        Module[{mat, i, k, j1, j, vecs, vals, 
            mat1}, \[IndentingNewLine]nqSID = \ 
            nM; \[IndentingNewLine]Print["\<nqelast = \>", nqSID]; 
          ielastq = 
            Table["\<nodal-coord \>", {nqSID}]; \[IndentingNewLine]phi0 = 
            Table[0, {nK}, {3}, {nqSID}]; 
          psi0 = Table[0, {nK}, {3}, {nqSID}]; \[IndentingNewLine]If[
            keyOrtho == 0, mat = IdentityMatrix[nF]; 
            mat1 = Table[0, {nM}, {nF}]; 
            Do[\(mat1\[LeftDoubleBracket]i\[RightDoubleBracket] = 
                  mat\[LeftDoubleBracket]IndM\[LeftDoubleBracket]
                      i\[RightDoubleBracket]\[RightDoubleBracket];\), {i, 
                nM}]; mat = 
              mat1;, \[IndentingNewLine]\[IndentingNewLine]MFM = 
              transMMin[nM, IndM, MF, "\<MFM\>", 0]; 
            KFM = transMMin[nM, IndM, KF, "\<KFM\>", 0]; 
            mat1 = Inverse[MFM] . KFM; {vals, vecsM} = Eigensystem[mat1]; 
            Do[scal = \@\(vecsM\[LeftDoubleBracket]j1\[RightDoubleBracket] . \
MFM . vecsM\[LeftDoubleBracket]j1\[RightDoubleBracket]\); 
              vecsM\[LeftDoubleBracket]j1\[RightDoubleBracket] = 
                Chop[vecsM\[LeftDoubleBracket]j1\[RightDoubleBracket]\/scal, 
                  epsmass];, {j1, nM}]; \[IndentingNewLine]If[nR > 0, 
              Do[\(Do[vecsM\[LeftDoubleBracket]j1\[RightDoubleBracket] = 
                      Insert[vecsM\[LeftDoubleBracket]
                          j1\[RightDoubleBracket], 0, 
                        IndR\[LeftDoubleBracket]j\[RightDoubleBracket]], {j, 
                      nR}];\), {j1, nM}]]; 
            mat = vecsM;]; \[IndentingNewLine]Do[\(Do[\[IndentingNewLine]phi0\
\[LeftDoubleBracket]k, 1, i\[RightDoubleBracket] = 
                  mat\[LeftDoubleBracket]i, \((k - 1)\)\ nfk + 
                      1\[RightDoubleBracket]; 
                phi0\[LeftDoubleBracket]k, 2, i\[RightDoubleBracket] = 
                  mat\[LeftDoubleBracket]i, \((k - 1)\)\ nfk + 
                      2\[RightDoubleBracket]; 
                phi0\[LeftDoubleBracket]k, 3, i\[RightDoubleBracket] = 
                  0; \[IndentingNewLine]psi0\[LeftDoubleBracket]k, 1, 
                    i\[RightDoubleBracket] = 
                  0; \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ psi0\[LeftDoubleBracket]k, 2, 
                    i\[RightDoubleBracket] = 
                  0; \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ psi0\[LeftDoubleBracket]k, 3, 
                    i\[RightDoubleBracket] = 
                  mat\[LeftDoubleBracket]i, \((k - 1)\)\ nfk + 
                      3\[RightDoubleBracket];, {k, nK}];\), {i, 
              nM}]; \[IndentingNewLine]If[
            key \[Equal] 
              1, \(Print["\<SeT=\>", mat];\), \(If[
                key \[Equal] 
                  2, \(Print["\<SeT=\>", 
                    MatrixForm[
                      mat]];\)];\)]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(If[
                key \[Equal] 
                  1, \(Print["\<phi0_k\>", k, "\<=\>", 
                    phi0[\([k]\)]];\), \(If[key \[Equal] 2, 
                    Print["\<phi0_k\>", k, "\<=\>", 
                      MatrixForm[
                        phi0[\([k]\)]]]];\)];\)\[IndentingNewLine], {k, 
              nK}]; \[IndentingNewLine]Do[\[IndentingNewLine]\(If[
                key \[Equal] 
                  1, \(Print["\<psi0_k\>", k, "\<=\>", 
                    psi0[\([k]\)]];\), \(If[key \[Equal] 2, 
                    Print["\<psi0_k\>", k, "\<=\>", 
                      MatrixForm[
                        psi0[\([k]\)]]]];\)];\)\[IndentingNewLine], {k, 
              nK}]; \[IndentingNewLine]mat];\)\)], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Write SID: Taylor1", "Text"],

Cell[BoxData[
    \(\(taylor1[file1_, matname_, orderv_, nrowv_, ncolv_, nqv_, nqnv_, 
          structv_, epswert_, m0mat_, m1mat_] := 
        Module[{sp1, sp2, sp3}, \[IndentingNewLine]Print["\<matname = \>", 
            matname]; \[IndentingNewLine]Write[file1, SpaceForm[11], 
            matname]; \[IndentingNewLine]Write[file1, 
            SpaceForm[26], "\<order\>", SpaceForm[17], "\<= \>", 
            orderv]; \[IndentingNewLine]Write[file1, 
            SpaceForm[26], "\<nrow\>", SpaceForm[18], "\<= \>", 
            nrowv]; \[IndentingNewLine]Write[file1, 
            SpaceForm[26], "\<ncol\>", SpaceForm[18], "\<= \>", 
            ncolv]; \[IndentingNewLine]Write[file1, SpaceForm[26], "\<nq\>", 
            SpaceForm[20], "\<= \>", nqv]; \[IndentingNewLine]Write[file1, 
            SpaceForm[26], "\<nqn\>", SpaceForm[19], "\<= \>", 
            nqnv]; \[IndentingNewLine]Write[file1, 
            SpaceForm[26], "\<structur\>", SpaceForm[14], "\<= \>", 
            structv]; \[IndentingNewLine]If[
            structv \[NotEqual] 0 && structv \[NotEqual] 4, 
            Do[\(Do[If[i > 9, sp1 = 1, sp1 = 2]; \ 
                  If[j > 9, sp2 = 1, sp2 = 2]; \[IndentingNewLine]If[
                    Abs[m0mat[\([i, j]\)]] > epswert, 
                    Write[file1, SpaceForm[26], "\<m0\>", SpaceForm[sp1], i, 
                      SpaceForm[sp2], j, SpaceForm[14], "\<=\>", 
                      FortranForm[m0mat[\([i, j]\)]]]];, {j, 1, 
                    ncolv}];\), {i, 1, nrowv}]]; \[IndentingNewLine]If[
            structv \[NotEqual] 0 && structv \[NotEqual] 4 && 
              orderv \[Equal] 
                1, \(Do[\(Do[\(Do[If[i > 9, sp1 = 1, sp1 = 2]; \ 
                        If[j > 9, sp2 = 1, sp2 = 2]; \[IndentingNewLine]If[
                          k > 9, sp3 = 1, sp3 = 2]; \[IndentingNewLine]If[
                          Abs[m1mat[\([i, k, j]\)]] > 
                            epswert, \(Write[file1, SpaceForm[26], "\<m1\>", 
                              SpaceForm[sp1], i, SpaceForm[sp2], k, 
                              SpaceForm[sp3], j, SpaceForm[11], "\<=\>", 
                              FortranForm[
                                m1mat[\([i, k, 
                                    j]\)]]];\)];\[IndentingNewLine], {k, 1, 
                          nqv}];\), {i, 1, nrowv}];\), {j, 1, 
                  ncolv}];\)]; \[IndentingNewLine]Write[file1, 
            SpaceForm[11], "\<end\>", SpaceForm[1], matname];];\)\)], "Input"],

Cell["Write the header", "Text"],

Cell[BoxData[
    \(\(writeheader[fileSID_, nqSID_, nK_, FEName_, mFE_, iel3astq_] := 
        Module[{}, \[IndentingNewLine]Write[fileSID, PaddedForm[nK + 1, 4], 
            PaddedForm[nqSID, 3], "\< = No. nodes & No. modes//model=(\>", 
            FEName, "\<)//geo=\>", keyGeo, "\<//Code=MatheFEM2D//Date=\>", 
            zeit, "\<//\>"]; \[IndentingNewLine]Write[
            fileSID, "\< part\>"]; \[IndentingNewLine]Write[
            fileSID, "\<      new modal\>", SpaceForm[33], "\<= \>", 
            FEName]; \[IndentingNewLine]Write[
            fileSID, "\<           refmod\>"]; \[IndentingNewLine]Write[
            fileSID, "\<                mass\>", SpaceForm[28], "\<= \>", 
            mFE]; \[IndentingNewLine]Write[
            fileSID, "\<                nelastq\>", SpaceForm[25], "\<= \>", 
            nqSID]; \[IndentingNewLine]Do[If[i > 9, sp1 = 1, sp1 = 2]; 
            Write[fileSID, SpaceForm[16], "\<ielastq\>", SpaceForm[sp1], i, 
              SpaceForm[22], "\<= \>", 
              ielastq\[LeftDoubleBracket]i\[RightDoubleBracket]];, {i, 1, 
              nqSID}]; 
          Write[fileSID, "\<           end refmod\>"];];\)\)], "Input"],

Cell["Write the frames", "Text"],

Cell[BoxData[
    \(\(writeframe[fileSID_, nqSID_, nK_, Rk_, phi0_, psi0_, KF0F1_, 
          epswert_] := 
        Module[{m0mat, m1mat, k, kk, orderv, nrowv, ncolv, nqnv, structv, i, 
            j}, \[IndentingNewLine]Write[
            fileSID, "\<           frame\>"]; \[IndentingNewLine]Write[
            fileSID, "\<                new node                        = \>"\
\ , "\<refernce frame\>"]; \[IndentingNewLine]Write[
            fileSID, "\<                rframe                          = \>"\
\ , "\<body ref\>"]; \[IndentingNewLine]orderv = 0; nrowv = 3; ncolv = 1; 
          nqnv = 0; structv = 0; 
          taylor1[fileSID, "\<origin-ref\>", orderv, nrowv, ncolv, nqSID, 
            nqnv, structv, epswert, m0mat, m1mat]; orderv = 0; nrowv = 3; 
          ncolv = nqSID; nqnv = 0; structv = 0; 
          taylor1[fileSID, "\<phi-ref\>", orderv, nrowv, ncolv, nqSID, nqnv, 
            structv, epswert, m0mat, m1mat]; \[IndentingNewLine]orderv = 0; 
          nrowv = 3; ncolv = nqSID; nqnv = 0; structv = 0; 
          taylor1[fileSID, "\<psi-ref\>", orderv, nrowv, ncolv, nqSID, nqnv, 
            structv, epswert, m0mat, m1mat]; \[IndentingNewLine]orderv = 0; 
          nrowv = 3; ncolv = 3; nqnv = 0; structv = 4; 
          taylor1[fileSID, "\<AP-ref\>", orderv, nrowv, ncolv, nqSID, nqnv, 
            structv, epswert, m0mat, m1mat]; \[IndentingNewLine]Write[
            fileSID, "\<                end node\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]Write[
              fileSID, "\<                new node                        = \
\>"\ , "\<marker\>", k]; \[IndentingNewLine]Write[
              fileSID, "\<                rframe                          = \
\>"\ , "\<body_ref\>"]; \[IndentingNewLine]m1mat = 
              Table[0, {3}, {nqSID}, {1}]; \[IndentingNewLine]Do[
              m1mat\[LeftDoubleBracket]1, kk, 1\[RightDoubleBracket] = 
                phi0\[LeftDoubleBracket]k, 1, kk\[RightDoubleBracket]; 
              m1mat\[LeftDoubleBracket]2, kk, 1\[RightDoubleBracket] = 
                phi0\[LeftDoubleBracket]k, 2, kk\[RightDoubleBracket]; 
              m1mat\[LeftDoubleBracket]3, kk, 1\[RightDoubleBracket] = 
                phi0\[LeftDoubleBracket]k, 3, kk\[RightDoubleBracket];, {kk, 
                nqSID}]; orderv = 1; nrowv = 3; ncolv = 1; nqnv = 0; 
            structv = 3; 
            taylor1[fileSID, "\<origin\>"\ , orderv, nrowv, ncolv, nqSID, 
              nqnv, structv, epswert, 
              Transpose[{RK\[LeftDoubleBracket]k\[RightDoubleBracket]}] // N, 
              m1mat // N]; m1mat = Table[0, {3}, {nqSID}, {nqSID}]; 
            Do[\(Do[m1mat\[LeftDoubleBracket]1, i, 
                      j\[RightDoubleBracket] = \(-KF0F1\[LeftDoubleBracket]k, 
                        i, j\[RightDoubleBracket]\); 
                  m1mat\[LeftDoubleBracket]2, i, j\[RightDoubleBracket] = 0; 
                  m1mat\[LeftDoubleBracket]3, i, j\[RightDoubleBracket] = 
                    0;, {i, nqSID}];\), {j, nqSID}]; orderv = 1; nrowv = 3; 
            ncolv = nqSID; nqnv = 0; structv = 3; 
            taylor1[fileSID, "\<phi\>"\ , orderv, nrowv, ncolv, nqSID, nqnv, 
              structv, epswert, 
              phi0\[LeftDoubleBracket]k\[RightDoubleBracket] // N, 
              m1mat // N]; \[IndentingNewLine]orderv = 0; nrowv = 3; 
            ncolv = nqSID; nqnv = 0; structv = 3; 
            taylor1[fileSID, "\<psi\>"\ , orderv, nrowv, ncolv, nqSID, nqnv, 
              structv, epswert, 
              psi0\[LeftDoubleBracket]k\[RightDoubleBracket] // N, 
              m1mat // N]; \[IndentingNewLine]m0mat\  = \ 
              IdentityMatrix[3] // N; \[IndentingNewLine]m1mat\  = \ 
              Table[0, {3}, {nqSID}, {3}]; \[IndentingNewLine]Do\ [\
\[IndentingNewLine]m1mat[\([1, j, 
                    2]\)] = \(-psi0[\([k, 3, 
                      j]\)]\); \[IndentingNewLine]m1mat[\([2, j, 
                    1]\)] = \(+psi0[\([k, 3, 
                      j]\)]\); \[IndentingNewLine]m1mat[\([1, j, 
                    3]\)] = \(+psi0[\([k, 2, 
                      j]\)]\); \[IndentingNewLine]m1mat[\([3, j, 
                    1]\)] = \(-psi0[\([k, 2, 
                      j]\)]\); \[IndentingNewLine]m1mat[\([2, j, 
                    3]\)] = \(-psi0[\([k, 1, 
                      j]\)]\); \[IndentingNewLine]m1mat[\([3, j, 
                    2]\)] = \(+psi0[\([k, 1, j]\)]\);, {j, 
                nqSID}]; \[IndentingNewLine]orderv = 1; nrowv = 3; ncolv = 3; 
            nqnv = 0; structv = 3; 
            taylor1[fileSID, "\<AP\>"\ , orderv, nrowv, ncolv, nqSID, nqnv, 
              structv, epswert, m0mat // N, 
              m1mat // N]; \[IndentingNewLine]Write[
              fileSID, "\<                end node\>"];\[IndentingNewLine], \
{k, nK}]; \[IndentingNewLine]Write[
            fileSID, "\<           end frame\>"];];\)\)], "Input"],

Cell["Write the mass data", "Text"],

Cell[BoxData[
    \(\(writemass[fileSID_, nqSID_, c0_, mFE_, C1_, I0_, C4_, K0t1_, K0t2_, 
          C2_, Kr_, Me_, keyMe_, Oe0T_, Oe_, K0o3_, epswert_] := 
        Module[{m0mat, m1mat, orderv, nrowv, ncolv, nqnv, structv, i, j, j1, 
            k}, \[IndentingNewLine]m0mat = Table[0, {3}, {1}]; 
          m0mat\[LeftDoubleBracket]1, 1\[RightDoubleBracket] = 
            c0\[LeftDoubleBracket]3, 2\[RightDoubleBracket]; 
          m0mat\[LeftDoubleBracket]2, 
              1\[RightDoubleBracket] = \(-c0\[LeftDoubleBracket]3, 
                1\[RightDoubleBracket]\); 
          m0mat\[LeftDoubleBracket]3, 1\[RightDoubleBracket] = 
            c0\[LeftDoubleBracket]2, 1\[RightDoubleBracket]; 
          m0mat\  = Chop[\ m0mat*mFE, epswert]; 
          m1mat = Table[0, {3}, {nqSID}, {1}]; 
          Do[\(Do[\(m1mat\[LeftDoubleBracket]i, j, 1\[RightDoubleBracket] = 
                    C1\[LeftDoubleBracket]i, j\[RightDoubleBracket];\), {i, 
                  3}];\), {j, nqSID}]; \[IndentingNewLine]orderv = 1; 
          nrowv = 3; ncolv = 1; nqnv = 0; structv = 3; 
          taylor1[fileSID, "\<mdCM\>", orderv, nrowv, ncolv, nqSID, nqnv, 
            structv, epswert, m0mat, 
            m1mat]; \[IndentingNewLine]\[IndentingNewLine]m0mat = 
            Table[0, {6}, {1}]; \
\[IndentingNewLine]m0mat\[LeftDoubleBracket]1, 1\[RightDoubleBracket] = 
            If[I0\[LeftDoubleBracket]1, 1\[RightDoubleBracket] < epswert, 
              1.0, I0\[LeftDoubleBracket]1, 
                1\[RightDoubleBracket]]; \[IndentingNewLine]m0mat\
\[LeftDoubleBracket]2, 1\[RightDoubleBracket] = 
            If[I0\[LeftDoubleBracket]2, 2\[RightDoubleBracket] < epswert, 
              1.0, I0\[LeftDoubleBracket]2, 2\[RightDoubleBracket]]; 
          m0mat\[LeftDoubleBracket]3, 1\[RightDoubleBracket] = 
            I0\[LeftDoubleBracket]3, 3\[RightDoubleBracket]; 
          m0mat\[LeftDoubleBracket]4, 1\[RightDoubleBracket] = 
            I0\[LeftDoubleBracket]1, 2\[RightDoubleBracket]; 
          m0mat\[LeftDoubleBracket]5, 1\[RightDoubleBracket] = 
            I0\[LeftDoubleBracket]1, 3\[RightDoubleBracket]; 
          m0mat\[LeftDoubleBracket]6, 1\[RightDoubleBracket] = 
            I0\[LeftDoubleBracket]2, 
              3\[RightDoubleBracket]; \[IndentingNewLine]m1mat = 
            Table[0, {6}, {nqSID}, {1}]; 
          Do[\(Do[\(m1mat\[LeftDoubleBracket]i, j, 
                      1\[RightDoubleBracket] = \(-2\)*
                      C4\[LeftDoubleBracket]i, j\[RightDoubleBracket];\), {i, 
                  3}];\), {j, nqSID}]; \[IndentingNewLine]orderv = 1; 
          nrowv = 6; ncolv = 1; nqnv = 0; structv = 3; 
          taylor1[fileSID, "\<J\>", orderv, nrowv, ncolv, nqSID, nqnv, 
            structv, epswert, m0mat, 
            m1mat]; \ \[IndentingNewLine]\[IndentingNewLine]m0mat = 
            Transpose[C1]; \[IndentingNewLine]m1mat = 
            Table[0, {nqSID}, {nqSID}, {3}]; \
\[IndentingNewLine]Do[\(Do[\(m1mat\[LeftDoubleBracket]i, j, 
                      1\[RightDoubleBracket] = 
                    K0t1\[LeftDoubleBracket]i, j\[RightDoubleBracket];\), {i, 
                  nqSID}];\), {j, 
              nqSID}]; \
\[IndentingNewLine]Do[\(Do[\(m1mat\[LeftDoubleBracket]i, j, 
                      2\[RightDoubleBracket] = 
                    K0t2\[LeftDoubleBracket]i, j\[RightDoubleBracket];\), {i, 
                  nqSID}];\), {j, nqSID}]; \[IndentingNewLine]orderv = 1; 
          nrowv = nqSID; ncolv = 3; nqnv = 0; structv = 3; 
          taylor1[fileSID, "\<Ct\>", orderv, nrowv, ncolv, nqSID, nqnv, 
            structv, epswert, m0mat, 
            m1mat]; \ \[IndentingNewLine]\ \[IndentingNewLine]m0mat = 
            Transpose[C2]; \[IndentingNewLine]m1mat = 
            Table[0, {nqSID}, {nqSID}, {3}]; 
          Do[Do[\(Do[\(m1mat\[LeftDoubleBracket]i, j, 
                        j1\[RightDoubleBracket] = 
                      Kr\[LeftDoubleBracket]j1, i, 
                        j\[RightDoubleBracket];\), {i, nqSID}];\), {j, 
                nqSID}], {j1, 3}]; \[IndentingNewLine]orderv = 1; 
          nrowv = nqSID; ncolv = 3; nqnv = 0; structv = 3; 
          taylor1[fileSID, "\<Cr\>", orderv, nrowv, ncolv, nqSID, nqnv, 
            structv, epswert, m0mat, 
            m1mat]; \ \[IndentingNewLine]\ \[IndentingNewLine]orderv = 0; 
          nrowv = nqSID; ncolv = nqSID; nqnv = 0; structv = keyMe; 
          taylor1[fileSID, "\<Me\>", orderv, nrowv, ncolv, nqSID, nqnv, 
            structv, epswert, Me, 
            0]; \ \[IndentingNewLine]\[IndentingNewLine]m0mat = 
            Table[0, {3}, {3*
                  nqSID}]; \
\[IndentingNewLine]Do[\(m0mat\[LeftDoubleBracket]3, 
                  2*nqSID + j\[RightDoubleBracket] = \(-2\)*
                  C4\[LeftDoubleBracket]3, j\[RightDoubleBracket];\), {j, 
              nqSID}]; \[IndentingNewLine]orderv = 0; nrowv = 3; 
          ncolv = 3*nqSID; nqnv = 0; structv = 3; 
          taylor1[fileSID, "\<Gr\>", orderv, nrowv, ncolv, nqSID, nqnv, 
            structv, epswert, m0mat, 
            0]; \ \[IndentingNewLine]\[IndentingNewLine]m0mat = 
            Table[0, {nqSID}, {3*
                  nqSID}]; \[IndentingNewLine]Do[\(Do[\(Do[\(m0mat\
\[LeftDoubleBracket]i, \((k - 1)\)*nqSID + j\[RightDoubleBracket] = 
                        2*Kr\[LeftDoubleBracket]k, i, 
                            j\[RightDoubleBracket];\), {i, nqSID}];\), {j, 
                  nqSID}];\), {k, 3}]; \[IndentingNewLine]orderv = 0; 
          nrowv = nqSID; ncolv = 3*nqSID; nqnv = 0; structv = 3; 
          taylor1[fileSID, "\<Ge\>", orderv, nrowv, ncolv, nqSID, nqnv, 
            structv, epswert, m0mat, 
            0]; \ \[IndentingNewLine]\[IndentingNewLine]m0mat = 
            Transpose[Oe0T]; \[IndentingNewLine]m1mat = 
            Table[0, {nqSID}, {nqSID}, {6}]; 
          Do[Do[\(Do[\(m1mat\[LeftDoubleBracket]i, j, 
                        j1\[RightDoubleBracket] = 
                      Oe\[LeftDoubleBracket]j1, i, j\[RightDoubleBracket] + 
                        If[j1 \[Equal] 3, K0o3[\([i, j]\)]];\), {i, 
                    nqSID}];\), {j, nqSID}], {j1, 
              6}]; \[IndentingNewLine]orderv = 1; nrowv = nqSID; ncolv = 6; 
          nqnv = 0; structv = 3; 
          taylor1[fileSID, "\<Oe\>", orderv, nrowv, ncolv, nqSID, nqnv, 
            structv, epswert, m0mat, 
            m1mat];\ \[IndentingNewLine]];\)\)], "Input"],

Cell["Write the stiffness data", "Text"],

Cell[BoxData[
    \(\(writestiffness[fileSID_, nqSID_, Ke_, De_, epswert_] := 
        Module[{orderv, nrowv, ncolv, nqnv, 
            structv}, \[IndentingNewLine]orderv = 0; nrowv = nqSID; 
          ncolv = 1; nqnv = 0; structv = 0; 
          taylor1[fileSID, "\<ksigma\>", orderv, nrowv, ncolv, nqSID, nqnv, 
            structv, epswert, 0, 
            0]; \[IndentingNewLine]\ \[IndentingNewLine]orderv = 0; 
          nrowv = nqSID; ncolv = nqSID; nqnv = 0; structv = 2; 
          taylor1[fileSID, "\<Ke\>", orderv, nrowv, ncolv, nqSID, nqnv, 
            structv, epswert, Ke, 
            0]; \ \[IndentingNewLine]\ \[IndentingNewLine]orderv = 0; 
          nrowv = nqSID; ncolv = nqSID; nqnv = 0; structv = 2; 
          taylor1[fileSID, "\<De\>", orderv, nrowv, ncolv, nqSID, nqnv, 
            structv, epswert, De, 0];\ \[IndentingNewLine]];\)\)], "Input"],

Cell["Write conclusion", "Text"],

Cell[BoxData[
    \(\(writeconclusion[fileSID_] := 
        Module[{}, \[IndentingNewLine]Write[
            fileSID, "\<      end modal\>"]; \[IndentingNewLine]Write[
            fileSID, "\< end part\>"];\[IndentingNewLine]];\)\)], "Input"],

Cell["Computation of the Damped Eigensystem", "Text"],

Cell[BoxData[
    \(\(evalEigenwithD[MFM_, KFM_, DFM_, nM_] := 
        Module[{vals, vecs, ALin, mat4, mat5, Imv, Rev, ome0val, Lehrval, 
            jj}, \[IndentingNewLine]mat4 = 
            Inverse[MFM]; \[IndentingNewLine]ALin = 
            Transpose[Join[NullMatrix[nM, nM], IdentityMatrix[nM]]]; 
          mat5 = Transpose[Join[\(-mat4 . KFM\), \(-mat4 . DFM\)]]; 
          ALin = Join[ALin, mat5]; \[IndentingNewLine]{vals, vecs} = 
            Eigensystem[ALin]; 
          vals = Reverse[
              vals]; \[IndentingNewLine]Print["\<No.|     Real +- Im \
Eigenvalue | Ang.Frequ[rad/s]| Frequ[Hz] |  D (Lehr)  \>"]; 
          Print["\<-----------------------------------------------------------\
------------------------\>"]; \[IndentingNewLine]nvals = 
            Length[vals]/2; \[IndentingNewLine]Do[
            Imv = Im[vals[\([jj*2]\)]]; \ 
            Rev = Re[vals[\([jj*2]\)]]; \[IndentingNewLine]ome0val = 
              Sqrt[Imv^2 + Rev^2] // N; \[IndentingNewLine]Lehrval = 
              Sqrt[\((Rev^2)\)/ome0val^2] // N; \[IndentingNewLine]If[
              Imv \[Equal] 0, ome0val = 0; \ 
              Lehrval = Sqrt[\((Rev^2)\)]]; \[IndentingNewLine]Print[
              PaddedForm[jj, 2], PaddedForm[Rev // N, {10, 4}], 
              PaddedForm[Abs[Imv] // N, {10, 4}], 
              PaddedForm[ome0val, {14, 5}], 
              PaddedForm[ome0val/\((2\ Pi)\) // N, {13, 5}], 
              PaddedForm[Lehrval, {8, 4}]];, {jj, 
              nvals}]; \[IndentingNewLine]ALin];\)\)], "Input"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1680}, {0, 989}},
WindowSize->{936, 820},
WindowMargins->{{Automatic, 269}, {77, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Cell[ 
      "Prof. Dr. O. Wallrapp, FHM FB06"]}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {54, 72}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False},
ShowCellLabel->False
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 50, 0, 52, "Subtitle"],
Cell[1829, 55, 81, 1, 27, "Input"],
Cell[1913, 58, 43, 0, 30, "Text"],
Cell[1959, 60, 302, 6, 43, "Input"],
Cell[2264, 68, 50, 0, 30, "Text"],
Cell[2317, 70, 82, 1, 27, "Input"],
Cell[2402, 73, 48, 0, 30, "Text"],
Cell[2453, 75, 806, 14, 112, "Input"],
Cell[3262, 91, 46, 0, 30, "Text"],
Cell[3311, 93, 551, 10, 75, "Input"],
Cell[3865, 105, 37, 0, 30, "Text"],
Cell[3905, 107, 3574, 66, 351, "Input"],
Cell[7482, 175, 34, 0, 30, "Text"],
Cell[7519, 177, 1176, 20, 155, "Input"],
Cell[8698, 199, 49, 0, 30, "Text"],
Cell[8750, 201, 2413, 45, 315, "Input"],
Cell[11166, 248, 42, 0, 30, "Text"],
Cell[11211, 250, 376, 7, 67, "Input"],
Cell[11590, 259, 35, 0, 30, "Text"],
Cell[11628, 261, 402, 6, 42, "Input"],
Cell[12033, 269, 36, 0, 30, "Text"],
Cell[12072, 271, 497, 8, 100, "Input"],
Cell[12572, 281, 37, 0, 30, "Text"],
Cell[12612, 283, 175, 3, 42, "Input"],
Cell[12790, 288, 39, 0, 30, "Text"],
Cell[12832, 290, 233, 4, 80, "Input"],
Cell[13068, 296, 39, 0, 30, "Text"],
Cell[13110, 298, 488, 8, 100, "Input"],
Cell[13601, 308, 39, 0, 30, "Text"],
Cell[13643, 310, 290, 5, 80, "Input"],
Cell[13936, 317, 41, 0, 30, "Text"],
Cell[13980, 319, 621, 11, 94, "Input"],
Cell[14604, 332, 62, 2, 30, "Text"],
Cell[14669, 336, 548, 9, 110, "Input"],
Cell[15220, 347, 99, 3, 30, "Text"],
Cell[15322, 352, 458, 7, 59, "Input"],
Cell[15783, 361, 131, 4, 30, "Text"],
Cell[15917, 367, 1338, 21, 152, "Input"],
Cell[17258, 390, 175, 4, 30, "Text"],
Cell[17436, 396, 525, 8, 75, "Input"],
Cell[17964, 406, 122, 4, 30, "Text"],
Cell[18089, 412, 995, 18, 107, "Input"],
Cell[19087, 432, 99, 3, 30, "Text"],
Cell[19189, 437, 1062, 21, 107, "Input"],
Cell[20254, 460, 117, 4, 30, "Text"],
Cell[20374, 466, 782, 15, 91, "Input"],
Cell[21159, 483, 169, 4, 30, "Text"],
Cell[21331, 489, 1120, 22, 107, "Input"],
Cell[22454, 513, 258, 6, 46, "Text"],
Cell[22715, 521, 2099, 41, 171, "Input"],
Cell[24817, 564, 101, 1, 30, "Text"],
Cell[24921, 567, 463, 8, 91, "Input"],
Cell[25387, 577, 71, 0, 30, "Text"],
Cell[25461, 579, 1590, 28, 161, "Input"],
Cell[27054, 609, 70, 0, 30, "Text"],
Cell[27127, 611, 387, 8, 75, "Input"],
Cell[27517, 621, 64, 0, 30, "Text"],
Cell[27584, 623, 558, 16, 177, "Input"],
Cell[28145, 641, 203, 4, 30, "Text"],
Cell[28351, 647, 1250, 22, 203, "Input"],
Cell[29604, 671, 203, 5, 30, "Text"],
Cell[29810, 678, 1182, 21, 171, "Input"],
Cell[30995, 701, 154, 4, 30, "Text"],
Cell[31152, 707, 657, 11, 123, "Input"],
Cell[31812, 720, 40, 0, 30, "Text"],
Cell[31855, 722, 535, 9, 107, "Input"],
Cell[32393, 733, 475, 8, 107, "Input"],
Cell[32871, 743, 71, 1, 30, "Text"],
Cell[32945, 746, 2966, 57, 299, "Input"],
Cell[35914, 805, 94, 1, 30, "Text"],
Cell[36011, 808, 1651, 32, 186, "Input"],
Cell[37665, 842, 56, 0, 30, "Text"],
Cell[37724, 844, 3848, 77, 315, "Input"],
Cell[41575, 923, 113, 3, 30, "Text"],
Cell[41691, 928, 2656, 48, 315, "Input"],
Cell[44350, 978, 148, 4, 30, "Text"],
Cell[44501, 984, 4473, 79, 349, "Input"],
Cell[48977, 1065, 43, 0, 30, "Text"],
Cell[49023, 1067, 1374, 22, 235, "Input"],
Cell[50400, 1091, 42, 0, 30, "Text"],
Cell[50445, 1093, 1133, 19, 187, "Input"],
Cell[51581, 1114, 40, 0, 30, "Text"],
Cell[51624, 1116, 1086, 18, 171, "Input"],
Cell[52713, 1136, 41, 0, 30, "Text"],
Cell[52757, 1138, 976, 16, 189, "Input"],
Cell[53736, 1156, 60, 0, 30, "Text"],
Cell[53799, 1158, 1230, 22, 171, "Input"],
Cell[55032, 1182, 34, 0, 30, "Text"],
Cell[55069, 1184, 1887, 33, 237, "Input"],
Cell[56959, 1219, 42, 0, 30, "Text"],
Cell[57004, 1221, 1765, 30, 236, "Input"],

Cell[CellGroupData[{
Cell[58794, 1255, 42, 1, 27, "Input"],
Cell[58839, 1258, 43, 1, 27, "Output"]
}, Open  ]],
Cell[58897, 1262, 138, 3, 30, "Text"],
Cell[59038, 1267, 3022, 55, 379, "Input"],
Cell[62063, 1324, 136, 3, 30, "Text"],
Cell[62202, 1329, 3958, 70, 460, "Input"],
Cell[66163, 1401, 34, 0, 30, "Text"],
Cell[66200, 1403, 2504, 39, 379, "Input"],
Cell[68707, 1444, 32, 0, 30, "Text"],
Cell[68742, 1446, 1178, 18, 171, "Input"],
Cell[69923, 1466, 32, 0, 30, "Text"],
Cell[69958, 1468, 4886, 78, 667, "Input"],
Cell[74847, 1548, 35, 0, 30, "Text"],
Cell[74885, 1550, 6408, 108, 779, "Input"],
Cell[81296, 1660, 40, 0, 30, "Text"],
Cell[81339, 1662, 873, 14, 187, "Input"],
Cell[82215, 1678, 32, 0, 30, "Text"],
Cell[82250, 1680, 242, 4, 75, "Input"],
Cell[82495, 1686, 53, 0, 30, "Text"],
Cell[82551, 1688, 1531, 26, 283, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

