(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     75635,       2357]*)
(*NotebookOutlinePosition[     76653,       2390]*)
(*  CellTagsIndexPosition[     76609,       2386]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Linear Finite-Element Analyse of a 2D-Beam Strukture",
  
  FontSize->24]], "Title",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[1, 0.999985, 0.780011]],

Cell["\<\
COPYRIGHT Prof. Dr. Oskar Wallrapp, Fachhochschule Muenchen. Jan. \
2000\
\>", "Subsubtitle",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Setting up model paramters", "Subtitle",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[0.833356, 1, 0.8]],

Cell[TextData[StyleBox[" Name of structure", "Text"]], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["FEName  = \"2D Balken 2 Elementen, ow, 13.01.2000\" ", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[0.833356, 1, 0.8]],

Cell[BoxData[
    \("2D Balken 2 Elementen, ow, 13.01.2000"\)], "Output"]
}, Open  ]],

Cell["Position of nodes w.r.t. reference frame", "Text"],

Cell[CellGroupData[{

Cell["\<\
RK      = {{ 0,   0, 0},
           { 1,   0, 0},
           { 2,   0, 0}
          }\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[0.833356, 1, 0.8]],

Cell[BoxData[
    \({{0, 0, 0}, {1, 0, 0}, {2, 0, 0}}\)], "Output"]
}, Open  ]],

Cell["Setting up elements between nodes", "Text"],

Cell[CellGroupData[{

Cell["\<\
Inde    = {{1,2},
           {2,3}
          }\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[0.833356, 1, 0.8]],

Cell[BoxData[
    \({{1, 2}, {2, 3}}\)], "Output"]
}, Open  ]],

Cell["Compute number of nodes = nK; number of elements nE", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["nK = Length[RK]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(3\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["nE = Length[Inde]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Element data:\n",
  StyleBox["rho = mass desity,",
    FontFamily->"Courier"],
  "\n",
  StyleBox["E = E-modulus, \nG = shere-modulus, \nA = cross section area, \n\
rho = mass desity, h1 = hight in 2, \nIt = moment of inertia about torsion, \n\
Iy = aera moment of inertia about 2-axis, \nIz = aera moment of inertia about \
3-axis, \nhy = hight in 2,\nhz = hight in 3,\n\nNo input: ",
    FontFamily->"Courier"],
  "le=element length,  me = element mass"
}], "Text"],

Cell["\<\
E1 = 7.0*10^10; A1 = 0.0018; I1 = 1.215*10^-8; rho1 = 3000; h1 = \
0.009;  
E3 = 2.1*10^11; A3 = 0.0019; I3 = 1.429*10^-8; rho3 = 7895; h3 = 0.0095;
Iy1 = 0; It = 0; hz = 0; G = 0;\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[0.833356, 1, 0.8]],

Cell["\<\
Edata[e] =       1   2   3   4    5   6   7   8    9   10  11
                [E , A , Iz, rho, le, me, hy, Iy , hz, It, G]\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}},
  FontFamily->"Courier"],

Cell["\<\
Edata = {{E1,A1,I1,rho1,0, 0, h1, Iy1, hz, It, G},
         {E1,A1,I1,rho1,0, 0, h1, Iy1, hz, It, G}
        }//N;\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[0.833356, 1, 0.8]],

Cell["\<\
Setup print key  (* 0 = no print of system matrices, 1 = print of \
matrices in simple form, 2 = print of matrices in matrix form*)\
\>", "Text"],

Cell["keyPrint = 2;            ", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[0.833356, 1, 0.8]],

Cell["Control of solution (2D or 3D)", "Text"],

Cell["FECode = 2D;            ", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[0.833356, 1, 0.8]],

Cell["\<\
Setup key to compute geomtric stiffening matrices KF0 keyKF0 =0 / \
1; 
IndKF0node(k), k=1,nK gives the following No. for which the geometric \
stiffening matrices are prepared, else 0\
\>", "Text"],

Cell["\<\
keyKF0 = 1;
IndKF0node = {1,2,3};            \
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[0.833356, 1, 0.8]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Solution - ",
  StyleBox["1. Restore input data",
    FontSize->18]
}], "Subtitle",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["1.1 Computation of lengths and masses", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
EdataT = Transpose[Edata]; 
EdataT[[5]] = evalleData[nE, nK, RK, Inde, Edata]; 
EdataT[[6]] = evalmeData[nE, EdataT[[5]], Edata]; Edata = Transpose[EdataT]; \
\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.2 Print of  data; mFE = total mass, lFE = total length", \
"Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(printElementData[nE, nK, FEname, RK, Inde, Edata];\)\)], "Input"],

Cell[BoxData[
    \("-----------------------------------------------------------------------\
-----------------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("2D Balken 2 Elementen, ow, 13.01.2000"\
\[InvisibleSpace]": No nodes="\[InvisibleSpace]3\[InvisibleSpace]", No \
elements="\[InvisibleSpace]2\[InvisibleSpace]", \
Tot.mass="\[InvisibleSpace]10.799999999999999`\[InvisibleSpace]", \
Tot.length="\[InvisibleSpace]2\[InvisibleSpace]","\[InvisibleSpace]0\
\[InvisibleSpace]","\[InvisibleSpace]0\[InvisibleSpace]"!"\),
      SequenceForm[ 
      "2D Balken 2 Elementen, ow, 13.01.2000", ": No nodes=", 3, 
        ", No elements=", 2, ", Tot.mass=", 10.799999999999999, 
        ", Tot.length=", 2, ",", 0, ",", 0, "!"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------------\
-----------------------------"\)], "Print"],

Cell[BoxData[
    \("#el ! btw nodes ! length ! c.s.area !   Iz  ,  Iy   ,   It   ! density \
!  mass  !  E-  ,  G-modulus !  hy ,  hz  !"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  1\"\>",
            1,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" ! \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  1\"\>",
            1,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   2\"\>",
            2,
            Editable->False],
          (PaddedForm[ #, 3]&)], "\[InvisibleSpace]", "\<\"  !\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 1.000\"\>",
            1,
            Editable->False],
          (PaddedForm[ #, {4, 3}]&)], "\[InvisibleSpace]", "\<\"  !\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 0.001800\"\>",
            0.0018,
            AutoDelete->True],
          (PaddedForm[ #, {6, 6}]&)], "\[InvisibleSpace]", "\<\"  !\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\(" 1.215"\[Times]10\^"-8"\),
            1.2150000000000001*^-08,
            AutoDelete->True],
          (PaddedForm[ #, {4, 3}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 0.000\"\>",
            0.0,
            AutoDelete->True],
          (PaddedForm[ #, {4, 3}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 0.000\"\>",
            0.0,
            AutoDelete->True],
          (PaddedForm[ #, {4, 3}]&)], "\[InvisibleSpace]", "\<\" !\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 3000.00\"\>",
            3000.0,
            AutoDelete->True],
          (PaddedForm[ #, {4, 2}]&)], "\[InvisibleSpace]", "\<\" !\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 5.4000\"\>",
            5.3999999999999995,
            AutoDelete->True],
          (PaddedForm[ #, {4, 4}]&)], "\[InvisibleSpace]", "\<\" !\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\(" 7.000"\[Times]10\^"10"\),
            70000000000.0,
            AutoDelete->True],
          (PaddedForm[ #, {4, 3}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  0.000\"\>",
            0.0,
            AutoDelete->True],
          (PaddedForm[ #, {5, 3}]&)], "\[InvisibleSpace]", "\<\" !\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 0.009\"\>",
            0.0089999999999999993,
            AutoDelete->True],
          (PaddedForm[ #, {3, 3}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 0.000\"\>",
            0.0,
            AutoDelete->True],
          (PaddedForm[ #, {4, 3}]&)], "\[InvisibleSpace]", "\<\" !\"\>"}],
      SequenceForm[ 
        PaddedForm[ 1, 2], " ! ", 
        PaddedForm[ 1, 2], 
        PaddedForm[ 2, 3], "  !", 
        PaddedForm[ 1, {4, 3}], "  !", 
        PaddedForm[ 0.0018, {6, 6}], "  !", 
        PaddedForm[ 1.2150000000000001*^-08, {4, 3}], 
        PaddedForm[ 0.0, {4, 3}], 
        PaddedForm[ 0.0, {4, 3}], " !", 
        PaddedForm[ 3000.0, {4, 2}], " !", 
        PaddedForm[ 5.3999999999999995, {4, 4}], " !", 
        PaddedForm[ 70000000000.0, {4, 3}], 
        PaddedForm[ 0.0, {5, 3}], " !", 
        PaddedForm[ 0.0089999999999999993, {3, 3}], 
        PaddedForm[ 0.0, {4, 3}], " !"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"  2\"\>",
            2,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" ! \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  2\"\>",
            2,
            Editable->False],
          (PaddedForm[ #, 2]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   3\"\>",
            3,
            Editable->False],
          (PaddedForm[ #, 3]&)], "\[InvisibleSpace]", "\<\"  !\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 1.000\"\>",
            1,
            Editable->False],
          (PaddedForm[ #, {4, 3}]&)], "\[InvisibleSpace]", "\<\"  !\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 0.001800\"\>",
            0.0018,
            AutoDelete->True],
          (PaddedForm[ #, {6, 6}]&)], "\[InvisibleSpace]", "\<\"  !\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\(" 1.215"\[Times]10\^"-8"\),
            1.2150000000000001*^-08,
            AutoDelete->True],
          (PaddedForm[ #, {4, 3}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 0.000\"\>",
            0.0,
            AutoDelete->True],
          (PaddedForm[ #, {4, 3}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 0.000\"\>",
            0.0,
            AutoDelete->True],
          (PaddedForm[ #, {4, 3}]&)], "\[InvisibleSpace]", "\<\" !\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 3000.00\"\>",
            3000.0,
            AutoDelete->True],
          (PaddedForm[ #, {4, 2}]&)], "\[InvisibleSpace]", "\<\" !\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 5.4000\"\>",
            5.3999999999999995,
            AutoDelete->True],
          (PaddedForm[ #, {4, 4}]&)], "\[InvisibleSpace]", "\<\" !\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\(" 7.000"\[Times]10\^"10"\),
            70000000000.0,
            AutoDelete->True],
          (PaddedForm[ #, {4, 3}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"  0.000\"\>",
            0.0,
            AutoDelete->True],
          (PaddedForm[ #, {5, 3}]&)], "\[InvisibleSpace]", "\<\" !\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 0.009\"\>",
            0.0089999999999999993,
            AutoDelete->True],
          (PaddedForm[ #, {3, 3}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\" 0.000\"\>",
            0.0,
            AutoDelete->True],
          (PaddedForm[ #, {4, 3}]&)], "\[InvisibleSpace]", "\<\" !\"\>"}],
      SequenceForm[ 
        PaddedForm[ 2, 2], " ! ", 
        PaddedForm[ 2, 2], 
        PaddedForm[ 3, 3], "  !", 
        PaddedForm[ 1, {4, 3}], "  !", 
        PaddedForm[ 0.0018, {6, 6}], "  !", 
        PaddedForm[ 1.2150000000000001*^-08, {4, 3}], 
        PaddedForm[ 0.0, {4, 3}], 
        PaddedForm[ 0.0, {4, 3}], " !", 
        PaddedForm[ 3000.0, {4, 2}], " !", 
        PaddedForm[ 5.3999999999999995, {4, 4}], " !", 
        PaddedForm[ 70000000000.0, {4, 3}], 
        PaddedForm[ 0.0, {5, 3}], " !", 
        PaddedForm[ 0.0089999999999999993, {3, 3}], 
        PaddedForm[ 0.0, {4, 3}], " !"],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(printNodeData[nE, nK, FEname, RK];\)\)], "Input"],

Cell[BoxData[
    \("-----------------------------------------------------------------------\
-----------------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("2D Balken 2 Elementen, ow, 13.01.2000"\
\[InvisibleSpace]": No nodes="\[InvisibleSpace]3\[InvisibleSpace]", No \
elements="\[InvisibleSpace]2\[InvisibleSpace]", \
Tot.mass="\[InvisibleSpace]10.799999999999999`\[InvisibleSpace]", \
Tot.length="\[InvisibleSpace]2\[InvisibleSpace]","\[InvisibleSpace]0\
\[InvisibleSpace]","\[InvisibleSpace]0\[InvisibleSpace]"!"\),
      SequenceForm[ 
      "2D Balken 2 Elementen, ow, 13.01.2000", ": No nodes=", 3, 
        ", No elements=", 2, ", Tot.mass=", 10.799999999999999, 
        ", Tot.length=", 2, ",", 0, ",", 0, "!"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------------\
-----------------------------"\)], "Print"],

Cell[BoxData[
    \("#node! position Rx  ,  Ry   ,   Rz   ! "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"   1\"\>",
            1,
            Editable->False],
          (PaddedForm[ #, 3]&)], "\[InvisibleSpace]", "\<\" ! \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     0.0000\"\>",
            0,
            Editable->False],
          (PaddedForm[ #, {9, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   0.0000\"\>",
            0,
            Editable->False],
          (PaddedForm[ #, {7, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   0.0000\"\>",
            0,
            Editable->False],
          (PaddedForm[ #, {7, 4}]&)], "\[InvisibleSpace]", "\<\"  !\"\>"}],
      SequenceForm[ 
        PaddedForm[ 1, 3], " ! ", 
        PaddedForm[ 0, {9, 4}], 
        PaddedForm[ 0, {7, 4}], 
        PaddedForm[ 0, {7, 4}], "  !"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"   2\"\>",
            2,
            Editable->False],
          (PaddedForm[ #, 3]&)], "\[InvisibleSpace]", "\<\" ! \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     1.0000\"\>",
            1,
            Editable->False],
          (PaddedForm[ #, {9, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   0.0000\"\>",
            0,
            Editable->False],
          (PaddedForm[ #, {7, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   0.0000\"\>",
            0,
            Editable->False],
          (PaddedForm[ #, {7, 4}]&)], "\[InvisibleSpace]", "\<\"  !\"\>"}],
      SequenceForm[ 
        PaddedForm[ 2, 3], " ! ", 
        PaddedForm[ 1, {9, 4}], 
        PaddedForm[ 0, {7, 4}], 
        PaddedForm[ 0, {7, 4}], "  !"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"   3\"\>",
            3,
            Editable->False],
          (PaddedForm[ #, 3]&)], "\[InvisibleSpace]", "\<\" ! \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     2.0000\"\>",
            2,
            Editable->False],
          (PaddedForm[ #, {9, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   0.0000\"\>",
            0,
            Editable->False],
          (PaddedForm[ #, {7, 4}]&)], "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"   0.0000\"\>",
            0,
            Editable->False],
          (PaddedForm[ #, {7, 4}]&)], "\[InvisibleSpace]", "\<\"  !\"\>"}],
      SequenceForm[ 
        PaddedForm[ 3, 3], " ! ", 
        PaddedForm[ 2, {9, 4}], 
        PaddedForm[ 0, {7, 4}], 
        PaddedForm[ 0, {7, 4}], "  !"],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.3 Plot of structure", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plotStructure[nE, nK, FEname, RK];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -113 0 ]
[.5 .17917 113 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -174 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 13.000 moveto
(D) show
81.000 13.000 moveto
(Balken) show
123.000 13.000 moveto
(2) show
135.000 13.000 moveto
(Elementen) show
189.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
201.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
213.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
225.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
255.000 13.000 moveto
(.2000) show
285.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 48},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Solution - ",
  StyleBox["2. Setup of Element Matrices",
    FontSize->18]
}], "Subtitle",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Number of DOFs of a node", "Text"],

Cell[BoxData[
    \(\(nfk = 3;\)\)], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Interpolation matrix Ne(xi) where \[Xi] = x/le\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ne\  = \ setNe2DBeam[]; MatrixForm[Ne]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1 - \[Xi]\), "0", "0", "\[Xi]", "0", "0"},
            {
              "0", \(1 - 3\ \[Xi]\^2 + 2\ \[Xi]\^3\), \(le\ \[Xi] - 
                2\ le\ \[Xi]\^2 + le\ \[Xi]\^3\), 
              "0", \(3\ \[Xi]\^2 - 2\ \[Xi]\^3\), \(\(-le\)\ \[Xi]\^2 + 
                le\ \[Xi]\^3\)},
            {"0", "0", "0", "0", "0", "0"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["\<\
Strain matrix Be(xi)  where \[Xi] = x/le\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Be\  = \ setBe2DBeam[]; MatrixForm[Be]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-\(1\/le\)\), \(-\(\(x2\ \((\(-6\) + 
                          12\ \[Xi])\)\)\/le\^2\)\), \(-\(\(x2\ \((\(-4\)\ le \
+ 6\ le\ \[Xi])\)\)\/le\^2\)\), \(1\/le\), \(-\(\(x2\ \((6 - 
                          12\ \[Xi])\)\)\/le\^2\)\), \(-\(\(x2\ \((\(-2\)\ le \
+ 6\ le\ \[Xi])\)\)\/le\^2\)\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["Mass matrix Me(le, me)", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Me\  = \ setMe2DBeam[]; MatrixForm[Me]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(me\/3\), "0", "0", \(me\/6\), "0", "0"},
            {"0", \(\(13\ me\)\/35\), \(\(11\ le\ me\)\/210\), 
              "0", \(\(9\ me\)\/70\), \(-\(\(13\ le\ me\)\/420\)\)},
            {"0", \(\(11\ le\ me\)\/210\), \(\(le\^2\ me\)\/105\), 
              "0", \(\(13\ le\ me\)\/420\), \(-\(\(le\^2\ me\)\/140\)\)},
            {\(me\/6\), "0", "0", \(me\/3\), "0", "0"},
            {"0", \(\(9\ me\)\/70\), \(\(13\ le\ me\)\/420\), 
              "0", \(\(13\ me\)\/35\), \(-\(\(11\ le\ me\)\/210\)\)},
            {"0", \(-\(\(13\ le\ me\)\/420\)\), \(-\(\(le\^2\ me\)\/140\)\), 
              "0", \(-\(\(11\ le\ me\)\/210\)\), \(\(le\^2\ me\)\/105\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["Mass matrix C1e(le, me)", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(C1e\  = \ setC1e2DBeam[]; MatrixForm[C1e]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(me\/2\), "0", "0", \(me\/2\), "0", "0"},
            {"0", \(me\/2\), \(\(le\ me\)\/12\), 
              "0", \(me\/2\), \(-\(\(le\ me\)\/12\)\)},
            {"0", "0", "0", "0", "0", "0"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["Mass matrix C3e11(le, me)", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(C3e11\  = \ setC3e112DBeam[]; MatrixForm[C3e11]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(me\/3\), "0", "0", \(me\/6\), "0", "0"},
            {"0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0"},
            {\(me\/6\), "0", "0", \(me\/3\), "0", "0"},
            {"0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["Mass matrix C3e22(le, me)", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(C3e22\  = \ setC3e222DBeam[]; MatrixForm[C3e22]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", "0", "0", "0", "0"},
            {"0", \(\(13\ me\)\/35\), \(\(11\ le\ me\)\/210\), 
              "0", \(\(9\ me\)\/70\), \(-\(\(13\ le\ me\)\/420\)\)},
            {"0", \(\(11\ le\ me\)\/210\), \(\(le\^2\ me\)\/105\), 
              "0", \(\(13\ le\ me\)\/420\), \(-\(\(le\^2\ me\)\/140\)\)},
            {"0", "0", "0", "0", "0", "0"},
            {"0", \(\(9\ me\)\/70\), \(\(13\ le\ me\)\/420\), 
              "0", \(\(13\ me\)\/35\), \(-\(\(11\ le\ me\)\/210\)\)},
            {"0", \(-\(\(13\ le\ me\)\/420\)\), \(-\(\(le\^2\ me\)\/140\)\), 
              "0", \(-\(\(11\ le\ me\)\/210\)\), \(\(le\^2\ me\)\/105\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["Mass matrix C3e12(le, me)", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(C3e12\  = \ setC3e122DBeam[]; MatrixForm[C3e12]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", \(\(7\ me\)\/20\), \(\(le\ me\)\/20\), 
              "0", \(\(3\ me\)\/20\), \(-\(\(le\ me\)\/30\)\)},
            {"0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0"},
            {"0", \(\(3\ me\)\/20\), \(\(le\ me\)\/30\), 
              "0", \(\(7\ me\)\/20\), \(-\(\(le\ me\)\/20\)\)},
            {"0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["\<\
Stiffness matrix Ke(le, Ae, Ie)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ke\  = \ setKe2DBeam[]; MatrixForm[Ke]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(Ae\ Ee\)\/le\), "0", "0", \(-\(\(Ae\ Ee\)\/le\)\), "0", 
              "0"},
            {"0", \(\(12\ Ee\ Ie\)\/le\^3\), \(\(6\ Ee\ Ie\)\/le\^2\), 
              "0", \(-\(\(12\ Ee\ Ie\)\/le\^3\)\), \(\(6\ Ee\ Ie\)\/le\^2\)},
            {"0", \(\(6\ Ee\ Ie\)\/le\^2\), \(\(4\ Ee\ Ie\)\/le\), 
              "0", \(-\(\(6\ Ee\ Ie\)\/le\^2\)\), \(\(2\ Ee\ Ie\)\/le\)},
            {\(-\(\(Ae\ Ee\)\/le\)\), "0", "0", \(\(Ae\ Ee\)\/le\), "0", 
              "0"},
            {
              "0", \(-\(\(12\ Ee\ Ie\)\/le\^3\)\), \(-\(\(6\ Ee\ \
Ie\)\/le\^2\)\), 
              "0", \(\(12\ Ee\ Ie\)\/le\^3\), \(-\(\(6\ Ee\ Ie\)\/le\^2\)\)},
            {"0", \(\(6\ Ee\ Ie\)\/le\^2\), \(\(2\ Ee\ Ie\)\/le\), 
              "0", \(-\(\(6\ Ee\ Ie\)\/le\^2\)\), \(\(4\ Ee\ Ie\)\/le\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["\<\
Stiffness matrix Ke\[Sigma]Bogen (le, Ae)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ke\[Sigma]Bogen\  = \ setKe\[Sigma]Bogen2DBeam[]; 
    MatrixForm[Ke\[Sigma]Bogen]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", "0", "0", "0", "0"},
            {"0", \(\(6\ Ae\)\/\(5\ le\)\), \(Ae\/10\), 
              "0", \(-\(\(6\ Ae\)\/\(5\ le\)\)\), \(Ae\/10\)},
            {"0", \(Ae\/10\), \(\(2\ Ae\ le\)\/15\), 
              "0", \(-\(Ae\/10\)\), \(-\(\(Ae\ le\)\/30\)\)},
            {"0", "0", "0", "0", "0", "0"},
            {"0", \(-\(\(6\ Ae\)\/\(5\ le\)\)\), \(-\(Ae\/10\)\), 
              "0", \(\(6\ Ae\)\/\(5\ le\)\), \(-\(Ae\/10\)\)},
            {"0", \(Ae\/10\), \(-\(\(Ae\ le\)\/30\)\), 
              "0", \(-\(Ae\/10\)\), \(\(2\ Ae\ le\)\/15\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Solution - ",
  StyleBox["3. Evaluation of System Matrices ",
    FontSize->18]
}], "Subtitle",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Number of system DOFs", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["nF = nfk * nK", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(9\)], "Output"]
}, Open  ]],

Cell["\<\
State vector ZF0(nF) in the reference configuration (position only)\
\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(ZF0\  = \ evalZF02DBeam[nF, RK, nfk]\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 1, 0, 0, 2, 0, 0}\)], "Output"]
}, Open  ]],

Cell["\<\
Orinetation matrices of elements \[CapitalGamma]e(e,(3,3))\
\>", \
"Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[CapitalGamma]e = 
        evalGammae2DBeam[nE, RK, Inde, Edata, keyPrint];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"\[CapitalGamma]e_\"\>", "\[InvisibleSpace]", "1", 
        "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0", "0"},
                {"0", "1", "0"},
                {"0", "0", "1.`"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}],
      SequenceForm[ "\[CapitalGamma]e_", 1, " = ", 
        MatrixForm[ {{1, 0, 0}, {0, 1, 0}, {0, 0, 1.0}}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"\[CapitalGamma]e_\"\>", "\[InvisibleSpace]", "2", 
        "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0", "0"},
                {"0", "1", "0"},
                {"0", "0", "1.`"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}],
      SequenceForm[ "\[CapitalGamma]e_", 2, " = ", 
        MatrixForm[ {{1, 0, 0}, {0, 1, 0}, {0, 0, 1.0}}]],
      Editable->False]], "Print"]
}, Open  ]],

Cell["\<\
Index matrix Indufe(e,2) due to zF to tell 1: state index -1 for \
node A, 2: state index -1 for node B,\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Indufe = evalInduf2DBeam[nE, Inde]\)], "Input"],

Cell[BoxData[
    \({{0, 3}, {3, 6}}\)], "Output"]
}, Open  ]],

Cell["\<\
Transformation matrices of elements TeT(e,(nF,6))\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(TeT = 
        evalTeT2DBeam[nF, nE, \[CapitalGamma]e, Indufe, 
          keyPrint];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Te_\"\>", "\[InvisibleSpace]", "1", 
        "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0", "0", "0", "0", "0", "0", "0", "0"},
                {"0", "1", "0", "0", "0", "0", "0", "0", "0"},
                {"0", "0", "1.`", "0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "1", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "1", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "1.`", "0", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}],
      SequenceForm[ "Te_", 1, " = ", 
        MatrixForm[ {{1, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 1, 0, 0, 0, 0, 0, 0, 
          0}, {0, 0, 1.0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 1, 0, 0, 0, 0, 0}, {0, 
          0, 0, 0, 1, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 1.0, 0, 0, 0}}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Te_\"\>", "\[InvisibleSpace]", "2", 
        "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "1", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "1", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "1.`", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0", "1", "0", "0"},
                {"0", "0", "0", "0", "0", "0", "0", "1", "0"},
                {"0", "0", "0", "0", "0", "0", "0", "0", "1.`"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}],
      SequenceForm[ "Te_", 2, " = ", 
        MatrixForm[ {{0, 0, 0, 1, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 1, 0, 0, 0, 
          0}, {0, 0, 0, 0, 0, 1.0, 0, 0, 0}, {0, 0, 0, 0, 0, 0, 1, 0, 0}, {0, 
          0, 0, 0, 0, 0, 0, 1, 0}, {0, 0, 0, 0, 0, 0, 0, 0, 1.0}}]],
      Editable->False]], "Print"]
}, Open  ]],

Cell["System mass matrix MF(nF,nF)", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(MF = evalMF[nF, Edata, TeT, Me, keyPrint];\),
      "Input"]], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.7999999999999998`", "0.`", "0.`", "0.8999999999999999`", 
              "0.`", "0.`", "0.`", "0.`", "0.`"},
            {"0.`", "2.005714285714286`", "0.28285714285714286`", "0.`", 
              "0.6942857142857142`", \(-0.16714285714285712`\), "0.`", "0.`", 
              "0.`"},
            {"0.`", "0.28285714285714286`", "0.05142857142857143`", "0.`", 
              "0.16714285714285712`", \(-0.03857142857142857`\), "0.`", "0.`",
               "0.`"},
            {"0.8999999999999999`", "0.`", "0.`", "3.5999999999999996`", 
              "0.`", "0.`", "0.8999999999999999`", "0.`", "0.`"},
            {"0.`", "0.6942857142857142`", "0.16714285714285712`", "0.`", 
              "4.011428571428572`", "0.`", "0.`", 
              "0.6942857142857142`", \(-0.16714285714285712`\)},
            {"0.`", \(-0.16714285714285712`\), \(-0.03857142857142857`\), 
              "0.`", "0.`", "0.10285714285714286`", "0.`", 
              "0.16714285714285712`", \(-0.03857142857142857`\)},
            {"0.`", "0.`", "0.`", "0.8999999999999999`", "0.`", "0.`", 
              "1.7999999999999998`", "0.`", "0.`"},
            {"0.`", "0.`", "0.`", "0.`", "0.6942857142857142`", 
              "0.16714285714285712`", "0.`", 
              "2.005714285714286`", \(-0.28285714285714286`\)},
            {"0.`", "0.`", "0.`", 
              "0.`", \(-0.16714285714285712`\), \(-0.03857142857142857`\), 
              "0.`", \(-0.28285714285714286`\), "0.05142857142857143`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"]
}, Open  ]],

Cell["System stiffness matrix KF(nF,nF)", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(KF = evalMF[nF, Edata, TeT, Ke, keyPrint];\),
      "Input"]], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.26`*^8", "0.`", "0.`", \(-1.26`*^8\), "0.`", "0.`", "0.`", 
              "0.`", "0.`"},
            {"0.`", "10206.000000000002`", "5103.000000000001`", 
              "0.`", \(-10206.000000000002`\), "5103.000000000001`", "0.`", 
              "0.`", "0.`"},
            {"0.`", "5103.000000000001`", "3402.0000000000005`", 
              "0.`", \(-5103.000000000001`\), "1701.0000000000002`", "0.`", 
              "0.`", "0.`"},
            {\(-1.26`*^8\), "0.`", "0.`", "2.52`*^8", "0.`", 
              "0.`", \(-1.26`*^8\), "0.`", "0.`"},
            {"0.`", \(-10206.000000000002`\), \(-5103.000000000001`\), "0.`", 
              "20412.000000000004`", "0.`", "0.`", \(-10206.000000000002`\), 
              "5103.000000000001`"},
            {"0.`", "5103.000000000001`", "1701.0000000000002`", "0.`", "0.`",
               "6804.000000000001`", "0.`", \(-5103.000000000001`\), 
              "1701.0000000000002`"},
            {"0.`", "0.`", "0.`", \(-1.26`*^8\), "0.`", "0.`", "1.26`*^8", 
              "0.`", "0.`"},
            {"0.`", "0.`", "0.`", 
              "0.`", \(-10206.000000000002`\), \(-5103.000000000001`\), "0.`",
               "10206.000000000002`", \(-5103.000000000001`\)},
            {"0.`", "0.`", "0.`", "0.`", "5103.000000000001`", 
              "1701.0000000000002`", "0.`", \(-5103.000000000001`\), 
              "3402.0000000000005`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"]
}, Open  ]],

Cell["Compute CFt0 = TeT . Ce1T . \[CapitalGamma]e", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
CFt0 = evalCFt0[nF,Edata,TeT,C1e,\[CapitalGamma]e,keyPrint];\
\>", \
"Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"2.6999999999999997`", "0", "0"},
            {"0", "2.6999999999999997`", "0"},
            {"0", "0.44999999999999996`", "0"},
            {"5.3999999999999995`", "0", "0"},
            {"0", "5.3999999999999995`", "0"},
            {"0", "0", "0"},
            {"2.6999999999999997`", "0", "0"},
            {"0", "2.6999999999999997`", "0"},
            {"0", \(-0.44999999999999996`\), "0"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"]
}, Open  ]],

Cell["\<\
Compute CFr(1...3) == KFr\[Alpha] =  -TeT . (C3exx - C3exxT) . Te;  \
KFralpha is screw symmetric;  CFr0 = CFr1...3 * ZF0\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["KFr = evalCFr[nF,Edata,TeT,C3e12,keyPrint];", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \("KFr1,2 = 0"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"KFr3=\"\>", "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0.`", \(-1.8899999999999997`\), \(-0.26999999999999996`\), 
                  "0.`", \(-0.8099999999999999`\), "0.18`", "0.`", "0.`", 
                  "0.`"},
                {"1.8899999999999997`", "0.`", "0.`", "0.8099999999999999`", 
                  "0.`", "0.`", "0.`", "0.`", "0.`"},
                {"0.26999999999999996`", "0.`", "0.`", "0.18`", "0.`", "0.`", 
                  "0.`", "0.`", "0.`"},
                {"0.`", \(-0.8099999999999999`\), \(-0.18`\), 
                  "0.`", \(-3.7799999999999994`\), "0.`", 
                  "0.`", \(-0.8099999999999999`\), "0.18`"},
                {"0.8099999999999999`", "0.`", "0.`", "3.7799999999999994`", 
                  "0.`", "0.`", "0.8099999999999999`", "0.`", "0.`"},
                {\(-0.18`\), "0.`", "0.`", "0.`", "0.`", "0.`", "0.18`", 
                  "0.`", "0.`"},
                {"0.`", "0.`", "0.`", 
                  "0.`", \(-0.8099999999999999`\), \(-0.18`\), 
                  "0.`", \(-1.8899999999999997`\), "0.26999999999999996`"},
                {"0.`", "0.`", "0.`", "0.8099999999999999`", "0.`", "0.`", 
                  "1.8899999999999997`", "0.`", "0.`"},
                {"0.`", "0.`", "0.`", \(-0.18`\), "0.`", 
                  "0.`", \(-0.26999999999999996`\), "0.`", "0.`"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}],
      SequenceForm[ "KFr3=", 
        MatrixForm[ {{0.0, -1.8899999999999997, -0.26999999999999996, 
          0.0, -0.80999999999999994, 0.17999999999999999, 0.0, 0.0, 0.0}, {
          1.8899999999999997, 0.0, 0.0, 0.80999999999999994, 0.0, 0.0, 0.0, 
          0.0, 0.0}, {0.26999999999999996, 0.0, 0.0, 0.17999999999999999, 0.0,
           0.0, 0.0, 0.0, 0.0}, {
          0.0, -0.80999999999999994, -0.17999999999999999, 
          0.0, -3.7799999999999994, 0.0, 0.0, -0.80999999999999994, 
          0.17999999999999999}, {0.80999999999999994, 0.0, 0.0, 
          3.7799999999999994, 0.0, 0.0, 0.80999999999999994, 0.0, 
          0.0}, {-0.17999999999999999, 0.0, 0.0, 0.0, 0.0, 0.0, 
          0.17999999999999999, 0.0, 0.0}, {0.0, 0.0, 0.0, 
          0.0, -0.80999999999999994, -0.17999999999999999, 
          0.0, -1.8899999999999997, 0.26999999999999996}, {0.0, 0.0, 0.0, 
          0.80999999999999994, 0.0, 0.0, 1.8899999999999997, 0.0, 0.0}, {0.0, 
          0.0, 0.0, -0.17999999999999999, 0.0, 0.0, -0.26999999999999996, 0.0,
           0.0}}]],
      Editable->False]], "Print"]
}, Open  ]],

Cell["\<\
Compute OF-Matrices  OF1...6 == KF\[Omega]i = TeT . (C3exx+C3exxT) \
. Te;   KF\[Alpha]i is  symmetric;  OF3 = - MF ; 
 Compute OF-Matrices  OF4 == KF\[Omega]3 = TeT . (C3e12+C3e12T) . Te; \
\>", \
"Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["OF = evalOF[nF,Edata,TeT,C3e11,C3e22,C3e12,keyPrint];", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \("KF\[Omega]1,2,5,6 = 0"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"KF\[Omega]3=\"\>", "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\(-1.7999999999999998`\), "0.`", 
                  "0.`", \(-0.8999999999999999`\), "0.`", "0.`", "0.`", "0.`",
                   "0.`"},
                {"0.`", \(-2.005714285714286`\), \(-0.28285714285714286`\), 
                  "0.`", \(-0.6942857142857142`\), "0.16714285714285712`", 
                  "0.`", "0.`", "0.`"},
                {"0.`", \(-0.28285714285714286`\), \(-0.05142857142857143`\), 
                  "0.`", \(-0.16714285714285712`\), "0.03857142857142857`", 
                  "0.`", "0.`", "0.`"},
                {\(-0.8999999999999999`\), "0.`", 
                  "0.`", \(-3.5999999999999996`\), "0.`", 
                  "0.`", \(-0.8999999999999999`\), "0.`", "0.`"},
                {"0.`", \(-0.6942857142857142`\), \(-0.16714285714285712`\), 
                  "0.`", \(-4.011428571428572`\), "0.`", 
                  "0.`", \(-0.6942857142857142`\), "0.16714285714285712`"},
                {"0.`", "0.16714285714285712`", "0.03857142857142857`", "0.`",
                   "0.`", \(-0.10285714285714286`\), 
                  "0.`", \(-0.16714285714285712`\), "0.03857142857142857`"},
                {"0.`", "0.`", "0.`", \(-0.8999999999999999`\), "0.`", 
                  "0.`", \(-1.7999999999999998`\), "0.`", "0.`"},
                {"0.`", "0.`", "0.`", 
                  "0.`", \(-0.6942857142857142`\), \(-0.16714285714285712`\), 
                  "0.`", \(-2.005714285714286`\), "0.28285714285714286`"},
                {"0.`", "0.`", "0.`", "0.`", "0.16714285714285712`", 
                  "0.03857142857142857`", "0.`", 
                  "0.28285714285714286`", \(-0.05142857142857143`\)}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}],
      SequenceForm[ "KF\[Omega]3=", 
        MatrixForm[ {{-1.7999999999999998, 0.0, 0.0, -0.89999999999999991, 
          0.0, 0.0, 0.0, 0.0, 0.0}, {
          0.0, -2.0057142857142858, -0.28285714285714286, 
          0.0, -0.69428571428571417, 0.16714285714285712, 0.0, 0.0, 0.0}, {
          0.0, -0.28285714285714286, -0.051428571428571428, 
          0.0, -0.16714285714285712, 0.038571428571428569, 0.0, 0.0, 
          0.0}, {-0.89999999999999991, 0.0, 0.0, -3.5999999999999996, 0.0, 
          0.0, -0.89999999999999991, 0.0, 0.0}, {
          0.0, -0.69428571428571417, -0.16714285714285712, 
          0.0, -4.0114285714285716, 0.0, 0.0, -0.69428571428571417, 
          0.16714285714285712}, {0.0, 0.16714285714285712, 
          0.038571428571428569, 0.0, 0.0, -0.10285714285714286, 
          0.0, -0.16714285714285712, 0.038571428571428569}, {0.0, 0.0, 
          0.0, -0.89999999999999991, 0.0, 0.0, -1.7999999999999998, 0.0, 
          0.0}, {0.0, 0.0, 0.0, 
          0.0, -0.69428571428571417, -0.16714285714285712, 
          0.0, -2.0057142857142858, 0.28285714285714286}, {0.0, 0.0, 0.0, 0.0,
           0.16714285714285712, 0.038571428571428569, 0.0, 
          0.28285714285714286, -0.051428571428571428}}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"KF\[Omega]4=\"\>", "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0.`", "1.8899999999999997`", "0.26999999999999996`", "0.`", 
                  "0.8099999999999999`", \(-0.18`\), "0.`", "0.`", "0.`"},
                {"1.8899999999999997`", "0.`", "0.`", "0.8099999999999999`", 
                  "0.`", "0.`", "0.`", "0.`", "0.`"},
                {"0.26999999999999996`", "0.`", "0.`", "0.18`", "0.`", "0.`", 
                  "0.`", "0.`", "0.`"},
                {"0.`", "0.8099999999999999`", "0.18`", "0.`", 
                  "3.7799999999999994`", "0.`", "0.`", 
                  "0.8099999999999999`", \(-0.18`\)},
                {"0.8099999999999999`", "0.`", "0.`", "3.7799999999999994`", 
                  "0.`", "0.`", "0.8099999999999999`", "0.`", "0.`"},
                {\(-0.18`\), "0.`", "0.`", "0.`", "0.`", "0.`", "0.18`", 
                  "0.`", "0.`"},
                {"0.`", "0.`", "0.`", "0.`", "0.8099999999999999`", "0.18`", 
                  "0.`", "1.8899999999999997`", \(-0.26999999999999996`\)},
                {"0.`", "0.`", "0.`", "0.8099999999999999`", "0.`", "0.`", 
                  "1.8899999999999997`", "0.`", "0.`"},
                {"0.`", "0.`", "0.`", \(-0.18`\), "0.`", 
                  "0.`", \(-0.26999999999999996`\), "0.`", "0.`"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}],
      SequenceForm[ "KF\[Omega]4=", 
        MatrixForm[ {{0.0, 1.8899999999999997, 0.26999999999999996, 0.0, 
          0.80999999999999994, -0.17999999999999999, 0.0, 0.0, 0.0}, {
          1.8899999999999997, 0.0, 0.0, 0.80999999999999994, 0.0, 0.0, 0.0, 
          0.0, 0.0}, {0.26999999999999996, 0.0, 0.0, 0.17999999999999999, 0.0,
           0.0, 0.0, 0.0, 0.0}, {0.0, 0.80999999999999994, 
          0.17999999999999999, 0.0, 3.7799999999999994, 0.0, 0.0, 
          0.80999999999999994, -0.17999999999999999}, {0.80999999999999994, 
          0.0, 0.0, 3.7799999999999994, 0.0, 0.0, 0.80999999999999994, 0.0, 
          0.0}, {-0.17999999999999999, 0.0, 0.0, 0.0, 0.0, 0.0, 
          0.17999999999999999, 0.0, 0.0}, {0.0, 0.0, 0.0, 0.0, 
          0.80999999999999994, 0.17999999999999999, 0.0, 
          1.8899999999999997, -0.26999999999999996}, {0.0, 0.0, 0.0, 
          0.80999999999999994, 0.0, 0.0, 1.8899999999999997, 0.0, 0.0}, {0.0, 
          0.0, 0.0, -0.17999999999999999, 0.0, 0.0, -0.26999999999999996, 0.0,
           0.0}}]],
      Editable->False]], "Print"]
}, Open  ]],

Cell["Compute  CFr0 = CFr1...3 * ZF0", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(CFr0T = evalCF0T[nF, ZF0, KFr, 3, keyPrint];\)\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0.`", "0.8099999999999999`", "0.18`", "0.`", 
              "5.3999999999999995`", "0.36`", "0.`", 
              "4.589999999999999`", \(-0.72`\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"]
}, Open  ]],

Cell["\<\
Computation of OF0 = OF1..6 * ZF\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(OF0T = evalCF0T[nF, ZF0, OF, 6, keyPrint];\)\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {\(-0.8999999999999999`\), "0.`", "0.`", \(-5.3999999999999995`\),
               "0.`", "0.`", \(-4.5`\), "0.`", "0.`"},
            {"0.`", "0.8099999999999999`", "0.18`", "0.`", 
              "5.3999999999999995`", "0.36`", "0.`", 
              "4.589999999999999`", \(-0.72`\)},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Geomtric Stiffening", "Subsubsection"],

Cell["\<\
Evaluate KF0 if keyKF0 = 1: 
\tKF0a1 due to a1
\tKF0a2 due to a2
\tKF0\[Omega]3 due to \[Omega]3
\tKF0d\[Omega]3 due to d\[Omega]3
\tKF0F1n# due to F1 at node #
\tKF0F2n# due to F2 at node #
\tKF0M3n# due to M3 at node #\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
 Geometrische Steifigkeitsmatrix Kesigma = KesigmaBogen*SeN, wo SeN \
Normalspannungen im Balken sind und wo
 SeN = He . BeL(x2=0) . ze0 = Ee*1/l * (ze01-ze04),  ze0 = Te . zFM,  zFM = \
KFM^-1 . hFM\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Hier m\[UDoubleDot]ssen Verbesserungen bez. KFM -1 eingebaut \
werden!
\
\>", "Text",
  Background->RGBColor[1, 0, 0]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(If[
        keyKF0 == 1, \[IndentingNewLine]Lager = {{1, 1, 1, 0, 0, 0, 
              1}}; \((\(IndR = evalIndr2D[nF, nfk, Lager];\))\)\ \((IndM = 
              evalIndM[nF, nR, IndR])\); 
        hF0 = evalhFref[nF, {1, 0, 0, 0, 0, 0, 0, 0, 0}, CFt0, CFr0T, OF0T, 
            0]; KF0a1 = 
          evalKF0[nF, nM, nR, IndM, IndR, nE, Edata, TeT, Ke\[Sigma]Bogen, 
            FECode, KF, hF0, "\<KF0a1\>", keyPrint]; 
        hF0 = evalhFref[nF, {0, 1, 0, 0, 0, 0, 0, 0, 0}, CFt0, CFr0T, OF0T, 
            0]; KF0a2 = 
          evalKF0[nF, nM, nR, IndM, IndR, nE, Edata, TeT, Ke\[Sigma]Bogen, 
            FECode, KF, hF0, "\<KF0a2\>", keyPrint]; 
        hF0 = evalhFref[nF, {0, 0, 0, 0, 0, 0, 0, 0, 1}, CFt0, CFr0T, OF0T, 
            0]; KF0\[Omega]3 = 
          evalKF0[nF, nM, nR, IndM, IndR, nE, Edata, TeT, Ke\[Sigma]Bogen, 
            FECode, KF, hF0, "\<KF0\[Omega]3\>", keyPrint]; 
        hF0 = evalhFref[nF, {0, 0, 0, 0, 0, 1, 0, 0, 0}, CFt0, CFr0T, OF0T, 
            0]; KF0d\[Omega]3 = 
          evalKF0[nF, nM, nR, IndM, IndR, nE, Edata, TeT, Ke\[Sigma]Bogen, 
            FECode, KF, hF0, "\<KF0d\[Omega]3\>", 
            keyPrint]; \[IndentingNewLine]nKF0node\  = \ 
          Max[IndKF0node]; \[IndentingNewLine]Lasten = {Table[0, {7}]}; 
        KF0F1 = Array[aaa, nKF0node]; 
        Do[kkk\  = IndKF0node\[LeftDoubleBracket]kk\[RightDoubleBracket]\ ; 
          If[kkk > 0, 
            Lasten\[LeftDoubleBracket]1, 1\[RightDoubleBracket] = kk; 
            Lasten\[LeftDoubleBracket]1, 2\[RightDoubleBracket] = 1; 
            Print["\<node = \>", kk]; hF0 = evalhFnodal[nF, nfk, Lasten, 0]; 
            KF0F1\[LeftDoubleBracket]kkk\[RightDoubleBracket] = 
              evalKF0[nF, nM, nR, IndM, IndR, nE, Edata, TeT, 
                Ke\[Sigma]Bogen, FECode, KF, hF0, "\<KF0F1\>", 
                keyPrint];];, {kk, 
            nK}]; \[IndentingNewLine]Lasten = {Table[0, {7}]}; 
        KF0F2 = Array[aaa, nKF0node]; 
        Do[kkk\  = IndKF0node\[LeftDoubleBracket]kk\[RightDoubleBracket]\ ; 
          If[kkk > 0, 
            Lasten\[LeftDoubleBracket]1, 1\[RightDoubleBracket] = kk; 
            Lasten\[LeftDoubleBracket]1, 3\[RightDoubleBracket] = 1; 
            Print["\<node = \>", kk]; hF0 = evalhFnodal[nF, nfk, Lasten, 0]; 
            KF0F2\[LeftDoubleBracket]kkk\[RightDoubleBracket] = 
              evalKF0[nF, nM, nR, IndM, IndR, nE, Edata, TeT, 
                Ke\[Sigma]Bogen, FECode, KF, hF0, "\<KF0F2\>", 
                keyPrint];];, {kk, 
            nK}]; \[IndentingNewLine]Lasten = {Table[0, {7}]}; 
        KF0M3 = Array[aaa, nKF0node]; 
        Do[kkk\  = IndKF0node\[LeftDoubleBracket]kk\[RightDoubleBracket]\ ; 
          If[kkk > 0, 
            Lasten\[LeftDoubleBracket]1, 1\[RightDoubleBracket] = kk; 
            Lasten\[LeftDoubleBracket]1, 7\[RightDoubleBracket] = 1; 
            Print["\<node = \>", kk]; hF0 = evalhFnodal[nF, nfk, Lasten, 0]; 
            KF0M3\[LeftDoubleBracket]kkk\[RightDoubleBracket] = 
              evalKF0[nF, nM, nR, IndM, IndR, nE, Edata, TeT, 
                Ke\[Sigma]Bogen, FECode, KF, hF0, "\<KF0M3\>", 
                keyPrint];];, {kk, nK}];\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("nR = "\[InvisibleSpace]3\[InvisibleSpace]", IndR = "\
\[InvisibleSpace]{1, 2, 3}\),
      SequenceForm[ "nR = ", 3, ", IndR = ", {1, 2, 3}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("nM = "\[InvisibleSpace]6\[InvisibleSpace]", IndM = "\
\[InvisibleSpace]{4, 5, 6, 7, 8, 9}\),
      SequenceForm[ "nM = ", 6, ", IndM = ", {4, 5, 6, 7, 8, 9}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("keya = "\[InvisibleSpace]1\[InvisibleSpace]", key\
\[Omega] = "\[InvisibleSpace]0\[InvisibleSpace]", keyd\[Omega] = "\
\[InvisibleSpace]0\),
      SequenceForm[ 
      "keya = ", 1, ", key\[Omega] = ", 0, ", keyd\[Omega] = ", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"KF0a1\"\>", "\[InvisibleSpace]", "\<\"=\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
                {"0", \(-9.719999999999999`\), \(-0.8099999999999998`\), "0", 
                  "9.719999999999999`", \(-0.8099999999999998`\), "0", "0", 
                  "0"},
                {"0", \(-0.8099999999999998`\), \(-1.0799999999999998`\), "0",
                   "0.8099999999999998`", "0.26999999999999996`", "0", "0", 
                  "0"},
                {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
                {"0", "9.719999999999999`", "0.8099999999999998`", 
                  "0", \(-12.959999999999997`\), "0.5399999999999998`", "0", 
                  "3.2399999999999993`", \(-0.26999999999999996`\)},
                {"0", \(-0.8099999999999998`\), "0.26999999999999996`", "0", 
                  "0.5399999999999998`", \(-1.4399999999999997`\), "0", 
                  "0.26999999999999996`", "0.08999999999999998`"},
                {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "3.2399999999999993`", 
                  "0.26999999999999996`", "0", \(-3.2399999999999993`\), 
                  "0.26999999999999996`"},
                {"0", "0", "0", "0", \(-0.26999999999999996`\), 
                  "0.08999999999999998`", "0", 
                  "0.26999999999999996`", \(-0.35999999999999993`\)}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}],
      SequenceForm[ "KF0a1", "=", 
        MatrixForm[ {{0, 0, 0, 0, 0, 0, 0, 0, 0}, {
          0, -9.7199999999999989, -0.80999999999999983, 0, 
          9.7199999999999989, -0.80999999999999983, 0, 0, 0}, {
          0, -0.80999999999999983, -1.0799999999999998, 0, 
          0.80999999999999983, 0.26999999999999996, 0, 0, 0}, {0, 0, 0, 0, 0, 
          0, 0, 0, 0}, {0, 9.7199999999999989, 0.80999999999999983, 
          0, -12.959999999999997, 0.53999999999999981, 0, 
          3.2399999999999993, -0.26999999999999996}, {0, -0.80999999999999983,
           0.26999999999999996, 0, 0.53999999999999981, -1.4399999999999997, 
          0, 0.26999999999999996, 0.089999999999999983}, {0, 0, 0, 0, 0, 0, 0,
           0, 0}, {0, 0, 0, 0, 3.2399999999999993, 0.26999999999999996, 
          0, -3.2399999999999993, 0.26999999999999996}, {0, 0, 0, 
          0, -0.26999999999999996, 0.089999999999999983, 0, 
          0.26999999999999996, -0.35999999999999993}}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("keya = "\[InvisibleSpace]1\[InvisibleSpace]", key\
\[Omega] = "\[InvisibleSpace]0\[InvisibleSpace]", keyd\[Omega] = "\
\[InvisibleSpace]0\),
      SequenceForm[ 
      "keya = ", 1, ", key\[Omega] = ", 0, ", keyd\[Omega] = ", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("KF0a2"\[InvisibleSpace]" = 0"\),
      SequenceForm[ "KF0a2", " = 0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("keya = "\[InvisibleSpace]0\[InvisibleSpace]", key\
\[Omega] = "\[InvisibleSpace]1\[InvisibleSpace]", keyd\[Omega] = "\
\[InvisibleSpace]0\),
      SequenceForm[ 
      "keya = ", 0, ", key\[Omega] = ", 1, ", keyd\[Omega] = ", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"KF0\[Omega]3\"\>", "\[InvisibleSpace]", "\<\"=\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
                {"0", "11.879999999999999`", "0.99`", 
                  "0", \(-11.879999999999999`\), "0.99`", "0", "0", "0"},
                {"0", "0.99`", "1.32`", "0", \(-0.99`\), \(-0.33`\), "0", "0",
                   "0"},
                {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
                {"0", \(-11.879999999999999`\), \(-0.99`\), "0", 
                  "17.279999999999998`", \(-0.54`\), 
                  "0", \(-5.3999999999999995`\), "0.44999999999999996`"},
                {"0", "0.99`", \(-0.33`\), "0", \(-0.54`\), "1.92`", 
                  "0", \(-0.44999999999999996`\), \(-0.14999999999999997`\)},
                {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", 
                  "0", \(-5.3999999999999995`\), \(-0.44999999999999996`\), 
                  "0", "5.3999999999999995`", \(-0.44999999999999996`\)},
                {"0", "0", "0", "0", 
                  "0.44999999999999996`", \(-0.14999999999999997`\), 
                  "0", \(-0.44999999999999996`\), "0.5999999999999999`"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}],
      SequenceForm[ "KF0\[Omega]3", "=", 
        MatrixForm[ {{0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 11.879999999999999, 
          0.98999999999999999, 0, -11.879999999999999, 0.98999999999999999, 0,
           0, 0}, {0, 0.98999999999999999, 1.3200000000000001, 
          0, -0.98999999999999999, -0.33000000000000002, 0, 0, 0}, {0, 0, 0, 
          0, 0, 0, 0, 0, 0}, {0, -11.879999999999999, -0.98999999999999999, 0,
           17.279999999999998, -0.54000000000000004, 0, -5.3999999999999995, 
          0.44999999999999996}, {0, 0.98999999999999999, -0.33000000000000002,
           0, -0.54000000000000004, 1.9199999999999999, 
          0, -0.44999999999999996, -0.14999999999999997}, {0, 0, 0, 0, 0, 0, 
          0, 0, 0}, {0, 0, 0, 0, -5.3999999999999995, -0.44999999999999996, 0,
           5.3999999999999995, -0.44999999999999996}, {0, 0, 0, 0, 
          0.44999999999999996, -0.14999999999999997, 0, -0.44999999999999996, 
          0.59999999999999987}}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("keya = "\[InvisibleSpace]0\[InvisibleSpace]", key\
\[Omega] = "\[InvisibleSpace]0\[InvisibleSpace]", keyd\[Omega] = "\
\[InvisibleSpace]1\),
      SequenceForm[ 
      "keya = ", 0, ", key\[Omega] = ", 0, ", keyd\[Omega] = ", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("KF0d\[Omega]3"\[InvisibleSpace]" = 0"\),
      SequenceForm[ "KF0d\[Omega]3", " = 0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("node = "\[InvisibleSpace]1\),
      SequenceForm[ "node = ", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("KF0F1"\[InvisibleSpace]" = 0"\),
      SequenceForm[ "KF0F1", " = 0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("node = "\[InvisibleSpace]2\),
      SequenceForm[ "node = ", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"KF0F1\"\>", "\[InvisibleSpace]", "\<\"=\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
                {"0", "1.2`", "0.1`", "0", \(-1.2`\), "0.1`", "0", "0", "0"},
                {"0", "0.1`", "0.13333333333333333`", 
                  "0", \(-0.1`\), \(-0.03333333333333333`\), "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
                {"0", \(-1.2`\), \(-0.1`\), "0", "1.2`", \(-0.1`\), "0", "0", 
                  "0"},
                {"0", "0.1`", \(-0.03333333333333333`\), "0", \(-0.1`\), 
                  "0.13333333333333333`", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0", "0", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}],
      SequenceForm[ "KF0F1", "=", 
        MatrixForm[ {{0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 1.2, 
          0.10000000000000001, 0, -1.2, 0.10000000000000001, 0, 0, 0}, {0, 
          0.10000000000000001, 0.13333333333333333, 
          0, -0.10000000000000001, -0.033333333333333333, 0, 0, 0}, {0, 0, 0, 
          0, 0, 0, 0, 0, 0}, {0, -1.2, -0.10000000000000001, 0, 
          1.2, -0.10000000000000001, 0, 0, 0}, {0, 
          0.10000000000000001, -0.033333333333333333, 0, -0.10000000000000001,
           0.13333333333333333, 0, 0, 0}, {0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 
          0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0, 0, 0, 0}}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("node = "\[InvisibleSpace]3\),
      SequenceForm[ "node = ", 3],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"KF0F1\"\>", "\[InvisibleSpace]", "\<\"=\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
                {"0", "1.2`", "0.1`", "0", \(-1.2`\), "0.1`", "0", "0", "0"},
                {"0", "0.1`", "0.13333333333333333`", 
                  "0", \(-0.1`\), \(-0.03333333333333333`\), "0", "0", "0"},
                {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
                {"0", \(-1.2`\), \(-0.1`\), "0", "2.4`", "0.`", 
                  "0", \(-1.2`\), "0.1`"},
                {"0", "0.1`", \(-0.03333333333333333`\), "0", "0.`", 
                  "0.26666666666666666`", 
                  "0", \(-0.1`\), \(-0.03333333333333333`\)},
                {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", \(-1.2`\), \(-0.1`\), "0", 
                  "1.2`", \(-0.1`\)},
                {"0", "0", "0", "0", "0.1`", \(-0.03333333333333333`\), 
                  "0", \(-0.1`\), "0.13333333333333333`"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}],
      SequenceForm[ "KF0F1", "=", 
        MatrixForm[ {{0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 1.2, 
          0.10000000000000001, 0, -1.2, 0.10000000000000001, 0, 0, 0}, {0, 
          0.10000000000000001, 0.13333333333333333, 
          0, -0.10000000000000001, -0.033333333333333333, 0, 0, 0}, {0, 0, 0, 
          0, 0, 0, 0, 0, 0}, {0, -1.2, -0.10000000000000001, 0, 
          2.3999999999999999, 0.0, 0, -1.2, 0.10000000000000001}, {0, 
          0.10000000000000001, -0.033333333333333333, 0, 0.0, 
          0.26666666666666666, 
          0, -0.10000000000000001, -0.033333333333333333}, {0, 0, 0, 0, 0, 0, 
          0, 0, 0}, {0, 0, 0, 0, -1.2, -0.10000000000000001, 0, 
          1.2, -0.10000000000000001}, {0, 0, 0, 0, 
          0.10000000000000001, -0.033333333333333333, 0, -0.10000000000000001,
           0.13333333333333333}}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("node = "\[InvisibleSpace]1\),
      SequenceForm[ "node = ", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("KF0F2"\[InvisibleSpace]" = 0"\),
      SequenceForm[ "KF0F2", " = 0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("node = "\[InvisibleSpace]2\),
      SequenceForm[ "node = ", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("KF0F2"\[InvisibleSpace]" = 0"\),
      SequenceForm[ "KF0F2", " = 0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("node = "\[InvisibleSpace]3\),
      SequenceForm[ "node = ", 3],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("KF0F2"\[InvisibleSpace]" = 0"\),
      SequenceForm[ "KF0F2", " = 0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("node = "\[InvisibleSpace]1\),
      SequenceForm[ "node = ", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("KF0M3"\[InvisibleSpace]" = 0"\),
      SequenceForm[ "KF0M3", " = 0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("node = "\[InvisibleSpace]2\),
      SequenceForm[ "node = ", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("KF0M3"\[InvisibleSpace]" = 0"\),
      SequenceForm[ "KF0M3", " = 0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("node = "\[InvisibleSpace]3\),
      SequenceForm[ "node = ", 3],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("KF0M3"\[InvisibleSpace]" = 0"\),
      SequenceForm[ "KF0M3", " = 0"],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1680}, {0, 989}},
WindowToolbars->"EditBar",
WindowSize->{913, 537},
WindowMargins->{{94, Automatic}, {124, Automatic}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {50.375, 72}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->False,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 188, 4, 97, "Title"],
Cell[1967, 59, 136, 4, 28, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2128, 67, 121, 2, 68, "Subtitle"],
Cell[2252, 71, 95, 1, 30, "Text"],

Cell[CellGroupData[{
Cell[2372, 76, 144, 2, 43, "Input"],
Cell[2519, 80, 73, 1, 27, "Output"]
}, Open  ]],
Cell[2607, 84, 56, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[2688, 88, 185, 7, 88, "Input"],
Cell[2876, 97, 67, 1, 27, "Output"]
}, Open  ]],
Cell[2958, 101, 49, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[3032, 105, 146, 6, 73, "Input"],
Cell[3181, 113, 50, 1, 27, "Output"]
}, Open  ]],
Cell[3246, 117, 100, 1, 30, "Text"],

Cell[CellGroupData[{
Cell[3371, 122, 65, 1, 27, "Input"],
Cell[3439, 125, 35, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3511, 131, 67, 1, 27, "Input"],
Cell[3581, 134, 35, 1, 27, "Output"]
}, Open  ]],
Cell[3631, 138, 486, 11, 234, "Text"],
Cell[4120, 151, 280, 7, 73, "Input"],
Cell[4403, 160, 205, 5, 48, "Text"],
Cell[4611, 167, 214, 6, 73, "Input"],
Cell[4828, 175, 155, 3, 30, "Text"],
Cell[4986, 180, 117, 2, 43, "Input"],
Cell[5106, 184, 46, 0, 30, "Text"],
Cell[5155, 186, 116, 2, 43, "Input"],
Cell[5274, 190, 208, 5, 46, "Text"],
Cell[5485, 197, 145, 5, 58, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5667, 207, 135, 5, 52, "Subtitle"],

Cell[CellGroupData[{
Cell[5827, 216, 95, 1, 28, "Subsubsection"],
Cell[5925, 219, 184, 5, 57, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6146, 229, 116, 2, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[6287, 235, 87, 1, 27, "Input"],
Cell[6377, 238, 137, 2, 23, "Print"],
Cell[6517, 242, 637, 11, 23, "Print"],
Cell[7157, 255, 137, 2, 23, "Print"],
Cell[7297, 259, 151, 2, 39, "Print"],
Cell[7451, 263, 3516, 96, 43, "Print"],
Cell[10970, 361, 3516, 96, 43, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14523, 462, 71, 1, 27, "Input"],
Cell[14597, 465, 137, 2, 23, "Print"],
Cell[14737, 469, 637, 11, 23, "Print"],
Cell[15377, 482, 137, 2, 23, "Print"],
Cell[15517, 486, 74, 1, 23, "Print"],
Cell[15594, 489, 980, 29, 23, "Print"],
Cell[16577, 520, 980, 29, 23, "Print"],
Cell[17560, 551, 980, 29, 23, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18589, 586, 79, 1, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[18693, 591, 71, 1, 27, "Input"],
Cell[18767, 594, 9256, 569, 56, 9138, 565, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[28084, 1170, 142, 5, 52, "Subtitle"],
Cell[28229, 1177, 40, 0, 30, "Text"],
Cell[28272, 1179, 78, 2, 27, "Input"],
Cell[28353, 1183, 70, 2, 30, "Text"],

Cell[CellGroupData[{
Cell[28448, 1189, 71, 1, 27, "Input"],
Cell[28522, 1192, 612, 15, 70, "Output"]
}, Open  ]],
Cell[29149, 1210, 64, 2, 30, "Text"],

Cell[CellGroupData[{
Cell[29238, 1216, 71, 1, 27, "Input"],
Cell[29312, 1219, 578, 13, 70, "Output"]
}, Open  ]],
Cell[29905, 1235, 38, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[29968, 1239, 71, 1, 27, "Input"],
Cell[30042, 1242, 942, 18, 70, "Output"]
}, Open  ]],
Cell[30999, 1263, 39, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[31063, 1267, 74, 1, 27, "Input"],
Cell[31140, 1270, 476, 12, 70, "Output"]
}, Open  ]],
Cell[31631, 1285, 41, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[31697, 1289, 80, 1, 27, "Input"],
Cell[31780, 1292, 558, 14, 70, "Output"]
}, Open  ]],
Cell[32353, 1309, 41, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[32419, 1313, 80, 1, 27, "Input"],
Cell[32502, 1316, 918, 18, 70, "Output"]
}, Open  ]],
Cell[33435, 1337, 41, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[33501, 1341, 80, 1, 27, "Input"],
Cell[33584, 1344, 690, 16, 70, "Output"]
}, Open  ]],
Cell[34289, 1363, 55, 2, 30, "Text"],

Cell[CellGroupData[{
Cell[34369, 1369, 71, 1, 27, "Input"],
Cell[34443, 1372, 1069, 22, 70, "Output"]
}, Open  ]],
Cell[35527, 1397, 65, 2, 30, "Text"],

Cell[CellGroupData[{
Cell[35617, 1403, 115, 2, 27, "Input"],
Cell[35735, 1407, 840, 18, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[36624, 1431, 147, 5, 54, "Subtitle"],
Cell[36774, 1438, 70, 1, 30, "Text"],

Cell[CellGroupData[{
Cell[36869, 1443, 63, 1, 27, "Input"],
Cell[36935, 1446, 35, 1, 70, "Output"]
}, Open  ]],
Cell[36985, 1450, 126, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[37136, 1458, 69, 1, 27, "Input"],
Cell[37208, 1461, 61, 1, 70, "Output"]
}, Open  ]],
Cell[37284, 1465, 117, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[37426, 1473, 113, 2, 27, "Input"],
Cell[37542, 1477, 698, 17, 70, "Print"],
Cell[38243, 1496, 698, 17, 70, "Print"]
}, Open  ]],
Cell[38956, 1516, 161, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[39142, 1524, 67, 1, 27, "Input"],
Cell[39212, 1527, 50, 1, 70, "Output"]
}, Open  ]],
Cell[39277, 1531, 106, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[39408, 1538, 121, 3, 27, "Input"],
Cell[39532, 1543, 1116, 22, 70, "Print"],
Cell[40651, 1567, 1116, 22, 70, "Print"]
}, Open  ]],
Cell[41782, 1592, 77, 1, 30, "Text"],

Cell[CellGroupData[{
Cell[41884, 1597, 100, 2, 27, "Input"],
Cell[41987, 1601, 1761, 32, 70, "Print"]
}, Open  ]],
Cell[43763, 1636, 82, 1, 30, "Text"],

Cell[CellGroupData[{
Cell[43870, 1641, 100, 2, 27, "Input"],
Cell[43973, 1645, 1667, 32, 70, "Print"]
}, Open  ]],
Cell[45655, 1680, 93, 1, 30, "Text"],

Cell[CellGroupData[{
Cell[45773, 1685, 120, 4, 27, "Input"],
Cell[45896, 1691, 679, 17, 70, "Print"]
}, Open  ]],
Cell[46590, 1711, 178, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[46793, 1719, 93, 1, 27, "Input"],
Cell[46889, 1722, 45, 1, 70, "Print"],
Cell[46937, 1725, 2772, 49, 70, "Print"]
}, Open  ]],
Cell[49724, 1777, 248, 6, 46, "Text"],

Cell[CellGroupData[{
Cell[49997, 1787, 103, 1, 27, "Input"],
Cell[50103, 1790, 56, 1, 70, "Print"],
Cell[50162, 1793, 3308, 57, 70, "Print"],
Cell[53473, 1852, 2709, 46, 70, "Print"]
}, Open  ]],
Cell[56197, 1901, 79, 1, 30, "Text"],

Cell[CellGroupData[{
Cell[56301, 1906, 81, 1, 27, "Input"],
Cell[56385, 1909, 550, 13, 70, "Print"]
}, Open  ]],
Cell[56950, 1925, 89, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[57064, 1932, 79, 1, 27, "Input"],
Cell[57146, 1935, 802, 17, 70, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57985, 1957, 44, 0, 42, "Subsubsection"],
Cell[58032, 1959, 277, 10, 142, "Text"],
Cell[58312, 1971, 256, 6, 46, "Text"],
Cell[58571, 1979, 128, 5, 62, "Text"],

Cell[CellGroupData[{
Cell[58724, 1988, 3217, 54, 443, "Input"],
Cell[61944, 2044, 213, 4, 70, "Print"],
Cell[62160, 2050, 231, 4, 70, "Print"],
Cell[62394, 2056, 302, 6, 70, "Print"],
Cell[62699, 2064, 2761, 48, 70, "Print"],
Cell[65463, 2114, 302, 6, 70, "Print"],
Cell[65768, 2122, 143, 3, 70, "Print"],
Cell[65914, 2127, 302, 6, 70, "Print"],
Cell[66219, 2135, 2553, 44, 70, "Print"],
Cell[68775, 2181, 302, 6, 70, "Print"],
Cell[69080, 2189, 159, 3, 70, "Print"],
Cell[69242, 2194, 137, 3, 70, "Print"],
Cell[69382, 2199, 143, 3, 70, "Print"],
Cell[69528, 2204, 137, 3, 70, "Print"],
Cell[69668, 2209, 1848, 34, 70, "Print"],
Cell[71519, 2245, 137, 3, 70, "Print"],
Cell[71659, 2250, 2208, 41, 70, "Print"],
Cell[73870, 2293, 137, 3, 70, "Print"],
Cell[74010, 2298, 143, 3, 70, "Print"],
Cell[74156, 2303, 137, 3, 70, "Print"],
Cell[74296, 2308, 143, 3, 70, "Print"],
Cell[74442, 2313, 137, 3, 70, "Print"],
Cell[74582, 2318, 143, 3, 70, "Print"],
Cell[74728, 2323, 137, 3, 70, "Print"],
Cell[74868, 2328, 143, 3, 70, "Print"],
Cell[75014, 2333, 137, 3, 70, "Print"],
Cell[75154, 2338, 143, 3, 70, "Print"],
Cell[75300, 2343, 137, 3, 70, "Print"],
Cell[75440, 2348, 143, 3, 70, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

