(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1496892,      62821]*)
(*NotebookOutlinePosition[   1497742,      62849]*)
(*  CellTagsIndexPosition[   1497698,      62845]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Solve a Eigenvalue Problem",
  FontSize->24]], "Title",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[1, 0.999985, 0.780011]],

Cell["\<\
COPYRIGHT Prof. Dr. Oskar Wallrapp, Fachhochschule Muenchen. Jan. \
2000\
\>", "Subsubtitle",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Setting up boundary conditions and load cases for geometric \
stiffening\
\>", "Subtitle",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[0.833356, 1, 0.8]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plotStructure[nE, nK, FEname, RK];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -113 0 ]
[.5 .17917 113 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -174 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 13.000 moveto
(D) show
81.000 13.000 moveto
(Balken) show
123.000 13.000 moveto
(2) show
135.000 13.000 moveto
(Elementen) show
189.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
201.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
213.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
225.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
255.000 13.000 moveto
(.2000) show
285.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 48},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000<2000`400?l00000o`00003ooooooolQ
ooooo`00F?ooool2o`0001?ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Boooo
o`?o00004_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`00017ooooo1Ol0001Ioooo
o`00Eoooool01?l0003oooooooooool0000Aooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`00000Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01ooo
ool01Ol0003ooooooooooooooooo0000017ooooo00Co0000oooooooooooo0000FOooool005Oooooo
00Co0000oooooooooooo00004Oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0FOooool005Oooooo00Co0000oooooooooooo00004Oooool01?l0
003oooooooooool0000;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0F?ooool0
05Oooooo00Co0000oooooooooooo00004Oooool01?l0003oooooooooool00007ooooo`Co00004ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo1?l0000Aooooo`05o`000?oo
ooooooooooooool00000FOooool005Oooooo00Co0000oooooooooooo00004Oooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo01?ooooo0_l0000Cooooo`;o00002Oooool00ol0003o
ooooooooo`0Booooo`05o`000?ooooooooooooooool00000FOooool005Sooooo0_l0000Cooooo`;o
00002?ooool5o`0001;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`Go
00004Oooool3o`0005[ooooo003oooooob7ooooo000iooooo`;o00001?ooool01?l0003ooooooooo
ooooool5o`000=Sooooo000hooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
0000f?ooool0037ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool00ooooon9o`0004cooooo000hooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooooooo
ool00_ooool2o`000003ooooool0003ooooo00Cooooo00?o0000ooooooooool00_ooool00ol00?oo
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`04o`000?oooooo0000o`0004cooooo000hooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000003ooooo`;o00003?ooool00ol00?ooooooooooo`1f
ooooo`;o0000C?ooool003Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000000?ooooo0_l0000<ooooo`03o`00oooooooooooo07Kooooo0_l0001<ooooo`00>Oooool2
o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Cooooo0_l0000<ooooo`03o`00oooooooo
oooo07Kooooo0_l0001<ooooo`00>?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooo
oooo00?ooooo0_l0000<ooooo`03o`00oooooooooooo07Kooooo0_l0001<ooooo`00<Oooool5o`00
00;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`;o00003?ooool0
0ol00?ooooooooooo`1[ooooo`;o003o00?oooooo`00ool00?l01_ooool2o`0004cooooo000hoooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool2o`0000cooooo00?o003o
ooooooooool0K?ooool00ol00?ooooooo`00o`07ooooo`;o0000C?ooool003Sooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`03ooooo`;o00003?ooool00ol00?ooooooooooo`1]
ooooo`03o`00oooooooooooo00Kooooo0_l0001<ooooo`00>?ooool01?l0003oooooooooool00008
ooooo`?o00001?ooool2o`0000cooooo00?o003oooooooooool0K?ooool00ol00?ooooooo`00o`07
ooooo`;o0000C?ooool003Wooooo0_l00009ooooo`;o000000?oooooo`000?ooool00_ooool2o`00
00cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0cooooo`05o`000?oooooo003o
o`00ooooool00_l00?l6ooooo`;o0000C?ooool004Cooooo00Co0000oooooooooooo00000oooool2
o`000003ooooool00?oo003o00So003oKol0000:o`00o`03ooooool0003o000004cooooo0014oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02_ooool00ol0003o003oo`00000c
ooooo`03o`000?oooooo000003?ooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`1:
ooooo`00A?ooool01?l0003oooooooooool00003ooooo`;o00003?ooool00ol0003o003oo`000002
o`00037ooooo1_l0000`ooooo`Co00002Oooool2o`0004cooooo000iooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`Co00000oooool2o`0000cooooo00Co003oooooool00?oo0000=?ooool0
1?l0003oooooooooool0000`ooooo`05o`000?ooooooooooooooool000002?ooool2o`0004cooooo
000hooooo`04o`000?ooooooooooo`0000Wooooo0_l00004ooooo`;o00003?ooool01?l00?oooooo
ooooool0000eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01_ooool2o`0004co
oooo000hooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool2o`0000co
oooo00Co003ooooooooooooo0000=_ooool00ol0003oooooooooo`0aooooo`;o00002Oooool2o`00
04cooooo000hooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool2o`00
00cooooo00Go003oooooool00?oo0000o`00o`0booooo`05o`000?ooooooooooooooool00000=?oo
ool00ol0003oooooooooo`06ooooo`;o0000C?ooool003Sooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`03ooooo`;o00003?ooool01Ol00?ooooooo`000?l0003o003o03;ooooo
00Go0000ooooooooooooooooo`00000`ooooo`05o`000?ooooooooooooooool000002?ooool2o`00
04cooooo000hooooo`04o`000?ooooooooooo`0000Sooooo0_l00005ooooo`;o00003?ooool3o`00
o`03o`000?l00?oo003o03;ooooo0ol0000booooo`?o00002Oooool2o`0004cooooo000iooooo`;o
00001?ooool01?l0003oooooooooooooool5o`0000?ooooo0_l0000<ooooo`03o`00oooooooooooo
07Kooooo0_l0001<ooooo`00>?ooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000?ooooo0_l0000<ooooo`03o`00oooooooooooo07Kooooo0_l0001<ooooo`00>?ooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo0_l000000ooooooo0000ooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooo`000?l0
001<ooooo`00>?ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00;oooooROl0
001<ooooo`00>?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
f?ooool003Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo00000=So
oooo000iooooo`;o00002Oooool3o`0005Wooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`1Uooooo`00XOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Cooooo000P
ooooo`Go000000?oooooo`000?l000000_l00008ooooo`Co00000oooool4o`000003ooooool0003o
000000?o000000Coooooo`000?l0003ooooo0_l00002ooooo`?o00000_ooool3o`000003ooooool0
003o000000Kooooo1Ol00007ooooo`Go000000?oooooo`000?l000000ol00002ooooo`?o00000_oo
ool01Ol0003oooooo`000?oooooo000000;ooooo0ol00002ooooo`?o000000?oooooo`000?l00000
0_ooool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`000?l000000oooool00ol0003ooooo
ooooo`07ooooo`?o00000oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Oooooo
0ol00003ooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0000Cooooo
00Co0000oooooooooooooooo1Ol00003ooooo`;o00001?ooool2o`0000Cooooo0_l0000Tooooo`00
8Oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooo
oooooooo0000ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000005ooooo`07o`000?oooooo0000ooooool0003oooooo`000006ooooo`04o`00
0?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`04o`000?oooooo
ooooo`0000gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo0000013ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002?o
oooo000Rooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00002ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`;o00000oooool5o`00
00;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Cooooo00Co0000oooooooooooooooo1Ol000001ooooooo0000ooooool0003oooooo`000?oo
ool01Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool5o`00
00;ooooo00Co0000oooooooooooo00003Oooool02ol0003ooooooooooooooooo0000ooooool0003o
ooooo`000?oooooo000000oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool0000Sooooo`008oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooooooo
ool01_ooool3o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000[ooooo00?o0000ooooooooool01oooool3o`0000Cooooo00Go0000oooooooooooooooo
o`000003ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000?ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool0000=ooooo`0;o`000?ooooooooooooooool0003oooooo`00
0?oooooo0000ooooool000003oooool00ol0003oooooooooo`03ooooo`;o00002Oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`0Qooooo`008?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00002ooooo`;o00001Oooool00ol0003oooooooooo`02oooo
o`04o`000?oooooo0000o`0000;ooooo0ol00002ooooo`Co00002?ooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`?o00000_oo
ool2o`000003ooooool0003ooooo00;ooooo0ol00002ooooo`Co00000_ooool4o`0000?ooooo0ol0
0002ooooo`Co00003oooool3o`0000;ooooo1_l0000>ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Oooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool0000Sooooo`008?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo0000
00Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo03?ooooo0_l00003ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003ooooooooo
ool00002ooooo`;o00002Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002?ooooo000Q
ooooo`?o00000_ooool4o`0000Sooooo1?l00008ooooo`?o00000oooool2o`0001Oooooo0ol00008
ooooo`Go000000Coooooo`000?l0003o00007?ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00;ooooo0ol0000:ooooo`;o00001?ooool00ol0003oooooooooo`08ooooo`?o00001?oo
ool2o`0000Cooooo0_l00004ooooo`;o00009?ooool00?oooooo8Oooool00?oooooo8Oooool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {47, 0}} -> {-1.66586, -0.4087, 0.0185775, \
0.0185775}}]
}, Open  ]],

Cell["Name of eigenvalue problem", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LoadName = "\<: Einspannung in 1:\>" FEName\)], "Input",
  Background->RGBColor[0.833356, 1, 0.8]],

Cell[BoxData[
    \("2D Balken 2 Elementen, ow, 13.01.2000"\ ": Einspannung in 1:"\)], \
"Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Lager = {{",
    FontFamily->"Courier"],
  "Node No. with restrictions",
  StyleBox[", Key-u1, Key-u2, Key-u3,Key-theta1, Key-theta2, Key-theta3}}, \n\
",
    FontFamily->"Courier"],
  "Key: 0 = free, 1 = motion is locked"
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Lager = {
         {1,  1,1,0, 0,0,0}
         } \
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[0.833356, 1, 0.8]],

Cell[BoxData[
    \({{1, 1, 1, 0, 0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell["\<\
Setup print key  (* 0 = no print of system matrices, 1 = print of \
matrices in simple form, 2 = print of matrices in matrix form*)\
\>", "Text"],

Cell["keyPrint = 0; ", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[0.833356, 1, 0.8]],

Cell["Setup key to normalize Me = I and border for eigensystem", "Text"],

Cell[BoxData[{
    \(\(keyNormal\  = \ 1;\)\), "\[IndentingNewLine]", 
    \(\(epsmass\  = \ 1*10^\(-6\);\)\)}], "Input"],

Cell["\<\
Setup key for geometric stiffening (* 0 = no geomtric stiffening \
matrices, 1 = consider geometric stiffening due to given loads*)\
\>", "Text"],

Cell["keyGeo   = 0; ", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[0.833356, 1, 0.8]],

Cell["\<\
If keyGeo = 1 than
Setting up load cases for geomtric stiffening matrices:\
\>", "Text"],

Cell[TextData[{
  "Setup loads at nodes: ",
  StyleBox["LastKnot = {{",
    FontFamily->"Courier"],
  "Node No. with load",
  StyleBox[", F1, F2, F3, M1, M2, M3}},\n",
    FontFamily->"Courier"],
  "Value of force F1, F2, F3; Torque M1, M2, M3 w.r.t. global frame"
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
LastKnot = {
            {3, 0,0,0, 0,0,0}
           } \
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[0.833356, 1, 0.8]],

Cell[BoxData[
    \({{3, 0, 0, 0, 0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Setup loads due to reference motion: ",
  StyleBox["LastRef = {a1,a2,a3, d\[Omega]1,d\[Omega]2,d\[Omega]3, \[Omega]1,\
\[Omega]2,\[Omega]3},\n",
    FontFamily->"Courier"],
  "Value of linear acceleration a1, a2, a3; angular acceleration ",
  StyleBox["d\[Omega]1,d\[Omega]2,d\[Omega]3",
    FontFamily->"Courier"],
  "; angular velocity ",
  StyleBox["\[Omega]1,\[Omega]2,\[Omega]3",
    FontFamily->"Courier"],
  " w.r.t. global frame\nNote: Gravity g = - a!"
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["LastRef = {0,0,0,  0,0,0,  0,0,6}", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  Background->RGBColor[0.833356, 1, 0.8]],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 6}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Solution - ",
  StyleBox["4. Computation of reduced system matrices",
    FontSize->18]
}], "Subtitle",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(nF\)], "Input"],

Cell[BoxData[
    \(9\)], "Output"]
}, Open  ]],

Cell["Evaluate number of locked state variables nR and IndR", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(IndR\  = \ evalIndr2D[nF, nfk, Lager];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("nR = "\[InvisibleSpace]2\[InvisibleSpace]", IndR = "\
\[InvisibleSpace]{1, 2}\),
      SequenceForm[ "nR = ", 2, ", IndR = ", {1, 2}],
      Editable->False]], "Print"]
}, Open  ]],

Cell["Evaluate number of reduced state variables nM and IndM", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(IndM\  = \ evalIndM[nF, nR, IndR];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("nM = "\[InvisibleSpace]7\[InvisibleSpace]", IndM = "\
\[InvisibleSpace]{3, 4, 5, 6, 7, 8, 9}\),
      SequenceForm[ "nM = ", 7, ", IndM = ", {3, 4, 5, 6, 7, 8, 9}],
      Editable->False]], "Print"]
}, Open  ]],

Cell["Evaluate load vector hF(nF)  due to nodal forces", "Text"],

Cell[BoxData[
    \(\(hF\  = \ evalhFnodal[nF, nfk, LastKnot, keyPrint];\)\)], "Input"],

Cell["\<\
Evaluate load vector hFref due to reference motion, keya = 0 and \
key\[Omega] = 0 and keyd\[Omega] = 0 means no lin. accel. no angular vel. and \
no angular accel., respecitively\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(hFref\  = \ 
        evalhFref[nF, LastRef, CFt0, CFr0T, OF0T, keyPrint];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("keya = "\[InvisibleSpace]0\[InvisibleSpace]", key\
\[Omega] = "\[InvisibleSpace]36\[InvisibleSpace]", keyd\[Omega] = "\
\[InvisibleSpace]0\),
      SequenceForm[ 
      "keya = ", 0, ", key\[Omega] = ", 36, ", keyd\[Omega] = ", 0],
      Editable->False]], "Print"]
}, Open  ]],

Cell["\<\
Evaluate \[Omega]-part und d\[Omega]-part in KFRef =  \
KFr1*d\[Omega]1 + KFr2* d\[Omega]2 + KFr3*d\[Omega]3 + KF\[Omega]i \
*\[Omega]qi,   i=1,6 \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(KFref\  = \ 
        evalKFref[nF, LastRef, KFr, OF, keyd\[Omega], key\[Omega], 
          keyPrint];\)\)], "Input"],

Cell[BoxData[
    \("KFRef = 0"\)], "Print"]
}, Open  ]],

Cell["\<\
Evaluate d\[Omega]-part in DFRef =  2 (KFr1 * \[Omega]1 + KFr2 * \
\[Omega]2 + KFr3 * \[Omega]3) \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DFref\  = \ 
        evalDFref[nF, LastRef, KFr, key\[Omega], keyPrint];\)\)], "Input"],

Cell[BoxData[
    \("DFRef = 0"\)], "Print"]
}, Open  ]],

Cell["\<\
Consideration of KFgeo due to loads if keyGeo = 1 \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(KFgeo\  = \ 
        evalgeost[nF, keyGeo, LastKnot, LastRef, KF0a1, KF0a2, KF0\[Omega]3, 
          KF0d\[Omega]3, KF0F1, KF0F2, KF0M3, IndKF0node, 
          keyPrint];\)\)], "Input"],

Cell[BoxData[
    \("KFgeo = 0"\)], "Print"]
}, Open  ]],

Cell["Sum of matrices", "Text"],

Cell["\<\
KFsum = Chop[KF + KFref + KFgeo];
DFsum = Chop[     DFref];
hFsum = Chop[hF + hFref];
\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Evaluate the minimal form due to boundary conditions", "Text"],

Cell[BoxData[{
    \(\(MFM = 
        transMMin[nM, IndM, MF\ \ \ \ \ \ \ \ , "\<MFM\>", 
          keyPrint];\)\), "\[IndentingNewLine]", 
    \(\(DFM = 
        transMMin[nM, IndM, DFsum, "\<DFM\>", 
          keyPrint];\)\), "\[IndentingNewLine]", 
    \(\(KFM = 
        transMMin[nM, IndM, KFsum, "\<KFM\>", 
          keyPrint];\)\), "\[IndentingNewLine]", 
    \(\(hFM = transhMin[nM, IndM, hFsum, "\<hFM\>", keyPrint];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Solution -",
  StyleBox[" 5.2 Evaluation of eigenvalues and eigenvectors of the undamped \
system",
    FontSize->18]
}], "Subtitle",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Solve freqEigen  = eigen natural frequencies in (Hz) and   zFEigen \
= eigenvectors, one per row   of the system MFM-1 . KFM;\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(\(zFEigen\  = \ 
        evalEigennoD[keyNormal, epsmass, MFM, KFM, nM, 
          0];\)\(\ \)\)\)], "Input"],

Cell["Print of natural frequencies undamped system", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(evfreq\  = \ 
      printEigen[LoadName, nM, freqEigen, modalmass, keyGeo]\)], "Input"],

Cell[BoxData[
    \("-----------------------------------------------------------------------\
-----------------------------"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\(\("2D Balken 2 Elementen, ow, 13.01.2000"\ ": \
Einspannung in 1:"\)\[InvisibleSpace]" with keyGeo = "\[InvisibleSpace]0\),
      SequenceForm[ 
        Times[ 
        "2D Balken 2 Elementen, ow, 13.01.2000", ": Einspannung in 1:"], 
        " with keyGeo = ", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("-----------------------------------------------------------------------\
-----------------------------"\)], "Print"],

Cell[BoxData[
    \("  No ! nat.frequ f(Hz) , angular frequ (rad/s) ! modal mass , modal \
stiffness !"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"   1\"\>",
            1,
            Editable->False],
          (PaddedForm[ #, 3]&)], "\[InvisibleSpace]", "\<\" ! \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          RowBox[{
            InterpretationBox["\<\"       0.0000\"\>",
              0.0,
              AutoDelete->True], "+", 
            RowBox[{
              InterpretationBox["\<\"       0.9549\"\>",
                0.95492965863376356,
                AutoDelete->True], " ", "\[ImaginaryI]"}]}],
          (PaddedForm[ #, {11, 4}]&)], "\[InvisibleSpace]", "\<\"  ,\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          RowBox[{
            InterpretationBox["\<\"         0.000\"\>",
              0.0,
              AutoDelete->True], "+", 
            RowBox[{
              InterpretationBox["\<\"         6.000\"\>",
                6.000000000517681,
                AutoDelete->True], " ", "\[ImaginaryI]"}]}],
          (PaddedForm[ #, {12, 3}]&)], 
        "\[InvisibleSpace]", "\<\"          !\"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"      1.000\"\>",
            1.0000000000000002,
            AutoDelete->True],
          (PaddedForm[ #, {9, 3}]&)], "\[InvisibleSpace]", "\<\" , \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          RowBox[{
            InterpretationBox["\<\"       -36.000\"\>",
              -36.000000006212183,
              AutoDelete->True], "+", 
            RowBox[{
              InterpretationBox["\<\"         0.000\"\>",
                0.0,
                AutoDelete->True], " ", "\[ImaginaryI]"}]}],
          (PaddedForm[ #, {12, 3}]&)], "\[InvisibleSpace]", "\<\"  !\"\>"}],
      SequenceForm[ 
        PaddedForm[ 1, 3], " ! ", 
        PaddedForm[ 
          Complex[ 0.0, 0.95492965863376356], {11, 4}], "  ,", 
        PaddedForm[ 
          Complex[ 0.0, 6.000000000517681], {12, 3}], "          !", 
        PaddedForm[ 1.0000000000000002, {9, 3}], " , ", 
        PaddedForm[ 
          Complex[ -36.000000006212183, 0.0], {12, 3}], "  !"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"   2\"\>",
            2,
            Editable->False],
          (PaddedForm[ #, 3]&)], "\[InvisibleSpace]", "\<\" ! \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"       7.6879\"\>",
            7.6878581494449305,
            AutoDelete->True],
          (PaddedForm[ #, {11, 4}]&)], "\[InvisibleSpace]", "\<\"  ,\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"        48.304\"\>",
            48.304237368273228,
            AutoDelete->True],
          (PaddedForm[ #, {12, 3}]&)], 
        "\[InvisibleSpace]", "\<\"          !\"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"      1.000\"\>",
            1.0,
            AutoDelete->True],
          (PaddedForm[ #, {9, 3}]&)], "\[InvisibleSpace]", "\<\" , \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"      2333.299\"\>",
            2333.2993477304835,
            AutoDelete->True],
          (PaddedForm[ #, {12, 3}]&)], "\[InvisibleSpace]", "\<\"  !\"\>"}],
      SequenceForm[ 
        PaddedForm[ 2, 3], " ! ", 
        PaddedForm[ 7.6878581494449305, {11, 4}], "  ,", 
        PaddedForm[ 48.304237368273228, {12, 3}], "          !", 
        PaddedForm[ 1.0, {9, 3}], " , ", 
        PaddedForm[ 2333.2993477304835, {12, 3}], "  !"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"   3\"\>",
            3,
            Editable->False],
          (PaddedForm[ #, 3]&)], "\[InvisibleSpace]", "\<\" ! \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"      27.8585\"\>",
            27.858463168216616,
            AutoDelete->True],
          (PaddedForm[ #, {11, 4}]&)], "\[InvisibleSpace]", "\<\"  ,\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"       175.040\"\>",
            175.03988645914231,
            AutoDelete->True],
          (PaddedForm[ #, {12, 3}]&)], 
        "\[InvisibleSpace]", "\<\"          !\"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"      1.000\"\>",
            1.0000000000000002,
            AutoDelete->True],
          (PaddedForm[ #, {9, 3}]&)], "\[InvisibleSpace]", "\<\" , \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     30638.962\"\>",
            30638.961851629439,
            AutoDelete->True],
          (PaddedForm[ #, {12, 3}]&)], "\[InvisibleSpace]", "\<\"  !\"\>"}],
      SequenceForm[ 
        PaddedForm[ 3, 3], " ! ", 
        PaddedForm[ 27.858463168216616, {11, 4}], "  ,", 
        PaddedForm[ 175.03988645914231, {12, 3}], "          !", 
        PaddedForm[ 1.0000000000000002, {9, 3}], " , ", 
        PaddedForm[ 30638.961851629439, {12, 3}], "  !"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"   4\"\>",
            4,
            Editable->False],
          (PaddedForm[ #, 3]&)], "\[InvisibleSpace]", "\<\" ! \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"      67.6842\"\>",
            67.684182068882322,
            AutoDelete->True],
          (PaddedForm[ #, {11, 4}]&)], "\[InvisibleSpace]", "\<\"  ,\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"       425.272\"\>",
            425.27225830366939,
            AutoDelete->True],
          (PaddedForm[ #, {12, 3}]&)], 
        "\[InvisibleSpace]", "\<\"          !\"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"      1.000\"\>",
            0.99999999999999978,
            AutoDelete->True],
          (PaddedForm[ #, {9, 3}]&)], "\[InvisibleSpace]", "\<\" , \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    180856.494\"\>",
            180856.49368270286,
            AutoDelete->True],
          (PaddedForm[ #, {12, 3}]&)], "\[InvisibleSpace]", "\<\"  !\"\>"}],
      SequenceForm[ 
        PaddedForm[ 4, 3], " ! ", 
        PaddedForm[ 67.684182068882322, {11, 4}], "  ,", 
        PaddedForm[ 425.27225830366939, {12, 3}], "          !", 
        PaddedForm[ 0.99999999999999978, {9, 3}], " , ", 
        PaddedForm[ 180856.49368270286, {12, 3}], "  !"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"   5\"\>",
            5,
            Editable->False],
          (PaddedForm[ #, 3]&)], "\[InvisibleSpace]", "\<\" ! \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     124.4483\"\>",
            124.44830148970156,
            AutoDelete->True],
          (PaddedForm[ #, {11, 4}]&)], "\[InvisibleSpace]", "\<\"  ,\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"       781.932\"\>",
            781.93173942354827,
            AutoDelete->True],
          (PaddedForm[ #, {12, 3}]&)], 
        "\[InvisibleSpace]", "\<\"          !\"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"      1.000\"\>",
            1.0000000000000002,
            AutoDelete->True],
          (PaddedForm[ #, {9, 3}]&)], "\[InvisibleSpace]", "\<\" , \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    611417.245\"\>",
            611417.24511793593,
            AutoDelete->True],
          (PaddedForm[ #, {12, 3}]&)], "\[InvisibleSpace]", "\<\"  !\"\>"}],
      SequenceForm[ 
        PaddedForm[ 5, 3], " ! ", 
        PaddedForm[ 124.44830148970156, {11, 4}], "  ,", 
        PaddedForm[ 781.93173942354827, {12, 3}], "          !", 
        PaddedForm[ 1.0000000000000002, {9, 3}], " , ", 
        PaddedForm[ 611417.24511793593, {12, 3}], "  !"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"   6\"\>",
            6,
            Editable->False],
          (PaddedForm[ #, 3]&)], "\[InvisibleSpace]", "\<\" ! \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     619.4205\"\>",
            619.42053423135383,
            AutoDelete->True],
          (PaddedForm[ #, {11, 4}]&)], "\[InvisibleSpace]", "\<\"  ,\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"      3891.934\"\>",
            3891.9339996477725,
            AutoDelete->True],
          (PaddedForm[ #, {12, 3}]&)], 
        "\[InvisibleSpace]", "\<\"          !\"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"      1.000\"\>",
            1.0000000000000002,
            AutoDelete->True],
          (PaddedForm[ #, {9, 3}]&)], "\[InvisibleSpace]", "\<\" , \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\("         1.515"\[Times]10\^"7"\),
            15147150.257614311,
            AutoDelete->True],
          (PaddedForm[ #, {12, 3}]&)], "\[InvisibleSpace]", "\<\"  !\"\>"}],
      SequenceForm[ 
        PaddedForm[ 6, 3], " ! ", 
        PaddedForm[ 619.42053423135383, {11, 4}], "  ,", 
        PaddedForm[ 3891.9339996477725, {12, 3}], "          !", 
        PaddedForm[ 1.0000000000000002, {9, 3}], " , ", 
        PaddedForm[ 15147150.257614311, {12, 3}], "  !"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          InterpretationBox["\<\"   7\"\>",
            7,
            Editable->False],
          (PaddedForm[ #, 3]&)], "\[InvisibleSpace]", "\<\" ! \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"    2163.8797\"\>",
            2163.8797471458834,
            AutoDelete->True],
          (PaddedForm[ #, {11, 4}]&)], "\[InvisibleSpace]", "\<\"  ,\"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"     13596.057\"\>",
            13596.057433770493,
            AutoDelete->True],
          (PaddedForm[ #, {12, 3}]&)], 
        "\[InvisibleSpace]", "\<\"          !\"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"      1.000\"\>",
            0.99999999999999989,
            AutoDelete->True],
          (PaddedForm[ #, {9, 3}]&)], "\[InvisibleSpace]", "\<\" , \"\>", 
        "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\("         1.849"\[Times]10\^"8"\),
            184852777.74238586,
            AutoDelete->True],
          (PaddedForm[ #, {12, 3}]&)], "\[InvisibleSpace]", "\<\"  !\"\>"}],
      SequenceForm[ 
        PaddedForm[ 7, 3], " ! ", 
        PaddedForm[ 2163.8797471458834, {11, 4}], "  ,", 
        PaddedForm[ 13596.057433770493, {12, 3}], "          !", 
        PaddedForm[ 0.99999999999999989, {9, 3}], " , ", 
        PaddedForm[ 184852777.74238586, {12, 3}], "  !"],
      Editable->False]], "Print"]
}, Open  ]],

Cell["\<\
Plot of eigenmodes with scaling factor, noevgraf = numbers of \
plotted modes\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\(noevgraf = {1, 2, 3, 4, 5, 6};\)\[IndentingNewLine]
    \(plotUeEigen[LoadName, Ne, \[CapitalGamma]e, TeT, Edata, nE, IndR, nR, 
        zFEigen, ZF0, 1, noevgraf];\)\)\(\ \)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .7166 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.29142 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .09301 -24 -4.5 ]
[-0.0125 .09301 0 4.5 ]
[-0.0125 .19221 -30 -4.5 ]
[-0.0125 .19221 0 4.5 ]
[-0.0125 .29142 -6 -4.5 ]
[-0.0125 .29142 0 4.5 ]
[-0.0125 .39063 -24 -4.5 ]
[-0.0125 .39063 0 4.5 ]
[-0.0125 .48983 -18 -4.5 ]
[-0.0125 .48983 0 4.5 ]
[-0.0125 .58904 -24 -4.5 ]
[-0.0125 .58904 0 4.5 ]
[-0.0125 .68825 -6 -4.5 ]
[-0.0125 .68825 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .7166 .125 0 ]
[ 1 0 .125 0 ]
[.5 .7291 -225.875 0 ]
[.5 .7291 225.875 12 ]
[.93651 .26497 -5 -6 ]
[.93651 .26497 5 6 ]
[.12963 .3311 -5 -6 ]
[.12963 .3311 5 6 ]
[.12963 .31788 -3 -4.5 ]
[.12963 .31788 3 4.5 ]
[.52646 .31788 -3 -4.5 ]
[.52646 .31788 3 4.5 ]
[.92328 .31788 -3 -4.5 ]
[.92328 .31788 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .7166 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09301 m
.00625 .09301 L
s
[(-0.5)] -0.0125 .09301 1 0 Mshowa
0 .19221 m
.00625 .19221 L
s
[(-0.25)] -0.0125 .19221 1 0 Mshowa
0 .29142 m
.00625 .29142 L
s
[(0)] -0.0125 .29142 1 0 Mshowa
0 .39063 m
.00625 .39063 L
s
[(0.25)] -0.0125 .39063 1 0 Mshowa
0 .48983 m
.00625 .48983 L
s
[(0.5)] -0.0125 .48983 1 0 Mshowa
0 .58904 m
.00625 .58904 L
s
[(0.75)] -0.0125 .58904 1 0 Mshowa
0 .68825 m
.00625 .68825 L
s
[(1)] -0.0125 .68825 1 0 Mshowa
.125 Mabswid
0 .11285 m
.00375 .11285 L
s
0 .13269 m
.00375 .13269 L
s
0 .15253 m
.00375 .15253 L
s
0 .17237 m
.00375 .17237 L
s
0 .21206 m
.00375 .21206 L
s
0 .2319 m
.00375 .2319 L
s
0 .25174 m
.00375 .25174 L
s
0 .27158 m
.00375 .27158 L
s
0 .31126 m
.00375 .31126 L
s
0 .3311 m
.00375 .3311 L
s
0 .35094 m
.00375 .35094 L
s
0 .37079 m
.00375 .37079 L
s
0 .41047 m
.00375 .41047 L
s
0 .43031 m
.00375 .43031 L
s
0 .45015 m
.00375 .45015 L
s
0 .46999 m
.00375 .46999 L
s
0 .50967 m
.00375 .50967 L
s
0 .52952 m
.00375 .52952 L
s
0 .54936 m
.00375 .54936 L
s
0 .5692 m
.00375 .5692 L
s
0 .60888 m
.00375 .60888 L
s
0 .62872 m
.00375 .62872 L
s
0 .64856 m
.00375 .64856 L
s
0 .6684 m
.00375 .6684 L
s
0 .07317 m
.00375 .07317 L
s
0 .05332 m
.00375 .05332 L
s
0 .03348 m
.00375 .03348 L
s
0 .01364 m
.00375 .01364 L
s
0 .70809 m
.00375 .70809 L
s
.25 Mabswid
0 0 m
0 .7166 L
s
.10317 .71035 m
.10317 .7166 L
s
.30159 .71035 m
.30159 .7166 L
s
.5 .71035 m
.5 .7166 L
s
.69841 .71035 m
.69841 .7166 L
s
.89683 .71035 m
.89683 .7166 L
s
.125 Mabswid
.14286 .71285 m
.14286 .7166 L
s
.18254 .71285 m
.18254 .7166 L
s
.22222 .71285 m
.22222 .7166 L
s
.2619 .71285 m
.2619 .7166 L
s
.34127 .71285 m
.34127 .7166 L
s
.38095 .71285 m
.38095 .7166 L
s
.42063 .71285 m
.42063 .7166 L
s
.46032 .71285 m
.46032 .7166 L
s
.53968 .71285 m
.53968 .7166 L
s
.57937 .71285 m
.57937 .7166 L
s
.61905 .71285 m
.61905 .7166 L
s
.65873 .71285 m
.65873 .7166 L
s
.7381 .71285 m
.7381 .7166 L
s
.77778 .71285 m
.77778 .7166 L
s
.81746 .71285 m
.81746 .7166 L
s
.85714 .71285 m
.85714 .7166 L
s
.06349 .71285 m
.06349 .7166 L
s
.02381 .71285 m
.02381 .7166 L
s
.93651 .71285 m
.93651 .7166 L
s
.97619 .71285 m
.97619 .7166 L
s
.25 Mabswid
0 .7166 m
1 .7166 L
s
.99375 .09301 m
1 .09301 L
s
.99375 .19221 m
1 .19221 L
s
.99375 .29142 m
1 .29142 L
s
.99375 .39063 m
1 .39063 L
s
.99375 .48983 m
1 .48983 L
s
.99375 .58904 m
1 .58904 L
s
.99375 .68825 m
1 .68825 L
s
.125 Mabswid
.99625 .11285 m
1 .11285 L
s
.99625 .13269 m
1 .13269 L
s
.99625 .15253 m
1 .15253 L
s
.99625 .17237 m
1 .17237 L
s
.99625 .21206 m
1 .21206 L
s
.99625 .2319 m
1 .2319 L
s
.99625 .25174 m
1 .25174 L
s
.99625 .27158 m
1 .27158 L
s
.99625 .31126 m
1 .31126 L
s
.99625 .3311 m
1 .3311 L
s
.99625 .35094 m
1 .35094 L
s
.99625 .37079 m
1 .37079 L
s
.99625 .41047 m
1 .41047 L
s
.99625 .43031 m
1 .43031 L
s
.99625 .45015 m
1 .45015 L
s
.99625 .46999 m
1 .46999 L
s
.99625 .50967 m
1 .50967 L
s
.99625 .52952 m
1 .52952 L
s
.99625 .54936 m
1 .54936 L
s
.99625 .5692 m
1 .5692 L
s
.99625 .60888 m
1 .60888 L
s
.99625 .62872 m
1 .62872 L
s
.99625 .64856 m
1 .64856 L
s
.99625 .6684 m
1 .6684 L
s
.99625 .07317 m
1 .07317 L
s
.99625 .05332 m
1 .05332 L
s
.99625 .03348 m
1 .03348 L
s
.99625 .01364 m
1 .01364 L
s
.99625 .70809 m
1 .70809 L
s
.25 Mabswid
1 0 m
1 .7166 L
s
gsave
.5 .7291 -286.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
84.562 13.000 moveto
0.000 0.000 rmoveto
84.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
120.562 13.000 moveto
(modes) show
150.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
156.562 13.000 moveto
0.000 0.000 rmoveto
156.562 13.000 moveto
(,) show
166.125 13.000 moveto
0.000 0.000 rmoveto
166.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
172.125 13.000 moveto
(D) show
184.125 13.000 moveto
(Balken) show
226.125 13.000 moveto
(2) show
238.125 13.000 moveto
(Elementen) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
328.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
358.125 13.000 moveto
(.2000) show
388.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
390.750 13.000 moveto
0.000 0.000 rmoveto
390.750 13.000 moveto
(:) show
402.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
474.750 13.000 moveto
(in) show
492.750 13.000 moveto
(1) show
498.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
504.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
504.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .29142 m
.97619 .29142 L
s
.10317 .21206 m
.10317 .37079 L
s
.10317 .29142 m
.10317 .29142 .00794 0 365.73 arc
F
gsave
.93651 .26497 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .3311 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .31788 0 0 Mshowa
[(2)] .52646 .31788 0 0 Mshowa
[(3)] .92328 .31788 0 0 Mshowa
newpath
.10317 .29142 .00794 0 365.73 arc
s
newpath
.5 .29142 .00794 0 365.73 arc
s
newpath
.89683 .29142 .00794 0 365.73 arc
s
.10317 .29142 m
.5 .29142 L
s
.5 .29142 m
.89683 .29142 L
s
.167 0 0 r
.10317 .29142 m
.11927 .29566 L
.13683 .30029 L
.15332 .30463 L
.16917 .30881 L
.18605 .31326 L
.2023 .31754 L
.21957 .32209 L
.23621 .32648 L
.25221 .33069 L
.26924 .33518 L
.28564 .3395 L
.3014 .34366 L
.31819 .34808 L
.33434 .35234 L
.35152 .35686 L
.36806 .36122 L
.38398 .36542 L
.40091 .36988 L
.41722 .37418 L
.43454 .37874 L
.45124 .38314 L
.4673 .38738 L
.48439 .39188 L
.5 .39599 L
s
.5 .39599 m
.5161 .40024 L
.53365 .40486 L
.55014 .40921 L
.566 .41339 L
.58288 .41783 L
.59913 .42211 L
.61639 .42667 L
.63303 .43105 L
.64904 .43527 L
.66607 .43975 L
.68246 .44408 L
.69823 .44823 L
.71501 .45265 L
.73117 .45691 L
.74834 .46144 L
.76489 .4658 L
.7808 .46999 L
.79774 .47445 L
.81404 .47875 L
.83137 .48332 L
.84806 .48772 L
.86413 .49195 L
.88121 .49645 L
.89683 .50057 L
s
.333 0 0 r
.10317 .29142 m
.11927 .27817 L
.13683 .26402 L
.15332 .25107 L
.16917 .23898 L
.18605 .22656 L
.2023 .21508 L
.21957 .20346 L
.23621 .19287 L
.25221 .18331 L
.26924 .17386 L
.28564 .16551 L
.3014 .15823 L
.31819 .15133 L
.33434 .14557 L
.35152 .14046 L
.36806 .13657 L
.38398 .13383 L
.39217 .13282 L
.39673 .13238 L
.40091 .13206 L
.4052 .1318 L
.40745 .1317 L
.40983 .13161 L
.41083 .13158 L
.41191 .13156 L
.41283 .13154 L
.41384 .13152 L
.41445 .13152 L
.41502 .13151 L
.41557 .13151 L
.41584 .13151 L
.41614 .1315 L
.41666 .1315 L
.41696 .1315 L
.41722 .1315 L
.41772 .13151 L
.41824 .13151 L
.41875 .13151 L
.41931 .13152 L
.42032 .13153 L
.42131 .13155 L
.42222 .13157 L
.42428 .13163 L
.42646 .13172 L
.43011 .13191 L
.43412 .13219 L
.44222 .13298 L
.45093 .13419 L
.45975 .13578 L
Mistroke
.46812 .13765 L
.48406 .1422 L
.5 .14808 L
Mfstroke
.5 .14808 m
.5161 .15528 L
.53365 .1644 L
.55014 .17412 L
.566 .18446 L
.58288 .19648 L
.59913 .20898 L
.61639 .22322 L
.63303 .23779 L
.64904 .25256 L
.66607 .269 L
.68246 .28551 L
.69823 .30194 L
.71501 .31998 L
.73117 .33783 L
.74834 .35727 L
.76489 .37638 L
.7808 .39507 L
.79774 .41523 L
.81404 .43485 L
.83137 .45586 L
.84806 .4762 L
.86413 .49582 L
.88121 .51666 L
.89683 .53564 L
s
.5 0 0 r
.10317 .29142 m
.11927 .32232 L
.13683 .35211 L
.15332 .37646 L
.16917 .39666 L
.18605 .41476 L
.2023 .42898 L
.21957 .44072 L
.22822 .44534 L
.23621 .44886 L
.24398 .45162 L
.24794 .45277 L
.25221 .45383 L
.25646 .45468 L
.26035 .4553 L
.26222 .45554 L
.26426 .45576 L
.26605 .45592 L
.26798 .45605 L
.26913 .45612 L
.27019 .45616 L
.2712 .45619 L
.27172 .4562 L
.272 .45621 L
.27228 .45621 L
.27278 .45622 L
.27325 .45622 L
.27375 .45622 L
.27429 .45622 L
.27477 .45622 L
.27527 .45621 L
.2757 .4562 L
.27617 .45619 L
.27731 .45616 L
.27834 .45612 L
.28068 .45598 L
.28274 .45581 L
.28491 .45559 L
.28889 .45506 L
.29314 .45433 L
.30079 .45255 L
.30968 .44978 L
.31808 .44647 L
.33411 .43834 L
.35116 .42714 L
.36758 .41398 L
.38336 .39919 L
.40017 .38124 L
.41635 .36191 L
.43355 .33923 L
Mistroke
.45011 .31541 L
.46605 .29075 L
.48301 .26272 L
.49933 .23408 L
.5 .23288 L
Mfstroke
.5 .23288 m
.5161 .20604 L
.53365 .18175 L
.55014 .16351 L
.566 .15002 L
.57484 .14416 L
.58288 .13985 L
.59123 .13637 L
.59913 .134 L
.60316 .13313 L
.60538 .13275 L
.60745 .13246 L
.60936 .13224 L
.6111 .13208 L
.61203 .13202 L
.61304 .13196 L
.6136 .13193 L
.61411 .13191 L
.6146 .1319 L
.61513 .13188 L
.61567 .13187 L
.61596 .13187 L
.61623 .13187 L
.61672 .13186 L
.61725 .13187 L
.61754 .13187 L
.61786 .13187 L
.61816 .13188 L
.61844 .13188 L
.61897 .1319 L
.61953 .13191 L
.62055 .13196 L
.62151 .13201 L
.62368 .13218 L
.62563 .13239 L
.62741 .13262 L
.63143 .13329 L
.63552 .13419 L
.63932 .13523 L
.64795 .13825 L
.65647 .14214 L
.66421 .14645 L
.68087 .15811 L
.6969 .17231 L
.71395 .19045 L
.73037 .21074 L
.74615 .23272 L
.76296 .25862 L
.77914 .28584 L
.79634 .31709 L
Mistroke
.8129 .34928 L
.82884 .38203 L
.8458 .41867 L
.86212 .45551 L
.87947 .4962 L
.89619 .53674 L
.89683 .53831 L
Mfstroke
.667 0 0 r
.10317 .29142 m
.11927 .35579 L
.13683 .41002 L
.14536 .43077 L
.15332 .44699 L
.16147 .46064 L
.16917 .47089 L
.17325 .47531 L
.17768 .47936 L
.18168 .48235 L
.18542 .4846 L
.18935 .48641 L
.19144 .48714 L
.19369 .48775 L
.19481 .48799 L
.19603 .48821 L
.19719 .48836 L
.19774 .48842 L
.19826 .48846 L
.19877 .4885 L
.19904 .48851 L
.19933 .48852 L
.19983 .48854 L
.20029 .48855 L
.20082 .48855 L
.20132 .48854 L
.20186 .48852 L
.20217 .4885 L
.20245 .48849 L
.2034 .48841 L
.20445 .4883 L
.20555 .48814 L
.20658 .48795 L
.20842 .48754 L
.2104 .48697 L
.21491 .48524 L
.21905 .48313 L
.22694 .47777 L
.23556 .47003 L
.25246 .44981 L
.26873 .42498 L
.28602 .39409 L
.30268 .36117 L
.31871 .32769 L
.33576 .29134 L
.35218 .25679 L
.36796 .22507 L
.38477 .19406 L
.40095 .16803 L
.40918 .15658 L
Mistroke
.41815 .1457 L
.42684 .13692 L
.43471 .13061 L
.43866 .12807 L
.44293 .12583 L
.44527 .12482 L
.44743 .12404 L
.44948 .12343 L
.45167 .12292 L
.45276 .12272 L
.4538 .12257 L
.45473 .12246 L
.45521 .12242 L
.45574 .12238 L
.45623 .12235 L
.45669 .12233 L
.45718 .12231 L
.45771 .12231 L
.45817 .12231 L
.45866 .12232 L
.45907 .12234 L
.45953 .12236 L
.46011 .1224 L
.46066 .12245 L
.46169 .12257 L
.4628 .12273 L
.46399 .12296 L
.46616 .1235 L
.46814 .12414 L
.47219 .12589 L
.47598 .12807 L
.48458 .13507 L
.49264 .14433 L
.5 .15516 L
Mfstroke
.5 .15516 m
.5161 .18185 L
.53365 .21156 L
.55014 .23955 L
.566 .26609 L
.58288 .29348 L
.59913 .31854 L
.61639 .34328 L
.63303 .36476 L
.64904 .38281 L
.66607 .39871 L
.67453 .40518 L
.68246 .41032 L
.69054 .41457 L
.69823 .41764 L
.70226 .41886 L
.70439 .41939 L
.70666 .41987 L
.70876 .42023 L
.71066 .42049 L
.71158 .42059 L
.71258 .42068 L
.71352 .42075 L
.71438 .4208 L
.71485 .42082 L
.71537 .42084 L
.71591 .42086 L
.71643 .42087 L
.71691 .42087 L
.71742 .42087 L
.71786 .42086 L
.71834 .42085 L
.71862 .42085 L
.7189 .42084 L
.71942 .42082 L
.72058 .42075 L
.72159 .42068 L
.72269 .42057 L
.72489 .42029 L
.72724 .41989 L
.73147 .41888 L
.73573 .4175 L
.74036 .41557 L
.74876 .41091 L
.75704 .40479 L
.76581 .39659 L
.78159 .37716 L
.7984 .34949 L
.81458 .3156 L
.83178 .27127 L
Mistroke
.84834 .21998 L
.86428 .16227 L
.88124 .09134 L
.89683 .01706 L
Mfstroke
.833 0 0 r
.10317 .29142 m
.11927 .33914 L
.12765 .35884 L
.13683 .37664 L
.14546 .38998 L
.15332 .3994 L
.16147 .40658 L
.16596 .40947 L
.16797 .41053 L
.1702 .41153 L
.17214 .41226 L
.17424 .4129 L
.17539 .4132 L
.17645 .41342 L
.17752 .41362 L
.17852 .41376 L
.17943 .41387 L
.1804 .41395 L
.18096 .41399 L
.18148 .41401 L
.18195 .41402 L
.18246 .41403 L
.18291 .41403 L
.18341 .41402 L
.18392 .414 L
.18441 .41398 L
.18486 .41395 L
.18527 .41392 L
.1862 .41383 L
.18715 .41371 L
.1882 .41354 L
.19033 .41311 L
.1923 .41259 L
.19415 .41201 L
.19832 .41034 L
.2028 .40801 L
.21115 .40234 L
.21995 .39461 L
.23582 .37671 L
.25272 .35317 L
.26899 .3274 L
.28628 .29803 L
.30294 .26916 L
.31897 .24208 L
.33602 .21536 L
.35244 .19293 L
.36822 .17561 L
.37633 .1687 L
.38503 .16301 L
.38925 .16095 L
Mistroke
.39148 .16005 L
.39386 .15925 L
.39614 .15863 L
.3982 .1582 L
.3992 .15804 L
.40028 .1579 L
.40077 .15785 L
.4013 .1578 L
.40178 .15776 L
.40223 .15773 L
.40274 .15771 L
.40301 .1577 L
.4033 .15769 L
.40378 .15768 L
.4043 .15768 L
.40477 .15769 L
.40528 .15771 L
.40575 .15773 L
.40619 .15776 L
.40718 .15784 L
.40826 .15797 L
.40938 .15814 L
.41043 .15834 L
.41413 .15934 L
.4162 .1601 L
.41807 .16092 L
.42608 .16583 L
.4306 .16966 L
.43476 .17388 L
.44325 .18469 L
.4512 .19756 L
.467 .23173 L
.4832 .2795 L
.5 .34398 L
Mfstroke
.5 .34398 m
.50784 .37529 L
.5161 .40304 L
.52519 .42766 L
.53365 .44533 L
.54132 .45721 L
.54561 .46225 L
.54951 .46586 L
.55152 .46738 L
.55366 .46873 L
.5555 .46969 L
.55749 .47051 L
.5586 .47087 L
.55962 .47115 L
.56065 .47138 L
.56161 .47153 L
.56215 .4716 L
.56272 .47166 L
.56305 .47168 L
.56336 .4717 L
.56364 .47171 L
.56394 .47172 L
.5642 .47172 L
.5645 .47172 L
.5648 .47171 L
.56509 .4717 L
.5656 .47168 L
.56615 .47163 L
.56666 .47158 L
.56722 .4715 L
.56835 .47131 L
.5694 .47106 L
.57039 .47079 L
.57261 .47 L
.575 .46889 L
.57937 .4662 L
.58338 .46299 L
.59127 .45476 L
.59989 .44308 L
.61679 .4133 L
.63306 .37787 L
.65035 .33537 L
.66701 .29207 L
.68304 .2504 L
.70009 .20839 L
.71651 .17246 L
.73229 .14417 L
.7404 .13269 L
.7491 .12303 L
.75332 .11945 L
Mistroke
.75555 .11787 L
.75792 .11642 L
.7602 .11527 L
.76227 .11444 L
.76327 .11411 L
.76435 .11381 L
.76537 .11357 L
.7663 .1134 L
.76729 .11327 L
.76784 .11322 L
.76835 .11318 L
.76883 .11316 L
.76927 .11315 L
.76976 .11316 L
.77027 .11317 L
.77079 .1132 L
.77107 .11322 L
.77134 .11325 L
.77234 .11337 L
.77287 .11346 L
.77345 .11357 L
.77462 .11385 L
.77683 .11458 L
.77918 .11565 L
.78341 .11836 L
.78768 .12216 L
.79232 .12752 L
.80072 .14069 L
.80902 .15832 L
.81779 .18227 L
.8336 .24027 L
.85043 .32489 L
.86663 .43077 L
.88385 .57202 L
.89683 .69954 L
Mfstroke
1 0 0 r
.10317 .29142 m
.10351 .29142 L
.10381 .29142 L
.10416 .29142 L
.10449 .29142 L
.1048 .29142 L
.10508 .29142 L
.10539 .29142 L
.10572 .29142 L
.10605 .29142 L
.1064 .29142 L
.10674 .29142 L
.10704 .29142 L
.1074 .29142 L
.1076 .29142 L
.10779 .29142 L
.10813 .29142 L
.1085 .29142 L
.10869 .29142 L
.10888 .29142 L
.10923 .29142 L
.10942 .29142 L
.1096 .29142 L
.1098 .29142 L
.11002 .29142 L
.1102 .29142 L
.1104 .29142 L
.11076 .29142 L
.11112 .29142 L
.11145 .29142 L
.11176 .29142 L
.11206 .29142 L
.11239 .29142 L
.11274 .29142 L
.11309 .29142 L
.11346 .29142 L
.11377 .29142 L
.11412 .29142 L
.11432 .29142 L
.1145 .29142 L
.11471 .29142 L
.11492 .29142 L
.11528 .29142 L
.11549 .29142 L
.11568 .29142 L
.11604 .29142 L
.11637 .29142 L
.11655 .29142 L
.11675 .29142 L
.1171 .29142 L
Mistroke
.11732 .29142 L
.11753 .29142 L
.11771 .29142 L
.11791 .29142 L
.11812 .29142 L
.11835 .29142 L
.11855 .29142 L
.11876 .29142 L
.11896 .29142 L
.11915 .29142 L
.11936 .29142 L
.11956 .29142 L
.11991 .29142 L
.12011 .29142 L
.1203 .29142 L
.12063 .29142 L
.12098 .29142 L
.12132 .29142 L
.12162 .29142 L
.12197 .29142 L
.12234 .29142 L
.12253 .29142 L
.12273 .29142 L
.12309 .29142 L
.12329 .29142 L
.12347 .29142 L
.12367 .29142 L
.12389 .29142 L
.12425 .29142 L
.12445 .29142 L
.12464 .29142 L
.125 .29142 L
.12532 .29142 L
.12569 .29142 L
.12605 .29142 L
.12637 .29142 L
.12672 .29142 L
.12704 .29142 L
.12735 .29142 L
.12768 .29142 L
.12804 .29142 L
.12823 .29142 L
.12842 .29142 L
.12878 .29142 L
.12897 .29142 L
.12915 .29142 L
.12935 .29142 L
.12956 .29142 L
.12991 .29142 L
.13011 .29142 L
Mistroke
.1303 .29142 L
.13065 .29142 L
.13096 .29142 L
.13133 .29142 L
.13168 .29142 L
.13201 .29142 L
.13231 .29142 L
.13265 .29142 L
.13297 .29142 L
.13327 .29142 L
.13355 .29142 L
.13385 .29142 L
.13417 .29142 L
.1345 .29142 L
.13484 .29142 L
.13517 .29142 L
.13547 .29142 L
.13582 .29142 L
.13602 .29142 L
.1362 .29142 L
.13654 .29142 L
.13689 .29142 L
.13722 .29142 L
.13757 .29142 L
.13794 .29142 L
.13828 .29142 L
.1386 .29142 L
.13889 .29142 L
.13923 .29142 L
.13955 .29142 L
.1399 .29142 L
.14027 .29142 L
.14058 .29142 L
.14092 .29142 L
.14129 .29142 L
.1415 .29142 L
.14169 .29142 L
.14206 .29142 L
.14241 .29142 L
.14274 .29142 L
.14304 .29142 L
.14338 .29142 L
.1437 .29142 L
.144 .29142 L
.14427 .29142 L
.14457 .29142 L
.14489 .29142 L
.14521 .29142 L
.14556 .29142 L
.14588 .29142 L
Mistroke
.14618 .29142 L
.14653 .29142 L
.14672 .29142 L
.1469 .29142 L
.14724 .29142 L
.14759 .29142 L
.14793 .29142 L
.1483 .29142 L
.14865 .29142 L
.14898 .29142 L
.1493 .29142 L
.1496 .29142 L
.14994 .29142 L
.15025 .29142 L
.1506 .29142 L
.15097 .29142 L
.15129 .29142 L
.15163 .29142 L
.152 .29142 L
.15221 .29142 L
.1524 .29142 L
.15277 .29142 L
.15312 .29142 L
.15342 .29142 L
.15374 .29142 L
.15409 .29142 L
.15441 .29142 L
.15471 .29142 L
.15498 .29142 L
.15528 .29142 L
.1556 .29142 L
.15592 .29142 L
.15627 .29142 L
.1566 .29142 L
.15689 .29142 L
.15724 .29142 L
.15744 .29142 L
.15762 .29142 L
.15795 .29142 L
.1583 .29142 L
.15864 .29142 L
.15902 .29142 L
.15937 .29142 L
.1597 .29142 L
.16002 .29142 L
.16031 .29142 L
.16065 .29142 L
.16097 .29142 L
.16132 .29142 L
.16169 .29142 L
Mistroke
.16201 .29142 L
.16235 .29142 L
.16272 .29142 L
.16293 .29142 L
.16312 .29142 L
.16349 .29142 L
.16384 .29142 L
.16414 .29142 L
.16447 .29142 L
.16481 .29142 L
.16513 .29142 L
.16543 .29142 L
.16571 .29142 L
.16601 .29142 L
.16633 .29142 L
.16665 .29142 L
.167 .29142 L
.16732 .29142 L
.16762 .29142 L
.16797 .29142 L
.16816 .29142 L
.16834 .29142 L
.16868 .29142 L
.16903 .29142 L
.16937 .29142 L
.16975 .29142 L
.1701 .29142 L
.17043 .29142 L
.17072 .29142 L
.17105 .29142 L
.17139 .29142 L
.17171 .29142 L
.17206 .29142 L
.17243 .29142 L
.17274 .29142 L
.17309 .29142 L
.17346 .29142 L
.17367 .29142 L
.17386 .29142 L
.17423 .29142 L
.17458 .29142 L
.17488 .29142 L
.17521 .29142 L
.17555 .29142 L
.17587 .29142 L
.17617 .29142 L
.17645 .29142 L
.17677 .29142 L
.17707 .29142 L
.17739 .29142 L
Mistroke
.17774 .29142 L
.17806 .29142 L
.17836 .29142 L
.17871 .29142 L
.1789 .29142 L
.17909 .29142 L
.17942 .29142 L
.17977 .29142 L
.18011 .29142 L
.18031 .29142 L
.18049 .29142 L
.18082 .29142 L
.18117 .29142 L
.18149 .29142 L
.18178 .29142 L
.18211 .29142 L
.18245 .29142 L
.1828 .29142 L
.183 .29142 L
.18319 .29142 L
.18356 .29142 L
.18377 .29142 L
.18396 .29142 L
.1843 .29142 L
.18466 .29142 L
.18501 .29142 L
.18533 .29142 L
.18563 .29142 L
.18595 .29142 L
.18626 .29142 L
.18653 .29142 L
.18686 .29142 L
.18721 .29142 L
.18754 .29142 L
.18785 .29142 L
.1882 .29142 L
.18853 .29142 L
.18883 .29142 L
.18915 .29142 L
.1895 .29142 L
.18987 .29142 L
.19018 .29142 L
.19052 .29142 L
.1909 .29142 L
.19124 .29142 L
.19142 .29142 L
.19161 .29142 L
.19182 .29142 L
.19201 .29142 L
.19237 .29142 L
Mistroke
.19269 .29142 L
.19307 .29142 L
.19342 .29142 L
.19374 .29142 L
.19408 .29142 L
.1944 .29142 L
.19468 .29142 L
.19502 .29142 L
.19539 .29142 L
.19574 .29142 L
.19606 .29142 L
.1964 .29142 L
.19677 .29142 L
.19712 .29142 L
.19744 .29142 L
.19781 .29142 L
.19802 .29142 L
.19821 .29142 L
.19857 .29142 L
.19874 .29142 L
.19894 .29142 L
.19914 .29142 L
.19934 .29142 L
.1997 .29142 L
.1999 .29142 L
.20009 .29142 L
.20029 .29142 L
.20051 .29142 L
.2007 .29142 L
.20091 .29142 L
.20111 .29142 L
.20129 .29142 L
.20163 .29142 L
.20199 .29142 L
.20233 .29142 L
.2027 .29142 L
.20306 .29142 L
.20338 .29142 L
.20371 .29142 L
.204 .29142 L
.20434 .29142 L
.20466 .29142 L
.20501 .29142 L
.20538 .29142 L
.20569 .29142 L
.20604 .29142 L
.20641 .29142 L
.20662 .29142 L
.20681 .29142 L
.20718 .29142 L
Mistroke
.20753 .29142 L
.20783 .29142 L
.20815 .29142 L
.2085 .29142 L
.20882 .29142 L
.20912 .29142 L
.20939 .29142 L
.20969 .29142 L
.21001 .29142 L
.21033 .29142 L
.21068 .29142 L
.21101 .29142 L
.2113 .29142 L
.21165 .29142 L
.21185 .29142 L
.21203 .29142 L
.21236 .29142 L
.21271 .29142 L
.21306 .29142 L
.21343 .29142 L
.21378 .29142 L
.21411 .29142 L
.21444 .29142 L
.21473 .29142 L
.21507 .29142 L
.21539 .29142 L
.21574 .29142 L
.21611 .29142 L
.21642 .29142 L
.21677 .29142 L
.21714 .29142 L
.21735 .29142 L
.21754 .29142 L
.21791 .29142 L
.21826 .29142 L
.21856 .29142 L
.21889 .29142 L
.21923 .29142 L
.21955 .29142 L
.21985 .29142 L
.22013 .29142 L
.22045 .29142 L
.22075 .29142 L
.22107 .29142 L
.22142 .29142 L
.22174 .29142 L
.22204 .29142 L
.22239 .29142 L
.22258 .29142 L
.22277 .29142 L
Mistroke
.2231 .29142 L
.22345 .29142 L
.22379 .29142 L
.22399 .29142 L
.22417 .29142 L
.2245 .29142 L
.22485 .29142 L
.22517 .29142 L
.22546 .29142 L
.22578 .29142 L
.22613 .29142 L
.22648 .29142 L
.22668 .29142 L
.22686 .29142 L
.22724 .29142 L
.22744 .29142 L
.22763 .29142 L
.22797 .29142 L
.22834 .29142 L
.22869 .29142 L
.22901 .29142 L
.22931 .29142 L
.22963 .29142 L
.22993 .29142 L
.23021 .29142 L
.23053 .29142 L
.23089 .29142 L
.23122 .29142 L
.23153 .29142 L
.23188 .29142 L
.23221 .29142 L
.23251 .29142 L
.23282 .29142 L
.23317 .29142 L
.23354 .29142 L
.23386 .29142 L
.2342 .29142 L
.23457 .29142 L
.23491 .29142 L
.23509 .29142 L
.23529 .29142 L
.2355 .29142 L
.23569 .29142 L
.23604 .29142 L
.23637 .29142 L
.23672 .29142 L
.2371 .29142 L
.23741 .29142 L
.23775 .29142 L
.23807 .29142 L
Mistroke
.23836 .29142 L
.2387 .29142 L
.23907 .29142 L
.23942 .29142 L
.23974 .29142 L
.24008 .29142 L
.24045 .29142 L
.24079 .29142 L
.24111 .29142 L
.24148 .29142 L
.24169 .29142 L
.24188 .29142 L
.24224 .29142 L
.24242 .29142 L
.24262 .29142 L
.24281 .29142 L
.24301 .29142 L
.24337 .29142 L
.24357 .29142 L
.24376 .29142 L
.24397 .29142 L
.24419 .29142 L
.24438 .29142 L
.24458 .29142 L
.24478 .29142 L
.24496 .29142 L
.2453 .29142 L
.24566 .29142 L
.246 .29142 L
.24638 .29142 L
.24673 .29142 L
.24706 .29142 L
.24738 .29142 L
.24767 .29142 L
.24801 .29142 L
.24833 .29142 L
.24868 .29142 L
.24905 .29142 L
.24936 .29142 L
.24971 .29142 L
.25008 .29142 L
.25029 .29142 L
.25048 .29142 L
.25085 .29142 L
.2512 .29142 L
.2515 .29142 L
.25182 .29142 L
.25217 .29142 L
.25249 .29142 L
.25279 .29142 L
Mistroke
.25306 .29142 L
.25336 .29142 L
.25368 .29142 L
.254 .29142 L
.25435 .29142 L
.25468 .29142 L
.25497 .29142 L
.25532 .29142 L
.25552 .29142 L
.2557 .29142 L
.25603 .29142 L
.25638 .29142 L
.25673 .29142 L
.2571 .29142 L
.25745 .29142 L
.25778 .29142 L
.2581 .29142 L
.2584 .29142 L
.25874 .29142 L
.25906 .29142 L
.25941 .29142 L
.25978 .29142 L
.26009 .29142 L
.26044 .29142 L
.26081 .29142 L
.26102 .29142 L
.26121 .29142 L
.26158 .29142 L
.26193 .29142 L
.26223 .29142 L
.26256 .29142 L
.2629 .29142 L
.26322 .29142 L
.26352 .29142 L
.2638 .29142 L
.26411 .29142 L
.26442 .29142 L
.26474 .29142 L
.26508 .29142 L
.26541 .29142 L
.26571 .29142 L
.26605 .29142 L
.26625 .29142 L
.26643 .29142 L
.26676 .29142 L
.26712 .29142 L
.26746 .29142 L
.26766 .29142 L
.26784 .29142 L
.26817 .29142 L
Mistroke
.26852 .29142 L
.26883 .29142 L
.26913 .29142 L
.26945 .29142 L
.2698 .29142 L
.27015 .29142 L
.27034 .29142 L
.27053 .29142 L
.2709 .29142 L
.27111 .29142 L
.2713 .29142 L
.27164 .29142 L
.27201 .29142 L
.27235 .29142 L
.27267 .29142 L
.27297 .29142 L
.27329 .29142 L
.2736 .29142 L
.27387 .29142 L
.2742 .29142 L
.27455 .29142 L
.27488 .29142 L
.27519 .29142 L
.27554 .29142 L
.27587 .29142 L
.27617 .29142 L
.27649 .29142 L
.27684 .29142 L
.2772 .29142 L
.27752 .29142 L
.27786 .29142 L
.27823 .29142 L
.27858 .29142 L
.27876 .29142 L
.27895 .29142 L
.27916 .29142 L
.27935 .29142 L
.27971 .29142 L
.28003 .29142 L
.28039 .29142 L
.28076 .29142 L
.28108 .29142 L
.28141 .29142 L
.28173 .29142 L
.28202 .29142 L
.28236 .29142 L
.28273 .29142 L
.28308 .29142 L
.2834 .29142 L
.28374 .29142 L
Mistroke
.28411 .29142 L
.28445 .29142 L
.28477 .29142 L
.28514 .29142 L
.28535 .29142 L
.28554 .29142 L
.2859 .29142 L
.28608 .29142 L
.28628 .29142 L
.28647 .29142 L
.28667 .29142 L
.28703 .29142 L
.28723 .29142 L
.28742 .29142 L
.28763 .29142 L
.28785 .29142 L
.28804 .29142 L
.28824 .29142 L
.28844 .29142 L
.28862 .29142 L
.28896 .29142 L
.28932 .29142 L
.28966 .29142 L
.29004 .29142 L
.29039 .29142 L
.29071 .29142 L
.29104 .29142 L
.29133 .29142 L
.29167 .29142 L
.29199 .29142 L
.29234 .29142 L
.29271 .29142 L
.29302 .29142 L
.29337 .29142 L
.29374 .29142 L
.29395 .29142 L
.29414 .29142 L
.29451 .29142 L
.29486 .29142 L
.29515 .29142 L
.29548 .29142 L
.29582 .29142 L
.29614 .29142 L
.29644 .29142 L
.29672 .29142 L
.29702 .29142 L
.29734 .29142 L
.29766 .29142 L
.29801 .29142 L
.29833 .29142 L
Mistroke
.29863 .29142 L
.29898 .29142 L
.29917 .29142 L
.29935 .29142 L
.29969 .29142 L
.30004 .29142 L
.30038 .29142 L
.30075 .29142 L
.30111 .29142 L
.30143 .29142 L
.30176 .29142 L
.30205 .29142 L
.30239 .29142 L
.30271 .29142 L
.30306 .29142 L
.30343 .29142 L
.30375 .29142 L
.30409 .29142 L
.30446 .29142 L
.30467 .29142 L
.30486 .29142 L
.30523 .29142 L
.30558 .29142 L
.30588 .29142 L
.30621 .29142 L
.30655 .29142 L
.30687 .29142 L
.30717 .29142 L
.30745 .29142 L
.30775 .29142 L
.30807 .29142 L
.30839 .29142 L
.30874 .29142 L
.30906 .29142 L
.30936 .29142 L
.30971 .29142 L
.3099 .29142 L
.31008 .29142 L
.31042 .29142 L
.31077 .29142 L
.31111 .29142 L
.31131 .29142 L
.31149 .29142 L
.31182 .29142 L
.31217 .29142 L
.31248 .29142 L
.31278 .29142 L
.3131 .29142 L
.31345 .29142 L
.3138 .29142 L
Mistroke
.31399 .29142 L
.31418 .29142 L
.31455 .29142 L
.31476 .29142 L
.31495 .29142 L
.31529 .29142 L
.31566 .29142 L
.316 .29142 L
.31632 .29142 L
.31662 .29142 L
.31694 .29142 L
.31725 .29142 L
.31752 .29142 L
.31785 .29142 L
.3182 .29142 L
.31853 .29142 L
.31884 .29142 L
.31919 .29142 L
.31952 .29142 L
.31982 .29142 L
.32014 .29142 L
.32049 .29142 L
.32085 .29142 L
.32117 .29142 L
.32151 .29142 L
.32188 .29142 L
.32223 .29142 L
.3224 .29142 L
.3226 .29142 L
.32281 .29142 L
.323 .29142 L
.32335 .29142 L
.32368 .29142 L
.32403 .29142 L
.32441 .29142 L
.32472 .29142 L
.32506 .29142 L
.32538 .29142 L
.32567 .29142 L
.32601 .29142 L
.32637 .29142 L
.32672 .29142 L
.32704 .29142 L
.32739 .29142 L
.32775 .29142 L
.3281 .29142 L
.32841 .29142 L
.32878 .29142 L
.32899 .29142 L
.32919 .29142 L
Mistroke
.32954 .29142 L
.32974 .29142 L
.32992 .29142 L
.33011 .29142 L
.33032 .29142 L
.33068 .29142 L
.33088 .29142 L
.33107 .29142 L
.33127 .29142 L
.33149 .29142 L
.33168 .29142 L
.33189 .29142 L
.33208 .29142 L
.33226 .29142 L
.33261 .29142 L
.33297 .29142 L
.33331 .29142 L
.33368 .29142 L
.33403 .29142 L
.33436 .29142 L
.33468 .29142 L
.33497 .29142 L
.33531 .29142 L
.33563 .29142 L
.33598 .29142 L
.33635 .29142 L
.33666 .29142 L
.33701 .29142 L
.33738 .29142 L
.33759 .29142 L
.33778 .29142 L
.33815 .29142 L
.3385 .29142 L
.3388 .29142 L
.33912 .29142 L
.33947 .29142 L
.33979 .29142 L
.34009 .29142 L
.34036 .29142 L
.34066 .29142 L
.34098 .29142 L
.3413 .29142 L
.34165 .29142 L
.34197 .29142 L
.34227 .29142 L
.34262 .29142 L
.34281 .29142 L
.34299 .29142 L
.34333 .29142 L
.34368 .29142 L
Mistroke
.34402 .29142 L
.3444 .29142 L
.34475 .29142 L
.34508 .29142 L
.3454 .29142 L
.34569 .29142 L
.34603 .29142 L
.34635 .29142 L
.3467 .29142 L
.34707 .29142 L
.34739 .29142 L
.34773 .29142 L
.3481 .29142 L
.34831 .29142 L
.3485 .29142 L
.34887 .29142 L
.34922 .29142 L
.34952 .29142 L
.34985 .29142 L
.35019 .29142 L
.35051 .29142 L
.35081 .29142 L
.35109 .29142 L
.35139 .29142 L
.35171 .29142 L
.35203 .29142 L
.35238 .29142 L
.3527 .29142 L
.353 .29142 L
.35335 .29142 L
.35354 .29142 L
.35372 .29142 L
.35406 .29142 L
.35441 .29142 L
.35475 .29142 L
.35495 .29142 L
.35513 .29142 L
.35546 .29142 L
.35581 .29142 L
.35612 .29142 L
.35641 .29142 L
.35674 .29142 L
.35709 .29142 L
.35743 .29142 L
.35763 .29142 L
.35781 .29142 L
.35819 .29142 L
.35839 .29142 L
.35858 .29142 L
.35892 .29142 L
Mistroke
.35929 .29142 L
.35964 .29142 L
.35996 .29142 L
.36026 .29142 L
.36058 .29142 L
.36088 .29142 L
.36116 .29142 L
.36148 .29142 L
.36184 .29142 L
.36217 .29142 L
.36248 .29142 L
.36283 .29142 L
.36316 .29142 L
.36345 .29142 L
.36377 .29142 L
.36412 .29142 L
.36449 .29142 L
.3648 .29142 L
.36515 .29142 L
.3654 .29142 L
.36563 .29142 L
.36588 .29142 L
.36615 .29142 L
.36638 .29142 L
.3666 .29142 L
.36684 .29142 L
.3671 .29142 L
.36732 .29142 L
.36755 .29142 L
.3678 .29142 L
.36803 .29142 L
.36825 .29142 L
.36844 .29142 L
.36867 .29142 L
.36888 .29142 L
.36911 .29142 L
.36937 .29142 L
.36963 .29142 L
.36988 .29142 L
.37011 .29142 L
.37033 .29142 L
.37057 .29142 L
.3708 .29142 L
.37105 .29142 L
.37132 .29142 L
.37157 .29142 L
.3718 .29142 L
.37207 .29142 L
.37236 .29142 L
.37263 .29142 L
Mistroke
.37289 .29142 L
Mfstroke
.37289 .29142 m
.37331 .29142 L
.3737 .29142 L
.37414 .29142 L
.37456 .29142 L
.37495 .29142 L
.37531 .29142 L
.37571 .29142 L
.37613 .29142 L
.37655 .29142 L
.377 .29142 L
.37743 .29142 L
.37782 .29142 L
.37828 .29142 L
.37853 .29142 L
.37877 .29142 L
.37921 .29142 L
.37968 .29142 L
.37992 .29142 L
.38017 .29142 L
.38061 .29142 L
.38086 .29142 L
.38109 .29142 L
.38134 .29142 L
.38162 .29142 L
.38185 .29142 L
.38211 .29142 L
.38257 .29142 L
.38302 .29142 L
.38344 .29142 L
.38385 .29142 L
.38423 .29142 L
.38464 .29142 L
.38509 .29142 L
.38554 .29142 L
.38601 .29142 L
.38641 .29142 L
.38685 .29142 L
.3871 .29142 L
.38734 .29142 L
.3876 .29142 L
.38788 .29142 L
.38834 .29142 L
.3886 .29142 L
.38885 .29142 L
.3893 .29142 L
.38972 .29142 L
.38995 .29142 L
.3902 .29142 L
.39066 .29142 L
Mistroke
.39094 .29142 L
.3912 .29142 L
.39143 .29142 L
.39169 .29142 L
.39196 .29142 L
.39225 .29142 L
.3925 .29142 L
.39278 .29142 L
.39303 .29142 L
.39327 .29142 L
.39353 .29142 L
.39379 .29142 L
.39424 .29142 L
.3945 .29142 L
.39474 .29142 L
.39516 .29142 L
.39561 .29142 L
.39604 .29142 L
.39643 .29142 L
.39686 .29142 L
.39734 .29142 L
.39758 .29142 L
.39784 .29142 L
.3983 .29142 L
.39855 .29142 L
.39879 .29142 L
.39904 .29142 L
.39932 .29142 L
.39977 .29142 L
.40003 .29142 L
.40028 .29142 L
.40073 .29142 L
.40114 .29142 L
.40162 .29142 L
.40207 .29142 L
.40248 .29142 L
.40293 .29142 L
.40335 .29142 L
.40373 .29142 L
.40415 .29142 L
.40462 .29142 L
.40485 .29142 L
.4051 .29142 L
.40556 .29142 L
.40581 .29142 L
.40604 .29142 L
.40629 .29142 L
.40655 .29142 L
.407 .29142 L
.40726 .29142 L
Mistroke
.4075 .29142 L
.40794 .29142 L
.40835 .29142 L
.40882 .29142 L
.40926 .29142 L
.40968 .29142 L
.41006 .29142 L
.4105 .29142 L
.41091 .29142 L
.41129 .29142 L
.41165 .29142 L
.41203 .29142 L
.41244 .29142 L
.41286 .29142 L
.4133 .29142 L
.41372 .29142 L
.4141 .29142 L
.41454 .29142 L
.4148 .29142 L
.41503 .29142 L
.41546 .29142 L
.41591 .29142 L
.41633 .29142 L
.41678 .29142 L
.41725 .29142 L
.41768 .29142 L
.41809 .29142 L
.41847 .29142 L
.4189 .29142 L
.4193 .29142 L
.41975 .29142 L
.42022 .29142 L
.42062 .29142 L
.42106 .29142 L
.42153 .29142 L
.4218 .29142 L
.42204 .29142 L
.42251 .29142 L
.42296 .29142 L
.42337 .29142 L
.42375 .29142 L
.42419 .29142 L
.4246 .29142 L
.42498 .29142 L
.42533 .29142 L
.42571 .29142 L
.42612 .29142 L
.42653 .29142 L
.42697 .29142 L
.42738 .29142 L
Mistroke
.42776 .29142 L
.42821 .29142 L
.42846 .29142 L
.42869 .29142 L
.42911 .29142 L
.42956 .29142 L
.43 .29142 L
.43047 .29142 L
.43092 .29142 L
.43134 .29142 L
.43175 .29142 L
.43212 .29142 L
.43256 .29142 L
.43296 .29142 L
.43341 .29142 L
.43388 .29142 L
.43428 .29142 L
.43472 .29142 L
.43519 .29142 L
.43546 .29142 L
.4357 .29142 L
.43617 .29142 L
.43662 .29142 L
.437 .29142 L
.43742 .29142 L
.43785 .29142 L
.43826 .29142 L
.43865 .29142 L
.439 .29142 L
.43938 .29142 L
.43979 .29142 L
.4402 .29142 L
.44064 .29142 L
.44105 .29142 L
.44143 .29142 L
.44188 .29142 L
.44213 .29142 L
.44236 .29142 L
.44278 .29142 L
.44323 .29142 L
.44367 .29142 L
.44415 .29142 L
.4446 .29142 L
.44501 .29142 L
.44543 .29142 L
.4458 .29142 L
.44623 .29142 L
.44664 .29142 L
.44709 .29142 L
.44756 .29142 L
Mistroke
.44796 .29142 L
.4484 .29142 L
.44888 .29142 L
.44914 .29142 L
.44938 .29142 L
.44986 .29142 L
.4503 .29142 L
.45068 .29142 L
.4511 .29142 L
.45154 .29142 L
.45195 .29142 L
.45233 .29142 L
.45268 .29142 L
.45307 .29142 L
.45347 .29142 L
.45389 .29142 L
.45433 .29142 L
.45474 .29142 L
.45512 .29142 L
.45556 .29142 L
.45582 .29142 L
.45605 .29142 L
.45647 .29142 L
.45692 .29142 L
.45736 .29142 L
.45784 .29142 L
.45829 .29142 L
.45871 .29142 L
.45908 .29142 L
.4595 .29142 L
.45993 .29142 L
.46034 .29142 L
.46078 .29142 L
.46126 .29142 L
.46166 .29142 L
.4621 .29142 L
.46258 .29142 L
.46284 .29142 L
.46309 .29142 L
.46356 .29142 L
.464 .29142 L
.46439 .29142 L
.46481 .29142 L
.46524 .29142 L
.46566 .29142 L
.46604 .29142 L
.46639 .29142 L
.46679 .29142 L
.46718 .29142 L
.46759 .29142 L
Mistroke
.46803 .29142 L
.46845 .29142 L
.46883 .29142 L
.46927 .29142 L
.46952 .29142 L
.46975 .29142 L
.47018 .29142 L
.47063 .29142 L
.47107 .29142 L
.47132 .29142 L
.47155 .29142 L
.47197 .29142 L
.47242 .29142 L
.47282 .29142 L
.47319 .29142 L
.47361 .29142 L
.47405 .29142 L
.4745 .29142 L
.47475 .29142 L
.47499 .29142 L
.47546 .29142 L
.47573 .29142 L
.47597 .29142 L
.4764 .29142 L
.47687 .29142 L
.47732 .29142 L
.47772 .29142 L
.47811 .29142 L
.47852 .29142 L
.4789 .29142 L
.47926 .29142 L
.47967 .29142 L
.48012 .29142 L
.48055 .29142 L
.48094 .29142 L
.48139 .29142 L
.48181 .29142 L
.48219 .29142 L
.48259 .29142 L
.48304 .29142 L
.48351 .29142 L
.48391 .29142 L
.48435 .29142 L
.48482 .29142 L
.48526 .29142 L
.48549 .29142 L
.48574 .29142 L
.48601 .29142 L
.48625 .29142 L
.4867 .29142 L
Mistroke
.48712 .29142 L
.4876 .29142 L
.48805 .29142 L
.48845 .29142 L
.48888 .29142 L
.48929 .29142 L
.48966 .29142 L
.49009 .29142 L
.49056 .29142 L
.49101 .29142 L
.49142 .29142 L
.49185 .29142 L
.49232 .29142 L
.49277 .29142 L
.49317 .29142 L
.49364 .29142 L
.49391 .29142 L
.49416 .29142 L
.49461 .29142 L
.49484 .29142 L
.49509 .29142 L
.49534 .29142 L
.4956 .29142 L
.49606 .29142 L
.49632 .29142 L
.49655 .29142 L
.49682 .29142 L
.4971 .29142 L
.49734 .29142 L
.49761 .29142 L
.49785 .29142 L
.49808 .29142 L
.49852 .29142 L
.49898 .29142 L
.49942 .29142 L
.49989 .29142 L
.50034 .29142 L
.50076 .29142 L
.50117 .29142 L
.50155 .29142 L
.50198 .29142 L
.50239 .29142 L
.50283 .29142 L
.5033 .29142 L
.50371 .29142 L
.50415 .29142 L
.50462 .29142 L
.50489 .29142 L
.50513 .29142 L
.5056 .29142 L
Mistroke
.50605 .29142 L
.50643 .29142 L
.50685 .29142 L
.50728 .29142 L
.5077 .29142 L
.50808 .29142 L
.50843 .29142 L
.50881 .29142 L
.50922 .29142 L
.50963 .29142 L
.51007 .29142 L
.51049 .29142 L
.51086 .29142 L
.51131 .29142 L
.51156 .29142 L
.51179 .29142 L
.51221 .29142 L
.51266 .29142 L
.5131 .29142 L
.51358 .29142 L
.51403 .29142 L
.51445 .29142 L
.51486 .29142 L
.51524 .29142 L
.51567 .29142 L
.51608 .29142 L
.51653 .29142 L
.517 .29142 L
.5174 .29142 L
.51784 .29142 L
.51832 .29142 L
.51858 .29142 L
.51883 .29142 L
.5193 .29142 L
.51975 .29142 L
.52013 .29142 L
.52055 .29142 L
.52098 .29142 L
.5214 .29142 L
.52178 .29142 L
.52213 .29142 L
.52253 .29142 L
.52292 .29142 L
.52333 .29142 L
.52377 .29142 L
.52419 .29142 L
.52457 .29142 L
.52501 .29142 L
.52526 .29142 L
.52549 .29142 L
Mistroke
.52592 .29142 L
.52637 .29142 L
.52681 .29142 L
.52705 .29142 L
.52729 .29142 L
.52771 .29142 L
.52816 .29142 L
.52856 .29142 L
.52893 .29142 L
.52935 .29142 L
.52979 .29142 L
.53024 .29142 L
.53049 .29142 L
.53072 .29142 L
.5312 .29142 L
.53146 .29142 L
.5317 .29142 L
.53214 .29142 L
.53261 .29142 L
.53305 .29142 L
.53346 .29142 L
.53384 .29142 L
.53425 .29142 L
.53464 .29142 L
.53499 .29142 L
.53541 .29142 L
.53586 .29142 L
.53628 .29142 L
.53668 .29142 L
.53713 .29142 L
.53754 .29142 L
.53792 .29142 L
.53833 .29142 L
.53877 .29142 L
.53924 .29142 L
.53965 .29142 L
.54009 .29142 L
.54056 .29142 L
.541 .29142 L
.54122 .29142 L
.54148 .29142 L
.54174 .29142 L
.54199 .29142 L
.54244 .29142 L
.54285 .29142 L
.54331 .29142 L
.54378 .29142 L
.54419 .29142 L
.54462 .29142 L
.54502 .29142 L
Mistroke
.54539 .29142 L
.54583 .29142 L
.5463 .29142 L
.54674 .29142 L
.54715 .29142 L
.54759 .29142 L
.54805 .29142 L
.5485 .29142 L
.5489 .29142 L
.54937 .29142 L
.54964 .29142 L
.54989 .29142 L
.55034 .29142 L
.55057 .29142 L
.55082 .29142 L
.55107 .29142 L
.55133 .29142 L
.55179 .29142 L
.55205 .29142 L
.55229 .29142 L
.55255 .29142 L
.55283 .29142 L
.55307 .29142 L
.55334 .29142 L
.55359 .29142 L
.55381 .29142 L
.55425 .29142 L
.55471 .29142 L
.55515 .29142 L
.55562 .29142 L
.55607 .29142 L
.55649 .29142 L
.5569 .29142 L
.55728 .29142 L
.55771 .29142 L
.55812 .29142 L
.55856 .29142 L
.55903 .29142 L
.55943 .29142 L
.55987 .29142 L
.56035 .29142 L
.56061 .29142 L
.56086 .29142 L
.56133 .29142 L
.56178 .29142 L
.56216 .29142 L
.56257 .29142 L
.56301 .29142 L
.56342 .29142 L
.5638 .29142 L
Mistroke
.56415 .29142 L
.56454 .29142 L
.56494 .29142 L
.56536 .29142 L
.5658 .29142 L
.56621 .29142 L
.56659 .29142 L
.56703 .29142 L
.56729 .29142 L
.56752 .29142 L
.56794 .29142 L
.56839 .29142 L
.56883 .29142 L
.56931 .29142 L
.56976 .29142 L
.57017 .29142 L
.57059 .29142 L
.57096 .29142 L
.5714 .29142 L
.5718 .29142 L
.57225 .29142 L
.57272 .29142 L
.57312 .29142 L
.57357 .29142 L
.57404 .29142 L
.57431 .29142 L
.57455 .29142 L
.57502 .29142 L
.57547 .29142 L
.57585 .29142 L
.57627 .29142 L
.57671 .29142 L
.57712 .29142 L
.5775 .29142 L
.57785 .29142 L
.57826 .29142 L
.57864 .29142 L
.57905 .29142 L
.5795 .29142 L
.57991 .29142 L
.58029 .29142 L
.58073 .29142 L
.58098 .29142 L
.58121 .29142 L
.58164 .29142 L
.58209 .29142 L
.58253 .29142 L
.58278 .29142 L
.58301 .29142 L
.58343 .29142 L
Mistroke
.58388 .29142 L
.58428 .29142 L
.58465 .29142 L
.58507 .29142 L
.58551 .29142 L
.58595 .29142 L
.58621 .29142 L
.58644 .29142 L
.58692 .29142 L
.58718 .29142 L
.58742 .29142 L
.58786 .29142 L
.58833 .29142 L
.58877 .29142 L
.58918 .29142 L
.58956 .29142 L
.58997 .29142 L
.59036 .29142 L
.59071 .29142 L
.59112 .29142 L
.59158 .29142 L
.592 .29142 L
.5924 .29142 L
.59284 .29142 L
.59326 .29142 L
.59364 .29142 L
.59405 .29142 L
.59449 .29142 L
.59496 .29142 L
.59536 .29142 L
.5958 .29142 L
.59628 .29142 L
.59671 .29142 L
.59694 .29142 L
.59719 .29142 L
.59746 .29142 L
.5977 .29142 L
.59815 .29142 L
.59857 .29142 L
.59902 .29142 L
.5995 .29142 L
.5999 .29142 L
.60033 .29142 L
.60074 .29142 L
.60111 .29142 L
.60154 .29142 L
.60201 .29142 L
.60245 .29142 L
.60286 .29142 L
.6033 .29142 L
Mistroke
.60377 .29142 L
.60421 .29142 L
.60461 .29142 L
.60509 .29142 L
.60535 .29142 L
.6056 .29142 L
.60606 .29142 L
.60628 .29142 L
.60654 .29142 L
.60678 .29142 L
.60704 .29142 L
.6075 .29142 L
.60776 .29142 L
.608 .29142 L
.60826 .29142 L
.60854 .29142 L
.60878 .29142 L
.60905 .29142 L
.6093 .29142 L
.60953 .29142 L
.60996 .29142 L
.61042 .29142 L
.61086 .29142 L
.61134 .29142 L
.61178 .29142 L
.6122 .29142 L
.61261 .29142 L
.61299 .29142 L
.61342 .29142 L
.61383 .29142 L
.61427 .29142 L
.61474 .29142 L
.61514 .29142 L
.61558 .29142 L
.61606 .29142 L
.61632 .29142 L
.61657 .29142 L
.61704 .29142 L
.61749 .29142 L
.61786 .29142 L
.61828 .29142 L
.61872 .29142 L
.61913 .29142 L
.61951 .29142 L
.61986 .29142 L
.62025 .29142 L
.62065 .29142 L
.62107 .29142 L
.62151 .29142 L
.62192 .29142 L
Mistroke
.6223 .29142 L
.62274 .29142 L
.62299 .29142 L
.62322 .29142 L
.62365 .29142 L
.6241 .29142 L
.62454 .29142 L
.62501 .29142 L
.62546 .29142 L
.62588 .29142 L
.6263 .29142 L
.62667 .29142 L
.6271 .29142 L
.62751 .29142 L
.62796 .29142 L
.62843 .29142 L
.62883 .29142 L
.62927 .29142 L
.62975 .29142 L
.63001 .29142 L
.63026 .29142 L
.63073 .29142 L
.63117 .29142 L
.63155 .29142 L
.63197 .29142 L
.63241 .29142 L
.63282 .29142 L
.63321 .29142 L
.63356 .29142 L
.63394 .29142 L
.63435 .29142 L
.63476 .29142 L
.6352 .29142 L
.63562 .29142 L
.63599 .29142 L
.63644 .29142 L
.63669 .29142 L
.63692 .29142 L
.63734 .29142 L
.63779 .29142 L
.63823 .29142 L
.63848 .29142 L
.63871 .29142 L
.63913 .29142 L
.63958 .29142 L
.63998 .29142 L
.64036 .29142 L
.64077 .29142 L
.64121 .29142 L
.64166 .29142 L
Mistroke
.64191 .29142 L
.64214 .29142 L
.64262 .29142 L
.64288 .29142 L
.64312 .29142 L
.64356 .29142 L
.64403 .29142 L
.64447 .29142 L
.64488 .29142 L
.64526 .29142 L
.64567 .29142 L
.64606 .29142 L
.64641 .29142 L
.64682 .29142 L
.64728 .29142 L
.6477 .29142 L
.6481 .29142 L
.64854 .29142 L
.64896 .29142 L
.64934 .29142 L
.64975 .29142 L
.65019 .29142 L
.65066 .29142 L
.65106 .29142 L
.6515 .29142 L
.65198 .29142 L
.65241 .29142 L
.65264 .29142 L
.65289 .29142 L
.65315 .29142 L
.6534 .29142 L
.65385 .29142 L
.65426 .29142 L
.65472 .29142 L
.6552 .29142 L
.6556 .29142 L
.65603 .29142 L
.65643 .29142 L
.6568 .29142 L
.65724 .29142 L
.65771 .29142 L
.65815 .29142 L
.65856 .29142 L
.659 .29142 L
.65946 .29142 L
.65991 .29142 L
.66031 .29142 L
.66078 .29142 L
.66105 .29142 L
.6613 .29142 L
Mistroke
.66175 .29142 L
.662 .29142 L
.66223 .29142 L
.66248 .29142 L
.66274 .29142 L
.6632 .29142 L
.66345 .29142 L
.66369 .29142 L
.66396 .29142 L
.66424 .29142 L
.66448 .29142 L
.66474 .29142 L
.66499 .29142 L
.66522 .29142 L
.66566 .29142 L
.66612 .29142 L
.66656 .29142 L
.66703 .29142 L
.66748 .29142 L
.6679 .29142 L
.66831 .29142 L
.66868 .29142 L
.66911 .29142 L
.66952 .29142 L
.66996 .29142 L
.67043 .29142 L
.67084 .29142 L
.67128 .29142 L
.67175 .29142 L
.67202 .29142 L
.67226 .29142 L
.67273 .29142 L
.67318 .29142 L
.67356 .29142 L
.67397 .29142 L
.67441 .29142 L
.67482 .29142 L
.6752 .29142 L
.67555 .29142 L
.67594 .29142 L
.67634 .29142 L
.67676 .29142 L
.6772 .29142 L
.67761 .29142 L
.67799 .29142 L
.67843 .29142 L
.67868 .29142 L
.67892 .29142 L
.67934 .29142 L
.67979 .29142 L
Mistroke
.68023 .29142 L
.6807 .29142 L
.68115 .29142 L
.68157 .29142 L
.68198 .29142 L
.68236 .29142 L
.68279 .29142 L
.6832 .29142 L
.68364 .29142 L
.68412 .29142 L
.68452 .29142 L
.68496 .29142 L
.68543 .29142 L
.6857 .29142 L
.68594 .29142 L
.68641 .29142 L
.68686 .29142 L
.68724 .29142 L
.68766 .29142 L
.6881 .29142 L
.68851 .29142 L
.68889 .29142 L
.68924 .29142 L
.68963 .29142 L
.69003 .29142 L
.69045 .29142 L
.69089 .29142 L
.6913 .29142 L
.69168 .29142 L
.69212 .29142 L
.69237 .29142 L
.6926 .29142 L
.69303 .29142 L
.69348 .29142 L
.69392 .29142 L
.69417 .29142 L
.6944 .29142 L
.69482 .29142 L
.69526 .29142 L
.69566 .29142 L
.69604 .29142 L
.69645 .29142 L
.6969 .29142 L
.69734 .29142 L
.69759 .29142 L
.69783 .29142 L
.6983 .29142 L
.69857 .29142 L
.69881 .29142 L
.69924 .29142 L
Mistroke
.69971 .29142 L
.70015 .29142 L
.70056 .29142 L
.70094 .29142 L
.70135 .29142 L
.70174 .29142 L
.70209 .29142 L
.70251 .29142 L
.70296 .29142 L
.70338 .29142 L
.70378 .29142 L
.70422 .29142 L
.70464 .29142 L
.70502 .29142 L
.70543 .29142 L
.70587 .29142 L
.70634 .29142 L
.70674 .29142 L
.70719 .29142 L
.7075 .29142 L
.7078 .29142 L
.70812 .29142 L
.70847 .29142 L
.70876 .29142 L
.70904 .29142 L
.70935 .29142 L
.70968 .29142 L
.70995 .29142 L
.71026 .29142 L
.71057 .29142 L
.71086 .29142 L
.71114 .29142 L
.71139 .29142 L
.71168 .29142 L
.71195 .29142 L
.71225 .29142 L
.71257 .29142 L
.71291 .29142 L
.71323 .29142 L
.71352 .29142 L
.71379 .29142 L
.71411 .29142 L
.7144 .29142 L
.71472 .29142 L
.71506 .29142 L
.71538 .29142 L
.71567 .29142 L
.71602 .29142 L
.71639 .29142 L
.71674 .29142 L
Mistroke
.71706 .29142 L
Mfstroke
0 0 m
1 0 L
1 .7166 L
0 .7166 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 206.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000cR000`400?l00000o`00003ooooooolQ
ooooo`00:oooool2o`0002[ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Xoooo
o`?o0000:?ooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0002Sooooo1Ol0000/oooo
o`00:_ooool01?l0003oooooooooool0000Xooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`00000Xooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01ooo
ool01Ol0003ooooooooooooooooo000002Sooooo00Co0000oooooooooooo0000;?ooool002[ooooo
00Co0000oooooooooooo0000:?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0;?ooool002[ooooo00Co0000oooooooooooo0000:?ooool01?l0
003oooooooooool0000;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:oooool0
02[ooooo00Co0000oooooooooooo0000:?ooool01?l0003oooooooooool00007ooooo`Co0000:Ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Oooooo1?l0000Xooooo`05o`000?oo
ooooooooooooool00000;?ooool002[ooooo00Co0000oooooooooooo0000:?ooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo02Wooooo0_l0000Yooooo`;o00002Oooool00ol0003o
ooooooooo`0Yooooo`05o`000?ooooooooooooooool00000;?ooool002_ooooo0_l0000Zooooo`;o
00002?ooool5o`0002Sooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`07ooooo`Go
0000:?ooool3o`0002gooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo000CooooooWo00005?ooool001?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01;ooooo000Cooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01;ooooo000C
ooooo`03o`000?oooooooooo0?Gooooo00?o0000ooooooooool04_ooool001?ooooo0_l0003Moooo
o`03ojX00?oooooooooo01Gooooo0_l0000Dooooo`004oooool00ol0003oooooooooo`3Looooo`03
ojX00?oooooooooo01Kooooo00?o0000ooooooooool04_ooool001?ooooo00?o0000ooooooooool0
g?ooool00onZ003oooooooooo`0Fooooo`03o`000?oooooooooo01;ooooo000Cooooo`03o`000?oo
oooooooo0=_ooooo00?oZP00ooooooooool05oooool00ol0003oooooooooo`0Booooo`004oooool0
0ol0003oooooooooo`3Kooooo`03ojX00?oooooooooo01Oooooo00?o0000ooooooooool04_ooool0
01?ooooo0_l0003Looooo`03ojX00?oooooooooo01Kooooo0_l0000Dooooo`004oooool00ol0003o
ooooooooo`3Kooooo`03ojX00?oooooooooo01Oooooo00?o0000ooooooooool04_ooool001?ooooo
00?o0000ooooooooool0foooool00onZ003oooooooooo`0Gooooo`03o`000?oooooooooo01;ooooo
000Cooooo`03o`000?oooooooooo0=[ooooo00?oZP00ooooooooool06?ooool00ol0003ooooooooo
o`0Booooo`004oooool2o`000=_ooooo00?oZP00ooooooooool05oooool2o`0001Cooooo000Coooo
o`03o`000?oooooooooo0=[ooooo00?oZP00ooooooooool06?ooool00ol0003oooooooooo`0Boooo
o`004oooool00ol0003oooooooooo`3Jooooo`03ojX00?oooooooooo01Sooooo00?o0000oooooooo
ool04_ooool001?ooooo00?o0000ooooooooool0f_ooool00onZ003oooooooooo`0Hooooo`03o`00
0?oooooooooo01;ooooo000Cooooo`03o`000?oooooooooo0=Wooooo00?oZP00ooooooooool06Ooo
ool00ol0003oooooooooo`0Booooo`004oooool2o`000=[ooooo00?oZP00ooooooooool06?ooool2
o`0001Cooooo000Cooooo`03o`000?oooooooooo0=Wooooo00?oZP00ooooooooool06Oooool00ol0
003oooooooooo`0Booooo`004oooool00ol0003oooooooooo`3Iooooo`03ojX00?oooooooooo01Wo
oooo00?o0000ooooooooool04_ooool000;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1Oooool00ol0003oooooooooo`3Iooooo`03ojX00?oooooooooo01Wooooo00?o0000ooooooooool0
4_ooool000;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0f?ooool00onZ003oooooooooo`0Jooooo`03o`000?oooooooooo01;ooooo
0002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool2o`000=Wooooo00?o
ZP00ooooooooool06Oooool2o`0001Cooooo0002ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3Hooooo`03ojX00?oooooooooo01[ooooo00?o0000
ooooooooool04_ooool000;ooooo00?o0000ooooooooool01Oooool4o`0000Gooooo00?o0000oooo
ooooool0f?ooool00onZ003oooooooooo`0Jooooo`03o`000?oooooooooo01;ooooo0002ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Gooooo`03
ojX00?oooooooooo01_ooooo00?o0000ooooooooool04_ooool000;o00002?ooool5o`0000Cooooo
00?o0000ooooooooool0eoooool00onZ003oooooooooo`0Kooooo`03o`000?oooooooooo01;ooooo
000Cooooo`;o0000_?ooool3omD001Wooooo00?oZP00ooooooooool06_ooool2o`0001Cooooo000C
ooooo`03o`000?oooooooooo0;Wooooo0ooE00000oooooooe@00omD0000Hooooo`03ojX00?oooooo
oooo01_ooooo00?o0000ooooooooool04_ooool001?ooooo00?o0000ooooooooool0^?ooool2omD0
00Gooooo0_oE000Fooooo`03ojX00?oooooooooo01_ooooo00?o0000ooooooooool04_ooool001?o
oooo00?o0000ooooooooool0Joooool7ojX004Gooooo00?oe@00ooooooooool01oooool00ooE003o
ooooooooo`0Booooo`03ojX00?oooooooooo01cooooo00?o0000ooooooooool04_ooool001?ooooo
00?o0000ooooooooool0J_ooool2ojX000Kooooo0_nZ0012ooooo`03omD00?oooooooooo00Wooooo
00?oe@00ooooooooool04Oooool00onZ003oooooooooo`0Looooo`03o`000?oooooooooo01;ooooo
000Cooooo`;o0000G_ooool;oeD000;oZP000omE0007ooooo`03ojX00?oooooooooo01cooooo2?mo
000Jooooo`03omD00?oooooooooo00[ooooo00?oe@00ooooooooool04Oooool00onZ003ooooooooo
o`0Kooooo`;o00005?ooool001?ooooo00?o0000ooooooooool0E_ooool7oeD000[ooooo00?oZP00
ooooooooool00oooool6oeD000;ooooo00?oZP00ooooooooool05oooool4ogl000Sooooo0omo000G
ooooo`03omD00?oooooooooo00_ooooo00?oe@00ooooooooool04?ooool00onZ003oooooooooo`0L
ooooo`03o`000?oooooooooo01;ooooo000Cooooo`03o`000?oooooooooo05;ooooo1?mE000@oooo
o`03ojX00?oooooooooo00[ooooo0_mE00000oooooooZP00ooooo`0Eooooo`;oO`003oooool2ogl0
01Cooooo00?oe@00ooooooooool03Oooool00ooE003oooooooooo`0>ooooo`03ojX00?oooooooooo
01gooooo00?o0000ooooooooool04_ooool001?ooooo00?o0000ooooooooool0Coooool3oeD001?o
oooo00?oZP00ooooooooool03Oooool2oeD00003ojX00?oooooooooo017ooooo0_mo000Cooooo`;o
O`004Oooool00ooE003oooooooooo`0>ooooo`03omD00?oooooooooo00kooooo00?oZP00oooooooo
ool07Oooool00ol0003oooooooooo`0Booooo`004oooool00ol0003oooooooooo`1=ooooo`;oE@00
5Oooool00onZ003oooooooooo`0@ooooo`04ojX00?mE003oE@00oeD000oooooo00?oO`00oooooooo
ool05Oooool2ogl000oooooo00?oe@00ooooooooool03oooool00ooE003oooooooooo`0=ooooo`03
ojX00?oooooooooo01gooooo00?o0000ooooooooool04_ooool001?ooooo0_l0001<ooooo`;oE@00
5_ooool00onZ003oooooooooo`0Booooo`03ojX00?oooooooooo00;oE@002oooool2ogl001[ooooo
00?oO`00ooooooooool02oooool00ooE003oooooooooo`0@ooooo`03omD00?oooooooooo00gooooo
00?oZP00ooooooooool07?ooool2o`0001Cooooo000Cooooo`03o`000?oooooooooo04Wooooo0_mE
000Eooooo`?oe@005_ooool01?nZ003oooooooooooooool2oeD000Sooooo00?oO`00ooooooooool0
6oooool00omo003oooooooooo`0:ooooo`03omD00?oooooooooo013ooooo00?oe@00ooooooooool0
3Oooool00onZ003oooooooooo`0Mooooo`03o`000?oooooooooo01;ooooo000Cooooo`03o`000?oo
oooooooo04Kooooo0omE000Dooooo`Coe@0000?oooooomD00?oE00000ooE000Booooo`03ojX00?oo
oooooooo00?ooooo0_mE0005ooooo`03ogl00?oooooooooo01gooooo0_mo0009ooooo`03omD00?oo
oooooooo01;ooooo00?oe@00ooooooooool02oooool00onZ003oooooooooo`0Nooooo`03o`000?oo
oooooooo01;ooooo000Cooooo`03o`000?oooooooooo04?ooooo0omE000Eooooo`;oe@001?ooool0
0onZ003oooooooooo`03ooooo`03omD00?oooooooooo013ooooo00?oZP00ooooooooool01?ooool2
oeD000;ooooo00?oO`00ooooooooool08?ooool00omo003oooooooooo`05ooooo`03omD00?oooooo
oooo01?ooooo00?oe@00ooooooooool02oooool00onZ003oooooooooo`0Nooooo`03o`000?oooooo
oooo01;ooooo000Cooooo`03o`000?oooooooooo047ooooo0_mE000Gooooo`03omD00?oooooooooo
00?ooooo00?oZP00ooooooooool01Oooool00ooE003oooooooooo`0@ooooo`03ojX00?oooooooooo
00Gooooo00?oE@00ogl00?ooool08oooool00omo003oooooooooo`04ooooo`03omD00?oooooooooo
01Cooooo00?oe@00ooooooooool02_ooool00onZ003oooooooooo`0Nooooo`03o`000?oooooooooo
01;ooooo000Cooooo`;o0000@?ooool2oeD001Sooooo00?oe@00ooooooooool01?ooool00onZ003o
ooooooooo`06ooooo`03omD00?oooooooooo00oooooo00?oZP00ooooooooool01Oooool00omo003o
E@00ooooo`0Tooooo`03ogl00?oooooooooo00;ooooo00?oe@00ooooooooool05Oooool00ooE003o
ooooooooo`0:ooooo`03ojX00?oooooooooo01gooooo0_l0000Dooooo`004oooool00ol0003ooooo
ooooo`0mooooo`;oE@006Oooool00ooE003oooooooooo`04ooooo`03ojX00?oooooooooo00Oooooo
00?oe@00ooooooooool04?ooool00onZ003oooooooooo`03ooooo`03ogl00?oooooooooo00;oE@00
8oooool00omo003oooooooooo`02ooooo`03omD00?oooooooooo01Gooooo00?oe@00ooooooooool0
2Oooool00onZ003oooooooooo`0Oooooo`03o`000?oooooooooo01;ooooo000Cooooo`03o`000?oo
oooooooo03cooooo00?oE@00ooooooooool06?ooool00ooE003oooooooooo`04ooooo`03ojX00?oo
oooooooo00Wooooo00?oe@00ooooooooool04?ooool01OnZ003oooooooooooooooooO`0000Gooooo
0_mE000Rooooo`04ogl00?ooooooooooomD001Wooooo00?oe@00ooooooooool02?ooool00onZ003o
ooooooooo`0Oooooo`03o`000?oooooooooo01;ooooo00001?l0003oooooooooooooool5o`0000;o
oooo0ol00005ooooo`03o`000?oooooooooo03[ooooo0_mE000Jooooo`03omD00?oooooooooo00Go
oooo00?oZP00ooooooooool02_ooool00ooE003oooooooooo`0?ooooo`05ojX00?oooooooooooooo
oomo00001oooool2oeD0027ooooo00?oO`00oooooooE00006Oooool00ooE003oooooooooo`08oooo
o`03ojX00?oooooooooo01oooooo00?o0000ooooooooool04_ooool000Gooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>?ooool2
oeD001_ooooo00?oe@00ooooooooool01Oooool00onZ003oooooooooo`0;ooooo`03omD00?oooooo
oooo013ooooo00?oZP00oooooomo00002_ooool2oeD0023ooooo00?oe@00ooooooooool06?ooool0
0ooE003oooooooooo`07ooooo`03ojX00?oooooooooo023ooooo00?o0000ooooooooool04_ooool0
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000=oooool2oeD0
01cooooo00?oe@00ooooooooool01Oooool00onZ003oooooooooo`0=ooooo`03omD00?oooooooooo
00oooooo00?oZP00ogl00?ooool03?ooool00omE003oooooooooo`0Mooooo`03omD00?mo003ooooo
01Sooooo00?oe@00ooooooooool01oooool00onZ003oooooooooo`0Oooooo`;o00005?ooool000Oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Go
oooo00?oE@00ooooooooool07?ooool00ooE003oooooooooo`05ooooo`03ojX00?oooooooooo00ko
oooo00?oe@00ooooooooool03oooool00onZ003oooooooooo`0<ooooo`;oE@007Oooool00ooE003o
O`00ooooo`0Iooooo`03omD00?oooooooooo00Kooooo00?oZP00ooooooooool08?ooool00ol0003o
ooooooooo`0Booooo`001?ooool01_l0003ooooooooooooooooo0000ooooo`Co00001Oooool00ol0
003oooooooooo`0dooooo`03oeD00?oooooooooo01cooooo00?oe@00ooooooooool01Oooool00onZ
003oooooooooo`0?ooooo`03omD00?oooooooooo00kooooo00?oO`00ojX00?ooool03oooool00omE
003oooooooooo`0Iooooo`04omD00?ooooooooooogl001Wooooo00?oe@00ooooooooool01_ooool0
0onZ003oooooooooo`0Pooooo`03o`000?oooooooooo01;ooooo0004ooooo`07o`000?oooooooooo
ooooool0003oooooo`000008ooooo`03o`000?oooooooooo03;ooooo0_mE000Nooooo`03omD00?oo
oooooooo00Kooooo00?oZP00ooooooooool04?ooool00ooE003oooooooooo`0<ooooo`04ogl00?oo
ooooooooojX0013ooooo00?oE@00ooooooooool06?ooool01OoE003oooooooooooooooooO`0001So
oooo00?oe@00ooooooooool01Oooool00onZ003oooooooooo`0Qooooo`03o`000?oooooooooo01;o
oooo0005ooooo`?o00000_ooool5o`0000Cooooo00?o0000ooooooooool0<Oooool00omE003ooooo
ooooo`0Nooooo`03omD00?oooooooooo00Gooooo00?oZP00ooooooooool04Oooool00ooE003ooooo
ooooo`0<ooooo`04ogl00?ooooooooooojX0017ooooo00?oE@00ooooooooool05_ooool00ooE003o
ooooooooo`03ooooo`03ogl00?oooooooooo01Kooooo00?oe@00ooooooooool01?ooool00onZ003o
ooooooooo`0Qooooo`03o`000?oooooooooo01;ooooo000Cooooo`;o00005oooool00ol00?oooooo
ooooo`0Gooooo`03oeD00?oooooooooo01kooooo00?oe@00ooooooooool01_ooool00onZ003ooooo
ooooo`0Booooo`03omD00?oooooooooo00[ooooo00?oO`00ooooooooool00_ooool00onZ003ooooo
ooooo`0?ooooo`03oeD00?oooooooooo01Gooooo00?oe@00ooooooooool01?ooool00omo003ooooo
ooooo`0Eooooo`03omD00?oooooooooo00Cooooo00?oZP00ooooooooool08?ooool2o`0001Cooooo
000Cooooo`03o`000?oooooooooo01Kooooo00?o003oooooooooool05Oooool2oeD0023ooooo00?o
e@00ooooooooool01_ooool00onZ003oooooooooo`0Cooooo`03omD00?oooooooooo00[ooooo00?o
O`00ooooooooool00_ooool00onZ003oooooooooo`0@ooooo`03oeD00?oooooooooo01?ooooo00?o
e@00ooooooooool01Oooool00omo003oooooooooo`0Eooooo`03omD00?oooooooooo00?ooooo00?o
ZP00ooooooooool08_ooool00ol0003oooooooooo`0Booooo`004oooool00ol0003oooooooooo`0F
ooooo`03o`00oooooooooooo01Cooooo00?oE@00ooooooooool08?ooool00ooE003oooooooooo`06
ooooo`03ojX00?oooooooooo01?ooooo00?oe@00ooooooooool02Oooool00omo003oooooooooo`04
ooooo`03ojX00?oooooooooo013ooooo00?oE@00ooooooooool04_ooool00ooE003oooooooooo`06
ooooo`03ogl00?oooooooooo01Cooooo00?oe@00ooooooooool00oooool00onZ003oooooooooo`0R
ooooo`03o`000?oooooooooo01;ooooo000Cooooo`03o`000?oooooooooo01Kooooo00?o003ooooo
ooooool04oooool00omE003oooooooooo`0Pooooo`03omD00?oooooooooo00Kooooo00?oZP00oooo
ooooool05Oooool00ooE003oooooooooo`07ooooo`03ogl00?oooooooooo00Gooooo00?oZP00oooo
ooooool04Oooool2oeD001;ooooo00?oe@00ooooooooool01oooool00omo003oooooooooo`0Doooo
o`03omD00?oooooooooo00;ooooo00?oZP00ooooooooool08_ooool00ol0003oooooooooo`0Boooo
o`004oooool00ol0003oooooooooo`0Fooooo`03o`00oooooooooooo017ooooo0_mE000Rooooo`03
omD00?oooooooooo00Oooooo00?oZP00ooooooooool05Oooool00ooE003oooooooooo`07ooooo`03
ogl00?oooooooooo00Kooooo00?oZP00ooooooooool04_ooool00omE003oooooooooo`0>ooooo`03
omD00?oooooooooo00Wooooo00?oO`00ooooooooool04oooool01OoE003oooooooooooooooooZP00
02Gooooo00?o0000ooooooooool04_ooool001?ooooo0_l0000Gooooo`03o`00oooooooooooo013o
oooo00?oE@00ooooooooool08_ooool00ooE003oooooooooo`06ooooo`03ojX00?oooooooooo01Oo
oooo00?oe@00ooooooooool01Oooool00omo003oooooooooo`08ooooo`03ojX00?oooooooooo01;o
oooo00?oE@00ooooooooool03Oooool00ooE003oooooooooo`0:ooooo`03ogl00?oooooooooo01;o
oooo00Goe@00ooooooooooooooooojX0000Tooooo`;o00005?ooool001?ooooo00?o0000oooooooo
ool05_ooool00ol00?ooooooooooo`0?ooooo`03oeD00?oooooooooo02;ooooo00?oe@00oooooooo
ool01oooool00onZ003oooooooooo`0Gooooo`03omD00?oooooooooo00Gooooo00?oO`00oooooooo
ool02?ooool00onZ003oooooooooo`0Cooooo`03oeD00?oooooooooo00_ooooo00?oe@00oooooooo
ool02oooool00omo003oooooooooo`0Cooooo`04omD00?ooooooooooojX002Gooooo00?o0000oooo
ooooool04_ooool001?ooooo00?o0000ooooooooool05_ooool00ol00?ooooooooooo`0=ooooo`;o
E@009?ooool00ooE003oooooooooo`07ooooo`03ojX00?oooooooooo01Wooooo00?oe@00oooooooo
ool00oooool00omo003oooooooooo`0:ooooo`03ojX00?oooooooooo01?ooooo00?oE@00oooooooo
ool02_ooool00ooE003oooooooooo`0<ooooo`03ogl00?oooooooooo01;ooooo00?oe@00oooooonZ
00009_ooool00ol0003oooooooooo`0Booooo`004oooool00ol0003oooooooooo`0Fooooo`03o`00
oooooooooooo00cooooo00?oE@00ooooooooool09?ooool00ooE003oooooooooo`07ooooo`03ojX0
0?oooooooooo01Wooooo00?oe@00ooooooooool00oooool00omo003oooooooooo`0:ooooo`03ojX0
0?oooooooooo01Cooooo00?oE@00ooooooooool02Oooool00ooE003oooooooooo`0<ooooo`03ogl0
0?oooooooooo01;ooooo00?oe@00oooooonZ00009_ooool00ol0003oooooooooo`0Booooo`004ooo
ool00ol0003oooooooooo`0Fooooo`03o`00oooooooooooo00_ooooo00?oE@00ooooooooool09?oo
ool00ooE003oooooooooo`07ooooo`03ojX00?oooooooooo01[ooooo00?oe@00ooooooooool00_oo
ool00omo003oooooooooo`0<ooooo`03ojX00?oooooooooo01Cooooo00?oE@00ooooooooool01ooo
ool00ooE003oooooooooo`0>ooooo`03ogl00?oooooooooo017ooooo00?oe@00ojX00?ooool09_oo
ool00ol0003oooooooooo`0Booooo`004oooool2o`0001Oooooo00?o003oooooooooool02Oooool2
oeD002Oooooo00?oe@00ooooooooool01oooool00onZ003oooooooooo`0Kooooo`05omD00?oooooo
oooooooooomo00003oooool00onZ003oooooooooo`0Dooooo`03oeD00?oooooooooo00Kooooo00?o
e@00ooooooooool03oooool00omo003oooooooooo`0@ooooo`03omD00?nZ003ooooo02Gooooo0_l0
000Dooooo`004oooool00ol0003oooooooooo`0Fooooo`03o`00oooooooooooo00Sooooo00?oE@00
ooooooooool09_ooool00ooE003oooooooooo`07ooooo`03ojX00?oooooooooo01cooooo00Coe@00
ooooooooooooO`004?ooool00onZ003oooooooooo`0Eooooo`03oeD00?oooooooooo00Cooooo00?o
e@00ooooooooool04?ooool00omo003oooooooooo`0Aooooo`03omD00?oooooooooo01?ooooo0_l0
0?l00ooooooo003oo`00o`0=ooooo`03o`000?oooooooooo01;ooooo000Cooooo`03o`000?oooooo
oooo01Kooooo00?o003oooooooooool01oooool00omE003oooooooooo`0Vooooo`03omD00?oooooo
oooo00Sooooo00?oZP00ooooooooool07?ooool01?oE003ooooooooooomo000Aooooo`03ojX00?oo
oooooooo01Gooooo00?oE@00ooooooooool00oooool00ooE003oooooooooo`0Aooooo`03ogl00?oo
oooooooo00oooooo00?oZP00omD00?ooool05Oooool00ol00?ooooooo`00o`0>ooooo`03o`000?oo
oooooooo01;ooooo000Cooooo`03o`000?oooooooooo01Kooooo00?o003oooooooooool01Oooool2
oeD002Wooooo00?oe@00ooooooooool01oooool00onZ003oooooooooo`0Nooooo`03omD00?mo003o
oooo01;ooooo00?oZP00ooooooooool05Oooool00omE003oooooooooo`02ooooo`03omD00?oooooo
oooo017ooooo00?oO`00ooooooooool03oooool00onZ003oe@00ooooo`0Fooooo`03o`00oooooooo
oooo00gooooo00?o0000ooooooooool04_ooool001?ooooo00?o0000ooooooooool05_ooool00ol0
0?ooooooooooo`03ooooo`;oE@00:_ooool00ooE003oooooooooo`08ooooo`03ojX00?oooooooooo
01kooooo00?oe@00ogl00?ooool04_ooool00onZ003oooooooooo`0Fooooo`04oeD00?oooooooooo
omD001Gooooo00?oO`00ooooooooool03_ooool00onZ003oe@00ooooo`0Eooooo`03o`00oooooooo
003o00kooooo00?o0000ooooooooool04_ooool001?ooooo0_l0000Gooooo`03o`00oooooooooooo
00;ooooo00?oE@00ooooooooool0:_ooool00ooE003oooooooooo`07ooooo`03ojX00?oooooooooo
01oooooo00?oe@00ooooooooool04oooool00onZ003oooooooooo`0Fooooo`03oeD00?ooooooe@00
01Kooooo00?oO`00ooooooooool03?ooool00onZ003oooooomD0000Eooooo`;o003o00?oooooo`00
ool00?l03?ooool2o`0001Cooooo000Cooooo`03o`000?oooooooooo01Kooooo00Go003ooooooooo
oooooooooeD0000/ooooo`03omD00?oooooooooo00Sooooo00?oZP00ooooooooool07oooool00omo
003oe@00ooooo`0Dooooo`03ojX00?oooooooooo01Kooooo00?oE@00omD00?ooool05Oooool00omo
003oooooooooo`0<ooooo`04ojX00?ooooooooooomD002Kooooo00?o0000ooooooooool04_ooool0
00cooooo0_l00005ooooo`03o`000?oooooooooo01Kooooo00Co003oooooooooooooE@00;Oooool0
0ooE003oooooooooo`08ooooo`03ojX00?oooooooooo01kooooo00?oO`00oooooooE00005_ooool0
0onZ003oooooooooo`0Eooooo`03omD00?mE003ooooo01Kooooo00?oO`00ooooooooool02_ooool0
1OnZ003oooooooooooooooooe@0002Kooooo00?o0000ooooooooool04_ooool000_ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`0Eooooo`?o000000?oE@00ooooooooool0:ooo
ool00ooE003oooooooooo`08ooooo`03ojX00?oooooooooo01kooooo00CoO`00ooooooooooooe@00
0_ooool4o`00013ooooo00?oZP00ooooooooool05Oooool00ooE003ooooooeD0000Gooooo`03ogl0
0?oooooooooo00Wooooo00GoZP00ooooooooooooooooomD0000;ooooo`Co00005oooool00ol0003o
ooooooooo`0Booooo`002oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01Go
oooo00?o0000o`00oomE00001_oo00000oooooooo`00ool00004ooooo`05ool00?ooooooo`00ool0
0?ooool00_oo00000oooooooo`00ooooo`02ool00008oooooooo003ooooooooooooo003oooooool0
0?ooool2ool000Cooooo00Goo`00ooooooooooooo`00ooooo`02ool00003oooooooo003ooooo00?o
o`0000?oooooool00?ooool00ooo0003ooooo`04ool00?ooooooooooool001Wooooo00CoO`00oooo
ooooooooe@000_ooool01Ol0003oooooooooool0003oo`0000Kooooo00?oo`00ooooooooool01ooo
ool00onZ003oooooooooo`0Dooooo`04omD00?oooooooooooeD000;ooooo00?oo`00ooooooooool0
4Oooool00omo003oooooooooo`09ooooo`05ojX00?oooooooooooooooooE00002oooool01?l0003o
ooooooooool0000Gooooo`03o`000?oooooooooo01;ooooo000;ooooo`04o`000?ooooooooooo`00
00Cooooo0_l00004oooooa7o003o00?o0000o`00oooo0000VOoo000?o`000003ogl00?l0003o0000
00Oo000000?oZP00o`000?l000000_l000000ooE003o0000o`00000<o`000003o`00ool0003o003o
013o003o1?ooool2o`0001Cooooo000;ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool05Oooool01?l0003oe@00o`000?l00005obX002Kooooo00?oe@00ooooooooool02Oooool0
0onZ003oooooooooo`0Nooooo`03ogl00?oooooooooo00;ooooo00Goe@00ooooool0003oooooo`00
000Cooooo`03ojX00?oooooooooo01;ooooo00?oe@00ooooooooool00oooool00omE003ooooooooo
o`0Dooooo`03ogl00?oooooooooo00Kooooo00?oZP00ooooooooool00oooool00ooE003ooooooooo
o`08ooooo`;o000000?oooooo`000?ooool05_ooool00ol0003oooooooooo`0Booooo`002oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo01Kooooo00?oZP00omD00?ooool01Ooo
ool4obX002;ooooo00?oe@00ooooooooool02?ooool00onZ003oooooooooo`0Nooooo`03ogl00?oo
oooooooo00?ooooo00Coe@00oooooooooooo00005Oooool00onZ003oooooooooo`0@ooooo`03omD0
0?oooooooooo00Gooooo00?oE@00ooooooooool04oooool00omo003oooooooooo`06ooooo`03ojX0
0?oooooooooo00?ooooo00?oe@00ooooooooool02_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo01;ooooo000<ooooo`;o00001Oooool00ol0003oooooooooo`0Fooooo`03o`00oooE
003ooooo00Wooooo1?lZ000Mooooo`03omD00?oooooooooo00Wooooo00?oZP00ooooooooool07Ooo
ool00omo003oooooooooo`04ooooo`03omD00?oooooooooo01Oooooo00?oZP00ooooooooool03ooo
ool00ooE003oooooooooo`05ooooo`03oeD00?oooooooooo01Cooooo00?oO`00ooooooooool01?oo
ool00onZ003oooooooooo`04ooooo`03omD00?oooooooooo02?ooooo00?o0000ooooooooool04_oo
ool001?ooooo00?o0000ooooooooool05_ooool00ol00?ooe@00ogl00002ooooo`?o00002?ooool4
obX001Wooooo00?oe@00ooooooooool02?ooool00onZ003oooooooooo`0Nooooo`03ogl00?oooooo
oooo00Gooooo00?oe@00ooooooooool00oooool5o`0000kooooo00?oZP00ooooooooool03_ooool0
0ooE003oooooooooo`07ooooo`03oeD00?oooooooooo01?ooooo00?oO`00ooooooooool01?ooool0
0onZ003oooooooooo`04ooooo`03omD00?oooooooooo00kooooo0ol0000Booooo`03o`000?oooooo
oooo01;ooooo000Cooooo`;o00005oooool01?l00?ooZP00omD00?mo0002ooooo`03o`000?oooooo
oooo00_ooooo1?lZ000Dooooo`03omD00?oooooooooo00Wooooo00?oZP00ooooooooool07Oooool0
0omo003oooooooooo`06ooooo`03omD00?oooooooooo00Cooooo00Co0000oooooooooooo00003ooo
ool00onZ003oooooooooo`0=ooooo`03omD00?oooooooooo00Sooooo00?oE@00ooooooooool04ooo
ool00omo003oooooooooo`03ooooo`03ojX00?oooooooooo00Cooooo00?oe@00ooooooooool03Ooo
ool01Ol0003ooooooooooooooooo0000013ooooo0_l0000Dooooo`004oooool00ol0003ooooooooo
o`0Fooooo`04o`00oonZ003oe@00ogl000;o003o00?o0000ooooooooool03oooool4obX0013ooooo
00?oe@00ooooooooool02Oooool00onZ003oooooooooo`0Looooo`03ogl00?oooooooooo00Oooooo
00?oe@00ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03ojX00?oooooooooo00_ooooo
00?oe@00ooooooooool02_ooool00omE003oooooooooo`0Cooooo`05ogl00?oooooooooooooooonZ
00002?ooool00ooE003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool04_ooool001?ooooo00?o0000ooooooooool05_ooool01ol00?ooooooomD00?ooooooO`00o`00
ool000005Oooool4obX000_ooooo00?oe@00ooooooooool02Oooool00onZ003oooooooooo`0Moooo
o`03ogl00?oooooooooo00Oooooo00?oe@00ooooooooool01_ooool00ol0003oooooooooo`0?oooo
o`03ojX00?oooooooooo00_ooooo00?oe@00ooooooooool02oooool00omE003oooooooooo`0Boooo
o`05ogl00?oooooooooooooooonZ00002?ooool00ooE003oooooooooo`0>ooooo`;o00004_ooool0
0ol0003oooooooooo`0Booooo`004oooool00ol0003oooooooooo`0Fooooo`07o`00ooooooooZP00
omD00?mo003oooooo`00000Iooooo`Co:P001oooool00ooE003oooooooooo`09ooooo`03ojX00?oo
oooooooo01cooooo00?oO`00ooooooooool02Oooool00ooE003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000004Oooool00onZ003oooooooooo`0:ooooo`03omD00?oooooooooo00cooooo
00?oE@00ooooooooool04_ooool00omo003oooooojX00009ooooo`03omD00?oooooooooo013ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Booooo`004oooool00ol0003ooooooooo
o`0Fooooo`07o`00ooooooooZP00omD00?ooooooO`00o`00000Mooooo`?o:P000oooool00ooE003o
ooooooooo`09ooooo`03ojX00?oooooooooo01cooooo00?oO`00ooooooooool02_ooool00ooE003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000004Oooool00onZ003oooooooooo`09oooo
o`03omD00?oooooooooo00kooooo00?oE@00ooooooooool04Oooool00omo003oooooojX00009oooo
o`03omD00?oooooooooo00cooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooo
oooo01;ooooo000Cooooo`;o00005oooool02?l00?ooooooojX00?oE003oooooo`00oomo003o003o
7oooool3obX00003omD00?oooooooooo00Wooooo00?oZP00ooooooooool06oooool00omo003ooooo
ooooo`0;ooooo`03omD00?oooooooooo00?ooooo0ol0000Cooooo`03ojX00?oooooooooo00Sooooo
00?oe@00ooooooooool03oooool00omE003oooooooooo`0Aooooo`03ojX00?oooooooooo00Sooooo
00?oe@00ooooooooool03Oooool3o`00017ooooo0_l0000Dooooo`004oooool00ol0003ooooooooo
o`0Fooooo`08o`00ooooooooooooojX00?oE003o003oogl00?l00?lQooooo`04omD00?lZ003o:P00
obX000Sooooo00?oZP00ooooooooool06oooool00omo003oooooooooo`0<ooooo`03omD00?oooooo
oooo01[ooooo00?oZP00ooooooooool01_ooool00ooE003oooooooooo`0Aooooo`03oeD00?oooooo
oooo013ooooo00?oZP00ooooooooool02?ooool00ooE003oooooooooo`0Rooooo`03o`000?oooooo
oooo01;ooooo000Cooooo`03o`000?oooooooooo01Kooooo00Wo003oooooooooooooZP00omD00?l0
0?ooooooogl00?l00?l07oooool00ooE003oooooooooo`02ooooo`Co:P001?ooool00onZ003ooooo
ooooo`0Jooooo`03ogl00?oooooooooo00kooooo00?oe@00ooooooooool06Oooool00onZ003ooooo
ooooo`06ooooo`03omD00?oooooooooo01;ooooo00?oE@00ooooooooool03_ooool00onZ003ooooo
ogl0000:ooooo`03omD00?oooooooooo027ooooo00?o0000ooooooooool04_ooool001?ooooo00?o
0000ooooooooool05_ooool01Ol00?oooooooooooonZ003oe@0000;ooooo00?oO`00ooooooooool0
7_ooool00ooE003oooooooooo`06ooooo`?o:P0000?oZP00ooooooooool06oooool00omo003ooooo
ooooo`0>ooooo`03omD00?oooooooooo01[ooooo00?oZP00ooooooooool01?ooool00ooE003ooooo
ooooo`0Dooooo`03oeD00?oooooooooo00gooooo00?oZP00oooooomo00002_ooool00ooE003ooooo
ooooo`0Qooooo`03o`000?oooooooooo01;ooooo000Cooooo`;o00005oooool01_l00?oooooooooo
oonZ003oooooomD000;ooooo00?oO`00ooooooooool07?ooool00ooE003oooooooooo`0:ooooo`03
ojX00?lZ003o:P0000;o:P006?ooool00omo003oooooooooo`0?ooooo`03omD00?oooooooooo01[o
oooo00?oZP00ooooooooool01?ooool00ooE003oooooooooo`0Eooooo`03oeD00?oooooooooo00_o
oooo00GoZP00ooooooooooooooooogl00009ooooo`03omD00?oooooooooo023ooooo0_l0000Doooo
o`004oooool00ol0003oooooooooo`0Fooooo`06o`00oooooooooooooooooonZ003oe@000oooool0
0omo003oooooooooo`0Jooooo`03omD00?oooooooooo00[ooooo00?oZP00ooooooooool00oooool4
obX001?ooooo00?oO`00ooooooooool04?ooool00ooE003oooooooooo`0Kooooo`03ojX00?oooooo
oooo00?ooooo00?oe@00ooooooooool05_ooool00omE003oooooooooo`0:ooooo`05ojX00?oooooo
oooooooooomo00002Oooool00ooE003oooooooooo`0Qooooo`03o`000?oooooooooo01;ooooo000C
ooooo`03o`000?oooooooooo01Kooooo00Oo003oooooooooooooooooojX00?ooooooe@0000;ooooo
00?oO`00ooooooooool06_ooool00ooE003oooooooooo`0:ooooo`03ojX00?oooooooooo00Oooooo
1?lZ000>ooooo`03ogl00?oooooooooo01;ooooo00?oe@00ooooooooool06oooool01OnZ003ooooo
ooooooooooooe@0001[ooooo00?oE@00ooooooooool02?ooool00onZ003oooooooooo`03ooooo`03
ogl00?oooooooooo00Kooooo00?oe@00ooooooooool08Oooool00ol0003oooooooooo`0Booooo`00
4oooool00ol0003oooooooooo`0Fooooo`07o`00oooooooooooooooooonZ003oooooomD00003oooo
o`03ogl00?oooooooooo01Sooooo00?oe@00ooooooooool02_ooool00onZ003oooooooooo`0<oooo
o`Co:P002Oooool00omo003oooooooooo`0Cooooo`03omD00?oooooooooo01cooooo00CoZP00oooo
ooooooooe@006_ooool00omE003oooooooooo`08ooooo`03ojX00?oooooooooo00?ooooo00?oO`00
ooooooooool01_ooool00ooE003oooooooooo`0Qooooo`03o`000?oooooooooo01;ooooo000Coooo
o`03o`000?oooooooooo01Kooooo00?o003oooooooooool00_ooool00onZ003oooooomD00003oooo
o`03ogl00?oooooooooo01Kooooo00?oe@00ooooooooool02oooool00onZ003oooooooooo`0@oooo
o`Co:P001Oooool00omo003oooooooooo`0Cooooo`03omD00?oooooooooo01gooooo00?oZP00omD0
0?ooool06oooool00omE003oooooooooo`06ooooo`03ojX00?oooooooooo00Gooooo00?oO`00oooo
ooooool01Oooool00ooE003oooooooooo`0Qooooo`03o`000?oooooooooo01;ooooo000Cooooo`;o
00005oooool00ol00?ooooooooooo`02ooooo`04ojX00?ooooooooooomD000;ooooo00?oO`00oooo
ooooool05Oooool00ooE003oooooooooo`0;ooooo`03ojX00?oooooooooo01Gooooo1?lZ00000omo
003oooooooooo`0Dooooo`03omD00?oooooooooo01kooooo00?oe@00ooooooooool06oooool00omE
003oooooooooo`04ooooo`03ojX00?oooooooooo00Kooooo00?oO`00ooooooooool01_ooool00ooE
003oooooooooo`0Oooooo`;o00005?ooool001?ooooo00?o0000ooooooooool06oooool01?nZ003o
oooooooooooE0003ooooo`03ogl00?oooooooooo01?ooooo00?oe@00ooooooooool03?ooool00onZ
003oooooooooo`0Hooooo`03ogl00?lZ003o:P0000?o:P004oooool00ooE003oooooooooo`0Moooo
o`03omD00?nZ003ooooo01cooooo00?oE@00ooooooooool00oooool00onZ003oooooooooo`07oooo
o`03ogl00?oooooooooo00Gooooo00?oe@00ooooooooool08?ooool00ol0003oooooooooo`0Boooo
o`004oooool00ol0003oooooooooo`0Looooo`04ojX00?ooooooooooomD000?ooooo00?oO`00oooo
ooooool04Oooool00ooE003oooooooooo`0<ooooo`03ojX00?oooooooooo01Sooooo00?oO`00oooo
ooooool01?ooool4obX000oooooo00?oe@00ooooooooool07?ooool01?oE003ooooooooooonZ000M
ooooo`05oeD00?oooooooooooooooonZ00002_ooool00omo003oooooooooo`05ooooo`03omD00?oo
oooooooo023ooooo00?o0000ooooooooool04_ooool00004o`000?ooooooooooooooo`Go00000_oo
ool3o`0000Gooooo00?o0000ooooooooool07?ooool01?nZ003ooooooooooooE0003ooooo`03ogl0
0?oooooooooo013ooooo00?oe@00ooooooooool03Oooool00onZ003oooooooooo`0Gooooo`03ogl0
0?oooooooooo00Wooooo0olZ000<ooooo`03omD00?oooooooooo01cooooo00Goe@00oooooooooooo
ooooojX0000Mooooo`04oeD00?ooooooooooojX000_ooooo00?oO`00ooooooooool01?ooool00ooE
003oooooooooo`0Pooooo`03o`000?oooooooooo01;ooooo0005ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo00CoZP00
ooooooooooooe@000oooool00omo003oooooooooo`0>ooooo`03omD00?oooooooooo00gooooo00?o
ZP00ooooooooool05oooool00omo003oooooooooo`0=ooooo`;o:P002oooool00ooE003ooooooooo
o`0Jooooo`03omD00?oooooooooo00?ooooo00?oZP00ooooooooool06oooool00omE003oZP00oooo
o`0;ooooo`03ogl00?oooooooooo00Cooooo00?oe@00ooooooooool08?ooool00ol0003ooooooooo
o`0Booooo`001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l0000N
ooooo`05ojX00?oooooooooooooooooE00000oooool00omo003oooooooooo`0<ooooo`03omD00?oo
oooooooo00kooooo00?oZP00ooooooooool05_ooool00omo003oooooooooo`0@ooooo`?o:P002?oo
ool00ooE003oooooooooo`0Jooooo`03omD00?oooooooooo00Cooooo00?oZP00ooooooooool06_oo
ool00onZ003oE@00ooooo`0<ooooo`03ogl00?oooooooooo00?ooooo00?oe@00ooooooooool07ooo
ool2o`0001Cooooo0007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Mooooo`05ojX00?oooooooooooooooooE00001?ooool00omo003ooooooooo
o`0:ooooo`03omD00?oooooooooo00kooooo00?oZP00ooooooooool05_ooool00omo003ooooooooo
o`0Dooooo`Co:P001?ooool00ooE003oooooooooo`0Iooooo`03omD00?oooooooooo00Kooooo00?o
ZP00ooooooooool06?ooool01?nZ003ooooooooooomE000<ooooo`03ogl00?oooooooooo00Cooooo
00?oe@00ooooooooool07oooool00ol0003oooooooooo`0Booooo`001?ooool01_l0003ooooooooo
oooooooo0000ooooo`Co00001Oooool00ol0003oooooooooo`0Nooooo`05ojX00?oooooooooooooo
oooE00001?ooool00omo003oooooooooo`08ooooo`03omD00?oooooooooo00oooooo00?oZP00oooo
ooooool05Oooool00omo003oooooooooo`0Iooooo`Co:P0000?oooooomD00?ooool06Oooool00ooE
003oooooooooo`07ooooo`03ojX00?oooooooooo01Kooooo00GoZP00oooooooooooooooooeD0000=
ooooo`03ogl00?oooooooooo00?ooooo00?oe@00ooooooooool07oooool00ol0003oooooooooo`0B
ooooo`001?ooool01ol0003ooooooooooooooooo0000ooooool000002?ooool00ol0003ooooooooo
o`0Nooooo`03ojX00?oooooooooo00;ooooo0_oE0003ooooo`03ogl00?oooooooooo00Kooooo00?o
e@00ooooooooool03oooool00onZ003oooooooooo`0Eooooo`03ogl00?oooooooooo01kooooo00Co
:P00omD00?lZ003o:P006?ooool00ooE003oooooooooo`08ooooo`03ojX00?oooooooooo01Cooooo
00?oZP00ooooooooool00oooool00omE003oooooooooo`0:ooooo`03ogl00?oooooooooo00?ooooo
00?oe@00ooooooooool07oooool00ol0003oooooooooo`0Booooo`001Oooool3o`0000;ooooo1Ol0
0004ooooo`03o`000?oooooooooo01kooooo00?oZP00ooooooooool01?ooool01OoE003ooooooooo
ooooooooO`0000Kooooo00?oe@00ooooooooool04?ooool00onZ003oooooooooo`0Dooooo`03ogl0
0?oooooooooo023ooooo00?oe@00ooooooooool01?lZ000Cooooo`03omD00?oooooooooo00[ooooo
0_nZ000Booooo`;oZP001oooool00omE003oooooooooo`09ooooo`03ogl00?oooooooooo00?ooooo
00?oe@00ooooooooool07oooool00ol0003oooooooooo`0Booooo`004oooool2o`00023ooooo00?o
ZP00ooooooooool01?ooool01OoE003oooooooooooooooooO`0000?ooooo0_oE000Booooo`03ojX0
0?oooooooooo01Cooooo00?oO`00ooooooooool08Oooool00ooE003oooooooooo`04ooooo`Co:P00
3oooool00ooE003oooooooooo`0<ooooo`;oZP003oooool00onZ003oooooooooo`08ooooo`03oeD0
0?oooooooooo00Wooooo00?oO`00ooooooooool00_ooool00ooE003oooooooooo`0Nooooo`;o0000
5?ooool001?ooooo00?o0000ooooooooool07oooool00onZ003oooooooooo`05ooooo`Ooe@005?oo
ool00onZ003oooooooooo`0Booooo`;oO`009Oooool00ooE003oooooooooo`07ooooo`Go:P002Ooo
ool00ooE003oooooooooo`0?ooooo`;oZP003?ooool00onZ003oooooooooo`0:ooooo`03oeD00?oo
oooooooo00Sooooo00?oO`00ooooooooool00_ooool00ooE003oooooooooo`0Oooooo`03o`000?oo
oooooooo01;ooooo000Cooooo`03o`000?oooooooooo023ooooo00?oZP00ooooooooool02Oooool0
0omo003oooooooooo`0Booooo`03ojX00?oooooooooo01;ooooo00?oO`00ooooooooool09Oooool0
0ooE003oooooooooo`0<ooooo`Co:P001Oooool00ooE003oooooooooo`0Aooooo`?oZP001Oooool4
ojX000gooooo00?oE@00ooooooooool02Oooool01Omo003oooooooooooooooooe@00027ooooo00?o
0000ooooooooool04_ooool001?ooooo00?o0000ooooooooool08?ooool00onZ003oooooooooo`0:
ooooo`03ogl00?oooooooooo017ooooo00?oZP00ooooooooool04Oooool00omo003oooooooooo`0V
ooooo`03omD00?oooooooooo013ooooo1?lZ00000ooE003oooooooooo`0Dooooo`KoZP004_ooool0
0omE003oooooooooo`08ooooo`03ogl00?oooooooooo00;ooooo00?oe@00ooooooooool07_ooool0
0ol0003oooooooooo`0Booooo`004oooool00ol0003oooooooooo`0Pooooo`03ojX00?oooooooooo
00_ooooo00?oO`00ooooooooool03oooool00onZ003oooooooooo`0@ooooo`;oO`00:_ooool00ooE
003oooooooooo`0Cooooo`04omD00?lZ003o:P00obX002cooooo00?oE@00ooooooooool02?ooool0
1Omo003oooooooooooooooooe@00023ooooo00?o0000ooooooooool04_ooool001?ooooo0_l0000R
ooooo`03ojX00?oooooooooo00_ooooo0_mo000?ooooo`03ojX00?oooooooooo00oooooo00?oO`00
ooooooooool0:_ooool00ooE003oooooooooo`0Booooo`03omD00?oooooooooo00;ooooo1?lZ000Y
ooooo`03oeD00?oooooooooo00Oooooo00GoO`00ooooooooooooooooomD0000Oooooo`;o00005?oo
ool001?ooooo00?o0000ooooooooool08Oooool00onZ003oooooooooo`0=ooooo`03ogl00?oooooo
oooo00_ooooo00?oZP00ooooooooool03oooool00omo003oooooooooo`0[ooooo`03omD00?oooooo
oooo017ooooo00?oe@00ooooooooool01oooool3obX002Oooooo00?oE@00ooooooooool01oooool0
1?mo003ooooooooooooE000Pooooo`03o`000?oooooooooo01;ooooo000Cooooo`03o`000?oooooo
oooo02;ooooo00?oZP00ooooooooool03Oooool00omo003oooooooooo`09ooooo`03ojX00?oooooo
oooo00kooooo0_mo000_ooooo`03omD00?oooooooooo013ooooo00?oe@00ooooooooool02_ooool2
obX002Gooooo00?oE@00ooooooooool01oooool01?mo003ooooooooooooE000Pooooo`03o`000?oo
oooooooo01;ooooo000Cooooo`03o`000?oooooooooo02;ooooo00?oZP00ooooooooool03_ooool2
ogl000Sooooo00?oZP00ooooooooool03Oooool2ogl0037ooooo00?oe@00ooooooooool03oooool0
0ooE003oooooooooo`0=ooooo`?o:P008oooool00omE003oooooooooo`06ooooo`04ogl00?oooooo
ooooomD0023ooooo00?o0000ooooooooool04_ooool001?ooooo00?o0000ooooooooool08oooool0
0onZ003oooooooooo`0?ooooo`;oO`001Oooool00onZ003oooooooooo`0<ooooo`;oO`00=?ooool0
0ooE003oooooooooo`0>ooooo`03omD00?oooooooooo013ooooo1?lZ000Pooooo`03oeD00?oooooo
oooo00Kooooo00?oO`00oooooooE00008?ooool00ol0003oooooooooo`0Booooo`004oooool2o`00
02Cooooo00?oZP00ooooooooool04Oooool2ogl000;ooooo00?oZP00ooooooooool02oooool2ogl0
03Kooooo00?oe@00ooooooooool03Oooool00ooE003oooooooooo`0Eooooo`Co:P007?ooool00omE
003oooooooooo`06ooooo`04ogl00?ooooooooooomD001kooooo0_l0000Dooooo`004oooool00ol0
003oooooooooo`0Tooooo`03ojX00?oooooooooo01;ooooo0_mo00001?nZ003oO`00ogl00?mo0005
ooooo`GoO`00>Oooool00ooE003oooooooooo`0;ooooo`03omD00?oooooooooo01[ooooo1?lZ000I
ooooo`03oeD00?oooooooooo00Kooooo00?oO`00oooooooE00007oooool00ol0003oooooooooo`0B
ooooo`004oooool00ol0003oooooooooo`0Tooooo`03ojX00?oooooooooo01?ooooo00CoZP00oooo
oooooooooooo1_mo000oooooo`03omD00?oooooooooo00Wooooo00?oe@00ooooooooool07oooool5
obX001Gooooo00?oE@00ooooooooool01Oooool00omo003oooooomD0000Oooooo`03o`000?oooooo
oooo01;ooooo000Cooooo`03o`000?oooooooooo02Gooooo00?oZP00ooooooooool04Oooool00onZ
003oooooooooo`18ooooo`03omD00?oooooooooo00Oooooo00?oe@00ooooooooool09Oooool4obX0
01;ooooo00?oE@00ooooooooool01Oooool00omo003oe@00ooooo`0Nooooo`03o`000?oooooooooo
01;ooooo000Cooooo`03o`000?oooooooooo02Kooooo00?oZP00ooooooooool03oooool00onZ003o
ooooooooo`1:ooooo`;oe@001_ooool00ooE003oooooooooo`0Zooooo`Co:P003oooool00omE003o
ooooooooo`04ooooo`03ogl00?oE003ooooo01kooooo00?o0000ooooooooool04_ooool001?ooooo
0_l0000Xooooo`03ojX00?oooooooooo00gooooo00?oZP00ooooooooool0C?ooool7omD0037ooooo
1?lZ000<ooooo`03oeD00?oooooooooo00?ooooo00?oO`00omD00?ooool07Oooool2o`0001Cooooo
000Cooooo`03o`000?oooooooooo02Sooooo00?oZP00ooooooooool02oooool00onZ003ooooooooo
o`1@ooooo`03omD00?oooooooooo03Kooooo1?lZ0009ooooo`03oeD00?oooooooooo00?ooooo00?o
e@00ooooooooool07Oooool00ol0003oooooooooo`0Booooo`004oooool00ol0003oooooooooo`0Y
ooooo`03ojX00?oooooooooo00Sooooo0_nZ002@ooooo`Co:P001_ooool00omE003oooooooooo`02
ooooo`03omD00?oooooooooo01gooooo00?o0000ooooooooool04_ooool000;o00001?ooool00ol0
003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`0Zooooo`03ojX00?oooooooooo
00Kooooo00?oZP00ooooooooool0U?ooool5obX00003oooooomE003ooooo00?ooooo00?oe@00oooo
ooooool07Oooool00ol0003oooooooooo`0Booooo`000_ooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0[ooooo`?oZP000oooool2ojX0
09cooooo0_lZ00000omE003oooooooooo`02ooooo`03omD00?oooooooooo01cooooo00?o0000oooo
ooooool04_ooool000;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`;o
0000;_ooool4ojX00:7ooooo00GoE@00obX00?ooooooooooomD0000Mooooo`;o00005?ooool000;o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0=?o
oooo00CoE@00obX00?lZ003oe@007_ooool00ol0003oooooooooo`0Booooo`000_ooool00ol0003o
ooooooooo`05ooooo`Co00001Oooool00ol0003oooooooooo`3Dooooo`04oeD00?ooooooe@00ogl0
00?o:P006_ooool00ol0003oooooooooo`0Booooo`000_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0e?ooool01?mE003oooooomD00?mo0003oooo
o`;o:P006?ooool00ol0003oooooooooo`0Booooo`000_l00008ooooo`Go00001?ooool00ol0003o
ooooooooo`3Eooooo`04oeD00?oE003oooooogl001cooooo00?o0000ooooooooool04_ooool001?o
oooo0_l0003Gooooo`03omD00?ooooooO`0001_ooooo0_l0000Dooooo`004oooool00ol0003ooooo
ooooo`3Fooooo`04omD00?mE003oooooogl001_ooooo00?o0000ooooooooool04_ooool001?ooooo
00?o0000ooooooooool0e_ooool01?oE003ooooooeD00?mo000Kooooo`03o`000?oooooooooo01;o
oooo000Cooooo`03o`000?oooooooooo0=Oooooo00Coe@00oooooomE003oO`006_ooool00ol0003o
ooooooooo`0Booooo`004oooool00ol0003oooooooooo`3Gooooo`04omD00?ooooooooooogl001[o
oooo00?o0000ooooooooool04_ooool001?ooooo0_l0003Hooooo`05omD00?oooooooooooooooomo
00006?ooool2o`0001Cooooo000Cooooo`03o`000?oooooooooo0=Oooooo00Koe@00oooooooooooo
ooooogl00?mE000Hooooo`03o`000?oooooooooo01;ooooo000Cooooo`03o`000?oooooooooo0=Oo
oooo00?oe@00ooooooooool00_ooool00omo003oooooooooo`0Fooooo`03o`000?oooooooooo01;o
oooo000Cooooo`03o`000?oooooooooo0=Oooooo00?oe@00ooooooooool06oooool00ol0003ooooo
ooooo`0Booooo`004oooool00ol0003oooooooooo`3Gooooo`03omD00?oooooooooo01_ooooo00?o
0000ooooooooool04_ooool001?ooooo0_l0003Hooooo`03omD00?oooooooooo01[ooooo0_l0000D
ooooo`004oooool00ol0003oooooooooo`3Gooooo`03omD00?oooooooooo01_ooooo00?o0000oooo
ooooool04_ooool001?ooooo00?o0000ooooooooool0f?ooool00ooE003oooooooooo`0Jooooo`03
o`000?oooooooooo01;ooooo000Cooooo`03o`000?oooooooooo0=Sooooo00?oe@00ooooooooool0
6_ooool00ol0003oooooooooo`0Booooo`004oooool00ol0003oooooooooo`3Hooooo`03omD00?oo
oooooooo01[ooooo00?o0000ooooooooool04_ooool001?ooooo0_l0003Iooooo`03omD00?oooooo
oooo01Wooooo0_l0000Dooooo`004oooool00ol0003oooooooooo`3Hooooo`03omD00?oooooooooo
01[ooooo00?o0000ooooooooool04_ooool00003o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool3o`0000Gooooo00?o0000ooooooooool0f?ooool00ooE003oooooooooo`0Jooooo`03
o`000?oooooooooo01;ooooo0006ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0=Sooooo00?oe@00ooooooooool06_ooool00ol0003o
ooooooooo`0Booooo`001oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0f?ooool00ooE003oooooooooo`0Jooooo`03o`000?oooooooooo01;ooooo
0007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`000=[ooooo00?o
e@00ooooooooool06?ooool2o`0001Cooooo0008ooooo`03o`000?oooooo000000?o00001Oooool0
0ol0003oooooooooo`3Iooooo`03omD00?oooooooooo01Wooooo00?o0000ooooooooool04_ooool0
00Cooooo00Oo0000ooooooooooooooooo`000?oooooo000000Sooooo00?o0000ooooooooool0fOoo
ool00ooE003oooooooooo`0Iooooo`03o`000?oooooooooo01;ooooo0004ooooo`Go000000?ooooo
o`000?l000000ol00004ooooo`03o`000?oooooooooo0=Wooooo00?oe@00ooooooooool06Oooool0
0ol0003oooooooooo`0Booooo`004oooool00ol0003oooooooooo`3Iooooo`03omD00?oooooooooo
01Wooooo00?o0000ooooooooool04_ooool001?ooooo0_l0003Jooooo`03omD00?oooooooooo01So
oooo0_l0000Dooooo`004oooool00ol0003oooooooooo`3Iooooo`03omD00?oooooooooo01Wooooo
00?o0000ooooooooool04_ooool001?ooooo00?o0000ooooooooool0fOooool00ooE003ooooooooo
o`0Iooooo`03o`000?oooooooooo01;ooooo000Cooooo`03o`000?oooooooooo0=[ooooo00?oe@00
ooooooooool06?ooool00ol0003oooooooooo`0Booooo`004oooool00ol0003oooooooooo`3Joooo
o`03omD00?oooooooooo01Sooooo00?o0000ooooooooool04_ooool001?ooooo0_l0003Kooooo`03
omD00?oooooooooo01Oooooo0_l0000Dooooo`004oooool00ol0003oooooooooo`3Jooooo`03omD0
0?oooooooooo01Sooooo00?o0000ooooooooool04_ooool001?ooooo00?o0000ooooooooool0f_oo
ool00ooE003oooooooooo`0Hooooo`03o`000?oooooooooo01;ooooo000Cooooo`03o`000?oooooo
oooo0=[ooooo00?oe@00ooooooooool06?ooool00ol0003oooooooooo`0Booooo`004oooool2o`00
0=_ooooo00?oe@00ooooooooool05oooool2o`0001Cooooo000Cooooo`03o`000?oooooooooo0=[o
oooo00?oe@00ooooooooool06?ooool00ol0003oooooooooo`0Booooo`004oooool00ol0003ooooo
ooooo`3Kooooo`03omD00?oooooooooo01Oooooo00?o0000ooooooooool04_ooool001?ooooo00?o
0000ooooooooool0foooool00ooE003oooooooooo`0Gooooo`03o`000?oooooooooo01;ooooo000C
ooooo`03o`000?oooooooooo0=_ooooo00?oe@00ooooooooool05oooool00ol0003oooooooooo`0B
ooooo`004oooool2o`000=cooooo00?oe@00ooooooooool05_ooool2o`0001Cooooo000Cooooo`03
o`000?oooooooooo0=_ooooo00?oe@00ooooooooool05oooool00ol0003oooooooooo`0Booooo`00
4oooool00ol0003oooooooooo`3Kooooo`03omD00?oooooooooo01Oooooo00?o0000ooooooooool0
4_ooool000_ooooo0ol00005ooooo`03o`000?oooooooooo0=_ooooo00?oe@00ooooooooool05ooo
ool00ol0003oooooooooo`0Booooo`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0=_ooooo00?oe@00ooooooooool05oooool00ol0003oooooooooo`0Booooo`003?ooool00ol0
003oooooooooo`04ooooo`;o0000gOooool00ooE003oooooooooo`0Eooooo`;o00005?ooool000co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Looooo`03omD00?oooooooooo01Ko
oooo00?o0000ooooooooool04_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3Looooo`03omD00?oooooooooo01Kooooo00?o0000ooooooooool04_ooool000_ooooo0_l0
0006ooooo`03o`000?oooooooooo0=cooooo00?oe@00ooooooooool05_ooool00ol0003ooooooooo
o`0Booooo`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Gooooo00?o0000
ooooooooool04_ooool001?ooooo0_l0003eooooo`;o00005?ooool001?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo000CooooooWo0000
5?ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool000oooooo
00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06[ooooo
0ol00002ooooo`004?ooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0J_ooool00ol0003oooooooooo`01ooooo`0000?oooooo`000?l000000_l00004
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool5o`000003ooooool0003o
000000;o00002?ooool4o`0000?ooooo1?l000000ooooooo0000o`000003o`000004ooooool0003o
0000ooooo`;o00000_ooool3o`0000;ooooo0ol000000ooooooo0000o`000006ooooo`Go00001ooo
ool5o`000003ooooool0003o000000?o00000_ooool3o`0000;ooooo00Go0000ooooool0003ooooo
o`000002ooooo`?o00000_ooool3o`000003ooooool0003o000000;ooooo0_l00003ooooo`?o0000
0_ooool3o`000003ooooool0003o000000?ooooo00?o0000ooooooooool01oooool3o`0000?ooooo
00?o0000ooooool000001Oooool00ol0003oooooooooo`07ooooo`?o00000oooool3o`0000Cooooo
00?o0000ooooooooool00oooool2o`0000?ooooo0ol00004ooooo`04o`000?ooooooooooooooo`Go
00000oooool2o`0000Cooooo0_l00004ooooo`;o00001oooool00ol0003oooooooooo`07ooooo`Go
000000?oooooo`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00Ko00000oooool3o`00
007ooooo0005ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000001Oooool01ol0003oooooo`00
0?oooooo0000ooooool000001_ooool01?l0003oooooooooool00002ooooo`06o`000?oooooooooo
o`000?oooooo00001_ooool01?l0003oooooooooool0000=ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooo`00000@ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`06ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02?ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0000Aooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000;ooooo
0Ol0000000;ooooo0ol0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00002ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`;o
00000oooool5o`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooooooo1Ol000001ooooooo0000ooooool0
003oooooo`000?ooool01Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00_ooool5o`0000;ooooo00Co0000oooooooooooo00003Oooool02ol0003ooooooooooooooooo
0000ooooool0003oooooo`000?oooooo000000oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`?o00000oooool00ol0003oooooooooo`01o`000000
00?oooooo`000?ooool05_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooooooo
ool01_ooool3o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000[ooooo00?o0000ooooooooool01oooool3o`0000Cooooo00Go0000oooooooooooooooo
o`000003ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000?ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool0000=ooooo`0;o`000?ooooooooooooooool0003oooooo`00
0?oooooo0000ooooool000003oooool00ol0003oooooooooo`03ooooo`;o00002Oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`0?ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oo
oooo00001_ooool00ol0003oooooooooo`01o`0000000_ooool4o`0000?ooooo00?o0000oooooooo
ool02_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00002ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`04o`000?oo
oooo0000o`0000;ooooo0ol00002ooooo`Co00002?ooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`?o00000_ooool2o`000003
ooooool0003ooooo00;ooooo0ol00002ooooo`Co00000_ooool4o`0000?ooooo0ol00002ooooo`Co
00003oooool3o`0000;ooooo1_l0000>ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Oooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool00_ooool3o`0000?ooooo1?l00003ooooo`Co000000?oooooo`000?l000000_l00001ooooo`00
5_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool0
1Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo03?ooooo0_l00003ooooo`05o`000?ooooooooooooooool0
00002?ooool01?l0003oooooooooool00002ooooo`;o00002Oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`00017ooooo00Co0000oooooooooooo00006?ooool001Oooooo0ol00002ooooo`Co
00002?ooool4o`0000Sooooo0ol00003ooooo`;o00005oooool3o`0000Sooooo1Ol000001?oooooo
0000o`000?l0000Looooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00_ooool3o`00
00[ooooo0_l00004ooooo`03o`000?oooooooooo00Sooooo0ol00004ooooo`;o00001?ooool2o`00
00Cooooo0_l0000Aooooo`Go00000oooool00ol0003oooooooooo`0Booooo`00oooooolQooooo`00
oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {205.375, 0}} -> {-0.454537, -0.857114, \
0.0101361, 0.0101361}}]
}, Open  ]],

Cell["\<\
Animate an eigenmode (first value) scalled by the last values -> \
convert to QuickTime\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(animatUeEigen[1, Ne, \[CapitalGamma]e, TeT, Edata, nE, IndR, nR, 
        zFEigen, ZF0, 2.5];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .17117 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0834407 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00408 -24 -4.5 ]
[-0.0125 .00408 0 4.5 ]
[-0.0125 .04376 -24 -4.5 ]
[-0.0125 .04376 0 4.5 ]
[-0.0125 .08344 -6 -4.5 ]
[-0.0125 .08344 0 4.5 ]
[-0.0125 .12312 -18 -4.5 ]
[-0.0125 .12312 0 4.5 ]
[-0.0125 .16281 -18 -4.5 ]
[-0.0125 .16281 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .17117 .125 0 ]
[ 1 0 .125 0 ]
[.5 .18367 -219.875 0 ]
[.5 .18367 219.875 12 ]
[.93651 .05699 -5 -6 ]
[.93651 .05699 5 6 ]
[.12963 .12312 -5 -6 ]
[.12963 .12312 5 6 ]
[.12963 .1099 -3 -4.5 ]
[.12963 .1099 3 4.5 ]
[.52646 .1099 -3 -4.5 ]
[.52646 .1099 3 4.5 ]
[.92328 .1099 -3 -4.5 ]
[.92328 .1099 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .17117 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00408 m
.00625 .00408 L
s
[(-0.2)] -0.0125 .00408 1 0 Mshowa
0 .04376 m
.00625 .04376 L
s
[(-0.1)] -0.0125 .04376 1 0 Mshowa
0 .08344 m
.00625 .08344 L
s
[(0)] -0.0125 .08344 1 0 Mshowa
0 .12312 m
.00625 .12312 L
s
[(0.1)] -0.0125 .12312 1 0 Mshowa
0 .16281 m
.00625 .16281 L
s
[(0.2)] -0.0125 .16281 1 0 Mshowa
.125 Mabswid
0 .01201 m
.00375 .01201 L
s
0 .01995 m
.00375 .01995 L
s
0 .02789 m
.00375 .02789 L
s
0 .03582 m
.00375 .03582 L
s
0 .05169 m
.00375 .05169 L
s
0 .05963 m
.00375 .05963 L
s
0 .06757 m
.00375 .06757 L
s
0 .0755 m
.00375 .0755 L
s
0 .09138 m
.00375 .09138 L
s
0 .09931 m
.00375 .09931 L
s
0 .10725 m
.00375 .10725 L
s
0 .11519 m
.00375 .11519 L
s
0 .13106 m
.00375 .13106 L
s
0 .139 m
.00375 .139 L
s
0 .14693 m
.00375 .14693 L
s
0 .15487 m
.00375 .15487 L
s
0 .17074 m
.00375 .17074 L
s
.25 Mabswid
0 0 m
0 .17117 L
s
.10317 .16492 m
.10317 .17117 L
s
.30159 .16492 m
.30159 .17117 L
s
.5 .16492 m
.5 .17117 L
s
.69841 .16492 m
.69841 .17117 L
s
.89683 .16492 m
.89683 .17117 L
s
.125 Mabswid
.14286 .16742 m
.14286 .17117 L
s
.18254 .16742 m
.18254 .17117 L
s
.22222 .16742 m
.22222 .17117 L
s
.2619 .16742 m
.2619 .17117 L
s
.34127 .16742 m
.34127 .17117 L
s
.38095 .16742 m
.38095 .17117 L
s
.42063 .16742 m
.42063 .17117 L
s
.46032 .16742 m
.46032 .17117 L
s
.53968 .16742 m
.53968 .17117 L
s
.57937 .16742 m
.57937 .17117 L
s
.61905 .16742 m
.61905 .17117 L
s
.65873 .16742 m
.65873 .17117 L
s
.7381 .16742 m
.7381 .17117 L
s
.77778 .16742 m
.77778 .17117 L
s
.81746 .16742 m
.81746 .17117 L
s
.85714 .16742 m
.85714 .17117 L
s
.06349 .16742 m
.06349 .17117 L
s
.02381 .16742 m
.02381 .17117 L
s
.93651 .16742 m
.93651 .17117 L
s
.97619 .16742 m
.97619 .17117 L
s
.25 Mabswid
0 .17117 m
1 .17117 L
s
.99375 .00408 m
1 .00408 L
s
.99375 .04376 m
1 .04376 L
s
.99375 .08344 m
1 .08344 L
s
.99375 .12312 m
1 .12312 L
s
.99375 .16281 m
1 .16281 L
s
.125 Mabswid
.99625 .01201 m
1 .01201 L
s
.99625 .01995 m
1 .01995 L
s
.99625 .02789 m
1 .02789 L
s
.99625 .03582 m
1 .03582 L
s
.99625 .05169 m
1 .05169 L
s
.99625 .05963 m
1 .05963 L
s
.99625 .06757 m
1 .06757 L
s
.99625 .0755 m
1 .0755 L
s
.99625 .09138 m
1 .09138 L
s
.99625 .09931 m
1 .09931 L
s
.99625 .10725 m
1 .10725 L
s
.99625 .11519 m
1 .11519 L
s
.99625 .13106 m
1 .13106 L
s
.99625 .139 m
1 .139 L
s
.99625 .14693 m
1 .14693 L
s
.99625 .15487 m
1 .15487 L
s
.99625 .17074 m
1 .17074 L
s
.25 Mabswid
1 0 m
1 .17117 L
s
gsave
.5 .18367 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08344 m
.97619 .08344 L
s
.10317 .00408 m
.10317 .16281 L
s
.10317 .08344 m
.10317 .08344 .00794 0 365.73 arc
F
gsave
.93651 .05699 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12312 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .1099 0 0 Mshowa
[(2)] .52646 .1099 0 0 Mshowa
[(3)] .92328 .1099 0 0 Mshowa
newpath
.10317 .08344 .00794 0 365.73 arc
s
newpath
.5 .08344 .00794 0 365.73 arc
s
newpath
.89683 .08344 .00794 0 365.73 arc
s
.10317 .08344 m
.5 .08344 L
s
.5 .08344 m
.89683 .08344 L
s
1 0 0 r
.10317 .08344 m
.11927 .08514 L
.13683 .08699 L
.15332 .08873 L
.16917 .0904 L
.18605 .09218 L
.2023 .09389 L
.21957 .09571 L
.23621 .09746 L
.25221 .09915 L
.26924 .10095 L
.28564 .10267 L
.3014 .10434 L
.31819 .1061 L
.33434 .10781 L
.35152 .10962 L
.36806 .11136 L
.38398 .11304 L
.40091 .11483 L
.41722 .11654 L
.43454 .11837 L
.45124 .12013 L
.4673 .12182 L
.48439 .12362 L
.5 .12527 L
s
.5 .12527 m
.5161 .12697 L
.53365 .12882 L
.55014 .13056 L
.566 .13223 L
.58288 .13401 L
.59913 .13572 L
.61639 .13754 L
.63303 .13929 L
.64904 .14098 L
.66607 .14277 L
.68246 .1445 L
.69823 .14616 L
.71501 .14793 L
.73117 .14964 L
.74834 .15145 L
.76489 .15319 L
.7808 .15487 L
.79774 .15665 L
.81404 .15837 L
.83137 .1602 L
.84806 .16196 L
.86413 .16365 L
.88121 .16545 L
.89683 .1671 L
s
0 0 m
1 0 L
1 .17117 L
0 .17117 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{704.688, 120.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;00000N2000`400?l00000o`00003ooooooooo
oooool;ooooo002Vooooo`;o0000G?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
05[ooooo0ol0001Kooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000F_ooool5o`00
08Sooooo002Uooooo`04o`000?ooooooooooo`0005[ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000005[ooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool00000F_ooool01?l0003oooooooooool00028ooooo`00
YOooool01?l0003oooooooooool0001Jooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0FOooool00ol0003oooooooooo`28ooooo`00YOooool01?l0003oooooooooool0001Joooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`27
ooooo`00YOooool01?l0003oooooooooool0001Jooooo`04o`000?ooooooooooo`0000Oooooo1?l0
001Kooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool01oooool4o`0005[ooooo00Go
0000ooooooooooooooooo`000028ooooo`00YOooool01?l0003oooooooooool0001Jooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0Foooool2o`0005cooooo0_l00009ooooo`03
o`000?oooooooooo05_ooooo00Go0000ooooooooooooooooo`000028ooooo`00Y_ooool2o`0005co
oooo0_l00008ooooo`Go0000F_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00Oo
oooo1Ol0001Jooooo`?o0000ROooool00?ooooooooooooo2ooooo`00oooooooooooool;ooooo003o
oooooooooooo`_ooool00?ooooooooooooo2ooooo`00oooooooooooool;ooooo003ooooooooooooo
`_ooool00?ooooooooooooo2ooooo`00GOooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0
0007oooooooo0000nOl0001Eooooo`00G?ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo05?ooooo001Eooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Oooooo1?l00008ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo1?l0001Eooooo`00G?oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`1Qooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
HOooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
Doooool005cooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooool7ooooo00?o0000oooooooo
ool0Doooool005cooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooool7ooooo00?o0000oooo
ooooool0Doooool005gooooo0_l00009ooooo`?o00002?ooool3o`00037ooooo00?o003ooooooooo
ool0oooooonoooooo`?o0000EOooool007?ooooo00?o0000ooooooooool0<Oooool00ol00?oooooo
ooooo`3ooooool7ooooo00?o0000ooooooooool0Doooool007?ooooo00?o0000ooooooooool0<Ooo
ool00ol00?ooooooooooo`3ooooool7ooooo00?o0000ooooooooool0Doooool007?ooooo00?o0000
ooooooooool0<Oooool00ol00?ooooooooooo`3ooooool7ooooo00?o0000ooooooooool0Doooool0
07?ooooo0ol0000aooooo`03o`00oooooooooooo0?oooooo_oooool3o`0005Gooooo001cooooo`03
o`000?oooooooooo037ooooo00?o003oooooooooool0ooooooo1ooooo`03o`000?oooooooooo05?o
oooo001cooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0ooooooo1ooooo`03o`00
0?oooooooooo05?ooooo001cooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooo
ooo1ooooo`03o`000?oooooooooo05?ooooo001cooooo`?o0000<Oooool00ol00?ooooooooooo`3o
oooookoooooo0ol0001Eooooo`00Loooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo
0?oooooo`Oooool00ol0003oooooooooo`1Cooooo`00Loooool00ol0003oooooooooo`0aooooo`03
o`00oooooooooooo0?oooooo`Oooool00ol0003oooooooooo`1Cooooo`00Loooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo0?oooooo`Oooool00ol0003oooooooooo`1Cooooo`00Looo
ool3o`00037ooooo00?o003oooooooooool0oooooonoooooo`?o0000EOooool007?ooooo00?o0000
ooooooooool0<Oooool00ol00?ooooooooooo`3ooooool7ooooo00?o0000ooooooooool0Doooool0
05gooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo
037ooooo00?o003oooooooooool0ooooooo1ooooo`03o`000?oooooooooo05?ooooo001Looooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0aoooo
o`03o`00oooooooooooo0?oooooo`Oooool00ol0003oooooooooo`1Cooooo`00EOooool5o`0000;o
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07ooooo`Co0000<?ooool00ol0
0?ooooooooooo`3ooooookkooooo1?l0001Eooooo`00G?ooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooo
ol7ooooo00?o0000ooooooooool0Doooool005cooooo00Co0000oooooooooooo00002Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0ooooooo1oooo
o`03o`000?oooooooooo05?ooooo001Looooo`04o`000?ooooooooooo`0000Sooooo0_l00009oooo
o`03o`000?oooooooooo037ooooo00?o003oooooooooool0ooooooo1ooooo`03o`000?oooooooooo
05?ooooo001Mooooo`;o00002_ooool00ol0003oooooooooo`07ooooo`?o0000<Oooool00ol00?oo
ooooooooo`3ooooookoooooo0ol0001Eooooo`00Loooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo0?ooooooW_ooool2o`00o`03ooooool00?oo003o01kooooo00?o0000ooooooooool0
Doooool007?ooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooooioooooo00?o
003oooooool00?l07oooool00ol0003oooooooooo`1Cooooo`00Loooool00ol0003oooooooooo`0a
ooooo`03o`00oooooooooooo0?ooooooX?ooool00ol00?ooooooooooo`0Nooooo`03o`000?oooooo
oooo05?ooooo001cooooo`?o0000<Oooool00ol00?ooooooooooo`3ooooooioooooo00?o003ooooo
ool00?l07Oooool3o`0005Gooooo001cooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool0oooooonNooooo`;o003o00?oooooo`00ool00?l07_ooool00ol0003oooooooooo`1Cooooo`00
Loooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo`Oooool00ol0003ooooo
ooooo`1Cooooo`00Loooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo`Ooo
ool00ol0003oooooooooo`1Cooooo`00Loooool3o`00037ooooo00?o003oooooooooool0oooooono
ooooo`?o0000EOooool007?ooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooo
ol7ooooo00?o0000ooooooooool0Doooool007?ooooo00?o0000ooooooooool0<Oooool00ol00?oo
ooooooooo`3ooooool7ooooo00?o0000ooooooooool0Doooool007?ooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`3ooooool7ooooo00?o0000ooooooooool0Doooool007?ooooo0ol0
000`ooooo`?o0000aOooool2o`000<Gooooo0ol0000`ooooo`?o0000EOooool007?ooooo00?o0000
ooooooooool0;_ooool2o`0000?o003o00?o0000ooooooooool0`?ooool2o`0000;ooooo00?o0000
ooooooooool0`?ooool2o`0000?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1C
ooooo`00JOooool2o`0000Sooooo00?o0000ooooooooool0;_ooool00ol0003o003oo`00o`03o`00
o`03o`000?oooooooooo0;oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2ooooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Coooo
o`00J?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02gooooo00?o0000o`00
ool00?l01?l00?l00ol0003oooooooooo`2nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0__ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0Doooool006Sooooo00Co0000oooooooooooo00001oooool4o`0000Sooooo9?l00?l01?l0
003o003oo`00ool00?l5ool00?oo0000S?l00003o`00o`03o`000?l00?oo003o02;o003o2?ooool4
o`0005Gooooo001Xooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0;Oooool0
0ol0003o003oo`00o`05o`00o`03o`000?oo003oo`0000Ooo`00]Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0;gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo05?ooooo001Xooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool0;_ooool00ol0003o003oo`00o`03o`00o`03o`000?oooooooooo00Sooooo2?oo002^
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0_oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0Doooool006Sooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`0^ooooo`?o00000_l00?l2o`0001;ooooo2?oo002V
ooooo`?o00000_ooool2o`000<7ooooo0ol00002ooooo`;o0000<?ooool00ol0003oooooooooo`1C
ooooo`00JOooool2o`0000Sooooo0ol0000aooooo`;o00007?ooool9ool00:3ooooo0_l00036oooo
o`;o0000<?ooool3o`0005Gooooo001cooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool09?ooool@ool00?ooooooSOooool00ol0003oooooooooo`1Cooooo`00Loooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo03Cooooo2Ooo003oooooohCooooo00?o0000ooooooooool0
Doooool007?ooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`0mooooo`Soo`00oooo
oomlooooo`03o`000?oooooooooo05?ooooo001cooooo`?o0000<Oooool00ol00?ooooooooooo`15
ooooo`Soo`00oooooombooooo`?o0000EOooool007?ooooo00?o0000ooooooooool0<Oooool00ol0
0?ooooooooooo`1=ooooo`Woo`00oooooom[ooooo`03o`000?oooooooooo05?ooooo001cooooo`03
o`000?oooooooooo037ooooo00?o003oooooooooool0E_ooool8ool00?ooooooHoooool00ol0003o
ooooooooo`1Cooooo`00Loooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Sooooo
0ol0001Coooooa3oo`00HOooool5o`000<?ooooo0ol0000Vooooo`03o`000?oooooooooo05?ooooo
001cooooo`?o0000<Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo06;ooooo2Ooo
001Iooooo`04o`000?ooooooooooo`000<;ooooo00Go0000ooooooooooooooooo`00000Sooooo`?o
0000EOooool007?ooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`09ooooo`03o`00
0?oooooooooo06_ooooo2?oo001Booooo`03o`000?oooooooooo0<Kooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`1Cooooo`00Loooool00ol0003oooooooooo`0aooooo`03o`00oooo
oooooooo00Wooooo00?o0000ooooooooool0Loooool8ool004_ooooo00?o0000ooooooooool0`ooo
ool2o`0002Kooooo00?o0000ooooooooool0Doooool007?ooooo00?o0000ooooooooool0<Oooool0
0ol00?ooooooooooo`09ooooo`03o`000?oooooooooo07_ooooo2Ooo000oooooo`05o`000?oooooo
ooooooooool00000a_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05?ooooo001c
ooooo`?o0000<Oooool00ol00?ooooooooooo`07ooooo`03o`00ool0003o000008Kooooo2?oo000g
ooooo`05o`000?ooooooooooooooool00000`_ooool01Ol0003ooooooooooooooooo000002?ooooo
0ol0001Eooooo`00Loooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Sooooo00?o
003oo`000?ooool0SOooool9ool002oooooo0ol00034ooooo`?o00009_ooool00ol0003ooooooooo
o`1Cooooo`00GOooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Sooooo00?o0000
ooooooooool0<Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo09Gooooo2?oo003o
oooooaSooooo00?o0000ooooooooool0Doooool005cooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`2Moooooa7oo`00ooooool7ooooo`03o`000?oooooooooo05?ooooo001Loooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01oooool4o`00033ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooo`00o`2_ooooo`Soo`00noooool4o`0005Gooooo001Loooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0a
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooool00?l0]oooool8ool00?Kooooo00?o0000
ooooooooool0Doooool005cooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool01oooool2o`00o`03ooooool00?oo
003o0;kooooo2?oo003^ooooo`03o`000?oooooooooo05?ooooo001Looooo`04o`000?oooooooooo
o`0000Sooooo0_l00009ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0d_ooool9
ool00>Gooooo00?o0000ooooooooool0Doooool005gooooo0_l0000:ooooo`03o`000?oooooooooo
00Oooooo0ol0000aooooo`03o`00oooooooooooo0=_ooooo2?oo003Kooooo`?o0000EOooool007?o
oooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3Sooooo`Soo`00eOooool00ol0003o
ooooooooo`1Cooooo`00Loooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0>_ooooo
4Ooo0034ooooo`03o`000?oooooooooo05?ooooo001cooooo`03o`000?oooooooooo037ooooo00?o
003oooooooooool0o?ooool8ool00;cooooo00?o0000ooooooooool0Doooool007?ooooo0ol0000a
ooooo`03o`00oooooooooooo0?oooooo1Oooool8ool00;;ooooo0ol0001Eooooo`00Loooool00ol0
003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo3Oooool9ool00:_ooooo00?o0000oooo
ooooool0Doooool007?ooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooooaKo
oooo2?oo002Sooooo`03o`000?oooooooooo05?ooooo001cooooo`03o`000?oooooooooo037ooooo
00?o003oooooooooool0oooooolNooooo`Soo`00Voooool00ol0003oooooooooo`1Cooooo`00Looo
ool3o`00037ooooo00?o003oooooooooool0oooooolVooooo`Woo`00T?ooool3o`0005Gooooo001c
ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0ooooool_oooooa3oo`00P_ooool0
0ol0003oooooooooo`1Cooooo`00Loooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo
0?oooooo?oooool9ool007Wooooo00?o0000ooooooooool0Doooool007?ooooo00?o0000oooooooo
ool0<Oooool00ol00?ooooooooooo`3oooooodSooooo2?oo001aooooo`03o`000?oooooooooo05?o
oooo001cooooo`?o0000<Oooool00ol00?ooooooooooo`3ooooooe3ooooo2?oo001Wooooo`?o0000
EOooool007?ooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooooeSooooo2?oo
001Qooooo`03o`000?oooooooooo05?ooooo001Mooooo`;o00001?ooool01?l0003ooooooooooooo
ool5o`0000Oooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3oooooof3ooooo2Ooo
001Hooooo`03o`000?oooooooooo05?ooooo001Looooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00001oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo
JOooool8ool0053ooooo00?o0000ooooooooool0Doooool005cooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`07ooooo`Co0000<?ooool00ol00?ooooooooooo`3oooooog7ooooo
4Ooo000looooo`Co0000EOooool005cooooo00Co0000oooooooooooo00002_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0E_ooool8ool000?ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1Cooooo`00G?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00kooooo1?oo000Cooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`1Cooooo`00G?ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0Doooool005gooooo0_l00009ooooo`?o00002?ooooooo`000?Wo
0000EOooool00?ooooooooooooo2ooooo`00oooooooooooool;ooooo003ooooooooooooo`_ooool0
0?ooooooooooooo2ooooo`00oooooooooooool;ooooo003ooooooooooooo`_ooool00?oooooooooo
ooo2ooooo`00VOooool00ol0003oooooooooo`0<ooooo`?o0000;_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Y
ooooo`?o00008_ooool3o`0002Oooooo00?o0000ooooooooool0N_ooool009Sooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0QOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Wooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Wooooo002Hooooo`03
o`000?oooooooooo00Go000000?oooooo`000?l000000ol00002ooooo`Co00000_ooool3o`0000;o
oooo0ol000000ooooooo0000o`000006ooooo`05o`000?oooooo0000ooooool000000_ooool3o`00
00?ooooo1?l00002ooooo`?o00001Oooool00ol0003oooooooooo`04ooooo`?o00001Oooool00ol0
003oooooooooo`04ooooo`Go000000?oooooo`000?l000000_l00008ooooo`Co00000oooool4o`00
0003ooooool0003o000000?o000000Coooooo`000?l0003ooooo0_l00002ooooo`?o00000_ooool3
o`000003ooooool0003o000000Kooooo1Ol00007ooooo`Go000000?oooooo`000?l000000ol00002
ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol00002ooooo`?o000000?o
ooooo`000?l000000_ooool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`000?l000000ooo
ool00ol0003oooooooooo`07ooooo`?o00000oooool00ol0003oooooo`000005ooooo`03o`000?oo
oooooooo00Oooooo0ol00003ooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`;o00000ooo
ool3o`0000Cooooo00Co0000oooooooooooooooo1Ol00003ooooo`;o00001?ooool2o`0000Cooooo
0_l00006ooooo`03o`000?oooooooooo00Oooooo1Ol000000ooooooo0000o`000003o`000005oooo
ool0003o0000o`000?ooool01_l00003ooooo`?o00000oooool4o`000005ooooool0003o0000o`00
0?ooool01Ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_l000001?oo
oooo0000o`000?ooool4o`0000Oooooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o00001ooo
ool3o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1iooooo`00V?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`07o`00
0?ooooooooooooooool0003oooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00Oo0000
ooooool0003oooooo`000?oooooo000000?ooooo00?o0000ooooool000000_ooool01?l0003ooooo
ooooool0000@ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000001Oooool01ol0003oooooo`00
0?oooooo0000ooooool000001_ooool01?l0003oooooooooool00002ooooo`06o`000?oooooooooo
o`000?oooooo00001_ooool01?l0003oooooooooool0000=ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooo`00000@ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`06ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02?ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0000@ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooool000000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07Wooooo
002Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooool000001?l00002ooooo`04o`000?ooooooooooo`0000Oo
oooo00Oo0000ooooool0003oooooo`000?oooooo000000?ooooo00?o0000ooooool000000_ooool0
0ol0003oooooooooo`05o`0000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool3o`0000Cooooo
00?o0000ooooooooool00_ooool2o`0000?ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`04o`000?oooooooooooooo
o`Go000000Ooooooo`000?oooooo0000ooooool0003ooooo00Go00000_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000go
oooo00_o0000ooooooooooooooooo`000?oooooo0000ooooool0003oooooo`00000?ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00004?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo
00Co0000oooooooooooo00000_ooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0N?ooool009So
oooo00Co0000oooooooooooooooo0ol00004ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Ooo
ool01ol0003oooooo`000?oooooo0000ooooool000000oooool00ol0003oooooo`000002ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`06ooooo`?o00000_ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00002_ooool00ol0003o
ooooooooo`07ooooo`?o00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Wo0000oooo
ool0003oooooo`000?oooooo0000ooooool000000oooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000gooooo00_o0000ooooooooooooooooo`000?oooooo0000ooooool0003oooooo`00000?
ooooo`03o`000?oooooooooo00?ooooo0_l00009ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00kooooo0ol00004oooo
o`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`06o`000?oo
ooooooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooool000000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07Wo
oooo002Hooooo`05o`000?ooooooooooooooool000001?ooool3o`0000Cooooo1Ol000001?oooooo
0000o`000?l00002ooooo`Co00002?ooool2o`000003ooooool0003ooooo00;ooooo0ol00003oooo
o`?o00000oooool3o`0000gooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`;o0000
1Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo0000o`0000;ooooo0ol00002ooooo`Co
00002?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`?o00000_ooool2o`000003ooooool0003ooooo00;ooooo0ol00002oooo
o`Co00000_ooool4o`0000?ooooo0ol00002ooooo`Co00003oooool3o`0000;ooooo1_l0000>oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool3o`0000?ooooo1?l00003oooo
o`Co000000?oooooo`000?l000000_l00003ooooo`;o00000oooool4o`0000;ooooo1?l00002oooo
o`;o000000Coooooo`000?l0003ooooo1?l00003ooooo`Go00001_ooool3o`0000?ooooo1?l0000:
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1i
ooooo`00VOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool04?ooool2o`0000gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0cooooo`;o00000oooool0
1Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00000_ooool2o`0000Wooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool0000@ooooo`04o`000?ooooooooooo`0005Kooooo
0_l0000:ooooo`03o`000?oooooooooo07[ooooo002Kooooo`Go00000oooool00ol0003ooooooooo
o`0Wooooo`;o00004oooool00ol0003oooooooooo`0<ooooo`?o00000_ooool4o`0000Sooooo1?l0
0008ooooo`?o00000oooool2o`0001Oooooo0ol00008ooooo`Go000000Coooooo`000?l0003o0000
7?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00;ooooo0ol0000:ooooo`;o0000
1?ooool00ol0003oooooooooo`08ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o0000
4?ooool5o`0000?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo08Gooooo003ooooooooooooo`_ooool00?ooooooooooooo2ooooo`00\
\>"],
  ImageRangeCache->{{{0, 703.688}, {119.625, 0}} -> {-0.839189, -0.286885, \
0.00501246, 0.00501246}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .08471 L
.13683 .0862 L
.15332 .08761 L
.16917 .08896 L
.18605 .0904 L
.2023 .09179 L
.21957 .09326 L
.23621 .09468 L
.25221 .09604 L
.26924 .0975 L
.28564 .09889 L
.3014 .10024 L
.31819 .10167 L
.33434 .10305 L
.35152 .10451 L
.36806 .10592 L
.38398 .10728 L
.40091 .10872 L
.41722 .11011 L
.43454 .11159 L
.45124 .11302 L
.4673 .11439 L
.48439 .11584 L
.5 .11717 L
s
.5 .11717 m
.5161 .11855 L
.53365 .12004 L
.55014 .12145 L
.566 .1228 L
.58288 .12424 L
.59913 .12563 L
.61639 .1271 L
.63303 .12852 L
.64904 .12988 L
.66607 .13134 L
.68246 .13273 L
.69823 .13408 L
.71501 .13551 L
.73117 .13689 L
.74834 .13835 L
.76489 .13976 L
.7808 .14112 L
.79774 .14256 L
.81404 .14395 L
.83137 .14543 L
.84806 .14686 L
.86413 .14823 L
.88121 .14968 L
.89683 .15101 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{705.438, 117.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;10000MB000`400?l00000o`00003ooooooooo
oooool?ooooo002Xooooo`;o0000Foooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
05[ooooo0ol0001Jooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000FOooool5o`00
08[ooooo002Wooooo`04o`000?ooooooooooo`0005Wooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000005[ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool00000FOooool01?l0003oooooooooool0002:ooooo`00
Yoooool01?l0003oooooooooool0001Iooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`2:ooooo`00Yoooool01?l0003oooooooooool0001Ioooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`29
ooooo`00Yoooool01?l0003oooooooooool0001Iooooo`04o`000?ooooooooooo`0000Oooooo1?l0
001Kooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01oooool4o`0005Wooooo00Go
0000ooooooooooooooooo`00002:ooooo`00Yoooool01?l0003oooooooooool0001Iooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0Foooool2o`0005_ooooo0_l00009ooooo`03
o`000?oooooooooo05[ooooo00Go0000ooooooooooooooooo`00002:ooooo`00Z?ooool2o`0005_o
oooo0_l00008ooooo`Go0000F_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Oo
oooo1Ol0001Iooooo`?o0000Roooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003o
oooooooooooo`oooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003ooooooooooooo
`oooool00?ooooooooooooo3ooooo`00Goooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0
0007oooooooo0000mOl0001Hooooo`00G_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo05Kooooo001Gooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Oooooo1Ol00007ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo1?l0001Hooooo`00G_oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000oooooooo
ool0E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000oooo
ooooool0E_ooool005oooooo0_l00009ooooo`?o00002?ooool3o`00037ooooo00?o003ooooooooo
ool0oooooonkooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oooooo
ooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Ooo
ool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000
ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool0
07Gooooo0ol0000aooooo`03o`00oooooooooooo0?oooooo^oooool3o`0005Sooooo001eooooo`03
o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Ko
oooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`00
0?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooo
oonmooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3o
oooook_ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo
0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03
o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOoo
ool3o`00037ooooo00?o003oooooooooool0oooooonkooooo`?o0000F?ooool005oooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo037ooooo00?o003o
ooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`00oooooooo
oooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00Eoooool5o`0000;ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003o
ooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01oooool5o`0002oooooo00?o003oooooooooool0oooooonj
ooooo`Co0000F?ooool005kooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooo
oooo05Kooooo001Nooooo`04o`000?ooooooooooo`0000Sooooo0_l00009ooooo`03o`000?oooooo
oooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Ooooo
o`;o00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003ooooo
ooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?oo
ooooooooo`3ooooook_ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo0?ooooooV_ooool2o`00o`03ooooool00?oo003o01kooooo00?o0000ooooooooool0
E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooooi_ooooo00?o
003oooooool00?l07oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0a
ooooo`03o`00oooooooooooo0?ooooooW?ooool00ol00?ooooooooooo`0Nooooo`03o`000?oooooo
oooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3ooooooi_ooooo00?o003ooooo
ool00?l07Oooool3o`0005Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool0oooooonJooooo`;o003o00?oooooo`00ool00?l07_ooool00ol0003oooooooooo`1Fooooo`00
MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003ooooo
ooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_Ooo
ool00ol0003oooooooooo`1Fooooo`00MOooool3o`00037ooooo00?o003oooooooooool0oooooonk
ooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooo
okgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oo
ooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo0ol0
000`ooooo`Co0000`_ooool4o`000<;ooooo1?l0000^ooooo`?o0000F?ooool006_ooooo0_l00008
ooooo`03o`000?oooooooooo02kooooo0_l00004o`00o`03o`000?oooooooooo0;gooooo0_l00004
ooooo`03o`000?oooooooooo0;gooooo0_l00004ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0E_ooool006[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0^
ooooo`03o`000?l00?oo003o00?o003o00?o0000ooooooooool0_Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0;gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo05Kooooo001Zooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool0;Oooool00ol0003o003oo`00o`05o`00o`03o`000?oooooooooo0;_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2kooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`1Fooooo`00J_ooool01?l0003oooooooooool00007
ooooo`Go00001ooooolTo`00o`04o`000?l00?oo003oo`00o`koo`00ool00020o`0000?o003o00?o
0000o`00ool00?l08Ol00?l8ooooo`Co0000F?ooool006[ooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?l00?oo003o00Go003o00?o0000ooooooooool01ooo
ool8ool00:cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2kooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1Fooooo`00J_ooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo02kooooo0_l00004o`00o`03o`000?oo
oooooooo013ooooo2?oo002Uooooo`;o00001?ooool00ol0003oooooooooo`2mooooo`;o00001?oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo05Kooooo001[ooooo`;o00002?ooool0
0ol0003oooooooooo`0`ooooo`03o`000?l00?oo003o00;o00006_ooool@ool009Oooooo00?o0000
ooooooooool00_l00031ooooo`04o`000?oooooo0000o`00033ooooo00?o0000ooooooooool0E_oo
ool007Gooooo0ol0000aooooo`;o0000;?ooool9ool008oooooo0_l00034ooooo`03o`000?oooooo
oooo02kooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo
03Cooooo4?oo003oooooogWooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000oooooooo
ool0<Oooool00ol00?ooooooooooo`14ooooo`Woo`00oooooom`ooooo`03o`000?oooooooooo05Ko
oooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0COooool@ool00?oooooo
H?ooool00ol0003oooooooooo`1Fooooo`00MOooool3o`00037ooooo00?o003oooooooooool0GOoo
ool8ool00?ooooooE_ooool3o`0005Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003o
ooooooooool0IOooool8ool00?ooooooD?ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0
003oooooooooo`0aooooo`03o`00oooooooooooo00Sooooo0ol0001Roooooa7oo`00Coooool5o`00
0<;ooooo0ol0000Uooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037o
oooo00?o003oooooooooool02Oooool00ol0003oooooooooo`1booooo`Soo`00B?ooool01?l0003o
ooooooooool00031ooooo`05o`000?ooooooooooooooool000009?ooool00ol0003oooooooooo`1F
ooooo`00MOooool3o`00037ooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`1joooo
oa7oo`00>?ooool00ol0003oooooooooo`35ooooo`03o`000?oooooooooo023ooooo0ol0001Hoooo
o`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Wooooo00?o0000oooooooo
ool0Roooool8ool0037ooooo00?o0000ooooooooool0`_ooool2o`0002Gooooo00?o0000oooooooo
ool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`09ooooo`03o`00
0?oooooooooo09?ooooo2?oo000Vooooo`05o`000?ooooooooooooooool00000aOooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo
00?o003oooooooooool02?ooool2o`0009gooooo4Ooo000Eooooo`05o`000?ooooooooooooooool0
0000`Oooool01Ol0003ooooooooooooooooo000002Cooooo00?o0000ooooooooool0E_ooool007Go
oooo0ol0000aooooo`03o`00oooooooooooo00Oooooo0_l00?l00ol0003oooooooooo`2/ooooo`So
o`003_ooool3o`000<?ooooo0ol0000Sooooo`?o0000F?ooool005oooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`2eoooooa7oo`00joooool00ol0003oooooooooo`1Fooooo`00G_oo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo0<Gooooo2?oo003Sooooo`03o`00
0?oooooooooo05Kooooo001Nooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
cOooool@ool00=?ooooo00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`07ooooo`Go0000;oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooo003o0=kooooo2?oo0038ooooo`Co0000F?ooool005kooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooo`00o`3Vooooo`Woo`00`_ooool00ol0003oooooooooo`1Fooooo`00G_oo
ool01?l0003oooooooooool00008ooooo`;o00002Oooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo00Oooooo0_l00?l00ooooooo003oo`00o`3^oooooa3oo`00/_ooool00ol0003ooooo
ooooo`1Fooooo`00Goooool2o`0000[ooooo00?o0000ooooooooool01oooool3o`00037ooooo00?o
003oooooooooool0ooooool;ooooo`Woo`00Yoooool3o`0005Sooooo001eooooo`03o`000?oooooo
oooo037ooooo00?o003oooooooooool0oooooolDoooooa3oo`00VOooool00ol0003oooooooooo`1F
ooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo9?ooool8ool0
097ooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oo
ooooooooo`3oooooobcooooo4Ooo0020ooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000
<Oooool00ol00?ooooooooooo`3oooooocgooooo2?oo001fooooo`?o0000F?ooool007Gooooo00?o
0000ooooooooool0<Oooool00ol00?ooooooooooo`3oooooodGooooo2?oo001`ooooo`03o`000?oo
oooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooom=
oooooa3oo`00H?ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aoooo
o`03o`00oooooooooooo0?ooooooGOooool9ool005Oooooo00?o0000ooooooooool0E_ooool007Go
oooo0ol0000aooooo`03o`00oooooooooooo0?ooooooI_ooool@ool004Gooooo0ol0001Hooooo`00
MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?ooooooM_ooool9ool003kooooo
00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oooooooooo
o`3oooooogoooooo3?oo000booooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooo
oooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001eoooo
o`?o0000<Oooool00ol00?ooooooooooo`3ooooook_ooooo0ol0001Hooooo`00MOooool00ol0003o
ooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00
Goooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00007ooooo`03o`000?oooooooooo037o
oooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0aoooo
o`03o`00oooooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo063ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Foooo
o`00G_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo1Ol00007oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`0Aoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Kooooo1?l0001Hooooo`00G_ooool01?l0003oooooooooool0000:oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`000007oooooooo0000mOl0001Hooooo`00G_ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool00000oooooooooooooeGooooo001Oooooo`;o00002Oooool3
o`000?oooooooooooomFooooo`00oooooooooooool?ooooo003ooooooooooooo`oooool00?oooooo
ooooooo3ooooo`00oooooooooooool?ooooo003ooooooooooooo`oooool009Wooooo00?o0000oooo
ooooool03?ooool3o`0002kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`25oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0J_ooool3o`0002;ooooo0ol0000Woooo
o`03o`000?oooooooooo07[ooooo002Hooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08Gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1iooooo`00V?ooool00ol0003oooooooooo`05o`000003oooo
ool0003o000000?o00000_ooool4o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l00000
1_ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol00003ooooo`Co00000_ooool3o`0000Go
oooo00?o0000ooooooooool01?ooool3o`0000Gooooo00?o0000ooooooooool01?ooool5o`000003
ooooool0003o000000;o00002?ooool4o`0000?ooooo1?l000000ooooooo0000o`000003o`000004
ooooool0003o0000ooooo`;o00000_ooool3o`0000;ooooo0ol000000ooooooo0000o`000006oooo
o`Go00001oooool5o`000003ooooool0003o000000?o00000_ooool3o`0000;ooooo00Go0000oooo
ool0003oooooo`000002ooooo`?o00000_ooool3o`000003ooooool0003o000000;ooooo0_l00003
ooooo`?o00000_ooool3o`000003ooooool0003o000000?ooooo00?o0000ooooooooool01oooool3
o`0000?ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`07ooooo`?o00000oooool3
o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00004ooooo`04o`000?oooooo
ooooooooo`Go00000oooool2o`0000Cooooo0_l00004ooooo`;o00001oooool00ol0003ooooooooo
o`07ooooo`Go000000?oooooo`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00Ko0000
0oooool3o`0000?ooooo1?l000001Ooooooo0000o`000?l0003ooooo00Go000000?oooooo`000?l0
00000_ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo1?l00007oooo
o`Go000000Goooooo`000?l0003o0000ooooo`02o`0000Oooooo0ol00004ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0NOooool009Sooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01ol0003ooooooooooooooooo0000ooooool0
00001_ooool01?l0003oooooooooool00007ooooo`07o`000?oooooo0000ooooool0003oooooo`00
0003ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00004?ooool00ol0003ooooo
ooooo`0<ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000Gooooo00Oo0000ooooool0003oooooo`000?oooooo000000Kooooo
00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Kooooo00Co0000
oooooooooooo00003Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool00000
4?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00004Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1iooooo`00Uoooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooo000000Co00000_ooool01?l0003oooooooooool00007ooooo`07o`000?oooooo0000ooooool0
003oooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01Ol0000<oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0_l0
0003ooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooooooool5o`000007ooooool0003oooooo`00
0?oooooo0000ooooo`05o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`02ooooo`Go00000_ooool01?l0003oooooooooool0000=ooooo`0;o`000?ooooooooooooooool0
003oooooo`000?oooooo0000ooooool000003oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`00017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo
0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo07Sooooo002Hooooo`04o`000?ooooooooooooooo`?o
00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo00Oo0000ooooool0003oooooo`00
0?oooooo000000?ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool01_ooool3o`0000;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01oooool3o`0000Cooooo
00Go0000ooooooooooooooooo`000003ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000=ooooo`0;o`000?oooooo
ooooooooool0003oooooo`000?oooooo0000ooooool000003oooool00ol0003oooooooooo`03oooo
o`;o00002Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00[ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`06
o`000?ooooooooooo`000?oooooo00001_ooool01_l0003oooooooooool0003oooooo`0000;ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1iooooo`00V?ooool01Ol0003ooooooooo
oooooooo000000Cooooo0ol00004ooooo`Go000000Coooooo`000?l0003o00000_ooool4o`0000So
oooo0_l000000ooooooo0000ooooo`02ooooo`?o00000oooool3o`0000?ooooo0ol0000=ooooo`03
o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000_ooool2o`0000Gooooo00?o0000ooooooooool00_oo
ool01?l0003oooooo`000?l00002ooooo`?o00000_ooool4o`0000Sooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool3o`0000;o
oooo0_l000000ooooooo0000ooooo`02ooooo`?o00000_ooool4o`0000;ooooo1?l00003ooooo`?o
00000_ooool4o`0000oooooo0ol00002ooooo`Ko00003_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`07oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00;ooooo0ol00003ooooo`Co00000oooool4o`000003ooooool0003o000000;o
00000oooool2o`0000?ooooo1?l00002ooooo`Co00000_ooool2o`000004ooooool0003o0000oooo
o`Co00000oooool5o`0000Kooooo0ol00003ooooo`Co00002_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0NOooool009Wooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo013ooooo0_l0000=oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`05o`00
0?ooooooooooooooool000002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0<oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000008
ooooo`04o`000?ooooooooooo`0000;ooooo0_l00009ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00004Oooool01?l0003oooooooooool0001Fooooo`;o00002_ooool00ol0003ooooooooo
o`1jooooo`00Voooool5o`0000?ooooo00?o0000ooooooooool09oooool2o`0001?ooooo00?o0000
ooooooooool03?ooool3o`0000;ooooo1?l00008ooooo`Co00002?ooool3o`0000?ooooo0_l0000G
ooooo`?o00002?ooool5o`000004ooooool0003o0000o`0001cooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`02ooooo`?o00002_ooool2o`0000Cooooo00?o0000ooooooooool02?oo
ool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`00017ooooo1Ol00003ooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`25ooooo`00oooooooo
oooool?ooooo003ooooooooooooo`oooool00001\
\>"],
  ImageRangeCache->{{{0, 704.438}, {116.562, 0}} -> {-0.856351, -0.286992, \
0.00505443, 0.00505443}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .08386 L
.13683 .08443 L
.15332 .08497 L
.16917 .08548 L
.18605 .08603 L
.2023 .08656 L
.21957 .08712 L
.23621 .08767 L
.25221 .08819 L
.26924 .08874 L
.28564 .08928 L
.3014 .08979 L
.31819 .09034 L
.33434 .09086 L
.35152 .09142 L
.36806 .09196 L
.38398 .09248 L
.40091 .09303 L
.41722 .09356 L
.43454 .09413 L
.45124 .09467 L
.4673 .09519 L
.48439 .09575 L
.5 .09626 L
s
.5 .09626 m
.5161 .09678 L
.53365 .09736 L
.55014 .09789 L
.566 .09841 L
.58288 .09896 L
.59913 .09949 L
.61639 .10005 L
.63303 .10059 L
.64904 .10111 L
.66607 .10167 L
.68246 .1022 L
.69823 .10272 L
.71501 .10326 L
.73117 .10379 L
.74834 .10435 L
.76489 .10489 L
.7808 .10541 L
.79774 .10596 L
.81404 .10649 L
.83137 .10705 L
.84806 .1076 L
.86413 .10812 L
.88121 .10868 L
.89683 .10919 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{705.438, 117.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;10000MB000`400?l00000o`00003ooooooooo
oooool?ooooo002Xooooo`;o0000Foooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
05[ooooo0ol0001Jooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000FOooool5o`00
08[ooooo002Wooooo`04o`000?ooooooooooo`0005Wooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000005[ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool00000FOooool01?l0003oooooooooool0002:ooooo`00
Yoooool01?l0003oooooooooool0001Iooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`2:ooooo`00Yoooool01?l0003oooooooooool0001Ioooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`29
ooooo`00Yoooool01?l0003oooooooooool0001Iooooo`04o`000?ooooooooooo`0000Oooooo1?l0
001Kooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01oooool4o`0005Wooooo00Go
0000ooooooooooooooooo`00002:ooooo`00Yoooool01?l0003oooooooooool0001Iooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0Foooool2o`0005_ooooo0_l00009ooooo`03
o`000?oooooooooo05[ooooo00Go0000ooooooooooooooooo`00002:ooooo`00Z?ooool2o`0005_o
oooo0_l00008ooooo`Go0000F_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Oo
oooo1Ol0001Iooooo`?o0000Roooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003o
oooooooooooo`oooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003ooooooooooooo
`oooool00?ooooooooooooo3ooooo`00Goooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0
0007oooooooo0000mOl0001Hooooo`00G_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo05Kooooo001Gooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Oooooo1Ol00007ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo1?l0001Hooooo`00G_oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000oooooooo
ool0E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000oooo
ooooool0E_ooool005oooooo0_l00009ooooo`?o00002?ooool3o`00037ooooo00?o003ooooooooo
ool0oooooonkooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oooooo
ooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Ooo
ool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000
ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool0
07Gooooo0ol0000aooooo`03o`00oooooooooooo0?oooooo^oooool3o`0005Sooooo001eooooo`03
o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Ko
oooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`00
0?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooo
oonmooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3o
oooook_ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo
0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03
o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOoo
ool3o`00037ooooo00?o003oooooooooool0oooooonkooooo`?o0000F?ooool005oooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo037ooooo00?o003o
ooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`00oooooooo
oooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00Eoooool5o`0000;ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003o
ooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01oooool5o`0002oooooo00?o003oooooooooool0oooooonj
ooooo`Co0000F?ooool005kooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooo
oooo05Kooooo001Nooooo`04o`000?ooooooooooo`0000Sooooo0_l00009ooooo`03o`000?oooooo
oooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Ooooo
o`;o00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003ooooo
ooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?oo
ooooooooo`3ooooook_ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo0?ooooooV_ooool2o`00o`03ooooool00?oo003o01kooooo00?o0000ooooooooool0
E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooooi_ooooo00?o
003oooooool00?l07oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0a
ooooo`03o`00oooooooooooo0?ooooooW?ooool00ol00?ooooooooooo`0Nooooo`03o`000?oooooo
oooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3ooooooi_ooooo00?o003ooooo
ool00?l07Oooool3o`0005Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool0oooooonJooooo`;o003o00?oooooo`00ool00?l07_ooool00ol0003oooooooooo`1Fooooo`00
MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003ooooo
ooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_Ooo
ool00ol0003oooooooooo`1Fooooo`00MOooool3o`00037ooooo00?o003oooooooooool0oooooonk
ooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooo
okgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oo
ooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo0ol0
000`ooooo`Co0000`_ooool4o`000<;ooooo1?l0000^ooooo`?o0000F?ooool006_ooooo0_l00008
ooooo`03o`000?oooooooooo02kooooo0_l00004o`00o`03o`000?oooooooooo0;gooooo0_l00004
ooooo`03o`000?oooooooooo0;gooooo0_l00004ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0E_ooool006[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0^
ooooo`03o`000?l00?oo003o00?o003o00?o0000ooooooooool0_Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0;gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo05Kooooo001Zooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool0;Oooool00ol0003o003oo`00o`05o`00o`03o`000?oooooooooo0;_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2kooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`1Fooooo`00J_ooool01?l0003oooooooooool00007
ooooo`Go00001ooooolTo`00o`04o`000?l00?oo003oo`00oaKoo`00ool0001ho`0000?o003o00?o
0000o`00ool00?l08Ol00?l8ooooo`Co0000F?ooool006[ooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?l00?oo003o00Go003o00?o0000ooooooooool03ooo
oolQool008_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2kooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1Fooooo`00J_ooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo02kooooo0_l00004o`00o`03o`000?oo
oooooooo037ooooo8Ooo001[ooooo`;o00001?ooool00ol0003oooooooooo`2mooooo`;o00001?oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo05Kooooo001[ooooo`;o00002?ooool0
0ol0003oooooooooo`0`ooooo`03o`000?l00?oo003o00;o0000E?oooolQool004cooooo00?o0000
ooooooooool00_l00031ooooo`04o`000?oooooo0000o`00033ooooo00?o0000ooooooooool0E_oo
ool007Gooooo0ol0000aooooo`;o0000MooooolHool003Gooooo0_l00034ooooo`03o`000?oooooo
oooo02kooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo
08kooooo8Ooo003oooooo`kooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000oooooooo
ool0<Oooool00ol00?ooooooooooo`2_ooooob;oo`00joooool00ol0003oooooooooo`1Fooooo`00
MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0=7ooooo6?oo003Cooooo`03o`00
0?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3Yooooob7oo`00/?oo
ool3o`0005Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0ooooool;
ooooob7oo`00TOooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aoooo
o`03o`00oooooooooooo00Sooooo0ol00032ooooo`Go0000FOoooolQool004Sooooo0ol0000Uoooo
o`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool02Oooool00ol0003oooooooooo`32ooooo`04o`000?ooooooooooo`0007[ooooo6Ooo000^oooo
o`05o`000?ooooooooooooooool000009?ooool00ol0003oooooooooo`1Fooooo`00MOooool3o`00
037ooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`33ooooo`03o`000?oooooooooo
09?ooooo8Ooo000Aooooo`03o`000?oooooooooo023ooooo0ol0001Hooooo`00MOooool00ol0003o
ooooooooo`0aooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool0a?ooool00ol0003o
ooooooooo`2cooooo`Coo`002oooool2o`0002Gooooo00?o0000ooooooooool0E_ooool007Gooooo
00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo0<7ooooo
00Go0000ooooooooooooooooo`000035ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`08ooooo`;o0000
`oooool01Ol0003ooooooooooooooooo00000<7ooooo00Go0000ooooooooooooooooo`00000Toooo
o`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`07ooooo`;o
003o00?o0000ooooooooool0`_ooool3o`000<?ooooo0ol0000Sooooo`?o0000F?ooool005oooooo
0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo037ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`3ooooook;ooooo00?o0000ooooooooool0
E_ooool005kooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo037ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`3ooooook7ooooo
00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`3ooooook7ooooo00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`07ooooo`Go0000;oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooo003o0?oooooo[oooool4o`0005Sooooo001Nooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Sooooo
00?o003oooooool00?l0oooooonbooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oo
ooooooooo`0000Sooooo0_l00009ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0
1oooool2o`00o`03ooooool00?oo003o0?oooooo/Oooool00ol0003oooooooooo`1Fooooo`00Gooo
ool2o`0000[ooooo00?o0000ooooooooool01oooool3o`00037ooooo00?o003oooooooooool0oooo
oonkooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3o
oooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol0
0?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000oooooooo
ool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo
0ol0000aooooo`03o`00oooooooooooo0?oooooo^oooool3o`0005Sooooo001eooooo`03o`000?oo
oooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001e
ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooo
oooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmoooo
o`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3ooooook_o
oooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo
_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooo
oooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0a
ooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool3o`00
037ooooo00?o003oooooooooool0oooooonkooooo`?o0000F?ooool007Gooooo00?o0000oooooooo
ool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool005oooooo
0_l00004ooooo`04o`000?ooooooooooooooo`Go00001oooool00ol0003oooooooooo`0aooooo`03
o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00G_ooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0<Oooool00ol0
0?ooooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0E_ooool005ko
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07ooooo`Go00001oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool04Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`06ooooo`Co0000F?ooool005kooooo00Co0000oooooooooooo00002_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`1Fooooo`00G_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001oooooooo`000?Go0000F?ooool005kooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo00000?oooooooooooomEooooo`00Goooool2o`0000Wooooo0ol0003o
ooooooooooooE_ooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003ooooooooooooo
`oooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo002Iooooo`03o`000?oooooooooo
00cooooo0ol0000^ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0QOooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo06[ooooo0ol0000Rooooo`?o00009oooool00ol0
003oooooooooo`1jooooo`00V?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0NOooool009Sooooo00?o0000ooooooooool01Ol000000ooooooo0000
o`000003o`0000;ooooo1?l00002ooooo`?o00000_ooool3o`000003ooooool0003o000000Kooooo
00Go0000ooooool0003oooooo`000002ooooo`?o00000oooool4o`0000;ooooo0ol00005ooooo`03
o`000?oooooooooo00Cooooo0ol00005ooooo`03o`000?oooooooooo00Cooooo1Ol000000ooooooo
0000o`000002o`0000Sooooo1?l00003ooooo`Co000000?oooooo`000?l000000ol000001?oooooo
0000o`000?ooool2o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l000001_ooool5o`00
00Oooooo1Ol000000ooooooo0000o`000003o`0000;ooooo0ol00002ooooo`05o`000?oooooo0000
ooooool000000_ooool3o`0000;ooooo0ol000000ooooooo0000o`000002ooooo`;o00000oooool3
o`0000;ooooo0ol000000ooooooo0000o`000003ooooo`03o`000?oooooooooo00Oooooo0ol00003
ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01oooool3o`0000?ooooo0ol00004
ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001?ooool01?l0003ooooooooooooo
ool5o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000Oooooo00?o0000ooooooooool01ooo
ool5o`000003ooooool0003o000000?o000000Goooooo`000?l0003o0000ooooo`06o`0000?ooooo
0ol00003ooooo`Co000000Goooooo`000?l0003o0000ooooo`05o`000003ooooool0003o000000;o
oooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`Co00001oooool5o`00
0005ooooool0003o0000o`000?ooool00_l00007ooooo`?o00001?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo07Wooooo002Hooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Ko
oooo00Co0000oooooooooooo00001oooool01ol0003oooooo`000?oooooo0000ooooool000000ooo
ool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`00013ooooo00?o0000ooooooooool0
3?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooo
oooooooo0000ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000005ooooo`07o`000?oooooo0000ooooool0003oooooo`000006ooooo`04o`00
0?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`04o`000?oooooo
ooooo`0000gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo0000013ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00017o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000002ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0NOooool009Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`00
0004o`0000;ooooo00Co0000oooooooooooo00001oooool01ol0003oooooo`000?oooooo0000oooo
ool000000oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Go00003?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00002ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`;o00000ooo
ool5o`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooooooo1Ol000001ooooooo0000ooooool0003ooooo
o`000?ooool01Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool5o`0000;ooooo00Co0000oooooooooooo00003Oooool02ol0003ooooooooooooooooo0000oooo
ool0003oooooo`000?oooooo000000oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool0000Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`?o00000oooool01?l0003oooooooooool00002ooooo`?o0000
0oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1hooooo`00V?ooool01?l0003oooooooooooooool3o`0000Co
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`05ooooo`07o`000?oooooo0000ooooool0003ooooo
o`000003ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00Kooooo0ol00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Oooooo0ol00004ooooo`05o`00
0?ooooooooooooooool000000oooool02Ol0003oooooo`000?oooooo0000ooooool0003oooooo`00
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00003Oooool02ol0003ooooooooooooo
oooo0000ooooool0003oooooo`000?oooooo000000oooooo00?o0000ooooooooool00oooool2o`00
00Wooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0:ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool03oooool3o`0000Cooooo00?o0000ooooooooool00_ooool01_l0003o
ooooooooool0003oooooo`0000Kooooo00Ko0000oooooooooooo0000ooooool00002ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0NOooool009Sooooo00Go0000oooooooooooooooo
o`000004ooooo`?o00001?ooool5o`000004ooooool0003o0000o`0000;ooooo1?l00008ooooo`;o
000000?oooooo`000?ooool00_ooool3o`0000?ooooo0ol00003ooooo`?o00003Oooool00ol0003o
ooooooooo`0;ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000;ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00Co
0000ooooool0003o00000_ooool3o`0000;ooooo1?l00008ooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`;o
000000?oooooo`000?ooool00_ooool3o`0000;ooooo1?l00002ooooo`Co00000oooool3o`0000;o
oooo1?l0000?ooooo`?o00000_ooool6o`0000kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01oooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`02ooooo`?o00000oooool4o`0000?ooooo1?l000000ooooooo0000o`000002o`0000?o
oooo0_l00003ooooo`Co00000_ooool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool4o`00
00?ooooo1Ol00006ooooo`?o00000oooool4o`0000[ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo07Wooooo002Iooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0@ooooo`;o00003Oooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool01Ol0003ooooo
oooooooooooo000000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo03?ooooo0_l00003ooooo`05o`000?ooooooooooooooool000002?ooool0
1?l0003oooooooooool00002ooooo`;o00002Oooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`00017ooooo00Co0000oooooooooooo0000E_ooool2o`0000[ooooo00?o0000ooooooooool0N_oo
ool009_ooooo1Ol00003ooooo`03o`000?oooooooooo02Oooooo0_l0000Cooooo`03o`000?oooooo
oooo00cooooo0ol00002ooooo`Co00002?ooool4o`0000Sooooo0ol00003ooooo`;o00005oooool3
o`0000Sooooo1Ol000001?oooooo0000o`000?l0000Looooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool00_ooool3o`0000[ooooo0_l00004ooooo`03o`000?oooooooooo00Sooooo0ol0
0004ooooo`;o00001?ooool2o`0000Cooooo0_l0000Aooooo`Go00000oooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0QOooool00?ooooooooooooo3
ooooo`00oooooooooooool?ooooo0000\
\>"],
  ImageRangeCache->{{{0, 704.438}, {116.562, 0}} -> {-0.856351, -0.286992, \
0.00505443, 0.00505443}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .08281 L
.13683 .08224 L
.15332 .0817 L
.16917 .08118 L
.18605 .08063 L
.2023 .0801 L
.21957 .07954 L
.23621 .079 L
.25221 .07848 L
.26924 .07792 L
.28564 .07739 L
.3014 .07688 L
.31819 .07633 L
.33434 .0758 L
.35152 .07524 L
.36806 .07471 L
.38398 .07419 L
.40091 .07364 L
.41722 .0731 L
.43454 .07254 L
.45124 .072 L
.4673 .07147 L
.48439 .07092 L
.5 .07041 L
s
.5 .07041 m
.5161 .06988 L
.53365 .06931 L
.55014 .06877 L
.566 .06826 L
.58288 .06771 L
.59913 .06718 L
.61639 .06662 L
.63303 .06607 L
.64904 .06555 L
.66607 .065 L
.68246 .06446 L
.69823 .06395 L
.71501 .0634 L
.73117 .06288 L
.74834 .06232 L
.76489 .06178 L
.7808 .06126 L
.79774 .06071 L
.81404 .06018 L
.83137 .05961 L
.84806 .05907 L
.86413 .05855 L
.88121 .05799 L
.89683 .05748 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{705.438, 117.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;10000MB000`400?l00000o`00003ooooooooo
oooool?ooooo002Xooooo`;o0000Foooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
05[ooooo0ol0001Jooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000FOooool5o`00
08[ooooo002Wooooo`04o`000?ooooooooooo`0005Wooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000005[ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool00000FOooool01?l0003oooooooooool0002:ooooo`00
Yoooool01?l0003oooooooooool0001Iooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`2:ooooo`00Yoooool01?l0003oooooooooool0001Ioooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`29
ooooo`00Yoooool01?l0003oooooooooool0001Iooooo`04o`000?ooooooooooo`0000Oooooo1?l0
001Kooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01oooool4o`0005Wooooo00Go
0000ooooooooooooooooo`00002:ooooo`00Yoooool01?l0003oooooooooool0001Iooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0Foooool2o`0005_ooooo0_l00009ooooo`03
o`000?oooooooooo05[ooooo00Go0000ooooooooooooooooo`00002:ooooo`00Z?ooool2o`0005_o
oooo0_l00008ooooo`Go0000F_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Oo
oooo1Ol0001Iooooo`?o0000Roooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003o
oooooooooooo`oooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003ooooooooooooo
`oooool00?ooooooooooooo3ooooo`00Goooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0
0007oooooooo0000mOl0001Hooooo`00G_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo05Kooooo001Gooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Oooooo1Ol00007ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo1?l0001Hooooo`00G_oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000oooooooo
ool0E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000oooo
ooooool0E_ooool005oooooo0_l00009ooooo`?o00002?ooool3o`00037ooooo00?o003ooooooooo
ool0oooooonkooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oooooo
ooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Ooo
ool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000
ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool0
07Gooooo0ol0000aooooo`03o`00oooooooooooo0?oooooo^oooool3o`0005Sooooo001eooooo`03
o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Ko
oooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`00
0?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooo
oonmooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3o
oooook_ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo
0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03
o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOoo
ool3o`00037ooooo00?o003oooooooooool0oooooonkooooo`?o0000F?ooool005oooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo037ooooo00?o003o
ooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`00oooooooo
oooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00Eoooool5o`0000;ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003o
ooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01oooool5o`0002oooooo00?o003oooooooooool0oooooonj
ooooo`Co0000F?ooool005kooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooo
oooo05Kooooo001Nooooo`04o`000?ooooooooooo`0000Sooooo0_l00009ooooo`03o`000?oooooo
oooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Ooooo
o`;o00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003ooooo
ooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?oo
ooooooooo`3ooooook_ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo0?ooooooV_ooool2o`00o`03ooooool00?oo003o01kooooo00?o0000ooooooooool0
E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooooi_ooooo00?o
003oooooool00?l07oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0a
ooooo`03o`00oooooooooooo0?ooooooMOoooolFool0017ooooo00?o003oooooooooool07_ooool0
0ol0003oooooooooo`1Fooooo`00MOooool3o`00037ooooo00?o003oooooooooool0oooooomDoooo
ob7oo`009_ooool00ol00?ooooooo`00o`0Mooooo`?o0000F?ooool007Gooooo00?o0000oooooooo
ool0<Oooool00ol00?ooooooooooo`3ooooooccooooo6?oo0016ooooo`;o003o00?oooooo`00ool0
0?l07_ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo0?oooooo6ooooolQool0087ooooo00?o0000ooooooooool0E_ooool007Gooooo00?o
0000ooooooooool0<Oooool00ol00?ooooooooooo`3iooooob7oo`00X_ooool00ol0003ooooooooo
o`1Fooooo`00MOooool3o`00037ooooo00?o003oooooooooool0f?oooolQool00<7ooooo0ol0001H
ooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0;oooooo6Ooo003Toooo
o`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool0W_oooolQool00?gooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`1mooooob7oo`00oooooolOooooo`03o`000?oooooooooo05Kooooo
001eooooo`?o0000<?ooool4o`0005cooooo8Ooo0015ooooo`Co0000`_ooool4o`0002kooooo0ol0
001Hooooo`00Joooool2o`0000Sooooo00?o0000ooooooooool0;_ooool2o`0000Co003o00?o0000
ooooooooool0@?oooolIool006Cooooo0_l00004ooooo`03o`000?oooooooooo0;gooooo0_l00004
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0E_ooool006[ooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`0^ooooo`03o`000?l00?oo003o00?o003o00?o0000
ooooooooool07ooooolQool007gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2m
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1F
ooooo`00J_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02gooooo00?o0000
o`00ool00?l01Ol00?lQool009gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2k
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1F
ooooo`00J_ooool01?l0003oooooooooool00007ooooo`Go00001ooooolTo`00o`04o`000?l00?oo
003oo`00o`Coo`00ool0002:o`0000?o003o00?o0000o`00ool00?l08Ol00?l8ooooo`Co0000F?oo
ool006[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0]ooooo`03o`000?l0
0?oo003o00Go003o00?o0000ooooooooool0^oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0;_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo05Kooooo001Zooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0;_oo
ool2o`0000Co003o00?o0000ooooooooool0_Oooool2o`0000Cooooo00?o0000ooooooooool0_Ooo
ool2o`0000Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Fooooo`00Joooool2
o`0000Sooooo00?o0000ooooooooool0<?ooool00ol0003o003oo`00o`02o`000<7ooooo00?o0000
ooooooooool00_l00031ooooo`04o`000?oooooo0000o`00033ooooo00?o0000ooooooooool0E_oo
ool007Gooooo0ol0000aooooo`;o0000a?ooool2o`000<Cooooo00?o0000ooooooooool0;_ooool3
o`0005Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmoooo
o`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool0oooooonmooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo
00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Ooo
ool00ol00?ooooooooooo`3ooooook_ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0a
ooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0
003oooooooooo`0aooooo`03o`00oooooooooooo00Sooooo0ol00032ooooo`Go0000`_ooool3o`00
02Gooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oo
ooooooooo`09ooooo`03o`000?oooooooooo0<;ooooo00Co0000oooooooooooo0000`Oooool01Ol0
003ooooooooooooooooo000002Cooooo00?o0000ooooooooool0E_ooool007Gooooo0ol0000aoooo
o`03o`00oooooooooooo00Wooooo00?o0000ooooooooool0`oooool00ol0003oooooooooo`35oooo
o`03o`000?oooooooooo023ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03
o`00oooooooooooo00Wooooo00?o0000ooooooooool0a?ooool00ol0003oooooooooo`32ooooo`;o
00009Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo00Wooooo00?o0000ooooooooool0`Oooool01Ol0003ooooooooooooooooo00000<Go
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo00Sooooo0_l00033ooooo`05o`000?ooooooooooooooool0
0000`Oooool01Ol0003ooooooooooooooooo000002Cooooo00?o0000ooooooooool0E_ooool007Go
oooo0ol0000aooooo`03o`00oooooooooooo00Oooooo0_l00?l00ol0003oooooooooo`32ooooo`?o
0000`oooool3o`0002?ooooo0ol0001Hooooo`00Goooool2o`0000Cooooo00?o0000ooooooooool0
0_ooool3o`0000Sooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo0?oooooo/_ooool00ol0003oooooooooo`1Fooooo`00G_ooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo0?oooooo/Oooool00ol0003oooooooooo`1Fooooo`00G_oo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo0?oooooo/Oooool00ol0003ooooo
ooooo`1Fooooo`00G_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo
1Ol0000_ooooo`03o`00oooooooooooo00Sooooo00?o003oooooool00?l0oooooon_ooooo`Co0000
F?ooool005kooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo037ooooo00?o003oooooooooool02?ooool00ol00?ooooooo`00o`3ooooook;ooooo
00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo00002?ooool2o`0000Wooooo
00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`07ooooo`;o003o00?oooooo`00ool00?l0
oooooonaooooo`03o`000?oooooooooo05Kooooo001Oooooo`;o00002_ooool00ol0003ooooooooo
o`07ooooo`?o0000<Oooool00ol00?ooooooooooo`3ooooook_ooooo0ol0001Hooooo`00MOooool0
0ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1F
ooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0
003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oo
oooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool3o`00037ooooo00?o003oooooooooool0
oooooonkooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oooooooooo
o`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool0
0ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000oooo
ooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Go
oooo0ol0000aooooo`03o`00oooooooooooo0?oooooo^oooool3o`0005Sooooo001eooooo`03o`00
0?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo
001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oo
oooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonm
ooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3ooooo
ok_ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oo
oooo_Oooool00ol0003oooooooooo`1Fooooo`00Goooool2o`0000Cooooo00Co0000oooooooooooo
oooo1Ol00007ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03
o`000?oooooooooo05Kooooo001Nooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo063ooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Fooooo`00G_ooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo00Oooooo1Ol00007ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo1?l0001Hoooo
o`00G_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Kooooo001Nooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007oooooooo0000mOl0001H
ooooo`00G_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000oooo
oooooooooeGooooo001Oooooo`;o00002Oooool3o`000?oooooooooooomFooooo`00oooooooooooo
ol?ooooo003ooooooooooooo`oooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003o
oooooooooooo`oooool009Wooooo00?o0000ooooooooool03?ooool3o`0002kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0J_ooool3o`0002;ooooo0ol0000Wooooo`03o`000?oooooooooo07[ooooo002Hooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo08Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Zooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1iooooo`00
V?ooool00ol0003oooooooooo`05o`000003ooooool0003o000000?o00000_ooool4o`0000;ooooo
0ol00002ooooo`?o000000?oooooo`000?l000001_ooool01Ol0003oooooo`000?oooooo000000;o
oooo0ol00003ooooo`Co00000_ooool3o`0000Gooooo00?o0000ooooooooool01?ooool3o`0000Go
oooo00?o0000ooooooooool01?ooool5o`000003ooooool0003o000000;o00002?ooool4o`0000?o
oooo1?l000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`;o00000_ooool3o`00
00;ooooo0ol000000ooooooo0000o`000006ooooo`Go00001oooool5o`000003ooooool0003o0000
00?o00000_ooool3o`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`?o00000_ooool3
o`000003ooooool0003o000000;ooooo0_l00003ooooo`?o00000_ooool3o`000003ooooool0003o
000000?ooooo00?o0000ooooooooool01oooool3o`0000?ooooo00?o0000ooooool000001Oooool0
0ol0003oooooooooo`07ooooo`?o00000oooool3o`0000Cooooo00?o0000ooooooooool00oooool2
o`0000?ooooo0ol00004ooooo`04o`000?ooooooooooooooo`Go00000oooool2o`0000Cooooo0_l0
0004ooooo`;o00001oooool00ol0003oooooooooo`07ooooo`Go000000?oooooo`000?l000000ol0
00001Ooooooo0000o`000?l0003ooooo00Ko00000oooool3o`0000?ooooo1?l000001Ooooooo0000
o`000?l0003ooooo00Go000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000;o
000000Coooooo`000?l0003ooooo1?l00007ooooo`Go000000Goooooo`000?l0003o0000ooooo`02
o`0000Oooooo0ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0NOooool0
09Sooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool01ol0003ooooooooooooooooo0000ooooool000001_ooool01?l0003oooooooooool00007oooo
o`07o`000?oooooo0000ooooool0003oooooo`000003ooooo`03o`000?oooooo000000;ooooo00Co
0000oooooooooooo00004?ooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000Gooooo00Oo0000
ooooool0003oooooo`000?oooooo000000Kooooo00Co0000oooooooooooo00000_ooool01_l0003o
ooooooooool0003oooooo`0000Kooooo00Co0000oooooooooooo00003Oooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooool000004?ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool01_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00004Oooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1iooooo`00Uoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooo000000Co00000_ooool01?l0003ooooooooo
ool00007ooooo`07o`000?oooooo0000ooooool0003oooooo`000003ooooo`03o`000?oooooo0000
00;ooooo00?o0000ooooooooool01Ol0000<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo0ol0
0004ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`Go00000_ooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooooooool5o`000007ooooool0003oooooo`000?oooooo0000ooooo`05o`0000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`Go00000_ooool01?l0003ooooooooo
ool0000=ooooo`0;o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000003ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00017ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07So
oooo002Hooooo`04o`000?ooooooooooooooo`?o00001?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00Gooooo00Oo0000ooooool0003oooooo`000?oooooo000000?ooooo00?o0000ooooool00000
0_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool03_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01_ooool3o`00
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000[ooooo
00?o0000ooooooooool01oooool3o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`09
o`000?oooooo0000ooooool0003oooooo`000?oooooo000000?ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000=ooooo`0;o`000?ooooooooooooooool0003oooooo`000?oooooo0000oooo
ool000003oooool00ol0003oooooooooo`03ooooo`;o00002Oooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0?ooooo`?o
00001?ooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool0
1_l0003oooooooooool0003oooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1iooooo`00V?ooool01Ol0003ooooooooooooooooo000000Cooooo0ol00004ooooo`Go0000
00Coooooo`000?l0003o00000_ooool4o`0000Sooooo0_l000000ooooooo0000ooooo`02ooooo`?o
00000oooool3o`0000?ooooo0ol0000=ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_oo
ool2o`0000Gooooo00?o0000ooooooooool00_ooool01?l0003oooooo`000?l00002ooooo`?o0000
0_ooool4o`0000Sooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool3o`0000;ooooo0_l000000ooooooo0000ooooo`02ooooo`?o
00000_ooool4o`0000;ooooo1?l00003ooooo`?o00000_ooool4o`0000oooooo0ol00002ooooo`Ko
00003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`Co
00000oooool4o`000003ooooool0003o000000;o00000oooool2o`0000?ooooo1?l00002ooooo`Co
00000_ooool2o`000004ooooool0003o0000ooooo`Co00000oooool5o`0000Kooooo0ol00003oooo
o`Co00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0NOooool009Wooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo013ooooo0_l0000=ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Dooooo`05o`000?ooooooooooooooool000002?ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0<oooool2o`00
00?ooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000;ooooo0_l0
0009ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00004Oooool01?l0003oooooooooool0
001Fooooo`;o00002_ooool00ol0003oooooooooo`1jooooo`00Voooool5o`0000?ooooo00?o0000
ooooooooool09oooool2o`0001?ooooo00?o0000ooooooooool03?ooool3o`0000;ooooo1?l00008
ooooo`Co00002?ooool3o`0000?ooooo0_l0000Gooooo`?o00002?ooool5o`000004ooooool0003o
0000o`0001cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`?o00002_oo
ool2o`0000Cooooo00?o0000ooooooooool02?ooool3o`0000Cooooo0_l00004ooooo`;o00001?oo
ool2o`00017ooooo1Ol00003ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`25ooooo`00oooooooooooool?ooooo003ooooooooooooo`oooool00001
\
\>"],
  ImageRangeCache->{{{0, 704.438}, {116.562, 0}} -> {-0.856351, -0.286992, \
0.00505443, 0.00505443}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .08196 L
.13683 .08046 L
.15332 .07906 L
.16917 .07771 L
.18605 .07627 L
.2023 .07488 L
.21957 .07341 L
.23621 .07199 L
.25221 .07062 L
.26924 .06917 L
.28564 .06777 L
.3014 .06643 L
.31819 .065 L
.33434 .06362 L
.35152 .06216 L
.36806 .06074 L
.38398 .05939 L
.40091 .05794 L
.41722 .05655 L
.43454 .05507 L
.45124 .05365 L
.4673 .05228 L
.48439 .05082 L
.5 .04949 L
s
.5 .04949 m
.5161 .04812 L
.53365 .04662 L
.55014 .04522 L
.566 .04386 L
.58288 .04243 L
.59913 .04104 L
.61639 .03957 L
.63303 .03815 L
.64904 .03678 L
.66607 .03533 L
.68246 .03393 L
.69823 .03259 L
.71501 .03116 L
.73117 .02978 L
.74834 .02831 L
.76489 .0269 L
.7808 .02555 L
.79774 .0241 L
.81404 .02271 L
.83137 .02123 L
.84806 .01981 L
.86413 .01844 L
.88121 .01698 L
.89683 .01565 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{705.438, 117.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;10000MB000`400?l00000o`00003ooooooooo
oooool?ooooo002Xooooo`;o0000Foooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
05[ooooo0ol0001Jooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000FOooool5o`00
08[ooooo002Wooooo`04o`000?ooooooooooo`0005Wooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000005[ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool00000FOooool01?l0003oooooooooool0002:ooooo`00
Yoooool01?l0003oooooooooool0001Iooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`2:ooooo`00Yoooool01?l0003oooooooooool0001Ioooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`29
ooooo`00Yoooool01?l0003oooooooooool0001Iooooo`04o`000?ooooooooooo`0000Oooooo1?l0
001Kooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01oooool4o`0005Wooooo00Go
0000ooooooooooooooooo`00002:ooooo`00Yoooool01?l0003oooooooooool0001Iooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0Foooool2o`0005_ooooo0_l00009ooooo`03
o`000?oooooooooo05[ooooo00Go0000ooooooooooooooooo`00002:ooooo`00Z?ooool2o`0005_o
oooo0_l00008ooooo`Go0000F_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Oo
oooo1Ol0001Iooooo`?o0000Roooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003o
oooooooooooo`oooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003ooooooooooooo
`oooool00?ooooooooooooo3ooooo`00Goooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0
0007oooooooo0000mOl0001Hooooo`00G_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo05Kooooo001Gooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Oooooo1Ol00007ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo1?l0001Hooooo`00G_oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000oooooooo
ool0E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000oooo
ooooool0E_ooool005oooooo0_l00009ooooo`?o00002?ooool3o`00037ooooo00?o003ooooooooo
ool0oooooonkooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oooooo
ooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Ooo
ool00ol00?ooooooooooo`3oooooohKooooo1Ooo000booooo`03o`000?oooooooooo05Kooooo001e
ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooomeoooooa7oo`00=oooool0
0ol0003oooooooooo`1Fooooo`00MOooool3o`00037ooooo00?o003oooooooooool0oooooom]oooo
o`Soo`00A_ooool3o`0005Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool0oooooomLoooooa7oo`00D?ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo0?ooooooE?ooool8ool0067ooooo00?o0000ooooooooool0
E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3oooooodcooooo2?oo
001Yooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3o
oooooccooooo4?oo001_ooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol0
0?ooooooooooo`3ooooooc?ooooo2Ooo0021ooooo`03o`000?oooooooooo05Kooooo001eooooo`03
o`000?oooooooooo037ooooo00?o003oooooooooool0oooooolSoooooa3oo`00R_ooool00ol0003o
ooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo
6oooool8ool009[ooooo00?o0000ooooooooool0E_ooool007Gooooo0ol0000aooooo`03o`00oooo
oooooooo0?oooooo4oooool8ool00:3ooooo0ol0001Hooooo`00Goooool2o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0000Sooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3o
ooooo`;ooooo4Ooo002Zooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`00oooooooo
oooo0?Wooooo2?oo002kooooo`03o`000?oooooooooo05Kooooo001Gooooo`Go00000_ooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Oooool0
0ol00?ooooooooooo`3Xoooooa7oo`00`oooool00ol0003oooooooooo`1Fooooo`00G_ooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo1Ol0000_ooooo`03o`00oooooooo
oooo0>3ooooo2?oo003Aooooo`Co0000F?ooool005kooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0d?ooool@
ool00=cooooo00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo00002?ooool2
o`0000Wooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`37ooooo`Woo`00k?ooool0
0ol0003oooooooooo`1Fooooo`00Goooool2o`0000[ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0aooooo`03o`00oooooooooooo0;oooooo2?oo003eooooo`03o`000?oooooooooo
05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`2^oooooa7oo`00noooool3o`0005So
oooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0Y_ooool8ool00>_ooooo
0_l00?l00ooooooo003oo`00o`0Nooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oo
oooooooo037ooooo00?o003oooooooooool0U_ooool@ool00?Cooooo00?o003oooooool00?l07ooo
ool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooo
oooo08gooooo2Ooo003oooooo`Kooooo00?o003oooooooooool07_ooool00ol0003oooooooooo`1F
ooooo`00MOooool3o`00037ooooo00?o003oooooooooool0OOooool@ool00?oooooo3_ooool00ol0
0?ooooooo`00o`0Mooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oo
ooooooooo`1eooooo`Soo`00oooooolMooooo`;o003o00?oooooo`00ool00?l07_ooool00ol0003o
ooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo06cooooo
2Ooo003oooooodSooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Ooo
ool00ol00?ooooooooooo`1Loooooa3oo`00oooooomAooooo`03o`000?oooooooooo05Kooooo001e
ooooo`?o0000<Oooool00ol00?ooooooooooo`1Dooooo`Soo`00oooooomOooooo`?o0000F?ooool0
07Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`13oooooa7oo`00oooooomYoooo
o`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool0>oooool8ool00?ooooooN_ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo03?ooooo2?oo003ooooooh;ooooo00?o0000ooooooooool0
E_ooool007Gooooo0ol0000`ooooo`Co00008_oooolAool008oooooo1?l00032ooooo`Co0000;_oo
ool3o`0005Sooooo001[ooooo`;o00002?ooool00ol0003oooooooooo`0^ooooo`;o00001?l00?l0
0ol0003oooooooooo`0Gooooo`Soo`00W_ooool2o`0000Cooooo00?o0000ooooooooool0_Oooool2
o`0000Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Fooooo`00J_ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo02kooooo00?o0000o`00ool00?l00ol00?l0
0ol0003oooooooooo`07oooooa3oo`00Y_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0;gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo05Kooooo001Zooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0;Oooool0
0ol0003o003oo`00o`05o`00o`Woo`00]Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0;_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo05Kooooo001Zooooo`04o`000?ooooooooooo`0000Oooooo1Ol00007ooooobCo003o00Co0000
o`00ool00?oo003o1?oo003oo`0008[o00000ol00?l00ol0003o003oo`00o`0Qo`00o`Sooooo1?l0
001Hooooo`00J_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02gooooo00?o
0000o`00ool00?l01Ol00?l00ol0003oooooooooo`2kooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0^oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0E_ooool006[ooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`0^ooooo`;o00001?l00?l00ol0003oooooooooo`2mooooo`;o00001?ooool00ol0003ooooooooo
o`2mooooo`;o00001?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo05Kooooo001[
ooooo`;o00002?ooool00ol0003oooooooooo`0`ooooo`03o`000?l00?oo003o00;o0000`Oooool0
0ol0003oooooooooo`02o`000<7ooooo00Co0000ooooool0003o0000<?ooool00ol0003ooooooooo
o`1Fooooo`00MOooool3o`00037ooooo0_l00034ooooo`;o0000a?ooool00ol0003oooooooooo`0^
ooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooo
okgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oo
ooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo0ol0
000aooooo`03o`00oooooooooooo0?oooooo^oooool3o`0005Sooooo001eooooo`03o`000?oooooo
oooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001eoooo
o`03o`000?oooooooooo037ooooo00?o003oooooooooool02?ooool3o`000<;ooooo1Ol00032oooo
o`?o00009Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03
o`00oooooooooooo00Wooooo00?o0000ooooooooool0`_ooool01?l0003oooooooooool00031oooo
o`05o`000?ooooooooooooooool000009?ooool00ol0003oooooooooo`1Fooooo`00MOooool3o`00
037ooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`33ooooo`03o`000?oooooooooo
0<Gooooo00?o0000ooooooooool08?ooool3o`0005Sooooo001eooooo`03o`000?oooooooooo037o
oooo00?o003oooooooooool02Oooool00ol0003oooooooooo`34ooooo`03o`000?oooooooooo0<;o
oooo0_l0000Uooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo
00?o003oooooooooool02Oooool00ol0003oooooooooo`31ooooo`05o`000?ooooooooooooooool0
0000aOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`00
0?oooooooooo037ooooo00?o003oooooooooool02?ooool2o`000<?ooooo00Go0000oooooooooooo
ooooo`000031ooooo`05o`000?ooooooooooooooool000009?ooool00ol0003oooooooooo`1Foooo
o`00MOooool3o`00037ooooo00?o003oooooooooool01oooool2o`00o`03o`000?oooooooooo0<;o
oooo0ol00033ooooo`?o00008oooool3o`0005Sooooo001Oooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`?o00002?ooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool0oooooonbooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool0oooooonaooooo`03o`000?oooooooooo05Kooooo
001Nooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0oooooonaooooo`03o`00
0?oooooooooo05Kooooo001Nooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
1oooool5o`0002oooooo00?o003oooooooooool02?ooool00ol00?ooooooo`00o`3oooooojoooooo
1?l0001Hooooo`00G_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo003o0?oooooo
/_ooool00ol0003oooooooooo`1Fooooo`00G_ooool01?l0003oooooooooool00008ooooo`;o0000
2Oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Oooooo0_l00?l00ooooooo003o
o`00o`3ooooook7ooooo00?o0000ooooooooool0E_ooool005oooooo0_l0000:ooooo`03o`000?oo
oooooooo00Oooooo0ol0000aooooo`03o`00oooooooooooo0?oooooo^oooool3o`0005Sooooo001e
ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooo
oooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmoooo
o`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool0oooooonmooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?oooooo
ooooo`3ooooook_ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooo
oooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0a
ooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0
003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Foooo
o`00MOooool3o`00037ooooo00?o003oooooooooool0oooooonkooooo`?o0000F?ooool007Gooooo
00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0
E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o
0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3o
oooookgooooo00?o0000ooooooooool0E_ooool007Gooooo0ol0000aooooo`03o`00oooooooooooo
0?oooooo^oooool3o`0005Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Oooooo`;o00001?ooool01?l0003ooooo
ooooooooool5o`0000Oooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgo
oooo00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0H?ooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool01oooool5o`0000Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool4o`00
05Sooooo001Nooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0E_ooool005ko
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Ooooooool0003e
o`0005Sooooo001Nooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
003oooooooooooooEOooool005oooooo0_l00009ooooo`?o0000oooooooooooooeKooooo003ooooo
oooooooo`oooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003ooooooooooooo`ooo
ool00?ooooooooooooo3ooooo`00VOooool00ol0003oooooooooo`0<ooooo`?o0000;_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`1Zooooo`?o00008_ooool3o`0002Oooooo00?o0000ooooooooool0N_ooool009So
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Wo
oooo002Hooooo`03o`000?oooooooooo00Go000000?oooooo`000?l000000ol00002ooooo`Co0000
0_ooool3o`0000;ooooo0ol000000ooooooo0000o`000006ooooo`05o`000?oooooo0000ooooool0
00000_ooool3o`0000?ooooo1?l00002ooooo`?o00001Oooool00ol0003oooooooooo`04ooooo`?o
00001Oooool00ol0003oooooooooo`04ooooo`Go000000?oooooo`000?l000000_l00008ooooo`Co
00000oooool4o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo0_l00002oooo
o`?o00000_ooool3o`000003ooooool0003o000000Kooooo1Ol00007ooooo`Go000000?oooooo`00
0?l000000ol00002ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol00002
ooooo`?o000000?oooooo`000?l000000_ooool2o`0000?ooooo0ol00002ooooo`?o000000?ooooo
o`000?l000000oooool00ol0003oooooooooo`07ooooo`?o00000oooool00ol0003oooooo`000005
ooooo`03o`000?oooooooooo00Oooooo0ol00003ooooo`?o00001?ooool00ol0003oooooooooo`03
ooooo`;o00000oooool3o`0000Cooooo00Co0000oooooooooooooooo1Ol00003ooooo`;o00001?oo
ool2o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo00Oooooo1Ol000000ooooooo0000o`00
0003o`000005ooooool0003o0000o`000?ooool01_l00003ooooo`?o00000oooool4o`000005oooo
ool0003o0000o`000?ooool01Ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l0
00000_l000001?oooooo0000o`000?ooool4o`0000Oooooo1Ol000001Ooooooo0000o`000?l0003o
oooo00;o00001oooool3o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1i
ooooo`00V?ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`07o`000?ooooooooooooooool0003oooooo`000006ooooo`04o`000?ooooooooooo`00
00Oooooo00Oo0000ooooool0003oooooo`000?oooooo000000?ooooo00?o0000ooooool000000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000001Oooool0
1ol0003oooooo`000?oooooo0000ooooool000001_ooool01?l0003oooooooooool00002ooooo`06
o`000?ooooooooooo`000?oooooo00001_ooool01?l0003oooooooooool0000=ooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooo`00000@ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool02?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0000Aooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo07Wooooo002Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000001?l00002ooooo`04o`000?oo
ooooooooo`0000Oooooo00Oo0000ooooool0003oooooo`000?oooooo000000?ooooo00?o0000oooo
ool000000_ooool00ol0003oooooooooo`05o`0000cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_oo
ool3o`0000Cooooo00?o0000ooooooooool00_ooool2o`0000?ooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooooooo`Go000000Ooooooo`000?oooooo0000ooooool0003ooooo00Go00000_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0000gooooo00_o0000ooooooooooooooooo`000?oooooo0000ooooool0003oooooo`00
000?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00004Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool3o`0000?ooooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0N?ooool009Sooooo00Co0000oooooooooooooooo0ol00004ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool01Oooool01ol0003oooooo`000?oooooo0000ooooool000000oooool00ol0003ooooo
o`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0>ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`06oooo
o`?o00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
2_ooool00ol0003oooooooooo`07ooooo`?o00001?ooool01Ol0003ooooooooooooooooo000000?o
oooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000000oooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000gooooo00_o0000ooooooooooooooooo`000?oooooo0000ooooool0
003oooooo`00000?ooooo`03o`000?oooooooooo00?ooooo0_l00009ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oo
oooo0ol00004ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00006
ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo07Wooooo002Hooooo`05o`000?ooooooooooooooool000001?ooool3o`0000Cooooo
1Ol000001?oooooo0000o`000?l00002ooooo`Co00002?ooool2o`000003ooooool0003ooooo00;o
oooo0ol00003ooooo`?o00000oooool3o`0000gooooo00?o0000ooooooooool02oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0002ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo0000o`0000;ooooo
0ol00002ooooo`Co00002?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`?o00000_ooool2o`000003ooooool0003ooooo00;o
oooo0ol00002ooooo`Co00000_ooool4o`0000?ooooo0ol00002ooooo`Co00003oooool3o`0000;o
oooo1_l0000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00006ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool3o`0000?o
oooo1?l00003ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o00000oooool4o`0000;o
oooo1?l00002ooooo`;o000000Coooooo`000?l0003ooooo1?l00003ooooo`Go00001_ooool3o`00
00?ooooo1?l0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1iooooo`00VOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool04?ooool2o`0000gooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`000008ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0coooo
o`;o00000oooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00000_oo
ool2o`0000Wooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Aooooo`04o`000?oooooo
ooooo`0005Kooooo0_l0000:ooooo`03o`000?oooooooooo07[ooooo002Kooooo`Go00000oooool0
0ol0003oooooooooo`0Wooooo`;o00004oooool00ol0003oooooooooo`0<ooooo`?o00000_ooool4
o`0000Sooooo1?l00008ooooo`?o00000oooool2o`0001Oooooo0ol00008ooooo`Go000000Cooooo
o`000?l0003o00007?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00;ooooo0ol0
000:ooooo`;o00001?ooool00ol0003oooooooooo`08ooooo`?o00001?ooool2o`0000Cooooo0_l0
0004ooooo`;o00004Oooool5o`0000?ooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo08Gooooo003ooooooooooooo`oooool00?ooooooooooooo3oooo
o`00\
\>"],
  ImageRangeCache->{{{0, 704.438}, {116.562, 0}} -> {-0.856351, -0.286992, \
0.00505443, 0.00505443}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .17117 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0877337 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00837 -24 -4.5 ]
[-0.0125 .00837 0 4.5 ]
[-0.0125 .04805 -24 -4.5 ]
[-0.0125 .04805 0 4.5 ]
[-0.0125 .08773 -6 -4.5 ]
[-0.0125 .08773 0 4.5 ]
[-0.0125 .12742 -18 -4.5 ]
[-0.0125 .12742 0 4.5 ]
[-0.0125 .1671 -18 -4.5 ]
[-0.0125 .1671 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .17117 .125 0 ]
[ 1 0 .125 0 ]
[.5 .18367 -219.875 0 ]
[.5 .18367 219.875 12 ]
[.93651 .06128 -5 -6 ]
[.93651 .06128 5 6 ]
[.12963 .12742 -5 -6 ]
[.12963 .12742 5 6 ]
[.12963 .11419 -3 -4.5 ]
[.12963 .11419 3 4.5 ]
[.52646 .11419 -3 -4.5 ]
[.52646 .11419 3 4.5 ]
[.92328 .11419 -3 -4.5 ]
[.92328 .11419 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .17117 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00837 m
.00625 .00837 L
s
[(-0.2)] -0.0125 .00837 1 0 Mshowa
0 .04805 m
.00625 .04805 L
s
[(-0.1)] -0.0125 .04805 1 0 Mshowa
0 .08773 m
.00625 .08773 L
s
[(0)] -0.0125 .08773 1 0 Mshowa
0 .12742 m
.00625 .12742 L
s
[(0.1)] -0.0125 .12742 1 0 Mshowa
0 .1671 m
.00625 .1671 L
s
[(0.2)] -0.0125 .1671 1 0 Mshowa
.125 Mabswid
0 .01631 m
.00375 .01631 L
s
0 .02424 m
.00375 .02424 L
s
0 .03218 m
.00375 .03218 L
s
0 .04011 m
.00375 .04011 L
s
0 .05599 m
.00375 .05599 L
s
0 .06392 m
.00375 .06392 L
s
0 .07186 m
.00375 .07186 L
s
0 .0798 m
.00375 .0798 L
s
0 .09567 m
.00375 .09567 L
s
0 .10361 m
.00375 .10361 L
s
0 .11154 m
.00375 .11154 L
s
0 .11948 m
.00375 .11948 L
s
0 .13535 m
.00375 .13535 L
s
0 .14329 m
.00375 .14329 L
s
0 .15123 m
.00375 .15123 L
s
0 .15916 m
.00375 .15916 L
s
0 .00043 m
.00375 .00043 L
s
.25 Mabswid
0 0 m
0 .17117 L
s
.10317 .16492 m
.10317 .17117 L
s
.30159 .16492 m
.30159 .17117 L
s
.5 .16492 m
.5 .17117 L
s
.69841 .16492 m
.69841 .17117 L
s
.89683 .16492 m
.89683 .17117 L
s
.125 Mabswid
.14286 .16742 m
.14286 .17117 L
s
.18254 .16742 m
.18254 .17117 L
s
.22222 .16742 m
.22222 .17117 L
s
.2619 .16742 m
.2619 .17117 L
s
.34127 .16742 m
.34127 .17117 L
s
.38095 .16742 m
.38095 .17117 L
s
.42063 .16742 m
.42063 .17117 L
s
.46032 .16742 m
.46032 .17117 L
s
.53968 .16742 m
.53968 .17117 L
s
.57937 .16742 m
.57937 .17117 L
s
.61905 .16742 m
.61905 .17117 L
s
.65873 .16742 m
.65873 .17117 L
s
.7381 .16742 m
.7381 .17117 L
s
.77778 .16742 m
.77778 .17117 L
s
.81746 .16742 m
.81746 .17117 L
s
.85714 .16742 m
.85714 .17117 L
s
.06349 .16742 m
.06349 .17117 L
s
.02381 .16742 m
.02381 .17117 L
s
.93651 .16742 m
.93651 .17117 L
s
.97619 .16742 m
.97619 .17117 L
s
.25 Mabswid
0 .17117 m
1 .17117 L
s
.99375 .00837 m
1 .00837 L
s
.99375 .04805 m
1 .04805 L
s
.99375 .08773 m
1 .08773 L
s
.99375 .12742 m
1 .12742 L
s
.99375 .1671 m
1 .1671 L
s
.125 Mabswid
.99625 .01631 m
1 .01631 L
s
.99625 .02424 m
1 .02424 L
s
.99625 .03218 m
1 .03218 L
s
.99625 .04011 m
1 .04011 L
s
.99625 .05599 m
1 .05599 L
s
.99625 .06392 m
1 .06392 L
s
.99625 .07186 m
1 .07186 L
s
.99625 .0798 m
1 .0798 L
s
.99625 .09567 m
1 .09567 L
s
.99625 .10361 m
1 .10361 L
s
.99625 .11154 m
1 .11154 L
s
.99625 .11948 m
1 .11948 L
s
.99625 .13535 m
1 .13535 L
s
.99625 .14329 m
1 .14329 L
s
.99625 .15123 m
1 .15123 L
s
.99625 .15916 m
1 .15916 L
s
.99625 .00043 m
1 .00043 L
s
.25 Mabswid
1 0 m
1 .17117 L
s
gsave
.5 .18367 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08773 m
.97619 .08773 L
s
.10317 .00837 m
.10317 .1671 L
s
.10317 .08773 m
.10317 .08773 .00794 0 365.73 arc
F
gsave
.93651 .06128 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12742 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .11419 0 0 Mshowa
[(2)] .52646 .11419 0 0 Mshowa
[(3)] .92328 .11419 0 0 Mshowa
newpath
.10317 .08773 .00794 0 365.73 arc
s
newpath
.5 .08773 .00794 0 365.73 arc
s
newpath
.89683 .08773 .00794 0 365.73 arc
s
.10317 .08773 m
.5 .08773 L
s
.5 .08773 m
.89683 .08773 L
s
1 0 0 r
.10317 .08773 m
.11927 .08604 L
.13683 .08419 L
.15332 .08245 L
.16917 .08078 L
.18605 .079 L
.2023 .07729 L
.21957 .07546 L
.23621 .07371 L
.25221 .07202 L
.26924 .07023 L
.28564 .0685 L
.3014 .06684 L
.31819 .06507 L
.33434 .06337 L
.35152 .06156 L
.36806 .05981 L
.38398 .05813 L
.40091 .05635 L
.41722 .05463 L
.43454 .0528 L
.45124 .05104 L
.4673 .04935 L
.48439 .04755 L
.5 .0459 L
s
.5 .0459 m
.5161 .04421 L
.53365 .04236 L
.55014 .04062 L
.566 .03895 L
.58288 .03717 L
.59913 .03546 L
.61639 .03364 L
.63303 .03188 L
.64904 .03019 L
.66607 .0284 L
.68246 .02667 L
.69823 .02501 L
.71501 .02324 L
.73117 .02154 L
.74834 .01973 L
.76489 .01798 L
.7808 .01631 L
.79774 .01452 L
.81404 .0128 L
.83137 .01098 L
.84806 .00922 L
.86413 .00752 L
.88121 .00572 L
.89683 .00408 L
s
0 0 m
1 0 L
1 .17117 L
0 .17117 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{704.688, 120.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;00000N2000`400?l00000o`00003ooooooooo
oooool;ooooo002Vooooo`;o0000G?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
05[ooooo0ol0001Kooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000F_ooool5o`00
08Sooooo002Uooooo`04o`000?ooooooooooo`0005[ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000005[ooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool00000F_ooool01?l0003oooooooooool00028ooooo`00
YOooool01?l0003oooooooooool0001Jooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0FOooool00ol0003oooooooooo`28ooooo`00YOooool01?l0003oooooooooool0001Joooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`27
ooooo`00YOooool01?l0003oooooooooool0001Jooooo`04o`000?ooooooooooo`0000Oooooo1?l0
001Kooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool01oooool4o`0005[ooooo00Go
0000ooooooooooooooooo`000028ooooo`00YOooool01?l0003oooooooooool0001Jooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0Foooool2o`0005cooooo0_l00009ooooo`03
o`000?oooooooooo05_ooooo00Go0000ooooooooooooooooo`000028ooooo`00Y_ooool2o`0005co
oooo0_l00008ooooo`Go0000F_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00Oo
oooo1Ol0001Jooooo`?o0000ROooool00?ooooooooooooo2ooooo`00oooooooooooool;ooooo003o
oooooooooooo`_ooool00?ooooooooooooo2ooooo`00oooooooooooool;ooooo003ooooooooooooo
`_ooool00?ooooooooooooo2ooooo`00Loooooooo`000?Wo0000EOooool007?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05?ooooo001Mooooo`;o
00001?ooool01?l0003oooooooooooooool5o`0000Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0=ooooo`Goo`004oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0Doooool005cooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0HOooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0EOooool8
ool000Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1Cooooo`00EOooool5o`00
00;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07ooooo`Co0000<?ooool0
0ol00?ooooooooooo`3oooooogSooooo2Ooo000mooooo`Co0000EOooool005cooooo00Co0000oooo
oooooooo00002_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo037ooooo00?o003o
ooooooooool0oooooom`ooooo`Soo`00BOooool00ol0003oooooooooo`1Cooooo`00G?ooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooooooo
o`0aooooo`03o`00oooooooooooo0?ooooooJ?ooool8ool0057ooooo00?o0000ooooooooool0Dooo
ool005cooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooooeOooooo4Ooo001Iooooo`03o`00
0?oooooooooo05?ooooo001Mooooo`;o00002Oooool3o`0000Sooooo0ol0000aooooo`03o`00oooo
oooooooo0?ooooooCoooool8ool006Sooooo0ol0001Eooooo`00Loooool00ol0003oooooooooo`0a
ooooo`03o`00oooooooooooo0?ooooooAoooool8ool007;ooooo00?o0000ooooooooool0Doooool0
07?ooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3oooooockooooo2Ooo001joooo
o`03o`000?oooooooooo05?ooooo001cooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool0oooooolfooooo`Soo`00Poooool00ol0003oooooooooo`1Cooooo`00Loooool3o`00037ooooo
00?o003oooooooooool0ooooool^ooooo`Soo`00ROooool3o`0005Gooooo001cooooo`03o`000?oo
oooooooo037ooooo00?o003oooooooooool0oooooolUooooo`Woo`00Toooool00ol0003ooooooooo
o`1Cooooo`00Loooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo5Oooool@
ool009cooooo00?o0000ooooooooool0Doooool007?ooooo00?o0000ooooooooool0<Oooool00ol0
0?ooooooooooo`3oooooo`cooooo2Ooo002/ooooo`03o`000?oooooooooo05?ooooo001cooooo`?o
0000<Oooool00ol00?ooooooooooo`3oooooo`Cooooo2?oo002cooooo`?o0000EOooool007?ooooo
00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3kooooo`Soo`00_Oooool00ol0003ooooo
ooooo`1Cooooo`00Loooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?;ooooo2Ooo
0035ooooo`03o`000?oooooooooo05?ooooo001cooooo`03o`000?oooooooooo037ooooo00?o003o
ooooooooool0j_ooool8ool00<kooooo00?o0000ooooooooool0Doooool007?ooooo0ol0000aoooo
o`03o`00oooooooooooo0>;ooooo2?oo003Dooooo`?o0000EOooool007?ooooo00?o0000oooooooo
ool0<Oooool00ol00?ooooooooooo`3Aoooooa7oo`00g_ooool00ol0003oooooooooo`1Cooooo`00
GOooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Sooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`39ooooo`Soo`00koooool00ol0003oooooooooo`1Cooooo`00G?oo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`31ooooo`Soo`00moooool00ol0003oooooooooo`1Cooooo`00EOoo
ool5o`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07ooooo`Co0000
<?ooool00ol00?ooooooooooo`2iooooo`Soo`00o?ooool4o`0005Gooooo001Looooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo0;3ooooo2Ooo003oooooo`Sooooo00?o0000ooooooooool0Doooool005cooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo
00?o003oooooooooool0Z?ooool8ool00?oooooo4Oooool00ol0003oooooooooo`1Cooooo`00G?oo
ool01?l0003oooooooooool00008ooooo`;o00002Oooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo0:3ooooo2?oo003ooooooaWooooo00?o0000ooooooooool0Doooool005gooooo0_l0
000:ooooo`03o`000?oooooooooo00Oooooo0ol0000aooooo`03o`00oooooooooooo08oooooo4Ooo
003ooooooaoooooo0ol0001Eooooo`00Loooool00ol0003oooooooooo`0aooooo`03o`00oooooooo
oooo08Kooooo2Ooo003oooooo`oooooo0_l00?l00ooooooo003oo`00o`0Nooooo`03o`000?oooooo
oooo05?ooooo001cooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0O_ooool8ool0
0?oooooo6Oooool00ol00?ooooooo`00o`0Oooooo`03o`000?oooooooooo05?ooooo001cooooo`03
o`000?oooooooooo037ooooo00?o003oooooooooool0M_ooool8ool00?oooooo8_ooool00ol00?oo
ooooooooo`0Nooooo`03o`000?oooooooooo05?ooooo001cooooo`?o0000<Oooool00ol00?oooooo
ooooo`1]ooooo`Woo`00oooooolYooooo`03o`00oooooooo003o01gooooo0ol0001Eooooo`00Looo
ool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo06Gooooo2?oo003ooooooc7ooooo0_l0
0?l00ooooooo003oo`00o`0Nooooo`03o`000?oooooooooo05?ooooo001cooooo`03o`000?oooooo
oooo037ooooo00?o003oooooooooool0GOooool8ool00?ooooooG?ooool00ol0003oooooooooo`1C
ooooo`00Loooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo04cooooo4Ooo003ooooo
ofCooooo00?o0000ooooooooool0Doooool007?ooooo0ol0000aooooo`03o`00oooooooooooo04Co
oooo2?oo003oooooog?ooooo0ol0001Eooooo`00Loooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo03cooooo2?oo003ooooooggooooo00?o0000ooooooooool0Doooool007?ooooo00?o
0000ooooooooool0<Oooool00ol00?ooooooooooo`0cooooo`Woo`00oooooon5ooooo`03o`000?oo
oooooooo05?ooooo001cooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0:oooool8
ool00?ooooooS_ooool00ol0003oooooooooo`1Cooooo`00Loooool3o`00033ooooo0ol0000Toooo
o`Soo`00VOooool2o`000<Gooooo0ol0000`ooooo`?o0000EOooool007?ooooo00?o0000oooooooo
ool0;_ooool2o`0000?o003o00?o0000ooooooooool06?ooool9ool009oooooo0_l00002ooooo`03
o`000?oooooooooo0<3ooooo0_l00003ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0Doooool006Wooooo0_l00008ooooo`03o`000?oooooooooo02kooooo00?o0000o`00ool00?l0
0ol00?l00ol0003oooooooooo`07oooooa3oo`00Z?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo05?ooooo001Xooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
;Oooool00ol0003o003oo`00o`04o`00o`03o`000?oo003oo`0000Ooo`00]oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0;kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo05?ooooo001Xooooo`04o`000?ooooooooooo`0000Oooooo
1?l00008ooooobCo003o00Co0000o`00ool00?oo003o1?oo003oo`0008go00000ol00?l00ol0003o
003oo`00o`0Ro`00o`Sooooo1?l0001Eooooo`00J?ooool01?l0003oooooooooool00007ooooo`03
o`000?oooooooooo02gooooo00?o0000o`00ool00?l01Ol00?l00ol0003oooooooooo`2looooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0_Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0Doooool006Sooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0^ooooo`03o`000?l00?oo003o00?o003o00?o0000oooooooo
ool0__ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo05?ooooo001Xooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0;_ooool3o`0000;o003o0_l00030ooooo`?o
00000_ooool2o`000<7ooooo0ol00002ooooo`;o0000<?ooool00ol0003oooooooooo`1Cooooo`00
JOooool2o`0000Sooooo0ol0000aooooo`;o0000aOooool2o`000<Kooooo0_l0000`ooooo`?o0000
EOooool007?ooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooool7ooooo00?o
0000ooooooooool0Doooool007?ooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3o
oooool7ooooo00?o0000ooooooooool0Doooool007?ooooo00?o0000ooooooooool0<Oooool00ol0
0?ooooooooooo`3ooooool7ooooo00?o0000ooooooooool0Doooool007?ooooo0ol0000aooooo`03
o`00oooooooooooo0?oooooo_oooool3o`0005Gooooo001cooooo`03o`000?oooooooooo037ooooo
00?o003oooooooooool0ooooooo1ooooo`03o`000?oooooooooo05?ooooo001cooooo`03o`000?oo
oooooooo037ooooo00?o003oooooooooool0ooooooo1ooooo`03o`000?oooooooooo05?ooooo001c
ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool02?ooool3o`000<Cooooo1Ol00033
ooooo`?o00009_ooool00ol0003oooooooooo`1Cooooo`00Loooool3o`00037ooooo00?o003ooooo
ooooool02Oooool00ol0003oooooooooo`34ooooo`04o`000?ooooooooooo`000<;ooooo00Go0000
ooooooooooooooooo`00000Sooooo`?o0000EOooool007?ooooo00?o0000ooooooooool0<Oooool0
0ol00?ooooooooooo`09ooooo`03o`000?oooooooooo0<Gooooo00?o0000ooooooooool0a_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05?ooooo001cooooo`03o`000?oooooooooo
037ooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`36ooooo`03o`000?oooooooooo
0<?ooooo0_l0000Vooooo`03o`000?oooooooooo05?ooooo001cooooo`03o`000?oooooooooo037o
oooo00?o003oooooooooool02Oooool00ol0003oooooooooo`33ooooo`05o`000?oooooooooooooo
ool00000a_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05?ooooo001cooooo`?o
0000<Oooool00ol00?ooooooooooo`07ooooo`03o`00ool0003o00000<Gooooo00Go0000oooooooo
ooooooooo`000032ooooo`05o`000?ooooooooooooooool000008oooool3o`0005Gooooo001coooo
o`03o`000?oooooooooo037ooooo00?o003oooooooooool02?ooool00ol00?oo0000ooooo`35oooo
o`?o0000a?ooool3o`0002Kooooo00?o0000ooooooooool0Doooool005gooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`3ooooookGooooo00?o0000ooooooooool0Doooool005cooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`3ooooookGooooo00?o0000oooooooo
ool0Doooool005cooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07ooooo`Co
0000<?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo003o0?oooooo/oooool4o`0005Go
oooo001Looooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0aooooo`03o`00oooooooooooo00Sooooo00?o003oooooool00?l0oooooonfooooo`03
o`000?oooooooooo05?ooooo001Looooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Oooooo0_l00?l00ooooooo
003oo`00o`3ooooookGooooo00?o0000ooooooooool0Doooool005cooooo00Co0000oooooooooooo
00002?ooool2o`0000Wooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooool7o
oooo00?o0000ooooooooool0Doooool005gooooo0_l0000:ooooo`03o`000?oooooooooo00Oooooo
0ol0000aooooo`03o`00oooooooooooo0?oooooo_oooool3o`0005Gooooo001cooooo`03o`000?oo
oooooooo037ooooo00?o003oooooooooool0ooooooo1ooooo`03o`000?oooooooooo05?ooooo001c
ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0ooooooo1ooooo`03o`000?oooooo
oooo05?ooooo001cooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0ooooooo1oooo
o`03o`000?oooooooooo05?ooooo001cooooo`?o0000<Oooool00ol00?ooooooooooo`3ooooookoo
oooo0ol0001Eooooo`00Loooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo
`Oooool00ol0003oooooooooo`1Cooooo`00Loooool00ol0003oooooooooo`0aooooo`03o`00oooo
oooooooo0?oooooo`Oooool00ol0003oooooooooo`1Cooooo`00Loooool00ol0003oooooooooo`0a
ooooo`03o`00oooooooooooo0?oooooo`Oooool00ol0003oooooooooo`1Cooooo`00Loooool3o`00
037ooooo00?o003oooooooooool0oooooonoooooo`?o0000EOooool007?ooooo00?o0000oooooooo
ool0<Oooool00ol00?ooooooooooo`3ooooool7ooooo00?o0000ooooooooool0Doooool007?ooooo
00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooool7ooooo00?o0000ooooooooool0
Doooool007?ooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooool7ooooo00?o
0000ooooooooool0Doooool007?ooooo0ol0000aooooo`03o`00oooooooooooo0?oooooo_oooool3
o`0005Gooooo001cooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0ooooooo1oooo
o`03o`000?oooooooooo05?ooooo001Mooooo`;o00001?ooool01?l0003oooooooooooooool5o`00
00Oooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooool7ooooo00?o0000oooo
ooooool0Doooool005cooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0HOooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo05?ooooo001Looooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool01oooool4o`0000Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0A
ooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool4o`0005Gooooo001Loooo
o`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Doooool005cooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Ooooooool0003io`0005Gooooo001L
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00003ooooooooooooo
E_ooool005gooooo0_l00009ooooo`?o0000oooooooooooooeOooooo003ooooooooooooo`_ooool0
0?ooooooooooooo2ooooo`00oooooooooooool;ooooo003ooooooooooooo`_ooool00?oooooooooo
ooo2ooooo`00VOooool00ol0003oooooooooo`0<ooooo`?o0000;_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Y
ooooo`?o00008_ooool3o`0002Oooooo00?o0000ooooooooool0N_ooool009Sooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0QOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Wooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Wooooo002Hooooo`03
o`000?oooooooooo00Go000000?oooooo`000?l000000ol00002ooooo`Co00000_ooool3o`0000;o
oooo0ol000000ooooooo0000o`000006ooooo`05o`000?oooooo0000ooooool000000_ooool3o`00
00?ooooo1?l00002ooooo`?o00001Oooool00ol0003oooooooooo`04ooooo`?o00001Oooool00ol0
003oooooooooo`04ooooo`Go000000?oooooo`000?l000000_l00008ooooo`Co00000oooool4o`00
0003ooooool0003o000000?o000000Coooooo`000?l0003ooooo0_l00002ooooo`?o00000_ooool3
o`000003ooooool0003o000000Kooooo1Ol00007ooooo`Go000000?oooooo`000?l000000ol00002
ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol00002ooooo`?o000000?o
ooooo`000?l000000_ooool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`000?l000000ooo
ool00ol0003oooooooooo`07ooooo`?o00000oooool00ol0003oooooo`000005ooooo`03o`000?oo
oooooooo00Oooooo0ol00003ooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`;o00000ooo
ool3o`0000Cooooo00Co0000oooooooooooooooo1Ol00003ooooo`;o00001?ooool2o`0000Cooooo
0_l00006ooooo`03o`000?oooooooooo00Oooooo1Ol000000ooooooo0000o`000003o`000005oooo
ool0003o0000o`000?ooool01_l00003ooooo`?o00000oooool4o`000005ooooool0003o0000o`00
0?ooool01Ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_l000001?oo
oooo0000o`000?ooool4o`0000Oooooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o00001ooo
ool3o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1iooooo`00V?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`07o`00
0?ooooooooooooooool0003oooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00Oo0000
ooooool0003oooooo`000?oooooo000000?ooooo00?o0000ooooool000000_ooool01?l0003ooooo
ooooool0000@ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000001Oooool01ol0003oooooo`00
0?oooooo0000ooooool000001_ooool01?l0003oooooooooool00002ooooo`06o`000?oooooooooo
o`000?oooooo00001_ooool01?l0003oooooooooool0000=ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooo`00000@ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`06ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02?ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0000@ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooool000000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07Wooooo
002Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooool000001?l00002ooooo`04o`000?ooooooooooo`0000Oo
oooo00Oo0000ooooool0003oooooo`000?oooooo000000?ooooo00?o0000ooooool000000_ooool0
0ol0003oooooooooo`05o`0000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool3o`0000Cooooo
00?o0000ooooooooool00_ooool2o`0000?ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`04o`000?oooooooooooooo
o`Go000000Ooooooo`000?oooooo0000ooooool0003ooooo00Go00000_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000go
oooo00_o0000ooooooooooooooooo`000?oooooo0000ooooool0003oooooo`00000?ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00004?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo
00Co0000oooooooooooo00000_ooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0N?ooool009So
oooo00Co0000oooooooooooooooo0ol00004ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Ooo
ool01ol0003oooooo`000?oooooo0000ooooool000000oooool00ol0003oooooo`000002ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`06ooooo`?o00000_ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00002_ooool00ol0003o
ooooooooo`07ooooo`?o00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Wo0000oooo
ool0003oooooo`000?oooooo0000ooooool000000oooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000gooooo00_o0000ooooooooooooooooo`000?oooooo0000ooooool0003oooooo`00000?
ooooo`03o`000?oooooooooo00?ooooo0_l00009ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00kooooo0ol00004oooo
o`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`06o`000?oo
ooooooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooool000000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07Wo
oooo002Hooooo`05o`000?ooooooooooooooool000001?ooool3o`0000Cooooo1Ol000001?oooooo
0000o`000?l00002ooooo`Co00002?ooool2o`000003ooooool0003ooooo00;ooooo0ol00003oooo
o`?o00000oooool3o`0000gooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`;o0000
1Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo0000o`0000;ooooo0ol00002ooooo`Co
00002?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`?o00000_ooool2o`000003ooooool0003ooooo00;ooooo0ol00002oooo
o`Co00000_ooool4o`0000?ooooo0ol00002ooooo`Co00003oooool3o`0000;ooooo1_l0000>oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool3o`0000?ooooo1?l00003oooo
o`Co000000?oooooo`000?l000000_l00003ooooo`;o00000oooool4o`0000;ooooo1?l00002oooo
o`;o000000Coooooo`000?l0003ooooo1?l00003ooooo`Go00001_ooool3o`0000?ooooo1?l0000:
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1i
ooooo`00VOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool04?ooool2o`0000gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0cooooo`;o00000oooool0
1Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00000_ooool2o`0000Wooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool0000@ooooo`04o`000?ooooooooooo`0005Kooooo
0_l0000:ooooo`03o`000?oooooooooo07[ooooo002Kooooo`Go00000oooool00ol0003ooooooooo
o`0Wooooo`;o00004oooool00ol0003oooooooooo`0<ooooo`?o00000_ooool4o`0000Sooooo1?l0
0008ooooo`?o00000oooool2o`0001Oooooo0ol00008ooooo`Go000000Coooooo`000?l0003o0000
7?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00;ooooo0ol0000:ooooo`;o0000
1?ooool00ol0003oooooooooo`08ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o0000
4?ooool5o`0000?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo08Gooooo003ooooooooooooo`_ooool00?ooooooooooooo2ooooo`00\
\>"],
  ImageRangeCache->{{{0, 703.688}, {119.625, 0}} -> {-0.839189, -0.297704, \
0.00501246, 0.00501246}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .08196 L
.13683 .08046 L
.15332 .07906 L
.16917 .07771 L
.18605 .07627 L
.2023 .07488 L
.21957 .07341 L
.23621 .07199 L
.25221 .07062 L
.26924 .06917 L
.28564 .06777 L
.3014 .06643 L
.31819 .065 L
.33434 .06362 L
.35152 .06216 L
.36806 .06074 L
.38398 .05939 L
.40091 .05794 L
.41722 .05655 L
.43454 .05507 L
.45124 .05365 L
.4673 .05228 L
.48439 .05082 L
.5 .04949 L
s
.5 .04949 m
.5161 .04812 L
.53365 .04662 L
.55014 .04522 L
.566 .04386 L
.58288 .04243 L
.59913 .04104 L
.61639 .03957 L
.63303 .03815 L
.64904 .03678 L
.66607 .03533 L
.68246 .03393 L
.69823 .03259 L
.71501 .03116 L
.73117 .02978 L
.74834 .02831 L
.76489 .0269 L
.7808 .02555 L
.79774 .0241 L
.81404 .02271 L
.83137 .02123 L
.84806 .01981 L
.86413 .01844 L
.88121 .01698 L
.89683 .01565 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{705.438, 117.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;10000MB000`400?l00000o`00003ooooooooo
oooool?ooooo002Xooooo`;o0000Foooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
05[ooooo0ol0001Jooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000FOooool5o`00
08[ooooo002Wooooo`04o`000?ooooooooooo`0005Wooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000005[ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool00000FOooool01?l0003oooooooooool0002:ooooo`00
Yoooool01?l0003oooooooooool0001Iooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`2:ooooo`00Yoooool01?l0003oooooooooool0001Ioooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`29
ooooo`00Yoooool01?l0003oooooooooool0001Iooooo`04o`000?ooooooooooo`0000Oooooo1?l0
001Kooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01oooool4o`0005Wooooo00Go
0000ooooooooooooooooo`00002:ooooo`00Yoooool01?l0003oooooooooool0001Iooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0Foooool2o`0005_ooooo0_l00009ooooo`03
o`000?oooooooooo05[ooooo00Go0000ooooooooooooooooo`00002:ooooo`00Z?ooool2o`0005_o
oooo0_l00008ooooo`Go0000F_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Oo
oooo1Ol0001Iooooo`?o0000Roooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003o
oooooooooooo`oooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003ooooooooooooo
`oooool00?ooooooooooooo3ooooo`00Goooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0
0007oooooooo0000mOl0001Hooooo`00G_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo05Kooooo001Gooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Oooooo1Ol00007ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo1?l0001Hooooo`00G_oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000oooooooo
ool0E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000oooo
ooooool0E_ooool005oooooo0_l00009ooooo`?o00002?ooool3o`00037ooooo00?o003ooooooooo
ool0oooooonkooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oooooo
ooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Ooo
ool00ol00?ooooooooooo`3oooooohKooooo1Ooo000booooo`03o`000?oooooooooo05Kooooo001e
ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooomeoooooa7oo`00=oooool0
0ol0003oooooooooo`1Fooooo`00MOooool3o`00037ooooo00?o003oooooooooool0oooooom]oooo
o`Soo`00A_ooool3o`0005Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool0oooooomLoooooa7oo`00D?ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo0?ooooooE?ooool8ool0067ooooo00?o0000ooooooooool0
E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3oooooodcooooo2?oo
001Yooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3o
oooooccooooo4?oo001_ooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol0
0?ooooooooooo`3ooooooc?ooooo2Ooo0021ooooo`03o`000?oooooooooo05Kooooo001eooooo`03
o`000?oooooooooo037ooooo00?o003oooooooooool0oooooolSoooooa3oo`00R_ooool00ol0003o
ooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo
6oooool8ool009[ooooo00?o0000ooooooooool0E_ooool007Gooooo0ol0000aooooo`03o`00oooo
oooooooo0?oooooo4oooool8ool00:3ooooo0ol0001Hooooo`00Goooool2o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0000Sooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3o
ooooo`;ooooo4Ooo002Zooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`00oooooooo
oooo0?Wooooo2?oo002kooooo`03o`000?oooooooooo05Kooooo001Gooooo`Go00000_ooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Oooool0
0ol00?ooooooooooo`3Xoooooa7oo`00`oooool00ol0003oooooooooo`1Fooooo`00G_ooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo1Ol0000_ooooo`03o`00oooooooo
oooo0>3ooooo2?oo003Aooooo`Co0000F?ooool005kooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0d?ooool@
ool00=cooooo00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo00002?ooool2
o`0000Wooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`37ooooo`Woo`00k?ooool0
0ol0003oooooooooo`1Fooooo`00Goooool2o`0000[ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0aooooo`03o`00oooooooooooo0;oooooo2?oo003eooooo`03o`000?oooooooooo
05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`2^oooooa7oo`00noooool3o`0005So
oooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0Y_ooool8ool00>_ooooo
0_l00?l00ooooooo003oo`00o`0Nooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oo
oooooooo037ooooo00?o003oooooooooool0U_ooool@ool00?Cooooo00?o003oooooool00?l07ooo
ool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooo
oooo08gooooo2Ooo003oooooo`Kooooo00?o003oooooooooool07_ooool00ol0003oooooooooo`1F
ooooo`00MOooool3o`00037ooooo00?o003oooooooooool0OOooool@ool00?oooooo3_ooool00ol0
0?ooooooo`00o`0Mooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oo
ooooooooo`1eooooo`Soo`00oooooolMooooo`;o003o00?oooooo`00ool00?l07_ooool00ol0003o
ooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo06cooooo
2Ooo003oooooodSooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Ooo
ool00ol00?ooooooooooo`1Loooooa3oo`00oooooomAooooo`03o`000?oooooooooo05Kooooo001e
ooooo`?o0000<Oooool00ol00?ooooooooooo`1Dooooo`Soo`00oooooomOooooo`?o0000F?ooool0
07Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`13oooooa7oo`00oooooomYoooo
o`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool0>oooool8ool00?ooooooN_ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo03?ooooo2?oo003ooooooh;ooooo00?o0000ooooooooool0
E_ooool007Gooooo0ol0000`ooooo`Co00008_oooolAool008oooooo1?l00032ooooo`Co0000;_oo
ool3o`0005Sooooo001[ooooo`;o00002?ooool00ol0003oooooooooo`0^ooooo`;o00001?l00?l0
0ol0003oooooooooo`0Gooooo`Soo`00W_ooool2o`0000Cooooo00?o0000ooooooooool0_Oooool2
o`0000Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Fooooo`00J_ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo02kooooo00?o0000o`00ool00?l00ol00?l0
0ol0003oooooooooo`07oooooa3oo`00Y_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0;gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo05Kooooo001Zooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0;Oooool0
0ol0003o003oo`00o`05o`00o`Woo`00]Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0;_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo05Kooooo001Zooooo`04o`000?ooooooooooo`0000Oooooo1Ol00007ooooobCo003o00Co0000
o`00ool00?oo003o1?oo003oo`0008[o00000ol00?l00ol0003o003oo`00o`0Qo`00o`Sooooo1?l0
001Hooooo`00J_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02gooooo00?o
0000o`00ool00?l01Ol00?l00ol0003oooooooooo`2kooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0^oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0E_ooool006[ooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`0^ooooo`;o00001?l00?l00ol0003oooooooooo`2mooooo`;o00001?ooool00ol0003ooooooooo
o`2mooooo`;o00001?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo05Kooooo001[
ooooo`;o00002?ooool00ol0003oooooooooo`0`ooooo`03o`000?l00?oo003o00;o0000`Oooool0
0ol0003oooooooooo`02o`000<7ooooo00Co0000ooooool0003o0000<?ooool00ol0003ooooooooo
o`1Fooooo`00MOooool3o`00037ooooo0_l00034ooooo`;o0000a?ooool00ol0003oooooooooo`0^
ooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooo
okgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oo
ooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo0ol0
000aooooo`03o`00oooooooooooo0?oooooo^oooool3o`0005Sooooo001eooooo`03o`000?oooooo
oooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001eoooo
o`03o`000?oooooooooo037ooooo00?o003oooooooooool02?ooool3o`000<;ooooo1Ol00032oooo
o`?o00009Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03
o`00oooooooooooo00Wooooo00?o0000ooooooooool0`_ooool01?l0003oooooooooool00031oooo
o`05o`000?ooooooooooooooool000009?ooool00ol0003oooooooooo`1Fooooo`00MOooool3o`00
037ooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`33ooooo`03o`000?oooooooooo
0<Gooooo00?o0000ooooooooool08?ooool3o`0005Sooooo001eooooo`03o`000?oooooooooo037o
oooo00?o003oooooooooool02Oooool00ol0003oooooooooo`34ooooo`03o`000?oooooooooo0<;o
oooo0_l0000Uooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo
00?o003oooooooooool02Oooool00ol0003oooooooooo`31ooooo`05o`000?ooooooooooooooool0
0000aOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`00
0?oooooooooo037ooooo00?o003oooooooooool02?ooool2o`000<?ooooo00Go0000oooooooooooo
ooooo`000031ooooo`05o`000?ooooooooooooooool000009?ooool00ol0003oooooooooo`1Foooo
o`00MOooool3o`00037ooooo00?o003oooooooooool01oooool2o`00o`03o`000?oooooooooo0<;o
oooo0ol00033ooooo`?o00008oooool3o`0005Sooooo001Oooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`?o00002?ooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool0oooooonbooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool0oooooonaooooo`03o`000?oooooooooo05Kooooo
001Nooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0oooooonaooooo`03o`00
0?oooooooooo05Kooooo001Nooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
1oooool5o`0002oooooo00?o003oooooooooool02?ooool00ol00?ooooooo`00o`3oooooojoooooo
1?l0001Hooooo`00G_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo003o0?oooooo
/_ooool00ol0003oooooooooo`1Fooooo`00G_ooool01?l0003oooooooooool00008ooooo`;o0000
2Oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Oooooo0_l00?l00ooooooo003o
o`00o`3ooooook7ooooo00?o0000ooooooooool0E_ooool005oooooo0_l0000:ooooo`03o`000?oo
oooooooo00Oooooo0ol0000aooooo`03o`00oooooooooooo0?oooooo^oooool3o`0005Sooooo001e
ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooo
oooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmoooo
o`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool0oooooonmooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?oooooo
ooooo`3ooooook_ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooo
oooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0a
ooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0
003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Foooo
o`00MOooool3o`00037ooooo00?o003oooooooooool0oooooonkooooo`?o0000F?ooool007Gooooo
00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0
E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o
0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3o
oooookgooooo00?o0000ooooooooool0E_ooool007Gooooo0ol0000aooooo`03o`00oooooooooooo
0?oooooo^oooool3o`0005Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Oooooo`;o00001?ooool01?l0003ooooo
ooooooooool5o`0000Oooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgo
oooo00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0H?ooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool01oooool5o`0000Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool4o`00
05Sooooo001Nooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0E_ooool005ko
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Ooooooool0003e
o`0005Sooooo001Nooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
003oooooooooooooEOooool005oooooo0_l00009ooooo`?o0000oooooooooooooeKooooo003ooooo
oooooooo`oooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003ooooooooooooo`ooo
ool00?ooooooooooooo3ooooo`00VOooool00ol0003oooooooooo`0<ooooo`?o0000;_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`1Zooooo`?o00008_ooool3o`0002Oooooo00?o0000ooooooooool0N_ooool009So
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Wo
oooo002Hooooo`03o`000?oooooooooo00Go000000?oooooo`000?l000000ol00002ooooo`Co0000
0_ooool3o`0000;ooooo0ol000000ooooooo0000o`000006ooooo`05o`000?oooooo0000ooooool0
00000_ooool3o`0000?ooooo1?l00002ooooo`?o00001Oooool00ol0003oooooooooo`04ooooo`?o
00001Oooool00ol0003oooooooooo`04ooooo`Go000000?oooooo`000?l000000_l00008ooooo`Co
00000oooool4o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo0_l00002oooo
o`?o00000_ooool3o`000003ooooool0003o000000Kooooo1Ol00007ooooo`Go000000?oooooo`00
0?l000000ol00002ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol00002
ooooo`?o000000?oooooo`000?l000000_ooool2o`0000?ooooo0ol00002ooooo`?o000000?ooooo
o`000?l000000oooool00ol0003oooooooooo`07ooooo`?o00000oooool00ol0003oooooo`000005
ooooo`03o`000?oooooooooo00Oooooo0ol00003ooooo`?o00001?ooool00ol0003oooooooooo`03
ooooo`;o00000oooool3o`0000Cooooo00Co0000oooooooooooooooo1Ol00003ooooo`;o00001?oo
ool2o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo00Oooooo1Ol000000ooooooo0000o`00
0003o`000005ooooool0003o0000o`000?ooool01_l00003ooooo`?o00000oooool4o`000005oooo
ool0003o0000o`000?ooool01Ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l0
00000_l000001?oooooo0000o`000?ooool4o`0000Oooooo1Ol000001Ooooooo0000o`000?l0003o
oooo00;o00001oooool3o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1i
ooooo`00V?ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`07o`000?ooooooooooooooool0003oooooo`000006ooooo`04o`000?ooooooooooo`00
00Oooooo00Oo0000ooooool0003oooooo`000?oooooo000000?ooooo00?o0000ooooool000000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000001Oooool0
1ol0003oooooo`000?oooooo0000ooooool000001_ooool01?l0003oooooooooool00002ooooo`06
o`000?ooooooooooo`000?oooooo00001_ooool01?l0003oooooooooool0000=ooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooo`00000@ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool02?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0000Aooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo07Wooooo002Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000001?l00002ooooo`04o`000?oo
ooooooooo`0000Oooooo00Oo0000ooooool0003oooooo`000?oooooo000000?ooooo00?o0000oooo
ool000000_ooool00ol0003oooooooooo`05o`0000cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_oo
ool3o`0000Cooooo00?o0000ooooooooool00_ooool2o`0000?ooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooooooo`Go000000Ooooooo`000?oooooo0000ooooool0003ooooo00Go00000_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0000gooooo00_o0000ooooooooooooooooo`000?oooooo0000ooooool0003oooooo`00
000?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00004Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool3o`0000?ooooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0N?ooool009Sooooo00Co0000oooooooooooooooo0ol00004ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool01Oooool01ol0003oooooo`000?oooooo0000ooooool000000oooool00ol0003ooooo
o`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0>ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`06oooo
o`?o00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
2_ooool00ol0003oooooooooo`07ooooo`?o00001?ooool01Ol0003ooooooooooooooooo000000?o
oooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000000oooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000gooooo00_o0000ooooooooooooooooo`000?oooooo0000ooooool0
003oooooo`00000?ooooo`03o`000?oooooooooo00?ooooo0_l00009ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oo
oooo0ol00004ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00006
ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo07Wooooo002Hooooo`05o`000?ooooooooooooooool000001?ooool3o`0000Cooooo
1Ol000001?oooooo0000o`000?l00002ooooo`Co00002?ooool2o`000003ooooool0003ooooo00;o
oooo0ol00003ooooo`?o00000oooool3o`0000gooooo00?o0000ooooooooool02oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0002ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo0000o`0000;ooooo
0ol00002ooooo`Co00002?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`?o00000_ooool2o`000003ooooool0003ooooo00;o
oooo0ol00002ooooo`Co00000_ooool4o`0000?ooooo0ol00002ooooo`Co00003oooool3o`0000;o
oooo1_l0000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00006ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool3o`0000?o
oooo1?l00003ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o00000oooool4o`0000;o
oooo1?l00002ooooo`;o000000Coooooo`000?l0003ooooo1?l00003ooooo`Go00001_ooool3o`00
00?ooooo1?l0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1iooooo`00VOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool04?ooool2o`0000gooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`000008ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0coooo
o`;o00000oooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00000_oo
ool2o`0000Wooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Aooooo`04o`000?oooooo
ooooo`0005Kooooo0_l0000:ooooo`03o`000?oooooooooo07[ooooo002Kooooo`Go00000oooool0
0ol0003oooooooooo`0Wooooo`;o00004oooool00ol0003oooooooooo`0<ooooo`?o00000_ooool4
o`0000Sooooo1?l00008ooooo`?o00000oooool2o`0001Oooooo0ol00008ooooo`Go000000Cooooo
o`000?l0003o00007?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00;ooooo0ol0
000:ooooo`;o00001?ooool00ol0003oooooooooo`08ooooo`?o00001?ooool2o`0000Cooooo0_l0
0004ooooo`;o00004Oooool5o`0000?ooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo08Gooooo003ooooooooooooo`oooool00?ooooooooooooo3oooo
o`00\
\>"],
  ImageRangeCache->{{{0, 704.438}, {116.562, 0}} -> {-0.856351, -0.286992, \
0.00505443, 0.00505443}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .08281 L
.13683 .08224 L
.15332 .0817 L
.16917 .08118 L
.18605 .08063 L
.2023 .0801 L
.21957 .07954 L
.23621 .079 L
.25221 .07848 L
.26924 .07792 L
.28564 .07739 L
.3014 .07688 L
.31819 .07633 L
.33434 .0758 L
.35152 .07524 L
.36806 .07471 L
.38398 .07419 L
.40091 .07364 L
.41722 .0731 L
.43454 .07254 L
.45124 .072 L
.4673 .07147 L
.48439 .07092 L
.5 .07041 L
s
.5 .07041 m
.5161 .06988 L
.53365 .06931 L
.55014 .06877 L
.566 .06826 L
.58288 .06771 L
.59913 .06718 L
.61639 .06662 L
.63303 .06607 L
.64904 .06555 L
.66607 .065 L
.68246 .06446 L
.69823 .06395 L
.71501 .0634 L
.73117 .06288 L
.74834 .06232 L
.76489 .06178 L
.7808 .06126 L
.79774 .06071 L
.81404 .06018 L
.83137 .05961 L
.84806 .05907 L
.86413 .05855 L
.88121 .05799 L
.89683 .05748 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{705.438, 117.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;10000MB000`400?l00000o`00003ooooooooo
oooool?ooooo002Xooooo`;o0000Foooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
05[ooooo0ol0001Jooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000FOooool5o`00
08[ooooo002Wooooo`04o`000?ooooooooooo`0005Wooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000005[ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool00000FOooool01?l0003oooooooooool0002:ooooo`00
Yoooool01?l0003oooooooooool0001Iooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`2:ooooo`00Yoooool01?l0003oooooooooool0001Ioooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`29
ooooo`00Yoooool01?l0003oooooooooool0001Iooooo`04o`000?ooooooooooo`0000Oooooo1?l0
001Kooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01oooool4o`0005Wooooo00Go
0000ooooooooooooooooo`00002:ooooo`00Yoooool01?l0003oooooooooool0001Iooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0Foooool2o`0005_ooooo0_l00009ooooo`03
o`000?oooooooooo05[ooooo00Go0000ooooooooooooooooo`00002:ooooo`00Z?ooool2o`0005_o
oooo0_l00008ooooo`Go0000F_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Oo
oooo1Ol0001Iooooo`?o0000Roooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003o
oooooooooooo`oooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003ooooooooooooo
`oooool00?ooooooooooooo3ooooo`00Goooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0
0007oooooooo0000mOl0001Hooooo`00G_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo05Kooooo001Gooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Oooooo1Ol00007ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo1?l0001Hooooo`00G_oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000oooooooo
ool0E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000oooo
ooooool0E_ooool005oooooo0_l00009ooooo`?o00002?ooool3o`00037ooooo00?o003ooooooooo
ool0oooooonkooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oooooo
ooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Ooo
ool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000
ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool0
07Gooooo0ol0000aooooo`03o`00oooooooooooo0?oooooo^oooool3o`0005Sooooo001eooooo`03
o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Ko
oooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`00
0?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooo
oonmooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3o
oooook_ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo
0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03
o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOoo
ool3o`00037ooooo00?o003oooooooooool0oooooonkooooo`?o0000F?ooool005oooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo037ooooo00?o003o
ooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`00oooooooo
oooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00Eoooool5o`0000;ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003o
ooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01oooool5o`0002oooooo00?o003oooooooooool0oooooonj
ooooo`Co0000F?ooool005kooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooo
oooo05Kooooo001Nooooo`04o`000?ooooooooooo`0000Sooooo0_l00009ooooo`03o`000?oooooo
oooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Ooooo
o`;o00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003ooooo
ooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?oo
ooooooooo`3ooooook_ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo0?ooooooV_ooool2o`00o`03ooooool00?oo003o01kooooo00?o0000ooooooooool0
E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooooi_ooooo00?o
003oooooool00?l07oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0a
ooooo`03o`00oooooooooooo0?ooooooMOoooolFool0017ooooo00?o003oooooooooool07_ooool0
0ol0003oooooooooo`1Fooooo`00MOooool3o`00037ooooo00?o003oooooooooool0oooooomDoooo
ob7oo`009_ooool00ol00?ooooooo`00o`0Mooooo`?o0000F?ooool007Gooooo00?o0000oooooooo
ool0<Oooool00ol00?ooooooooooo`3ooooooccooooo6?oo0016ooooo`;o003o00?oooooo`00ool0
0?l07_ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo0?oooooo6ooooolQool0087ooooo00?o0000ooooooooool0E_ooool007Gooooo00?o
0000ooooooooool0<Oooool00ol00?ooooooooooo`3iooooob7oo`00X_ooool00ol0003ooooooooo
o`1Fooooo`00MOooool3o`00037ooooo00?o003oooooooooool0f?oooolQool00<7ooooo0ol0001H
ooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0;oooooo6Ooo003Toooo
o`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool0W_oooolQool00?gooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`1mooooob7oo`00oooooolOooooo`03o`000?oooooooooo05Kooooo
001eooooo`?o0000<?ooool4o`0005cooooo8Ooo0015ooooo`Co0000`_ooool4o`0002kooooo0ol0
001Hooooo`00Joooool2o`0000Sooooo00?o0000ooooooooool0;_ooool2o`0000Co003o00?o0000
ooooooooool0@?oooolIool006Cooooo0_l00004ooooo`03o`000?oooooooooo0;gooooo0_l00004
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0E_ooool006[ooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`0^ooooo`03o`000?l00?oo003o00?o003o00?o0000
ooooooooool07ooooolQool007gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2m
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1F
ooooo`00J_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02gooooo00?o0000
o`00ool00?l01Ol00?lQool009gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2k
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1F
ooooo`00J_ooool01?l0003oooooooooool00007ooooo`Go00001ooooolTo`00o`04o`000?l00?oo
003oo`00o`Coo`00ool0002:o`0000?o003o00?o0000o`00ool00?l08Ol00?l8ooooo`Co0000F?oo
ool006[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0]ooooo`03o`000?l0
0?oo003o00Go003o00?o0000ooooooooool0^oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0;_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo05Kooooo001Zooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0;_oo
ool2o`0000Co003o00?o0000ooooooooool0_Oooool2o`0000Cooooo00?o0000ooooooooool0_Ooo
ool2o`0000Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Fooooo`00Joooool2
o`0000Sooooo00?o0000ooooooooool0<?ooool00ol0003o003oo`00o`02o`000<7ooooo00?o0000
ooooooooool00_l00031ooooo`04o`000?oooooo0000o`00033ooooo00?o0000ooooooooool0E_oo
ool007Gooooo0ol0000aooooo`;o0000a?ooool2o`000<Cooooo00?o0000ooooooooool0;_ooool3
o`0005Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmoooo
o`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool0oooooonmooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo
00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Ooo
ool00ol00?ooooooooooo`3ooooook_ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0a
ooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0
003oooooooooo`0aooooo`03o`00oooooooooooo00Sooooo0ol00032ooooo`Go0000`_ooool3o`00
02Gooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oo
ooooooooo`09ooooo`03o`000?oooooooooo0<;ooooo00Co0000oooooooooooo0000`Oooool01Ol0
003ooooooooooooooooo000002Cooooo00?o0000ooooooooool0E_ooool007Gooooo0ol0000aoooo
o`03o`00oooooooooooo00Wooooo00?o0000ooooooooool0`oooool00ol0003oooooooooo`35oooo
o`03o`000?oooooooooo023ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03
o`00oooooooooooo00Wooooo00?o0000ooooooooool0a?ooool00ol0003oooooooooo`32ooooo`;o
00009Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo00Wooooo00?o0000ooooooooool0`Oooool01Ol0003ooooooooooooooooo00000<Go
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo00Sooooo0_l00033ooooo`05o`000?ooooooooooooooool0
0000`Oooool01Ol0003ooooooooooooooooo000002Cooooo00?o0000ooooooooool0E_ooool007Go
oooo0ol0000aooooo`03o`00oooooooooooo00Oooooo0_l00?l00ol0003oooooooooo`32ooooo`?o
0000`oooool3o`0002?ooooo0ol0001Hooooo`00Goooool2o`0000Cooooo00?o0000ooooooooool0
0_ooool3o`0000Sooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo0?oooooo/_ooool00ol0003oooooooooo`1Fooooo`00G_ooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo0?oooooo/Oooool00ol0003oooooooooo`1Fooooo`00G_oo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo0?oooooo/Oooool00ol0003ooooo
ooooo`1Fooooo`00G_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo
1Ol0000_ooooo`03o`00oooooooooooo00Sooooo00?o003oooooool00?l0oooooon_ooooo`Co0000
F?ooool005kooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo037ooooo00?o003oooooooooool02?ooool00ol00?ooooooo`00o`3ooooook;ooooo
00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo00002?ooool2o`0000Wooooo
00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`07ooooo`;o003o00?oooooo`00ool00?l0
oooooonaooooo`03o`000?oooooooooo05Kooooo001Oooooo`;o00002_ooool00ol0003ooooooooo
o`07ooooo`?o0000<Oooool00ol00?ooooooooooo`3ooooook_ooooo0ol0001Hooooo`00MOooool0
0ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1F
ooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0
003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oo
oooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool3o`00037ooooo00?o003oooooooooool0
oooooonkooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oooooooooo
o`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool0
0ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000oooo
ooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Go
oooo0ol0000aooooo`03o`00oooooooooooo0?oooooo^oooool3o`0005Sooooo001eooooo`03o`00
0?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo
001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oo
oooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonm
ooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3ooooo
ok_ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oo
oooo_Oooool00ol0003oooooooooo`1Fooooo`00Goooool2o`0000Cooooo00Co0000oooooooooooo
oooo1Ol00007ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03
o`000?oooooooooo05Kooooo001Nooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo063ooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Fooooo`00G_ooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo00Oooooo1Ol00007ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo1?l0001Hoooo
o`00G_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Kooooo001Nooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007oooooooo0000mOl0001H
ooooo`00G_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000oooo
oooooooooeGooooo001Oooooo`;o00002Oooool3o`000?oooooooooooomFooooo`00oooooooooooo
ol?ooooo003ooooooooooooo`oooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003o
oooooooooooo`oooool009Wooooo00?o0000ooooooooool03?ooool3o`0002kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0J_ooool3o`0002;ooooo0ol0000Wooooo`03o`000?oooooooooo07[ooooo002Hooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo08Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Zooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1iooooo`00
V?ooool00ol0003oooooooooo`05o`000003ooooool0003o000000?o00000_ooool4o`0000;ooooo
0ol00002ooooo`?o000000?oooooo`000?l000001_ooool01Ol0003oooooo`000?oooooo000000;o
oooo0ol00003ooooo`Co00000_ooool3o`0000Gooooo00?o0000ooooooooool01?ooool3o`0000Go
oooo00?o0000ooooooooool01?ooool5o`000003ooooool0003o000000;o00002?ooool4o`0000?o
oooo1?l000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`;o00000_ooool3o`00
00;ooooo0ol000000ooooooo0000o`000006ooooo`Go00001oooool5o`000003ooooool0003o0000
00?o00000_ooool3o`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`?o00000_ooool3
o`000003ooooool0003o000000;ooooo0_l00003ooooo`?o00000_ooool3o`000003ooooool0003o
000000?ooooo00?o0000ooooooooool01oooool3o`0000?ooooo00?o0000ooooool000001Oooool0
0ol0003oooooooooo`07ooooo`?o00000oooool3o`0000Cooooo00?o0000ooooooooool00oooool2
o`0000?ooooo0ol00004ooooo`04o`000?ooooooooooooooo`Go00000oooool2o`0000Cooooo0_l0
0004ooooo`;o00001oooool00ol0003oooooooooo`07ooooo`Go000000?oooooo`000?l000000ol0
00001Ooooooo0000o`000?l0003ooooo00Ko00000oooool3o`0000?ooooo1?l000001Ooooooo0000
o`000?l0003ooooo00Go000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000;o
000000Coooooo`000?l0003ooooo1?l00007ooooo`Go000000Goooooo`000?l0003o0000ooooo`02
o`0000Oooooo0ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0NOooool0
09Sooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool01ol0003ooooooooooooooooo0000ooooool000001_ooool01?l0003oooooooooool00007oooo
o`07o`000?oooooo0000ooooool0003oooooo`000003ooooo`03o`000?oooooo000000;ooooo00Co
0000oooooooooooo00004?ooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000Gooooo00Oo0000
ooooool0003oooooo`000?oooooo000000Kooooo00Co0000oooooooooooo00000_ooool01_l0003o
ooooooooool0003oooooo`0000Kooooo00Co0000oooooooooooo00003Oooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooool000004?ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool01_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00004Oooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1iooooo`00Uoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooo000000Co00000_ooool01?l0003ooooooooo
ool00007ooooo`07o`000?oooooo0000ooooool0003oooooo`000003ooooo`03o`000?oooooo0000
00;ooooo00?o0000ooooooooool01Ol0000<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo0ol0
0004ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`Go00000_ooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooooooool5o`000007ooooool0003oooooo`000?oooooo0000ooooo`05o`0000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`Go00000_ooool01?l0003ooooooooo
ool0000=ooooo`0;o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000003ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00017ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo0ol0
0003ooooo`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07So
oooo002Hooooo`04o`000?ooooooooooooooo`?o00001?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00Gooooo00Oo0000ooooool0003oooooo`000?oooooo000000?ooooo00?o0000ooooool00000
0_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool03_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01_ooool3o`00
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000[ooooo
00?o0000ooooooooool01oooool3o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`09
o`000?oooooo0000ooooool0003oooooo`000?oooooo000000?ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000=ooooo`0;o`000?ooooooooooooooool0003oooooo`000?oooooo0000oooo
ool000003oooool00ol0003oooooooooo`03ooooo`;o00002Oooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0?ooooo`?o
00001?ooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool0
1_l0003oooooooooool0003oooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1iooooo`00V?ooool01Ol0003ooooooooooooooooo000000Cooooo0ol00004ooooo`Go0000
00Coooooo`000?l0003o00000_ooool4o`0000Sooooo0_l000000ooooooo0000ooooo`02ooooo`?o
00000oooool3o`0000?ooooo0ol0000=ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_oo
ool2o`0000Gooooo00?o0000ooooooooool00_ooool01?l0003oooooo`000?l00002ooooo`?o0000
0_ooool4o`0000Sooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool3o`0000;ooooo0_l000000ooooooo0000ooooo`02ooooo`?o
00000_ooool4o`0000;ooooo1?l00003ooooo`?o00000_ooool4o`0000oooooo0ol00002ooooo`Ko
00003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`Co
00000oooool4o`000003ooooool0003o000000;o00000oooool2o`0000?ooooo1?l00002ooooo`Co
00000_ooool2o`000004ooooool0003o0000ooooo`Co00000oooool5o`0000Kooooo0ol00003oooo
o`Co00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0NOooool009Wooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo013ooooo0_l0000=ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Dooooo`05o`000?ooooooooooooooool000002?ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0<oooool2o`00
00?ooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000;ooooo0_l0
0009ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00004Oooool01?l0003oooooooooool0
001Fooooo`;o00002_ooool00ol0003oooooooooo`1jooooo`00Voooool5o`0000?ooooo00?o0000
ooooooooool09oooool2o`0001?ooooo00?o0000ooooooooool03?ooool3o`0000;ooooo1?l00008
ooooo`Co00002?ooool3o`0000?ooooo0_l0000Gooooo`?o00002?ooool5o`000004ooooool0003o
0000o`0001cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`?o00002_oo
ool2o`0000Cooooo00?o0000ooooooooool02?ooool3o`0000Cooooo0_l00004ooooo`;o00001?oo
ool2o`00017ooooo1Ol00003ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`25ooooo`00oooooooooooool?ooooo003ooooooooooooo`oooool00001
\
\>"],
  ImageRangeCache->{{{0, 704.438}, {116.562, 0}} -> {-0.856351, -0.286992, \
0.00505443, 0.00505443}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .08386 L
.13683 .08443 L
.15332 .08497 L
.16917 .08548 L
.18605 .08603 L
.2023 .08656 L
.21957 .08712 L
.23621 .08767 L
.25221 .08819 L
.26924 .08874 L
.28564 .08928 L
.3014 .08979 L
.31819 .09034 L
.33434 .09086 L
.35152 .09142 L
.36806 .09196 L
.38398 .09248 L
.40091 .09303 L
.41722 .09356 L
.43454 .09413 L
.45124 .09467 L
.4673 .09519 L
.48439 .09575 L
.5 .09626 L
s
.5 .09626 m
.5161 .09678 L
.53365 .09736 L
.55014 .09789 L
.566 .09841 L
.58288 .09896 L
.59913 .09949 L
.61639 .10005 L
.63303 .10059 L
.64904 .10111 L
.66607 .10167 L
.68246 .1022 L
.69823 .10272 L
.71501 .10326 L
.73117 .10379 L
.74834 .10435 L
.76489 .10489 L
.7808 .10541 L
.79774 .10596 L
.81404 .10649 L
.83137 .10705 L
.84806 .1076 L
.86413 .10812 L
.88121 .10868 L
.89683 .10919 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{705.438, 117.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;10000MB000`400?l00000o`00003ooooooooo
oooool?ooooo002Xooooo`;o0000Foooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
05[ooooo0ol0001Jooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000FOooool5o`00
08[ooooo002Wooooo`04o`000?ooooooooooo`0005Wooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000005[ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool00000FOooool01?l0003oooooooooool0002:ooooo`00
Yoooool01?l0003oooooooooool0001Iooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`2:ooooo`00Yoooool01?l0003oooooooooool0001Ioooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`29
ooooo`00Yoooool01?l0003oooooooooool0001Iooooo`04o`000?ooooooooooo`0000Oooooo1?l0
001Kooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01oooool4o`0005Wooooo00Go
0000ooooooooooooooooo`00002:ooooo`00Yoooool01?l0003oooooooooool0001Iooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0Foooool2o`0005_ooooo0_l00009ooooo`03
o`000?oooooooooo05[ooooo00Go0000ooooooooooooooooo`00002:ooooo`00Z?ooool2o`0005_o
oooo0_l00008ooooo`Go0000F_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Oo
oooo1Ol0001Iooooo`?o0000Roooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003o
oooooooooooo`oooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003ooooooooooooo
`oooool00?ooooooooooooo3ooooo`00Goooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0
0007oooooooo0000mOl0001Hooooo`00G_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo05Kooooo001Gooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Oooooo1Ol00007ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo1?l0001Hooooo`00G_oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000oooooooo
ool0E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000oooo
ooooool0E_ooool005oooooo0_l00009ooooo`?o00002?ooool3o`00037ooooo00?o003ooooooooo
ool0oooooonkooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oooooo
ooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Ooo
ool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000
ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool0
07Gooooo0ol0000aooooo`03o`00oooooooooooo0?oooooo^oooool3o`0005Sooooo001eooooo`03
o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Ko
oooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`00
0?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooo
oonmooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3o
oooook_ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo
0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03
o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOoo
ool3o`00037ooooo00?o003oooooooooool0oooooonkooooo`?o0000F?ooool005oooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo037ooooo00?o003o
ooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`00oooooooo
oooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00Eoooool5o`0000;ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003o
ooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01oooool5o`0002oooooo00?o003oooooooooool0oooooonj
ooooo`Co0000F?ooool005kooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooo
oooo05Kooooo001Nooooo`04o`000?ooooooooooo`0000Sooooo0_l00009ooooo`03o`000?oooooo
oooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Ooooo
o`;o00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003ooooo
ooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?oo
ooooooooo`3ooooook_ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo0?ooooooV_ooool2o`00o`03ooooool00?oo003o01kooooo00?o0000ooooooooool0
E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooooi_ooooo00?o
003oooooool00?l07oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0a
ooooo`03o`00oooooooooooo0?ooooooW?ooool00ol00?ooooooooooo`0Nooooo`03o`000?oooooo
oooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3ooooooi_ooooo00?o003ooooo
ool00?l07Oooool3o`0005Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool0oooooonJooooo`;o003o00?oooooo`00ool00?l07_ooool00ol0003oooooooooo`1Fooooo`00
MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003ooooo
ooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_Ooo
ool00ol0003oooooooooo`1Fooooo`00MOooool3o`00037ooooo00?o003oooooooooool0oooooonk
ooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooo
okgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oo
ooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo0ol0
000`ooooo`Co0000`_ooool4o`000<;ooooo1?l0000^ooooo`?o0000F?ooool006_ooooo0_l00008
ooooo`03o`000?oooooooooo02kooooo0_l00004o`00o`03o`000?oooooooooo0;gooooo0_l00004
ooooo`03o`000?oooooooooo0;gooooo0_l00004ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0E_ooool006[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0^
ooooo`03o`000?l00?oo003o00?o003o00?o0000ooooooooool0_Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0;gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo05Kooooo001Zooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool0;Oooool00ol0003o003oo`00o`05o`00o`03o`000?oooooooooo0;_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2kooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`1Fooooo`00J_ooool01?l0003oooooooooool00007
ooooo`Go00001ooooolTo`00o`04o`000?l00?oo003oo`00oaKoo`00ool0001ho`0000?o003o00?o
0000o`00ool00?l08Ol00?l8ooooo`Co0000F?ooool006[ooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?l00?oo003o00Go003o00?o0000ooooooooool03ooo
oolQool008_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2kooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1Fooooo`00J_ooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo02kooooo0_l00004o`00o`03o`000?oo
oooooooo037ooooo8Ooo001[ooooo`;o00001?ooool00ol0003oooooooooo`2mooooo`;o00001?oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo05Kooooo001[ooooo`;o00002?ooool0
0ol0003oooooooooo`0`ooooo`03o`000?l00?oo003o00;o0000E?oooolQool004cooooo00?o0000
ooooooooool00_l00031ooooo`04o`000?oooooo0000o`00033ooooo00?o0000ooooooooool0E_oo
ool007Gooooo0ol0000aooooo`;o0000MooooolHool003Gooooo0_l00034ooooo`03o`000?oooooo
oooo02kooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo
08kooooo8Ooo003oooooo`kooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000oooooooo
ool0<Oooool00ol00?ooooooooooo`2_ooooob;oo`00joooool00ol0003oooooooooo`1Fooooo`00
MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0=7ooooo6?oo003Cooooo`03o`00
0?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3Yooooob7oo`00/?oo
ool3o`0005Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0ooooool;
ooooob7oo`00TOooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aoooo
o`03o`00oooooooooooo00Sooooo0ol00032ooooo`Go0000FOoooolQool004Sooooo0ol0000Uoooo
o`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool02Oooool00ol0003oooooooooo`32ooooo`04o`000?ooooooooooo`0007[ooooo6Ooo000^oooo
o`05o`000?ooooooooooooooool000009?ooool00ol0003oooooooooo`1Fooooo`00MOooool3o`00
037ooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`33ooooo`03o`000?oooooooooo
09?ooooo8Ooo000Aooooo`03o`000?oooooooooo023ooooo0ol0001Hooooo`00MOooool00ol0003o
ooooooooo`0aooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool0a?ooool00ol0003o
ooooooooo`2cooooo`Coo`002oooool2o`0002Gooooo00?o0000ooooooooool0E_ooool007Gooooo
00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo0<7ooooo
00Go0000ooooooooooooooooo`000035ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`08ooooo`;o0000
`oooool01Ol0003ooooooooooooooooo00000<7ooooo00Go0000ooooooooooooooooo`00000Toooo
o`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`07ooooo`;o
003o00?o0000ooooooooool0`_ooool3o`000<?ooooo0ol0000Sooooo`?o0000F?ooool005oooooo
0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo037ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`3ooooook;ooooo00?o0000ooooooooool0
E_ooool005kooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo037ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`3ooooook7ooooo
00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`3ooooook7ooooo00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`07ooooo`Go0000;oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooo003o0?oooooo[oooool4o`0005Sooooo001Nooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Sooooo
00?o003oooooool00?l0oooooonbooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oo
ooooooooo`0000Sooooo0_l00009ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0
1oooool2o`00o`03ooooool00?oo003o0?oooooo/Oooool00ol0003oooooooooo`1Fooooo`00Gooo
ool2o`0000[ooooo00?o0000ooooooooool01oooool3o`00037ooooo00?o003oooooooooool0oooo
oonkooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3o
oooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol0
0?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000oooooooo
ool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo
0ol0000aooooo`03o`00oooooooooooo0?oooooo^oooool3o`0005Sooooo001eooooo`03o`000?oo
oooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001e
ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooo
oooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmoooo
o`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3ooooook_o
oooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo
_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooo
oooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0a
ooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool3o`00
037ooooo00?o003oooooooooool0oooooonkooooo`?o0000F?ooool007Gooooo00?o0000oooooooo
ool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool005oooooo
0_l00004ooooo`04o`000?ooooooooooooooo`Go00001oooool00ol0003oooooooooo`0aooooo`03
o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00G_ooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0<Oooool00ol0
0?ooooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0E_ooool005ko
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07ooooo`Go00001oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool04Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`06ooooo`Co0000F?ooool005kooooo00Co0000oooooooooooo00002_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`1Fooooo`00G_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001oooooooo`000?Go0000F?ooool005kooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo00000?oooooooooooomEooooo`00Goooool2o`0000Wooooo0ol0003o
ooooooooooooE_ooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003ooooooooooooo
`oooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo002Iooooo`03o`000?oooooooooo
00cooooo0ol0000^ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0QOooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo06[ooooo0ol0000Rooooo`?o00009oooool00ol0
003oooooooooo`1jooooo`00V?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0NOooool009Sooooo00?o0000ooooooooool01Ol000000ooooooo0000
o`000003o`0000;ooooo1?l00002ooooo`?o00000_ooool3o`000003ooooool0003o000000Kooooo
00Go0000ooooool0003oooooo`000002ooooo`?o00000oooool4o`0000;ooooo0ol00005ooooo`03
o`000?oooooooooo00Cooooo0ol00005ooooo`03o`000?oooooooooo00Cooooo1Ol000000ooooooo
0000o`000002o`0000Sooooo1?l00003ooooo`Co000000?oooooo`000?l000000ol000001?oooooo
0000o`000?ooool2o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l000001_ooool5o`00
00Oooooo1Ol000000ooooooo0000o`000003o`0000;ooooo0ol00002ooooo`05o`000?oooooo0000
ooooool000000_ooool3o`0000;ooooo0ol000000ooooooo0000o`000002ooooo`;o00000oooool3
o`0000;ooooo0ol000000ooooooo0000o`000003ooooo`03o`000?oooooooooo00Oooooo0ol00003
ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01oooool3o`0000?ooooo0ol00004
ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001?ooool01?l0003ooooooooooooo
ool5o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000Oooooo00?o0000ooooooooool01ooo
ool5o`000003ooooool0003o000000?o000000Goooooo`000?l0003o0000ooooo`06o`0000?ooooo
0ol00003ooooo`Co000000Goooooo`000?l0003o0000ooooo`05o`000003ooooool0003o000000;o
oooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`Co00001oooool5o`00
0005ooooool0003o0000o`000?ooool00_l00007ooooo`?o00001?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo07Wooooo002Hooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Ko
oooo00Co0000oooooooooooo00001oooool01ol0003oooooo`000?oooooo0000ooooool000000ooo
ool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`00013ooooo00?o0000ooooooooool0
3?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooo
oooooooo0000ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000005ooooo`07o`000?oooooo0000ooooool0003oooooo`000006ooooo`04o`00
0?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`04o`000?oooooo
ooooo`0000gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo0000013ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00017o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000002ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0NOooool009Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`00
0004o`0000;ooooo00Co0000oooooooooooo00001oooool01ol0003oooooo`000?oooooo0000oooo
ool000000oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Go00003?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00002ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`;o00000ooo
ool5o`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooooooo1Ol000001ooooooo0000ooooool0003ooooo
o`000?ooool01Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool5o`0000;ooooo00Co0000oooooooooooo00003Oooool02ol0003ooooooooooooooooo0000oooo
ool0003oooooo`000?oooooo000000oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool0000Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`?o00000oooool01?l0003oooooooooool00002ooooo`?o0000
0oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1hooooo`00V?ooool01?l0003oooooooooooooool3o`0000Co
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`05ooooo`07o`000?oooooo0000ooooool0003ooooo
o`000003ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00Kooooo0ol00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Oooooo0ol00004ooooo`05o`00
0?ooooooooooooooool000000oooool02Ol0003oooooo`000?oooooo0000ooooool0003oooooo`00
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00003Oooool02ol0003ooooooooooooo
oooo0000ooooool0003oooooo`000?oooooo000000oooooo00?o0000ooooooooool00oooool2o`00
00Wooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0:ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool03oooool3o`0000Cooooo00?o0000ooooooooool00_ooool01_l0003o
ooooooooool0003oooooo`0000Kooooo00Ko0000oooooooooooo0000ooooool00002ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0NOooool009Sooooo00Go0000oooooooooooooooo
o`000004ooooo`?o00001?ooool5o`000004ooooool0003o0000o`0000;ooooo1?l00008ooooo`;o
000000?oooooo`000?ooool00_ooool3o`0000?ooooo0ol00003ooooo`?o00003Oooool00ol0003o
ooooooooo`0;ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000;ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00Co
0000ooooool0003o00000_ooool3o`0000;ooooo1?l00008ooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`;o
000000?oooooo`000?ooool00_ooool3o`0000;ooooo1?l00002ooooo`Co00000oooool3o`0000;o
oooo1?l0000?ooooo`?o00000_ooool6o`0000kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01oooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`02ooooo`?o00000oooool4o`0000?ooooo1?l000000ooooooo0000o`000002o`0000?o
oooo0_l00003ooooo`Co00000_ooool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool4o`00
00?ooooo1Ol00006ooooo`?o00000oooool4o`0000[ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo07Wooooo002Iooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0@ooooo`;o00003Oooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool01Ol0003ooooo
oooooooooooo000000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo03?ooooo0_l00003ooooo`05o`000?ooooooooooooooool000002?ooool0
1?l0003oooooooooool00002ooooo`;o00002Oooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`00017ooooo00Co0000oooooooooooo0000E_ooool2o`0000[ooooo00?o0000ooooooooool0N_oo
ool009_ooooo1Ol00003ooooo`03o`000?oooooooooo02Oooooo0_l0000Cooooo`03o`000?oooooo
oooo00cooooo0ol00002ooooo`Co00002?ooool4o`0000Sooooo0ol00003ooooo`;o00005oooool3
o`0000Sooooo1Ol000001?oooooo0000o`000?l0000Looooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool00_ooool3o`0000[ooooo0_l00004ooooo`03o`000?oooooooooo00Sooooo0ol0
0004ooooo`;o00001?ooool2o`0000Cooooo0_l0000Aooooo`Go00000oooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0QOooool00?ooooooooooooo3
ooooo`00oooooooooooool?ooooo0000\
\>"],
  ImageRangeCache->{{{0, 704.438}, {116.562, 0}} -> {-0.856351, -0.286992, \
0.00505443, 0.00505443}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .08471 L
.13683 .0862 L
.15332 .08761 L
.16917 .08896 L
.18605 .0904 L
.2023 .09179 L
.21957 .09326 L
.23621 .09468 L
.25221 .09604 L
.26924 .0975 L
.28564 .09889 L
.3014 .10024 L
.31819 .10167 L
.33434 .10305 L
.35152 .10451 L
.36806 .10592 L
.38398 .10728 L
.40091 .10872 L
.41722 .11011 L
.43454 .11159 L
.45124 .11302 L
.4673 .11439 L
.48439 .11584 L
.5 .11717 L
s
.5 .11717 m
.5161 .11855 L
.53365 .12004 L
.55014 .12145 L
.566 .1228 L
.58288 .12424 L
.59913 .12563 L
.61639 .1271 L
.63303 .12852 L
.64904 .12988 L
.66607 .13134 L
.68246 .13273 L
.69823 .13408 L
.71501 .13551 L
.73117 .13689 L
.74834 .13835 L
.76489 .13976 L
.7808 .14112 L
.79774 .14256 L
.81404 .14395 L
.83137 .14543 L
.84806 .14686 L
.86413 .14823 L
.88121 .14968 L
.89683 .15101 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{705.438, 117.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;10000MB000`400?l00000o`00003ooooooooo
oooool?ooooo002Xooooo`;o0000Foooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
05[ooooo0ol0001Jooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000FOooool5o`00
08[ooooo002Wooooo`04o`000?ooooooooooo`0005Wooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000005[ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool00000FOooool01?l0003oooooooooool0002:ooooo`00
Yoooool01?l0003oooooooooool0001Iooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`2:ooooo`00Yoooool01?l0003oooooooooool0001Ioooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`29
ooooo`00Yoooool01?l0003oooooooooool0001Iooooo`04o`000?ooooooooooo`0000Oooooo1?l0
001Kooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01oooool4o`0005Wooooo00Go
0000ooooooooooooooooo`00002:ooooo`00Yoooool01?l0003oooooooooool0001Iooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0Foooool2o`0005_ooooo0_l00009ooooo`03
o`000?oooooooooo05[ooooo00Go0000ooooooooooooooooo`00002:ooooo`00Z?ooool2o`0005_o
oooo0_l00008ooooo`Go0000F_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Oo
oooo1Ol0001Iooooo`?o0000Roooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003o
oooooooooooo`oooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003ooooooooooooo
`oooool00?ooooooooooooo3ooooo`00Goooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0
0007oooooooo0000mOl0001Hooooo`00G_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo05Kooooo001Gooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Oooooo1Ol00007ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo1?l0001Hooooo`00G_oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000oooooooo
ool0E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000oooo
ooooool0E_ooool005oooooo0_l00009ooooo`?o00002?ooool3o`00037ooooo00?o003ooooooooo
ool0oooooonkooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oooooo
ooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Ooo
ool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000
ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool0
07Gooooo0ol0000aooooo`03o`00oooooooooooo0?oooooo^oooool3o`0005Sooooo001eooooo`03
o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Ko
oooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`00
0?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooo
oonmooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3o
oooook_ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo
0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03
o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOoo
ool3o`00037ooooo00?o003oooooooooool0oooooonkooooo`?o0000F?ooool005oooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo037ooooo00?o003o
ooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`00oooooooo
oooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00Eoooool5o`0000;ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003o
ooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01oooool5o`0002oooooo00?o003oooooooooool0oooooonj
ooooo`Co0000F?ooool005kooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooo
oooo05Kooooo001Nooooo`04o`000?ooooooooooo`0000Sooooo0_l00009ooooo`03o`000?oooooo
oooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Ooooo
o`;o00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003ooooo
ooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?oo
ooooooooo`3ooooook_ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo0?ooooooV_ooool2o`00o`03ooooool00?oo003o01kooooo00?o0000ooooooooool0
E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooooi_ooooo00?o
003oooooool00?l07oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0a
ooooo`03o`00oooooooooooo0?ooooooW?ooool00ol00?ooooooooooo`0Nooooo`03o`000?oooooo
oooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3ooooooi_ooooo00?o003ooooo
ool00?l07Oooool3o`0005Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool0oooooonJooooo`;o003o00?oooooo`00ool00?l07_ooool00ol0003oooooooooo`1Fooooo`00
MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003ooooo
ooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_Ooo
ool00ol0003oooooooooo`1Fooooo`00MOooool3o`00037ooooo00?o003oooooooooool0oooooonk
ooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooo
okgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oo
ooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo0ol0
000`ooooo`Co0000`_ooool4o`000<;ooooo1?l0000^ooooo`?o0000F?ooool006_ooooo0_l00008
ooooo`03o`000?oooooooooo02kooooo0_l00004o`00o`03o`000?oooooooooo0;gooooo0_l00004
ooooo`03o`000?oooooooooo0;gooooo0_l00004ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0E_ooool006[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0^
ooooo`03o`000?l00?oo003o00?o003o00?o0000ooooooooool0_Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0;gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo05Kooooo001Zooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool0;Oooool00ol0003o003oo`00o`05o`00o`03o`000?oooooooooo0;_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2kooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`1Fooooo`00J_ooool01?l0003oooooooooool00007
ooooo`Go00001ooooolTo`00o`04o`000?l00?oo003oo`00o`koo`00ool00020o`0000?o003o00?o
0000o`00ool00?l08Ol00?l8ooooo`Co0000F?ooool006[ooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?l00?oo003o00Go003o00?o0000ooooooooool01ooo
ool8ool00:cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2kooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1Fooooo`00J_ooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo02kooooo0_l00004o`00o`03o`000?oo
oooooooo013ooooo2?oo002Uooooo`;o00001?ooool00ol0003oooooooooo`2mooooo`;o00001?oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo05Kooooo001[ooooo`;o00002?ooool0
0ol0003oooooooooo`0`ooooo`03o`000?l00?oo003o00;o00006_ooool@ool009Oooooo00?o0000
ooooooooool00_l00031ooooo`04o`000?oooooo0000o`00033ooooo00?o0000ooooooooool0E_oo
ool007Gooooo0ol0000aooooo`;o0000;?ooool9ool008oooooo0_l00034ooooo`03o`000?oooooo
oooo02kooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo
03Cooooo4?oo003oooooogWooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000oooooooo
ool0<Oooool00ol00?ooooooooooo`14ooooo`Woo`00oooooom`ooooo`03o`000?oooooooooo05Ko
oooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0COooool@ool00?oooooo
H?ooool00ol0003oooooooooo`1Fooooo`00MOooool3o`00037ooooo00?o003oooooooooool0GOoo
ool8ool00?ooooooE_ooool3o`0005Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003o
ooooooooool0IOooool8ool00?ooooooD?ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0
003oooooooooo`0aooooo`03o`00oooooooooooo00Sooooo0ol0001Roooooa7oo`00Coooool5o`00
0<;ooooo0ol0000Uooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037o
oooo00?o003oooooooooool02Oooool00ol0003oooooooooo`1booooo`Soo`00B?ooool01?l0003o
ooooooooool00031ooooo`05o`000?ooooooooooooooool000009?ooool00ol0003oooooooooo`1F
ooooo`00MOooool3o`00037ooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`1joooo
oa7oo`00>?ooool00ol0003oooooooooo`35ooooo`03o`000?oooooooooo023ooooo0ol0001Hoooo
o`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Wooooo00?o0000oooooooo
ool0Roooool8ool0037ooooo00?o0000ooooooooool0`_ooool2o`0002Gooooo00?o0000oooooooo
ool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`09ooooo`03o`00
0?oooooooooo09?ooooo2?oo000Vooooo`05o`000?ooooooooooooooool00000aOooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo
00?o003oooooooooool02?ooool2o`0009gooooo4Ooo000Eooooo`05o`000?ooooooooooooooool0
0000`Oooool01Ol0003ooooooooooooooooo000002Cooooo00?o0000ooooooooool0E_ooool007Go
oooo0ol0000aooooo`03o`00oooooooooooo00Oooooo0_l00?l00ol0003oooooooooo`2/ooooo`So
o`003_ooool3o`000<?ooooo0ol0000Sooooo`?o0000F?ooool005oooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`2eoooooa7oo`00joooool00ol0003oooooooooo`1Fooooo`00G_oo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo0<Gooooo2?oo003Sooooo`03o`00
0?oooooooooo05Kooooo001Nooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
cOooool@ool00=?ooooo00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`07ooooo`Go0000;oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooo003o0=kooooo2?oo0038ooooo`Co0000F?ooool005kooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooo`00o`3Vooooo`Woo`00`_ooool00ol0003oooooooooo`1Fooooo`00G_oo
ool01?l0003oooooooooool00008ooooo`;o00002Oooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo00Oooooo0_l00?l00ooooooo003oo`00o`3^oooooa3oo`00/_ooool00ol0003ooooo
ooooo`1Fooooo`00Goooool2o`0000[ooooo00?o0000ooooooooool01oooool3o`00037ooooo00?o
003oooooooooool0ooooool;ooooo`Woo`00Yoooool3o`0005Sooooo001eooooo`03o`000?oooooo
oooo037ooooo00?o003oooooooooool0oooooolDoooooa3oo`00VOooool00ol0003oooooooooo`1F
ooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo9?ooool8ool0
097ooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oo
ooooooooo`3oooooobcooooo4Ooo0020ooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000
<Oooool00ol00?ooooooooooo`3oooooocgooooo2?oo001fooooo`?o0000F?ooool007Gooooo00?o
0000ooooooooool0<Oooool00ol00?ooooooooooo`3oooooodGooooo2?oo001`ooooo`03o`000?oo
oooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooom=
oooooa3oo`00H?ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aoooo
o`03o`00oooooooooooo0?ooooooGOooool9ool005Oooooo00?o0000ooooooooool0E_ooool007Go
oooo0ol0000aooooo`03o`00oooooooooooo0?ooooooI_ooool@ool004Gooooo0ol0001Hooooo`00
MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?ooooooM_ooool9ool003kooooo
00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oooooooooo
o`3oooooogoooooo3?oo000booooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooo
oooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001eoooo
o`?o0000<Oooool00ol00?ooooooooooo`3ooooook_ooooo0ol0001Hooooo`00MOooool00ol0003o
ooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00
Goooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00007ooooo`03o`000?oooooooooo037o
oooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0aoooo
o`03o`00oooooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo063ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Foooo
o`00G_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo1Ol00007oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`0Aoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Kooooo1?l0001Hooooo`00G_ooool01?l0003oooooooooool0000:oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`000007oooooooo0000mOl0001Hooooo`00G_ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool00000oooooooooooooeGooooo001Oooooo`;o00002Oooool3
o`000?oooooooooooomFooooo`00oooooooooooool?ooooo003ooooooooooooo`oooool00?oooooo
ooooooo3ooooo`00oooooooooooool?ooooo003ooooooooooooo`oooool009Wooooo00?o0000oooo
ooooool03?ooool3o`0002kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`25oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0J_ooool3o`0002;ooooo0ol0000Woooo
o`03o`000?oooooooooo07[ooooo002Hooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08Gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1iooooo`00V?ooool00ol0003oooooooooo`05o`000003oooo
ool0003o000000?o00000_ooool4o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l00000
1_ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol00003ooooo`Co00000_ooool3o`0000Go
oooo00?o0000ooooooooool01?ooool3o`0000Gooooo00?o0000ooooooooool01?ooool5o`000003
ooooool0003o000000;o00002?ooool4o`0000?ooooo1?l000000ooooooo0000o`000003o`000004
ooooool0003o0000ooooo`;o00000_ooool3o`0000;ooooo0ol000000ooooooo0000o`000006oooo
o`Go00001oooool5o`000003ooooool0003o000000?o00000_ooool3o`0000;ooooo00Go0000oooo
ool0003oooooo`000002ooooo`?o00000_ooool3o`000003ooooool0003o000000;ooooo0_l00003
ooooo`?o00000_ooool3o`000003ooooool0003o000000?ooooo00?o0000ooooooooool01oooool3
o`0000?ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`07ooooo`?o00000oooool3
o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00004ooooo`04o`000?oooooo
ooooooooo`Go00000oooool2o`0000Cooooo0_l00004ooooo`;o00001oooool00ol0003ooooooooo
o`07ooooo`Go000000?oooooo`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00Ko0000
0oooool3o`0000?ooooo1?l000001Ooooooo0000o`000?l0003ooooo00Go000000?oooooo`000?l0
00000_ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo1?l00007oooo
o`Go000000Goooooo`000?l0003o0000ooooo`02o`0000Oooooo0ol00004ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0NOooool009Sooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01ol0003ooooooooooooooooo0000ooooool0
00001_ooool01?l0003oooooooooool00007ooooo`07o`000?oooooo0000ooooool0003oooooo`00
0003ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00004?ooool00ol0003ooooo
ooooo`0<ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000Gooooo00Oo0000ooooool0003oooooo`000?oooooo000000Kooooo
00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Kooooo00Co0000
oooooooooooo00003Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool00000
4?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00004Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1iooooo`00Uoooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooo000000Co00000_ooool01?l0003oooooooooool00007ooooo`07o`000?oooooo0000ooooool0
003oooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01Ol0000<oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0_l0
0003ooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooooooool5o`000007ooooool0003oooooo`00
0?oooooo0000ooooo`05o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`02ooooo`Go00000_ooool01?l0003oooooooooool0000=ooooo`0;o`000?ooooooooooooooool0
003oooooo`000?oooooo0000ooooool000003oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`00017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo
0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo07Sooooo002Hooooo`04o`000?ooooooooooooooo`?o
00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo00Oo0000ooooool0003oooooo`00
0?oooooo000000?ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool01_ooool3o`0000;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01oooool3o`0000Cooooo
00Go0000ooooooooooooooooo`000003ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000=ooooo`0;o`000?oooooo
ooooooooool0003oooooo`000?oooooo0000ooooool000003oooool00ol0003oooooooooo`03oooo
o`;o00002Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00[ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`06
o`000?ooooooooooo`000?oooooo00001_ooool01_l0003oooooooooool0003oooooo`0000;ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1iooooo`00V?ooool01Ol0003ooooooooo
oooooooo000000Cooooo0ol00004ooooo`Go000000Coooooo`000?l0003o00000_ooool4o`0000So
oooo0_l000000ooooooo0000ooooo`02ooooo`?o00000oooool3o`0000?ooooo0ol0000=ooooo`03
o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000_ooool2o`0000Gooooo00?o0000ooooooooool00_oo
ool01?l0003oooooo`000?l00002ooooo`?o00000_ooool4o`0000Sooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool3o`0000;o
oooo0_l000000ooooooo0000ooooo`02ooooo`?o00000_ooool4o`0000;ooooo1?l00003ooooo`?o
00000_ooool4o`0000oooooo0ol00002ooooo`Ko00003_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`07oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00;ooooo0ol00003ooooo`Co00000oooool4o`000003ooooool0003o000000;o
00000oooool2o`0000?ooooo1?l00002ooooo`Co00000_ooool2o`000004ooooool0003o0000oooo
o`Co00000oooool5o`0000Kooooo0ol00003ooooo`Co00002_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0NOooool009Wooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo013ooooo0_l0000=oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`05o`00
0?ooooooooooooooool000002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0<oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000008
ooooo`04o`000?ooooooooooo`0000;ooooo0_l00009ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00004Oooool01?l0003oooooooooool0001Fooooo`;o00002_ooool00ol0003ooooooooo
o`1jooooo`00Voooool5o`0000?ooooo00?o0000ooooooooool09oooool2o`0001?ooooo00?o0000
ooooooooool03?ooool3o`0000;ooooo1?l00008ooooo`Co00002?ooool3o`0000?ooooo0_l0000G
ooooo`?o00002?ooool5o`000004ooooool0003o0000o`0001cooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`02ooooo`?o00002_ooool2o`0000Cooooo00?o0000ooooooooool02?oo
ool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`00017ooooo1Ol00003ooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`25ooooo`00oooooooo
oooool?ooooo003ooooooooooooo`oooool00001\
\>"],
  ImageRangeCache->{{{0, 704.438}, {116.562, 0}} -> {-0.856351, -0.286992, \
0.00505443, 0.00505443}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .17117 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0834407 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00408 -24 -4.5 ]
[-0.0125 .00408 0 4.5 ]
[-0.0125 .04376 -24 -4.5 ]
[-0.0125 .04376 0 4.5 ]
[-0.0125 .08344 -6 -4.5 ]
[-0.0125 .08344 0 4.5 ]
[-0.0125 .12312 -18 -4.5 ]
[-0.0125 .12312 0 4.5 ]
[-0.0125 .16281 -18 -4.5 ]
[-0.0125 .16281 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .17117 .125 0 ]
[ 1 0 .125 0 ]
[.5 .18367 -219.875 0 ]
[.5 .18367 219.875 12 ]
[.93651 .05699 -5 -6 ]
[.93651 .05699 5 6 ]
[.12963 .12312 -5 -6 ]
[.12963 .12312 5 6 ]
[.12963 .1099 -3 -4.5 ]
[.12963 .1099 3 4.5 ]
[.52646 .1099 -3 -4.5 ]
[.52646 .1099 3 4.5 ]
[.92328 .1099 -3 -4.5 ]
[.92328 .1099 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .17117 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00408 m
.00625 .00408 L
s
[(-0.2)] -0.0125 .00408 1 0 Mshowa
0 .04376 m
.00625 .04376 L
s
[(-0.1)] -0.0125 .04376 1 0 Mshowa
0 .08344 m
.00625 .08344 L
s
[(0)] -0.0125 .08344 1 0 Mshowa
0 .12312 m
.00625 .12312 L
s
[(0.1)] -0.0125 .12312 1 0 Mshowa
0 .16281 m
.00625 .16281 L
s
[(0.2)] -0.0125 .16281 1 0 Mshowa
.125 Mabswid
0 .01201 m
.00375 .01201 L
s
0 .01995 m
.00375 .01995 L
s
0 .02789 m
.00375 .02789 L
s
0 .03582 m
.00375 .03582 L
s
0 .05169 m
.00375 .05169 L
s
0 .05963 m
.00375 .05963 L
s
0 .06757 m
.00375 .06757 L
s
0 .0755 m
.00375 .0755 L
s
0 .09138 m
.00375 .09138 L
s
0 .09931 m
.00375 .09931 L
s
0 .10725 m
.00375 .10725 L
s
0 .11519 m
.00375 .11519 L
s
0 .13106 m
.00375 .13106 L
s
0 .139 m
.00375 .139 L
s
0 .14693 m
.00375 .14693 L
s
0 .15487 m
.00375 .15487 L
s
0 .17074 m
.00375 .17074 L
s
.25 Mabswid
0 0 m
0 .17117 L
s
.10317 .16492 m
.10317 .17117 L
s
.30159 .16492 m
.30159 .17117 L
s
.5 .16492 m
.5 .17117 L
s
.69841 .16492 m
.69841 .17117 L
s
.89683 .16492 m
.89683 .17117 L
s
.125 Mabswid
.14286 .16742 m
.14286 .17117 L
s
.18254 .16742 m
.18254 .17117 L
s
.22222 .16742 m
.22222 .17117 L
s
.2619 .16742 m
.2619 .17117 L
s
.34127 .16742 m
.34127 .17117 L
s
.38095 .16742 m
.38095 .17117 L
s
.42063 .16742 m
.42063 .17117 L
s
.46032 .16742 m
.46032 .17117 L
s
.53968 .16742 m
.53968 .17117 L
s
.57937 .16742 m
.57937 .17117 L
s
.61905 .16742 m
.61905 .17117 L
s
.65873 .16742 m
.65873 .17117 L
s
.7381 .16742 m
.7381 .17117 L
s
.77778 .16742 m
.77778 .17117 L
s
.81746 .16742 m
.81746 .17117 L
s
.85714 .16742 m
.85714 .17117 L
s
.06349 .16742 m
.06349 .17117 L
s
.02381 .16742 m
.02381 .17117 L
s
.93651 .16742 m
.93651 .17117 L
s
.97619 .16742 m
.97619 .17117 L
s
.25 Mabswid
0 .17117 m
1 .17117 L
s
.99375 .00408 m
1 .00408 L
s
.99375 .04376 m
1 .04376 L
s
.99375 .08344 m
1 .08344 L
s
.99375 .12312 m
1 .12312 L
s
.99375 .16281 m
1 .16281 L
s
.125 Mabswid
.99625 .01201 m
1 .01201 L
s
.99625 .01995 m
1 .01995 L
s
.99625 .02789 m
1 .02789 L
s
.99625 .03582 m
1 .03582 L
s
.99625 .05169 m
1 .05169 L
s
.99625 .05963 m
1 .05963 L
s
.99625 .06757 m
1 .06757 L
s
.99625 .0755 m
1 .0755 L
s
.99625 .09138 m
1 .09138 L
s
.99625 .09931 m
1 .09931 L
s
.99625 .10725 m
1 .10725 L
s
.99625 .11519 m
1 .11519 L
s
.99625 .13106 m
1 .13106 L
s
.99625 .139 m
1 .139 L
s
.99625 .14693 m
1 .14693 L
s
.99625 .15487 m
1 .15487 L
s
.99625 .17074 m
1 .17074 L
s
.25 Mabswid
1 0 m
1 .17117 L
s
gsave
.5 .18367 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08344 m
.97619 .08344 L
s
.10317 .00408 m
.10317 .16281 L
s
.10317 .08344 m
.10317 .08344 .00794 0 365.73 arc
F
gsave
.93651 .05699 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12312 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .1099 0 0 Mshowa
[(2)] .52646 .1099 0 0 Mshowa
[(3)] .92328 .1099 0 0 Mshowa
newpath
.10317 .08344 .00794 0 365.73 arc
s
newpath
.5 .08344 .00794 0 365.73 arc
s
newpath
.89683 .08344 .00794 0 365.73 arc
s
.10317 .08344 m
.5 .08344 L
s
.5 .08344 m
.89683 .08344 L
s
1 0 0 r
.10317 .08344 m
.11927 .08514 L
.13683 .08699 L
.15332 .08873 L
.16917 .0904 L
.18605 .09218 L
.2023 .09389 L
.21957 .09571 L
.23621 .09746 L
.25221 .09915 L
.26924 .10095 L
.28564 .10267 L
.3014 .10434 L
.31819 .1061 L
.33434 .10781 L
.35152 .10962 L
.36806 .11136 L
.38398 .11304 L
.40091 .11483 L
.41722 .11654 L
.43454 .11837 L
.45124 .12013 L
.4673 .12182 L
.48439 .12362 L
.5 .12527 L
s
.5 .12527 m
.5161 .12697 L
.53365 .12882 L
.55014 .13056 L
.566 .13223 L
.58288 .13401 L
.59913 .13572 L
.61639 .13754 L
.63303 .13929 L
.64904 .14098 L
.66607 .14277 L
.68246 .1445 L
.69823 .14616 L
.71501 .14793 L
.73117 .14964 L
.74834 .15145 L
.76489 .15319 L
.7808 .15487 L
.79774 .15665 L
.81404 .15837 L
.83137 .1602 L
.84806 .16196 L
.86413 .16365 L
.88121 .16545 L
.89683 .1671 L
s
0 0 m
1 0 L
1 .17117 L
0 .17117 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{704.688, 120.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(animatUeEigen[2, Ne, \[CapitalGamma]e, TeT, Edata, nE, IndR, nR, 
        zFEigen, ZF0, 3.3];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .07932 L
.13683 .07503 L
.15332 .07111 L
.16917 .06744 L
.18605 .06368 L
.2023 .0602 L
.21957 .05668 L
.23621 .05347 L
.25221 .05057 L
.26924 .04771 L
.28564 .04518 L
.3014 .04297 L
.31819 .04088 L
.33434 .03914 L
.35152 .03759 L
.36806 .03641 L
.38398 .03558 L
.39217 .03527 L
.39673 .03514 L
.40091 .03504 L
.4052 .03496 L
.40745 .03493 L
.40983 .03491 L
.41083 .0349 L
.41191 .03489 L
.41283 .03488 L
.41384 .03488 L
.41445 .03488 L
.41502 .03488 L
.41557 .03487 L
.41584 .03487 L
.41614 .03487 L
.41666 .03487 L
.41696 .03487 L
.41722 .03487 L
.41772 .03487 L
.41824 .03488 L
.41875 .03488 L
.41931 .03488 L
.42032 .03488 L
.42131 .03489 L
.42222 .03489 L
.42428 .03491 L
.42646 .03494 L
.43011 .035 L
.43412 .03508 L
.44222 .03532 L
.45093 .03569 L
.45975 .03617 L
Mistroke
.46812 .03674 L
.48406 .03812 L
.5 .0399 L
Mfstroke
.5 .0399 m
.5161 .04208 L
.53365 .04484 L
.55014 .04779 L
.566 .05092 L
.58288 .05456 L
.59913 .05835 L
.61639 .06267 L
.63303 .06708 L
.64904 .07156 L
.66607 .07654 L
.68246 .08154 L
.69823 .08652 L
.71501 .09199 L
.73117 .0974 L
.74834 .10329 L
.76489 .10908 L
.7808 .11474 L
.79774 .12085 L
.81404 .1268 L
.83137 .13316 L
.84806 .13933 L
.86413 .14527 L
.88121 .15159 L
.89683 .15734 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{705.75, 117.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;10000MB000`400?l00000o`00003ooooooooo
oooool?ooooo002Xooooo`;o0000Foooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
05[ooooo0ol0001Jooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000FOooool5o`00
08[ooooo002Wooooo`04o`000?ooooooooooo`0005Wooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000005[ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool00000FOooool01?l0003oooooooooool0002:ooooo`00
Yoooool01?l0003oooooooooool0001Iooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`2:ooooo`00Yoooool01?l0003oooooooooool0001Ioooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`29
ooooo`00Yoooool01?l0003oooooooooool0001Iooooo`04o`000?ooooooooooo`0000Oooooo1?l0
001Kooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01oooool4o`0005Wooooo00Go
0000ooooooooooooooooo`00002:ooooo`00Yoooool01?l0003oooooooooool0001Iooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0Foooool2o`0005_ooooo0_l00009ooooo`03
o`000?oooooooooo05[ooooo00Go0000ooooooooooooooooo`00002:ooooo`00Z?ooool2o`0005_o
oooo0_l00008ooooo`Go0000F_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Oo
oooo1Ol0001Iooooo`?o0000Roooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003o
oooooooooooo`oooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003ooooooooooooo
`oooool00?ooooooooooooo3ooooo`00Goooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0
0007oooooooo0000mOl0001Hooooo`00G_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo05Kooooo001Gooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Oooooo1Ol00007ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo1?l0001Hooooo`00G_oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000oooooooo
ool0E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000oooo
ooooool0E_ooool005oooooo0_l00009ooooo`?o00002?ooool3o`00037ooooo00?o003ooooooooo
ool0oooooonlooooo`;o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oooooo
ooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Ooo
ool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000
ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool0
07Gooooo0ol0000aooooo`03o`00oooooooooooo0?oooooo_?ooool2o`0005Sooooo001eooooo`03
o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Ko
oooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`00
0?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooo
oonmooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3o
oooookcooooo0_l0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo
0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03
o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOoo
ool3o`00037ooooo00?o003oooooooooool0OOoooolkool00?oooooo1?ooool2o`0005Sooooo001O
ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00002?ooool00ol0003oooooooooo`0a
ooooo`03o`00oooooooooooo07Gooooo2?oo000kooooo`Soo`00o?ooool00ol0003oooooooooo`1F
ooooo`00G_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0<Oooool00ol00?ooooooooooo`1/ooooo`Woo`00Boooool8ool00?Cooooo00?o0000
ooooooooool0E_ooool005Oooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo06Cooooo2?oo001L
ooooo`Woo`00joooool00ol0003oooooooooo`1Fooooo`00G_ooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo00Oooooo1Ol0000_ooooo`03o`00oooooooooooo05cooooo2?oo001]
ooooo`Koo`00h_ooool4o`0005Sooooo001Nooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo05Cooooo2?oo001k
ooooo`Coo`00hOooool00ol0003oooooooooo`1Fooooo`00G_ooool01?l0003oooooooooool00008
ooooo`;o00002Oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo04cooooo2?oo0027
ooooo`Coo`00gOooool00ol0003oooooooooo`1Fooooo`00Goooool2o`0000[ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo04Gooooo1ooo002Coooo
o`Coo`00fOooool00ol0003oooooooooo`1Fooooo`00MOooool3o`00037ooooo00?o003ooooooooo
ool0@Oooool4ool009kooooo1_oo002aooooo`;o003o00?oooooo`00ool00?l07?ooool2o`0005So
oooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0>oooool6ool00:Sooooo
1_oo002/ooooo`03o`00oooooooo003o01kooooo00?o0000ooooooooool0E_ooool007Gooooo00?o
0000ooooooooool0<Oooool00ol00?ooooooooooo`0eooooo`Koo`00]?ooool4ool00:Wooooo00?o
003oooooooooool07Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0a
ooooo`03o`00oooooooooooo033ooooo1Ooo002nooooo`Coo`00Y?ooool00ol00?ooooooo`00o`0N
ooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`0/oooo
o`Coo`00aoooool5ool009kooooo0_l00?l00ooooooo003oo`00o`0Looooo`;o0000F?ooool007Go
oooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`0Xooooo`Coo`00d?ooool3ool00;go
oooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oooooo
ooooo`0Tooooo`Coo`00eoooool3ool00;[ooooo00?o0000ooooooooool0E_ooool007Gooooo00?o
0000ooooooooool0<Oooool00ol00?ooooooooooo`0Pooooo`Coo`00g_ooool3ool00;Oooooo00?o
0000ooooooooool0E_ooool007Gooooo0ol0000aooooo`03o`00oooooooooooo01cooooo1?oo003U
ooooo`?oo`00/oooool2o`0005Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooo
ooooool06?ooool4ool00>cooooo1?oo002`ooooo`03o`000?oooooooooo05Kooooo001eooooo`03
o`000?oooooooooo037ooooo00?o003oooooooooool05?ooool4ool00?Cooooo1?oo002/ooooo`03
o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0
4?ooool4ool00?cooooo1Ooo002Wooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<?oo
ool4o`0000cooooo1?oo002booooo`Co0000Coooool3ool0073ooooo1?l0000_ooooo`;o0000F?oo
ool006_ooooo0_l00008ooooo`03o`000?oooooooooo02kooooo0_l00004o`00o`03o`000?oooooo
oooo00Cooooo1Ooo002dooooo`;o00001?ooool00ol0003oooooooooo`1?ooooo`?oo`00Joooool2
o`0000Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Fooooo`00J_ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo02kooooo00?o0000o`00ool00?l00ol00?l0
0ol0003oooooooooo`04ool00;Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1B
ooooo`?oo`00J?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0E_ooool006[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0]
ooooo`03o`000?l00?oo003o00?o003o1?oo002looooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0E?ooool3ool006Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo05Kooooo001Zooooo`04o`000?ooooooooooo`0000Oooooo1Ol00007
ooooobCo003o00Co0000o`00ool00?oo003o0_oo003oo`0002?o00001?oo001Uo`0000?o003o00?o
0000o`00ool00?l08_l00?l7ooooo`Co0000F?ooool006[ooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`0^ooooo`03o`000?l00?oo003o00Co003o00?o0000ooooooooool0_?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05_ooooo0ooo001Nooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1Fooooo`00J_ooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo02kooooo0_l00004o`00o`03o`000?oo
oooooooo0;gooooo0_l00004ooooo`03o`000?oooooooooo05oooooo0ooo001Kooooo`;o00001?oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo05Kooooo001[ooooo`;o00002?ooool0
0ol0003oooooooooo`0`ooooo`03o`000?l00?oo003o00;o0000`Oooool00ol0003oooooooooo`02
o`0006Cooooo0ooo001Jooooo`03o`000?oooooooooo00;o0000;oooool00ol0003oooooooooo`1F
ooooo`00MOooool3o`00037ooooo0_l00034ooooo`;o0000JOooool2ool005Wooooo0_l0000`oooo
o`;o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooooc7o
oooo0ooo0029ooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo
00?o003oooooooooool0ooooooldooooo`?oo`00Q_ooool00ol0003oooooooooo`1Fooooo`00MOoo
ool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo=oooool3ool008?ooooo00?o
0000ooooooooool0E_ooool007Gooooo0ol0000aooooo`03o`00oooooooooooo0?oooooo>_ooool3
ool007oooooo0_l0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo
0?oooooo?Oooool3ool007gooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000oooooooo
ool0<Oooool00ol00?ooooooooooo`08ooooo`?o0000`_ooool5o`0006gooooo0_oo001Cooooo`?o
00009Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo00Wooooo00?o0000ooooooooool0`_ooool01?l0003oooooooooool0001_ooooo`?o
o`00Coooool01Ol0003ooooooooooooooooo000002Cooooo00?o0000ooooooooool0E_ooool007Go
oooo0ol0000aooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool0`oooool00ol0003o
ooooooooo`1booooo`?oo`00D?ooool00ol0003oooooooooo`0Qooooo`;o0000F?ooool007Gooooo
00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo0<Cooooo
00?o0000ooooooooool0M?ooool3ool004_ooooo0_l0000Uooooo`03o`000?oooooooooo05Kooooo
001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool02Oooool00ol0003ooooooooo
o`31ooooo`05o`000?ooooooooooooooool00000N?ooool4ool004Wooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooo
oooooooo00Oooooo00?o003oo`000?l00000`oooool01Ol0003ooooooooooooooooo000007cooooo
0ooo0012ooooo`05o`000?ooooooooooooooool000009?ooool00ol0003oooooooooo`1Fooooo`00
MOooool3o`00037ooooo00?o003oooooooooool02?ooool00ol00?oo0000ooooo`33ooooo`?o0000
P?ooool3ool0043ooooo0ol0000Tooooo`;o0000F?ooool005oooooo0_l00004ooooo`03o`000?oo
oooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`3oooooodWooooo0ooo001Uooooo`03o`000?oooooooooo05Kooooo001N
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0oooooom<ooooo`?oo`00H_oo
ool00ol0003oooooooooo`1Fooooo`00G_ooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo00Oooooo1Ol0000_ooooo`03o`00oooooooooooo00Sooooo00?o003oooooool00?l0oooo
oom@ooooo`?oo`00G?ooool4o`0005Sooooo001Nooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Sooooo00?o
003oooooool00?l0oooooomCooooo`?oo`00G?ooool00ol0003oooooooooo`1Fooooo`00G_ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Ooo
ool00ol00?ooooooooooo`07ooooo`;o003o00?oooooo`00ool00?l0oooooomEooooo`;oo`00F_oo
ool00ol0003oooooooooo`1Fooooo`00G_ooool01?l0003oooooooooool00008ooooo`;o00002Ooo
ool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?ooooooHoooool2ool005Sooooo00?o
0000ooooooooool0E_ooool005oooooo0_l0000:ooooo`03o`000?oooooooooo00Oooooo0ol0000a
ooooo`03o`00oooooooooooo0?ooooooIOooool2ool005Gooooo0_l0001Hooooo`00MOooool00ol0
003oooooooooo`0aooooo`03o`00oooooooooooo0?ooooooIoooool2ool005Cooooo00?o0000oooo
ooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3oooooofWo
oooo0ooo001Aooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo
00?o003oooooooooool0oooooom/ooooo`?oo`00C_ooool00ol0003oooooooooo`1Fooooo`00MOoo
ool3o`00037ooooo00?o003oooooooooool0oooooom_ooooo`?oo`00B_ooool2o`0005Sooooo001e
ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooombooooo`;oo`00BOooool0
0ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo
0?ooooooM?ooool3ool004Kooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000oooooooo
ool0<Oooool00ol00?ooooooooooo`3oooooogOooooo0ooo0013ooooo`03o`000?oooooooooo05Ko
oooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3oooooog[ooooo0_oo0010ooooo`;o0000
F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3oooooogcooooo0ooo
000nooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003o
ooooooooool0oooooomoooooo`?oo`00>oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0
003oooooooooo`0aooooo`03o`00oooooooooooo0?ooooooP_ooool2ool003Wooooo00?o0000oooo
ooooool0E_ooool007Gooooo0ol0000aooooo`03o`00oooooooooooo0?ooooooQ?ooool3ool003Go
oooo0_l0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo
Qoooool3ool003?ooooo00?o0000ooooooooool0E_ooool005oooooo0_l00004ooooo`04o`000?oo
ooooooooooooo`Go00001oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo
R_ooool00ooo003oooooooooo`0`ooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0aooooo`03
o`00oooooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Fooooo`00
G_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo1Ol00007ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00Gooooo1?l0001Hooooo`00G_ooool01?l0003oooooooooool0000:ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo05Kooooo001Nooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`000007oooooooo0000mOl0001Hooooo`00G_ooool01?l0003oooooooooool00007oooo
o`05o`000?ooooooooooooooool00000oooooooooooooeGooooo001Oooooo`;o00002Oooool3o`00
0?oooooooooooomFooooo`00oooooooooooool?ooooo003ooooooooooooo`oooool00?oooooooooo
ooo3ooooo`00oooooooooooool?ooooo003ooooooooooooo`oooool009Wooooo00?o0000oooooooo
ool03?ooool3o`0002kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`24ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0J_ooool3o`0002;ooooo0ol0000Wooooo`03
o`000?oooooooooo07[ooooo002Hooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1iooooo`00V?ooool00ol0003oooooooooo`05o`000003ooooool0
003o000000?o00000_ooool4o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l000001_oo
ool01Ol0003oooooo`000?oooooo000000;ooooo0ol00003ooooo`Co00000_ooool3o`0000Gooooo
00?o0000ooooooooool01?ooool5o`0000Cooooo00?o0000ooooooooool00oooool5o`000003oooo
ool0003o000000;o00002?ooool4o`0000?ooooo1?l000000ooooooo0000o`000003o`000004oooo
ool0003o0000ooooo`;o00000_ooool3o`0000;ooooo0ol000000ooooooo0000o`000006ooooo`Go
00001oooool5o`000003ooooool0003o000000?o00000_ooool3o`0000;ooooo00Go0000ooooool0
003oooooo`000002ooooo`?o00000_ooool3o`000003ooooool0003o000000;ooooo0_l00003oooo
o`?o00000_ooool3o`000003ooooool0003o000000?ooooo00?o0000ooooooooool01oooool3o`00
00?ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`07ooooo`?o00000oooool3o`00
00Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00004ooooo`04o`000?oooooooooo
ooooo`Go00000oooool2o`0000Cooooo0_l00004ooooo`;o00001oooool00ol0003oooooooooo`07
ooooo`Go000000?oooooo`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00Ko00000ooo
ool3o`0000?ooooo1?l000001Ooooooo0000o`000?l0003ooooo00Go000000?oooooo`000?l00000
0_ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo1?l00007ooooo`Go
000000Goooooo`000?l0003o0000ooooo`02o`0000Oooooo0ol00004ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0NOooool009Sooooo00Go0000ooooooooooooooooo`000002oooo
o`05o`000?ooooooooooooooool000000oooool01ol0003ooooooooooooooooo0000ooooool00000
1_ooool01?l0003oooooooooool00007ooooo`07o`000?oooooo0000ooooool0003oooooo`000003
ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00004?ooool01?l0003ooooooooo
ool0000;ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000Gooooo00Oo0000ooooool0003oooooo`000?oooooo000000Kooooo
00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Kooooo00Co0000
oooooooooooo00003Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool00000
4?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00004Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1iooooo`00Uoooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooo000000Co00000_ooool01?l0003oooooooooool00007ooooo`07o`000?oooooo0000ooooool0
003oooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01Ol0000=oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0_l0
0003ooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooooooool5o`000007ooooool0003oooooo`00
0?oooooo0000ooooo`05o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`02ooooo`Go00000_ooool01?l0003oooooooooool0000=ooooo`0;o`000?ooooooooooooooool0
003oooooo`000?oooooo0000ooooool000003oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`00017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo
0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo07Sooooo002Hooooo`04o`000?ooooooooooooooo`?o
00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo00Oo0000ooooool0003oooooo`00
0?oooooo000000?ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool01_ooool3o`0000;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01oooool3o`0000Cooooo
00Go0000ooooooooooooooooo`000003ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000=ooooo`0;o`000?oooooo
ooooooooool0003oooooo`000?oooooo0000ooooool000003oooool00ol0003oooooooooo`03oooo
o`;o00002Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00[ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`06
o`000?ooooooooooo`000?oooooo00001_ooool01_l0003oooooooooool0003oooooo`0000;ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1iooooo`00V?ooool01Ol0003ooooooooo
oooooooo000000Cooooo0ol00004ooooo`Go000000Coooooo`000?l0003o00000_ooool4o`0000So
oooo0_l000000ooooooo0000ooooo`02ooooo`?o00000oooool3o`0000?ooooo0ol0000<ooooo`05
o`000?ooooooooooooooool000002_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`;o00001Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?oooooo0000o`0000;ooooo0ol00002ooooo`Co00002?ooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`?o00000_ooool2o`000003ooooool0003ooooo00;ooooo0ol00002ooooo`Co00000_ooool4o`00
00?ooooo0ol00002ooooo`Co00003oooool3o`0000;ooooo1_l0000>ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00_ooool3o`0000?ooooo1?l00003ooooo`Co000000?oooooo`00
0?l000000_l00003ooooo`;o00000oooool4o`0000;ooooo1?l00002ooooo`;o000000Coooooo`00
0?l0003ooooo1?l00003ooooo`Go00001_ooool3o`0000?ooooo1?l0000:ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1iooooo`00VOooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool04?ooool0
1Ol0003ooooooooooooooooo000000[ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0cooooo`;o00000ooo
ool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00000_ooool2o`0000Wo
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000Aooooo`04o`000?ooooooooooo`0005Ko
oooo0_l0000:ooooo`03o`000?oooooooooo07[ooooo002Kooooo`Go00000oooool00ol0003ooooo
ooooo`0Wooooo`;o00004oooool3o`0000cooooo0ol00002ooooo`Co00002?ooool4o`0000Sooooo
0ol00003ooooo`;o00005oooool3o`0000Sooooo1Ol000001?oooooo0000o`000?l0000Looooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool00_ooool3o`0000[ooooo0_l00004ooooo`03
o`000?oooooooooo00Sooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l0000Aooooo`Go
00000oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0QOooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo0000\
\>"],
  ImageRangeCache->{{{0, 704.75}, {116.625, 0}} -> {-0.855938, -0.286963, \
0.00505112, 0.00505112}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .08008 L
.13683 .07662 L
.15332 .07344 L
.16917 .07048 L
.18605 .06743 L
.2023 .06462 L
.21957 .06177 L
.23621 .05917 L
.25221 .05683 L
.26924 .05451 L
.28564 .05246 L
.3014 .05068 L
.31819 .04899 L
.33434 .04758 L
.35152 .04632 L
.36806 .04537 L
.38398 .0447 L
.39217 .04445 L
.39673 .04434 L
.40091 .04426 L
.4052 .0442 L
.40745 .04418 L
.40983 .04415 L
.41083 .04415 L
.41191 .04414 L
.41283 .04414 L
.41384 .04413 L
.41445 .04413 L
.41502 .04413 L
.41557 .04413 L
.41584 .04413 L
.41614 .04413 L
.41666 .04413 L
.41696 .04413 L
.41722 .04413 L
.41772 .04413 L
.41824 .04413 L
.41875 .04413 L
.41931 .04413 L
.42032 .04414 L
.42131 .04414 L
.42222 .04415 L
.42428 .04416 L
.42646 .04418 L
.43011 .04423 L
.43412 .0443 L
.44222 .04449 L
.45093 .04479 L
.45975 .04518 L
Mistroke
.46812 .04564 L
.48406 .04675 L
.5 .04819 L
Mfstroke
.5 .04819 m
.5161 .04996 L
.53365 .05219 L
.55014 .05458 L
.566 .05711 L
.58288 .06006 L
.59913 .06312 L
.61639 .06661 L
.63303 .07019 L
.64904 .07381 L
.66607 .07784 L
.68246 .08188 L
.69823 .08591 L
.71501 .09034 L
.73117 .09471 L
.74834 .09948 L
.76489 .10416 L
.7808 .10874 L
.79774 .11369 L
.81404 .11849 L
.83137 .12365 L
.84806 .12863 L
.86413 .13344 L
.88121 .13855 L
.89683 .14321 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{705.75, 117.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;10000MB000`400?l00000o`00003ooooooooo
oooool?ooooo002Xooooo`;o0000Foooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
05[ooooo0ol0001Jooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000FOooool5o`00
08[ooooo002Wooooo`04o`000?ooooooooooo`0005Wooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000005[ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool00000FOooool01?l0003oooooooooool0002:ooooo`00
Yoooool01?l0003oooooooooool0001Iooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`2:ooooo`00Yoooool01?l0003oooooooooool0001Ioooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`29
ooooo`00Yoooool01?l0003oooooooooool0001Iooooo`04o`000?ooooooooooo`0000Oooooo1?l0
001Kooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01oooool4o`0005Wooooo00Go
0000ooooooooooooooooo`00002:ooooo`00Yoooool01?l0003oooooooooool0001Iooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0Foooool2o`0005_ooooo0_l00009ooooo`03
o`000?oooooooooo05[ooooo00Go0000ooooooooooooooooo`00002:ooooo`00Z?ooool2o`0005_o
oooo0_l00008ooooo`Go0000F_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Oo
oooo1Ol0001Iooooo`?o0000Roooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003o
oooooooooooo`oooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003ooooooooooooo
`oooool00?ooooooooooooo3ooooo`00Goooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0
0007oooooooo0000mOl0001Hooooo`00G_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo05Kooooo001Gooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Oooooo1Ol00007ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo1?l0001Hooooo`00G_oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000oooooooo
ool0E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000oooo
ooooool0E_ooool005oooooo0_l00009ooooo`?o00002?ooool3o`00037ooooo00?o003ooooooooo
ool0oooooonlooooo`;o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oooooo
ooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Ooo
ool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000
ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool0
07Gooooo0ol0000aooooo`03o`00oooooooooooo0?oooooo_?ooool2o`0005Sooooo001eooooo`03
o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Ko
oooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`00
0?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooo
oonmooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3o
oooookcooooo0_l0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo
0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03
o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOoo
ool3o`00037ooooo00?o003oooooooooool0oooooonlooooo`;o0000F?ooool005oooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo037ooooo00?o003o
ooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`00oooooooo
oooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00Eoooool5o`0000;ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003o
ooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01oooool5o`0002oooooo00?o003oooooooooool0QOoooolY
ool00?oooooo3?ooool4o`0005Sooooo001Nooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo07Gooooo4?oo000Y
oooooa;oo`00o?ooool00ol0003oooooooooo`1Fooooo`00G_ooool01?l0003oooooooooool00008
ooooo`;o00002Oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo06cooooo2Ooo001;
ooooo`Soo`00m?ooool00ol0003oooooooooo`1Fooooo`00Goooool2o`0000[ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo05cooooo4?oo001Loooo
o`Woo`00joooool00ol0003oooooooooo`1Fooooo`00MOooool3o`00037ooooo00?o003ooooooooo
ool0E?ooool8ool007Gooooo2?oo0031ooooo`;o003o00?oooooo`00ool00?l07?ooool2o`0005So
oooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0C?ooool8ool008Gooooo
1_oo002looooo`03o`00oooooooo003o01kooooo00?o0000ooooooooool0E_ooool007Gooooo00?o
0000ooooooooool0<Oooool00ol00?ooooooooooo`15ooooo`Ooo`00Toooool4ool00;Wooooo00?o
003oooooooooool07Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0a
ooooo`03o`00oooooooooooo047ooooo1?oo002Nooooo`Koo`00/_ooool00ol00?ooooooo`00o`0N
ooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`0koooo
o`Koo`00Z?ooool6ool00:_ooooo0_l00?l00ooooooo003oo`00o`0Looooo`;o0000F?ooool007Go
oooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`0cooooo`Soo`00]?ooool4ool00<Wo
oooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oooooo
ooooo`0/ooooo`Ooo`00`?ooool7ool00<;ooooo00?o0000ooooooooool0E_ooool007Gooooo00?o
0000ooooooooool0<Oooool00ol00?ooooooooooo`0Xooooo`Coo`00c_ooool6ool00;cooooo00?o
0000ooooooooool0E_ooool007Gooooo0ol0000aooooo`03o`00oooooooooooo02;ooooo1_oo003H
ooooo`Coo`00]oooool2o`0005Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooo
ooooool07?ooool6ool00>;ooooo1?oo002dooooo`03o`000?oooooooooo05Kooooo001eooooo`03
o`000?oooooooooo037ooooo00?o003oooooooooool06?ooool4ool00>cooooo1?oo002`ooooo`03
o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0
4_ooool6ool00?Cooooo1?oo002/ooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<?oo
ool4o`0000cooooo1_oo002`ooooo`Co0000B_ooool5ool007?ooooo1?l0000_ooooo`;o0000F?oo
ool006_ooooo0_l00008ooooo`03o`000?oooooooooo02kooooo0_l00004o`00o`03o`000?oooooo
oooo00Cooooo1Ooo002dooooo`;o00001?ooool00ol0003oooooooooo`1<ooooo`Coo`00KOooool2
o`0000Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Fooooo`00J_ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo02kooooo00?o0000o`00ool00?l00ol00?l0
0ol0003oooooooooo`04ool00;Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1@
ooooo`Coo`00JOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0E_ooool006[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0]
ooooo`03o`000?l00?oo003o00?o003o1?oo002looooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0Doooool4ool006Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo05Kooooo001Zooooo`04o`000?ooooooooooo`0000Oooooo1Ol00007
ooooobCo003o00Co0000o`00ool00?oo003o0_oo003oo`0002?o00001?oo001Uo`0000?o003o00?o
0000o`00ool00?l08_l00?l7ooooo`Co0000F?ooool006[ooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`0^ooooo`03o`000?l00?oo003o00Co003o00?o0000ooooooooool0_?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05_ooooo1?oo001Mooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1Fooooo`00J_ooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo02kooooo0_l00004o`00o`03o`000?oo
oooooooo0;gooooo0_l00004ooooo`03o`000?oooooooooo063ooooo1?oo001Iooooo`;o00001?oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo05Kooooo001[ooooo`;o00002?ooool0
0ol0003oooooooooo`0`ooooo`03o`000?l00?oo003o00;o0000`Oooool00ol0003oooooooooo`02
o`0006Kooooo1?oo001Gooooo`03o`000?oooooooooo00;o0000;oooool00ol0003oooooooooo`1F
ooooo`00MOooool3o`00037ooooo0_l00034ooooo`;o0000K?ooool4ool005Cooooo0_l0000`oooo
o`;o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3oooooocKo
oooo1?oo0023ooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo
00?o003oooooooooool0ooooooljooooo`?oo`00P?ooool00ol0003oooooooooo`1Fooooo`00MOoo
ool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo?Oooool3ool007gooooo00?o
0000ooooooooool0E_ooool007Gooooo0ol0000aooooo`03o`00oooooooooooo0?oooooo@?ooool3
ool007Wooooo0_l0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo
0?oooooo@oooool4ool007Kooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000oooooooo
ool0<Oooool00ol00?ooooooooooo`08ooooo`?o0000`_ooool5o`0007Cooooo1?oo001:ooooo`?o
00009Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo00Wooooo00?o0000ooooooooool0`_ooool01?l0003oooooooooool0001hooooo`Co
o`00AOooool01Ol0003ooooooooooooooooo000002Cooooo00?o0000ooooooooool0E_ooool007Go
oooo0ol0000aooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool0`oooool00ol0003o
ooooooooo`1looooo`?oo`00A_ooool00ol0003oooooooooo`0Qooooo`;o0000F?ooool007Gooooo
00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo0<Cooooo
00?o0000ooooooooool0O_ooool3ool0047ooooo0_l0000Uooooo`03o`000?oooooooooo05Kooooo
001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool02Oooool00ol0003ooooooooo
o`31ooooo`05o`000?ooooooooooooooool00000P_ooool3ool0043ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooo
oooooooo00Oooooo00?o003oo`000?l00000`oooool01Ol0003ooooooooooooooooo000008Gooooo
0ooo000iooooo`05o`000?ooooooooooooooool000009?ooool00ol0003oooooooooo`1Fooooo`00
MOooool3o`00037ooooo00?o003oooooooooool02?ooool00ol00?oo0000ooooo`33ooooo`?o0000
ROooool5ool003Gooooo0ol0000Tooooo`;o0000F?ooool005oooooo0_l00004ooooo`03o`000?oo
oooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`3ooooooeCooooo0ooo001Jooooo`03o`000?oooooooooo05Kooooo001N
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0oooooomGooooo`?oo`00Eooo
ool00ol0003oooooooooo`1Fooooo`00G_ooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo00Oooooo1Ol0000_ooooo`03o`00oooooooooooo00Sooooo00?o003oooooool00?l0oooo
oomKooooo`?oo`00DOooool4o`0005Sooooo001Nooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Sooooo00?o
003oooooool00?l0oooooomNooooo`?oo`00DOooool00ol0003oooooooooo`1Fooooo`00G_ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Ooo
ool00ol00?ooooooooooo`07ooooo`;o003o00?oooooo`00ool00?l0oooooomPooooo`Goo`00C?oo
ool00ol0003oooooooooo`1Fooooo`00G_ooool01?l0003oooooooooool00008ooooo`;o00002Ooo
ool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?ooooooLOooool3ool004Wooooo00?o
0000ooooooooool0E_ooool005oooooo0_l0000:ooooo`03o`000?oooooooooo00Oooooo0ol0000a
ooooo`03o`00oooooooooooo0?ooooooM?ooool3ool004Gooooo0_l0001Hooooo`00MOooool00ol0
003oooooooooo`0aooooo`03o`00oooooooooooo0?ooooooMoooool3ool004?ooooo00?o0000oooo
ooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3oooooog[o
oooo0ooo0010ooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo
00?o003oooooooooool0oooooommooooo`Coo`00??ooool00ol0003oooooooooo`1Fooooo`00MOoo
ool3o`00037ooooo00?o003oooooooooool0oooooon1ooooo`?oo`00>?ooool2o`0005Sooooo001e
ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooon4ooooo`?oo`00=_ooool0
0ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo
0?ooooooQoooool3ool003?ooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000oooooooo
ool0<Oooool00ol00?ooooooooooo`3ooooooh[ooooo00?oo`00ooooooooool0<?ooool00ol0003o
ooooooooo`1Fooooo`00MOooool3o`00037ooooo00?o003oooooooooool0oooooonlooooo`;o0000
F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o
0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3o
oooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol0
0?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo0ol0000aooooo`03
o`00oooooooooooo0?oooooo_?ooool2o`0005Sooooo001eooooo`03o`000?oooooooooo037ooooo
00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Oooooo`;o00001?oo
ool01?l0003oooooooooooooool5o`0000Oooooo00?o0000ooooooooool0<Oooool00ol00?oooooo
ooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool01oooool5o`0000Oooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo017ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool01Oooool4o`0005Sooooo001Nooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Ooooooool0003eo`0005Sooooo001Nooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00003oooooooooooooEOooool005oooooo0_l00009ooooo`?o0000oooooooooooo
oeKooooo003ooooooooooooo`oooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003o
oooooooooooo`oooool00?ooooooooooooo3ooooo`00VOooool00ol0003oooooooooo`0<ooooo`?o
0000;_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Cooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`1Zooooo`?o00008_ooool3o`0002Oooooo00?o0000oooooooo
ool0N_ooool009Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo06[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo07Wooooo002Hooooo`03o`000?oooooooooo00Go000000?oooooo`000?l000000ol0
0002ooooo`Co00000_ooool3o`0000;ooooo0ol000000ooooooo0000o`000006ooooo`05o`000?oo
oooo0000ooooool000000_ooool3o`0000?ooooo1?l00002ooooo`?o00001Oooool00ol0003ooooo
ooooo`04ooooo`Go00001?ooool00ol0003oooooooooo`03ooooo`Go000000?oooooo`000?l00000
0_l00008ooooo`Co00000oooool4o`000003ooooool0003o000000?o000000Coooooo`000?l0003o
oooo0_l00002ooooo`?o00000_ooool3o`000003ooooool0003o000000Kooooo1Ol00007ooooo`Go
000000?oooooo`000?l000000ol00002ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo0000
00;ooooo0ol00002ooooo`?o000000?oooooo`000?l000000_ooool2o`0000?ooooo0ol00002oooo
o`?o000000?oooooo`000?l000000oooool00ol0003oooooooooo`07ooooo`?o00000oooool00ol0
003oooooo`000005ooooo`03o`000?oooooooooo00Oooooo0ol00003ooooo`?o00001?ooool00ol0
003oooooooooo`03ooooo`;o00000oooool3o`0000Cooooo00Co0000oooooooooooooooo1Ol00003
ooooo`;o00001?ooool2o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo00Oooooo1Ol00000
0ooooooo0000o`000003o`000005ooooool0003o0000o`000?ooool01_l00003ooooo`?o00000ooo
ool4o`000005ooooool0003o0000o`000?ooool01Ol000000ooooooo0000o`000002ooooo`;o0000
00?oooooo`000?l000000_l000001?oooooo0000o`000?ooool4o`0000Oooooo1Ol000001Ooooooo
0000o`000?l0003ooooo00;o00001oooool3o`0000Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1iooooo`00V?ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`07o`000?ooooooooooooooool0003oooooo`000006ooooo`04o`00
0?ooooooooooo`0000Oooooo00Oo0000ooooool0003oooooo`000?oooooo000000?ooooo00?o0000
ooooool000000_ooool01?l0003oooooooooool0000@ooooo`04o`000?ooooooooooo`0000_ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`06o`000?oooooooooo
o`000?oooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool000000_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000001Oooool01ol0003oooooo`000?oooooo0000ooooool000001_ooool01?l0003ooooo
ooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool01?l0003oooooooooool0
000=ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooo`00000@ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Aooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo07Wooooo002Gooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000001?l0
0002ooooo`04o`000?ooooooooooo`0000Oooooo00Oo0000ooooool0003oooooo`000?oooooo0000
00?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`05o`0000gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool2o`0000?ooooo1Ol0
0002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooooooo`Go000000Ooooooo`000?oooooo0000ooooool0003o
oooo00Go00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo1Ol0
0002ooooo`04o`000?ooooooooooo`0000gooooo00_o0000ooooooooooooooooo`000?oooooo0000
ooooool0003oooooo`00000?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00004Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0N?ooool009Sooooo00Co0000oooooooooooooooo0ol00004ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooo`000003ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool01Oooool01ol0003oooooo`000?oooooo0000ooooool00000
0oooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooooooo`06ooooo`?o00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00002_ooool00ol0003oooooooooo`07ooooo`?o00001?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000000ooo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000gooooo00_o0000ooooooooooooooooo`00
0?oooooo0000ooooool0003oooooo`00000?ooooo`03o`000?oooooooooo00?ooooo0_l00009oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00oooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooo
oooo0000ooooool00006ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo07Wooooo002Hooooo`05o`000?ooooooooooooooool00000
1?ooool3o`0000Cooooo1Ol000001?oooooo0000o`000?l00002ooooo`Co00002?ooool2o`000003
ooooool0003ooooo00;ooooo0ol00003ooooo`?o00000oooool3o`0000cooooo00Go0000oooooooo
ooooooooo`00000:ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000;ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo
00Co0000ooooool0003o00000_ooool3o`0000;ooooo1?l00008ooooo`05o`000?oooooooooooooo
ool000002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0ol00002oooo
o`;o000000?oooooo`000?ooool00_ooool3o`0000;ooooo1?l00002ooooo`Co00000oooool3o`00
00;ooooo1?l0000?ooooo`?o00000_ooool6o`0000kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`02ooooo`?o00000oooool4o`0000?ooooo1?l000000ooooooo0000o`000002o`00
00?ooooo0_l00003ooooo`Co00000_ooool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool4
o`0000?ooooo1Ol00006ooooo`?o00000oooool4o`0000[ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo07Wooooo002Iooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooo
ooooooooool000002_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool05?ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03?ooooo0_l00003ooooo`05o`000?oo
ooooooooooooool000002?ooool01?l0003oooooooooool00002ooooo`;o00002Oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`00017ooooo00Co0000oooooooooooo0000E_ooool2o`0000[o
oooo00?o0000ooooooooool0N_ooool009_ooooo1Ol00003ooooo`03o`000?oooooooooo02Oooooo
0_l0000Cooooo`?o00003?ooool3o`0000;ooooo1?l00008ooooo`Co00002?ooool3o`0000?ooooo
0_l0000Gooooo`?o00002?ooool5o`000004ooooool0003o0000o`0001cooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`02ooooo`?o00002_ooool2o`0000Cooooo00?o0000oooooooo
ool02?ooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`00017ooooo1Ol00003ooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`25ooooo`00
oooooooooooool?ooooo003ooooooooooooo`oooool00001\
\>"],
  ImageRangeCache->{{{0, 704.75}, {116.625, 0}} -> {-0.855938, -0.286963, \
0.00505112, 0.00505112}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .08209 L
.13683 .08077 L
.15332 .07956 L
.16917 .07842 L
.18605 .07726 L
.2023 .07619 L
.21957 .0751 L
.23621 .07411 L
.25221 .07321 L
.26924 .07232 L
.28564 .07154 L
.3014 .07086 L
.31819 .07021 L
.33434 .06968 L
.35152 .0692 L
.36806 .06883 L
.38398 .06858 L
.39217 .06848 L
.39673 .06844 L
.40091 .06841 L
.4052 .06839 L
.40745 .06838 L
.40983 .06837 L
.41083 .06837 L
.41191 .06836 L
.41283 .06836 L
.41384 .06836 L
.41445 .06836 L
.41502 .06836 L
.41557 .06836 L
.41584 .06836 L
.41614 .06836 L
.41666 .06836 L
.41696 .06836 L
.41722 .06836 L
.41772 .06836 L
.41824 .06836 L
.41875 .06836 L
.41931 .06836 L
.42032 .06836 L
.42131 .06836 L
.42222 .06836 L
.42428 .06837 L
.42646 .06838 L
.43011 .0684 L
.43412 .06842 L
.44222 .0685 L
.45093 .06861 L
.45975 .06876 L
Mistroke
.46812 .06893 L
.48406 .06936 L
.5 .06991 L
Mfstroke
.5 .06991 m
.5161 .07058 L
.53365 .07144 L
.55014 .07235 L
.566 .07332 L
.58288 .07444 L
.59913 .07561 L
.61639 .07695 L
.63303 .07831 L
.64904 .07969 L
.66607 .08123 L
.68246 .08278 L
.69823 .08432 L
.71501 .08601 L
.73117 .08768 L
.74834 .0895 L
.76489 .09129 L
.7808 .09304 L
.79774 .09493 L
.81404 .09676 L
.83137 .09873 L
.84806 .10064 L
.86413 .10247 L
.88121 .10443 L
.89683 .1062 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{705.75, 117.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;10000MB000`400?l00000o`00003ooooooooo
oooool?ooooo002Xooooo`;o0000Foooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
05[ooooo0ol0001Jooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000FOooool5o`00
08[ooooo002Wooooo`04o`000?ooooooooooo`0005Wooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000005[ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool00000FOooool01?l0003oooooooooool0002:ooooo`00
Yoooool01?l0003oooooooooool0001Iooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`2:ooooo`00Yoooool01?l0003oooooooooool0001Ioooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`29
ooooo`00Yoooool01?l0003oooooooooool0001Iooooo`04o`000?ooooooooooo`0000Oooooo1?l0
001Kooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01oooool4o`0005Wooooo00Go
0000ooooooooooooooooo`00002:ooooo`00Yoooool01?l0003oooooooooool0001Iooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0Foooool2o`0005_ooooo0_l00009ooooo`03
o`000?oooooooooo05[ooooo00Go0000ooooooooooooooooo`00002:ooooo`00Z?ooool2o`0005_o
oooo0_l00008ooooo`Go0000F_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Oo
oooo1Ol0001Iooooo`?o0000Roooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003o
oooooooooooo`oooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003ooooooooooooo
`oooool00?ooooooooooooo3ooooo`00Goooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0
0007oooooooo0000mOl0001Hooooo`00G_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo05Kooooo001Gooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Oooooo1Ol00007ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo1?l0001Hooooo`00G_oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000oooooooo
ool0E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000oooo
ooooool0E_ooool005oooooo0_l00009ooooo`?o00002?ooool3o`00037ooooo00?o003ooooooooo
ool0oooooonlooooo`;o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oooooo
ooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Ooo
ool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000
ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_ooool0
07Gooooo0ol0000aooooo`03o`00oooooooooooo0?oooooo_?ooool2o`0005Sooooo001eooooo`03
o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Ko
oooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`00
0?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooo
oonmooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3o
oooookcooooo0_l0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo
0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03
o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOoo
ool3o`00037ooooo00?o003oooooooooool0oooooonlooooo`;o0000F?ooool005oooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo037ooooo00?o003o
ooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`00oooooooo
oooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00Eoooool5o`0000;ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003o
ooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool01oooool5o`0002oooooo00?o003oooooooooool0oooooonj
ooooo`Co0000F?ooool005kooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooo
oooo05Kooooo001Nooooo`04o`000?ooooooooooo`0000Sooooo0_l00009ooooo`03o`000?oooooo
oooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001Ooooo
o`;o00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003ooooo
ooooool0oooooonmooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?oo
ooooooooo`3ooooooi_ooooo0_l00?l00ooooooo003oo`00o`0Looooo`;o0000F?ooool007Gooooo
00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooooicooooo00?o003oooooool00?l0
7_ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooo
oooooooo0?ooooooWOooool00ol00?ooooooooooo`0Mooooo`03o`000?oooooooooo05Kooooo001e
ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonLooooo`03o`00oooooooo
003o01kooooo00?o0000ooooooooool0E_ooool007Gooooo0ol0000aooooo`03o`00oooooooooooo
0?ooooooVoooool2o`00o`03ooooool00?oo003o01cooooo0_l0001Hooooo`00MOooool00ol0003o
ooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00
MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003ooooo
ooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_Ooo
ool00ol0003oooooooooo`1Fooooo`00MOooool3o`00037ooooo00?o003oooooooooool0OOoooolk
ool00?oooooo1?ooool2o`0005Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooo
ooooool0G?oooolQool003_ooooo6Ooo003[ooooo`03o`000?oooooooooo05Kooooo001eooooo`03
o`000?oooooooooo037ooooo00?o003oooooooooool0C?ooool@ool007Gooooo4?oo003Kooooo`03
o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0
>ooooolAool009Gooooo4?oo003;ooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<?oo
ool4o`0002[ooooo4Ooo0027ooooo`Co0000:oooool9ool008kooooo1?l0000_ooooo`;o0000F?oo
ool006_ooooo0_l00008ooooo`03o`000?oooooooooo02kooooo0_l00004o`00o`03o`000?oooooo
oooo01Oooooo4?oo002Fooooo`;o00001?ooool00ol0003oooooooooo`0aoooooa3oo`00O?ooool2
o`0000Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Fooooo`00J_ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo02kooooo00?o0000o`00ool00?l00ol00?l0
0ol0003oooooooooo`07oooooa3oo`00Y_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo047ooooo2Ooo001cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`1Fooooo`00J_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo02gooooo00?o0000o`00ool00?l01Ol00?l9ool00;Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`19oooooa3oo`00H_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0E_ooool006[ooooo00Co0000oooooooooooo00001oooool5
o`0000Oooooo9?l00?l01?l0003o003oo`00ool00?l4ool00?oo00008ol00008ool005oo00000ol0
0?l00ol0003o003oo`00o`0Ro`00o`Oooooo1?l0001Hooooo`00J_ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo02kooooo00?o0000o`00ool00?l01?l00?l00ol0003ooooooooo
o`2looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0HOooool8ool005?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo05Kooooo001Z
ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0;_ooool2o`0000Co003o00?o
0000ooooooooool0_Oooool2o`0000Cooooo00?o0000ooooooooool0J_ooool9ool004[ooooo0_l0
0004ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0E_ooool006_ooooo0_l00008
ooooo`03o`000?oooooooooo033ooooo00?o0000o`00ool00?l00_l00031ooooo`03o`000?oooooo
oooo00;o0000MOooool8ool004Cooooo00?o0000ooooooooool00_l0000_ooooo`03o`000?oooooo
oooo05Kooooo001eooooo`?o0000<Oooool2o`000<Cooooo0_l0001oooooo`Soo`00?Oooool2o`00
033ooooo0_l0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oo
ooooCOoooolAool005oooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`3ooooooekooooo2?oo001Gooooo`03o`000?oooooooooo05Kooooo
001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooomVooooo`Woo`00C_oo
ool00ol0003oooooooooo`1Fooooo`00MOooool3o`00037ooooo00?o003oooooooooool0oooooom_
ooooo`Soo`00AOooool2o`0005Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooo
ooooool0oooooomgooooo`Soo`00?_ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003o
ooooooooo`0aooooo`03o`00oooooooooooo00Sooooo0ol00032ooooo`Go0000[?ooool8ool000ko
oooo0ol0000Uooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo
00?o003oooooooooool02Oooool00ol0003oooooooooo`32ooooo`04o`000?ooooooooooo`000;Co
oooo1?oo0009ooooo`05o`000?ooooooooooooooool000009?ooool00ol0003oooooooooo`1Foooo
o`00MOooool3o`00037ooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`33ooooo`03
o`000?oooooooooo0<Gooooo00?o0000ooooooooool08Oooool2o`0005Sooooo001eooooo`03o`00
0?oooooooooo037ooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`34ooooo`03o`00
0?oooooooooo0<;ooooo0_l0000Uooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oo
oooooooo037ooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`31ooooo`05o`000?oo
ooooooooooooool00000aOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo05Kooooo
001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool01oooool00ol00?oo0000o`00
0033ooooo`05o`000?ooooooooooooooool00000`Oooool01Ol0003ooooooooooooooooo000002Co
oooo00?o0000ooooooooool0E_ooool007Gooooo0ol0000aooooo`03o`00oooooooooooo00Sooooo
00?o003oo`000?ooool0`oooool3o`000<?ooooo0ol0000Tooooo`;o0000F?ooool005oooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo037ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`3ooooook7ooooo00?o0000ooooooooool0E_oo
ool005kooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo037ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`3ooooook7ooooo00?o
0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`07ooooo`Go0000;oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo003o0?oooooo[ooo
ool4o`0005Sooooo001Nooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Sooooo00?o003oooooool00?l0oooo
oonbooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Oooooo0_l0
0?l00ooooooo003oo`00o`3ooooook7ooooo00?o0000ooooooooool0E_ooool005kooooo00Co0000
oooooooooooo00002?ooool2o`0000Wooooo00?o0000ooooooooool0<Oooool00ol00?oooooooooo
o`3ooooookgooooo00?o0000ooooooooool0E_ooool005oooooo0_l0000:ooooo`03o`000?oooooo
oooo00Oooooo0ol0000aooooo`03o`00oooooooooooo0?oooooo_?ooool2o`0005Sooooo001eoooo
o`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03o`000?oooooooooo
05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonmooooo`03
o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0
oooooonmooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?oooooooooo
o`3ooooookcooooo0_l0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooo
oooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aoooo
o`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003o
ooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_Oooool00ol0003oooooooooo`1Fooooo`00
MOooool3o`00037ooooo00?o003oooooooooool0oooooonlooooo`;o0000F?ooool007Gooooo00?o
0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000ooooooooool0E_oo
ool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo00?o0000
ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooo
okgooooo00?o0000ooooooooool0E_ooool007Gooooo0ol0000aooooo`03o`00oooooooooooo0?oo
oooo_?ooool2o`0005Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0
oooooonmooooo`03o`000?oooooooooo05Kooooo001Oooooo`;o00001?ooool01?l0003ooooooooo
ooooool5o`0000Oooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookgooooo
00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0H?ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool01oooool5o`0000Oooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool4o`0005So
oooo001Nooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0E_ooool005kooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Ooooooool0003eo`00
05Sooooo001Nooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00003o
ooooooooooooEOooool005oooooo0_l00009ooooo`?o0000oooooooooooooeKooooo003ooooooooo
oooo`oooool00?ooooooooooooo3ooooo`00oooooooooooool?ooooo003ooooooooooooo`oooool0
0?ooooooooooooo3ooooo`00VOooool00ol0003oooooooooo`0<ooooo`?o0000;_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`1Zooooo`?o00008_ooool3o`0002Oooooo00?o0000ooooooooool0N_ooool009Sooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06[ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Wooooo
002Hooooo`03o`000?oooooooooo00Go000000?oooooo`000?l000000ol00002ooooo`Co00000_oo
ool3o`0000;ooooo0ol000000ooooooo0000o`000006ooooo`05o`000?oooooo0000ooooool00000
0_ooool3o`0000?ooooo1?l00002ooooo`?o00001Oooool00ol0003oooooooooo`04ooooo`Go0000
1?ooool00ol0003oooooooooo`03ooooo`Go000000?oooooo`000?l000000_l00008ooooo`Co0000
0oooool4o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo0_l00002ooooo`?o
00000_ooool3o`000003ooooool0003o000000Kooooo1Ol00007ooooo`Go000000?oooooo`000?l0
00000ol00002ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol00002oooo
o`?o000000?oooooo`000?l000000_ooool2o`0000?ooooo0ol00002ooooo`?o000000?oooooo`00
0?l000000oooool00ol0003oooooooooo`07ooooo`?o00000oooool00ol0003oooooo`000005oooo
o`03o`000?oooooooooo00Oooooo0ol00003ooooo`?o00001?ooool00ol0003oooooooooo`03oooo
o`;o00000oooool3o`0000Cooooo00Co0000oooooooooooooooo1Ol00003ooooo`;o00001?ooool2
o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo00Oooooo1Ol000000ooooooo0000o`000003
o`000005ooooool0003o0000o`000?ooool01_l00003ooooo`?o00000oooool4o`000005ooooool0
003o0000o`000?ooool01Ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l00000
0_l000001?oooooo0000o`000?ooool4o`0000Oooooo1Ol000001Ooooooo0000o`000?l0003ooooo
00;o00001oooool3o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1ioooo
o`00V?ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`07o`000?ooooooooooooooool0003oooooo`000006ooooo`04o`000?ooooooooooo`0000Oo
oooo00Oo0000ooooool0003oooooo`000?oooooo000000?ooooo00?o0000ooooool000000_ooool0
1?l0003oooooooooool0000@ooooo`04o`000?ooooooooooo`0000_ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000001Oooool0
1ol0003oooooo`000?oooooo0000ooooool000001_ooool01?l0003oooooooooool00002ooooo`06
o`000?ooooooooooo`000?oooooo00001_ooool01?l0003oooooooooool0000=ooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooo`00000@ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool02?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0000Aooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo07Wooooo002Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000001?l00002ooooo`04o`000?oo
ooooooooo`0000Oooooo00Oo0000ooooool0003oooooo`000?oooooo000000?ooooo00?o0000oooo
ool000000_ooool00ol0003oooooooooo`05o`0000gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_oo
ool3o`0000Cooooo00?o0000ooooooooool00_ooool2o`0000?ooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooooooo`Go000000Ooooooo`000?oooooo0000ooooool0003ooooo00Go00000_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0000gooooo00_o0000ooooooooooooooooo`000?oooooo0000ooooool0003oooooo`00
000?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00004Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool3o`0000?ooooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0N?ooool009Sooooo00Co0000oooooooooooooooo0ol00004ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool01Oooool01ol0003oooooo`000?oooooo0000ooooool000000oooool00ol0003ooooo
o`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`06oooo
o`?o00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
2_ooool00ol0003oooooooooo`07ooooo`?o00001?ooool01Ol0003ooooooooooooooooo000000?o
oooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000000oooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000gooooo00_o0000ooooooooooooooooo`000?oooooo0000ooooool0
003oooooo`00000?ooooo`03o`000?oooooooooo00?ooooo0_l00009ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oo
oooo0ol00004ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00006
ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo07Wooooo002Hooooo`05o`000?ooooooooooooooool000001?ooool3o`0000Cooooo
1Ol000001?oooooo0000o`000?l00002ooooo`Co00002?ooool2o`000003ooooool0003ooooo00;o
oooo0ol00003ooooo`?o00000oooool3o`0000cooooo00Go0000ooooooooooooooooo`00000:oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000;ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00Co0000ooooool0003o
00000_ooool3o`0000;ooooo1?l00008ooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`;o000000?oooooo`00
0?ooool00_ooool3o`0000;ooooo1?l00002ooooo`Co00000oooool3o`0000;ooooo1?l0000?oooo
o`?o00000_ooool6o`0000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02oooo
o`?o00000oooool4o`0000?ooooo1?l000000ooooooo0000o`000002o`0000?ooooo0_l00003oooo
o`Co00000_ooool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo1Ol00006
ooooo`?o00000oooool4o`0000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo07Wooooo002Iooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool000002_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool01Ol0
003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo03?ooooo0_l00003ooooo`05o`000?ooooooooooooooool00000
2?ooool01?l0003oooooooooool00002ooooo`;o00002Oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`00017ooooo00Co0000oooooooooooo0000E_ooool2o`0000[ooooo00?o0000oooooooo
ool0N_ooool009_ooooo1Ol00003ooooo`03o`000?oooooooooo02Oooooo0_l0000Cooooo`?o0000
3?ooool3o`0000;ooooo1?l00008ooooo`Co00002?ooool3o`0000?ooooo0_l0000Gooooo`?o0000
2?ooool5o`000004ooooool0003o0000o`0001cooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`02ooooo`?o00002_ooool2o`0000Cooooo00?o0000ooooooooool02?ooool3o`0000Co
oooo0_l00004ooooo`;o00001?ooool2o`00017ooooo1Ol00003ooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`25ooooo`00oooooooooooool?ooooo
003ooooooooooooo`oooool00001\
\>"],
  ImageRangeCache->{{{0, 704.75}, {116.625, 0}} -> {-0.855938, -0.286963, \
0.00505112, 0.00505112}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .08457 L
.13683 .0859 L
.15332 .08711 L
.16917 .08824 L
.18605 .08941 L
.2023 .09048 L
.21957 .09157 L
.23621 .09256 L
.25221 .09346 L
.26924 .09434 L
.28564 .09512 L
.3014 .09581 L
.31819 .09645 L
.33434 .09699 L
.35152 .09747 L
.36806 .09783 L
.38398 .09809 L
.39217 .09818 L
.39673 .09823 L
.40091 .09826 L
.4052 .09828 L
.40745 .09829 L
.40983 .0983 L
.41083 .0983 L
.41191 .0983 L
.41283 .0983 L
.41384 .09831 L
.41445 .09831 L
.41502 .09831 L
.41557 .09831 L
.41584 .09831 L
.41614 .09831 L
.41666 .09831 L
.41696 .09831 L
.41722 .09831 L
.41772 .09831 L
.41824 .09831 L
.41875 .09831 L
.41931 .09831 L
.42032 .09831 L
.42131 .0983 L
.42222 .0983 L
.42428 .0983 L
.42646 .09829 L
.43011 .09827 L
.43412 .09824 L
.44222 .09817 L
.45093 .09806 L
.45975 .09791 L
Mistroke
.46812 .09773 L
.48406 .09731 L
.5 .09676 L
Mfstroke
.5 .09676 m
.5161 .09608 L
.53365 .09523 L
.55014 .09432 L
.566 .09335 L
.58288 .09222 L
.59913 .09105 L
.61639 .08972 L
.63303 .08836 L
.64904 .08697 L
.66607 .08543 L
.68246 .08389 L
.69823 .08235 L
.71501 .08066 L
.73117 .07899 L
.74834 .07717 L
.76489 .07538 L
.7808 .07363 L
.79774 .07174 L
.81404 .0699 L
.83137 .06794 L
.84806 .06603 L
.86413 .06419 L
.88121 .06224 L
.89683 .06046 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{705.75, 117.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .08658 L
.13683 .09005 L
.15332 .09322 L
.16917 .09619 L
.18605 .09923 L
.2023 .10205 L
.21957 .1049 L
.23621 .10749 L
.25221 .10984 L
.26924 .11216 L
.28564 .1142 L
.3014 .11599 L
.31819 .11768 L
.33434 .11909 L
.35152 .12034 L
.36806 .1213 L
.38398 .12197 L
.39217 .12221 L
.39673 .12232 L
.40091 .1224 L
.4052 .12247 L
.40745 .12249 L
.40983 .12251 L
.41083 .12252 L
.41191 .12253 L
.41283 .12253 L
.41384 .12253 L
.41445 .12253 L
.41502 .12254 L
.41557 .12254 L
.41584 .12254 L
.41614 .12254 L
.41666 .12254 L
.41696 .12254 L
.41722 .12254 L
.41772 .12254 L
.41824 .12254 L
.41875 .12254 L
.41931 .12253 L
.42032 .12253 L
.42131 .12253 L
.42222 .12252 L
.42428 .12251 L
.42646 .12249 L
.43011 .12244 L
.43412 .12237 L
.44222 .12218 L
.45093 .12188 L
.45975 .12149 L
Mistroke
.46812 .12103 L
.48406 .11992 L
.5 .11847 L
Mfstroke
.5 .11847 m
.5161 .11671 L
.53365 .11447 L
.55014 .11209 L
.566 .10956 L
.58288 .10661 L
.59913 .10354 L
.61639 .10005 L
.63303 .09648 L
.64904 .09286 L
.66607 .08883 L
.68246 .08478 L
.69823 .08076 L
.71501 .07633 L
.73117 .07196 L
.74834 .06719 L
.76489 .06251 L
.7808 .05792 L
.79774 .05298 L
.81404 .04817 L
.83137 .04302 L
.84806 .03803 L
.86413 .03322 L
.88121 .02811 L
.89683 .02346 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{705.75, 117.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .08735 L
.13683 .09164 L
.15332 .09556 L
.16917 .09922 L
.18605 .10299 L
.2023 .10647 L
.21957 .10999 L
.23621 .1132 L
.25221 .11609 L
.26924 .11896 L
.28564 .12149 L
.3014 .1237 L
.31819 .12579 L
.33434 .12753 L
.35152 .12908 L
.36806 .13026 L
.38398 .13109 L
.39217 .13139 L
.39673 .13153 L
.40091 .13163 L
.4052 .1317 L
.40745 .13173 L
.40983 .13176 L
.41083 .13177 L
.41191 .13178 L
.41283 .13178 L
.41384 .13179 L
.41445 .13179 L
.41502 .13179 L
.41557 .13179 L
.41584 .13179 L
.41614 .13179 L
.41666 .13179 L
.41696 .13179 L
.41722 .13179 L
.41772 .13179 L
.41824 .13179 L
.41875 .13179 L
.41931 .13179 L
.42032 .13178 L
.42131 .13178 L
.42222 .13177 L
.42428 .13175 L
.42646 .13173 L
.43011 .13167 L
.43412 .13159 L
.44222 .13134 L
.45093 .13098 L
.45975 .1305 L
Mistroke
.46812 .12993 L
.48406 .12855 L
.5 .12677 L
Mfstroke
.5 .12677 m
.5161 .12459 L
.53365 .12182 L
.55014 .11888 L
.566 .11575 L
.58288 .1121 L
.59913 .10831 L
.61639 .104 L
.63303 .09958 L
.64904 .09511 L
.66607 .09013 L
.68246 .08513 L
.69823 .08015 L
.71501 .07468 L
.73117 .06927 L
.74834 .06338 L
.76489 .05759 L
.7808 .05193 L
.79774 .04582 L
.81404 .03987 L
.83137 .0335 L
.84806 .02734 L
.86413 .02139 L
.88121 .01508 L
.89683 .00933 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{705.75, 117.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .08658 L
.13683 .09005 L
.15332 .09322 L
.16917 .09619 L
.18605 .09923 L
.2023 .10205 L
.21957 .1049 L
.23621 .10749 L
.25221 .10984 L
.26924 .11216 L
.28564 .1142 L
.3014 .11599 L
.31819 .11768 L
.33434 .11909 L
.35152 .12034 L
.36806 .1213 L
.38398 .12197 L
.39217 .12221 L
.39673 .12232 L
.40091 .1224 L
.4052 .12247 L
.40745 .12249 L
.40983 .12251 L
.41083 .12252 L
.41191 .12253 L
.41283 .12253 L
.41384 .12253 L
.41445 .12253 L
.41502 .12254 L
.41557 .12254 L
.41584 .12254 L
.41614 .12254 L
.41666 .12254 L
.41696 .12254 L
.41722 .12254 L
.41772 .12254 L
.41824 .12254 L
.41875 .12254 L
.41931 .12253 L
.42032 .12253 L
.42131 .12253 L
.42222 .12252 L
.42428 .12251 L
.42646 .12249 L
.43011 .12244 L
.43412 .12237 L
.44222 .12218 L
.45093 .12188 L
.45975 .12149 L
Mistroke
.46812 .12103 L
.48406 .11992 L
.5 .11847 L
Mfstroke
.5 .11847 m
.5161 .11671 L
.53365 .11447 L
.55014 .11209 L
.566 .10956 L
.58288 .10661 L
.59913 .10354 L
.61639 .10005 L
.63303 .09648 L
.64904 .09286 L
.66607 .08883 L
.68246 .08478 L
.69823 .08076 L
.71501 .07633 L
.73117 .07196 L
.74834 .06719 L
.76489 .06251 L
.7808 .05792 L
.79774 .05298 L
.81404 .04817 L
.83137 .04302 L
.84806 .03803 L
.86413 .03322 L
.88121 .02811 L
.89683 .02346 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{705.75, 117.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .08457 L
.13683 .0859 L
.15332 .08711 L
.16917 .08824 L
.18605 .08941 L
.2023 .09048 L
.21957 .09157 L
.23621 .09256 L
.25221 .09346 L
.26924 .09434 L
.28564 .09512 L
.3014 .09581 L
.31819 .09645 L
.33434 .09699 L
.35152 .09747 L
.36806 .09783 L
.38398 .09809 L
.39217 .09818 L
.39673 .09823 L
.40091 .09826 L
.4052 .09828 L
.40745 .09829 L
.40983 .0983 L
.41083 .0983 L
.41191 .0983 L
.41283 .0983 L
.41384 .09831 L
.41445 .09831 L
.41502 .09831 L
.41557 .09831 L
.41584 .09831 L
.41614 .09831 L
.41666 .09831 L
.41696 .09831 L
.41722 .09831 L
.41772 .09831 L
.41824 .09831 L
.41875 .09831 L
.41931 .09831 L
.42032 .09831 L
.42131 .0983 L
.42222 .0983 L
.42428 .0983 L
.42646 .09829 L
.43011 .09827 L
.43412 .09824 L
.44222 .09817 L
.45093 .09806 L
.45975 .09791 L
Mistroke
.46812 .09773 L
.48406 .09731 L
.5 .09676 L
Mfstroke
.5 .09676 m
.5161 .09608 L
.53365 .09523 L
.55014 .09432 L
.566 .09335 L
.58288 .09222 L
.59913 .09105 L
.61639 .08972 L
.63303 .08836 L
.64904 .08697 L
.66607 .08543 L
.68246 .08389 L
.69823 .08235 L
.71501 .08066 L
.73117 .07899 L
.74834 .07717 L
.76489 .07538 L
.7808 .07363 L
.79774 .07174 L
.81404 .0699 L
.83137 .06794 L
.84806 .06603 L
.86413 .06419 L
.88121 .06224 L
.89683 .06046 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{705.75, 117.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .08209 L
.13683 .08077 L
.15332 .07956 L
.16917 .07842 L
.18605 .07726 L
.2023 .07619 L
.21957 .0751 L
.23621 .07411 L
.25221 .07321 L
.26924 .07232 L
.28564 .07154 L
.3014 .07086 L
.31819 .07021 L
.33434 .06968 L
.35152 .0692 L
.36806 .06883 L
.38398 .06858 L
.39217 .06848 L
.39673 .06844 L
.40091 .06841 L
.4052 .06839 L
.40745 .06838 L
.40983 .06837 L
.41083 .06837 L
.41191 .06836 L
.41283 .06836 L
.41384 .06836 L
.41445 .06836 L
.41502 .06836 L
.41557 .06836 L
.41584 .06836 L
.41614 .06836 L
.41666 .06836 L
.41696 .06836 L
.41722 .06836 L
.41772 .06836 L
.41824 .06836 L
.41875 .06836 L
.41931 .06836 L
.42032 .06836 L
.42131 .06836 L
.42222 .06836 L
.42428 .06837 L
.42646 .06838 L
.43011 .0684 L
.43412 .06842 L
.44222 .0685 L
.45093 .06861 L
.45975 .06876 L
Mistroke
.46812 .06893 L
.48406 .06936 L
.5 .06991 L
Mfstroke
.5 .06991 m
.5161 .07058 L
.53365 .07144 L
.55014 .07235 L
.566 .07332 L
.58288 .07444 L
.59913 .07561 L
.61639 .07695 L
.63303 .07831 L
.64904 .07969 L
.66607 .08123 L
.68246 .08278 L
.69823 .08432 L
.71501 .08601 L
.73117 .08768 L
.74834 .0895 L
.76489 .09129 L
.7808 .09304 L
.79774 .09493 L
.81404 .09676 L
.83137 .09873 L
.84806 .10064 L
.86413 .10247 L
.88121 .10443 L
.89683 .1062 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{705.75, 117.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .08008 L
.13683 .07662 L
.15332 .07344 L
.16917 .07048 L
.18605 .06743 L
.2023 .06462 L
.21957 .06177 L
.23621 .05917 L
.25221 .05683 L
.26924 .05451 L
.28564 .05246 L
.3014 .05068 L
.31819 .04899 L
.33434 .04758 L
.35152 .04632 L
.36806 .04537 L
.38398 .0447 L
.39217 .04445 L
.39673 .04434 L
.40091 .04426 L
.4052 .0442 L
.40745 .04418 L
.40983 .04415 L
.41083 .04415 L
.41191 .04414 L
.41283 .04414 L
.41384 .04413 L
.41445 .04413 L
.41502 .04413 L
.41557 .04413 L
.41584 .04413 L
.41614 .04413 L
.41666 .04413 L
.41696 .04413 L
.41722 .04413 L
.41772 .04413 L
.41824 .04413 L
.41875 .04413 L
.41931 .04413 L
.42032 .04414 L
.42131 .04414 L
.42222 .04415 L
.42428 .04416 L
.42646 .04418 L
.43011 .04423 L
.43412 .0443 L
.44222 .04449 L
.45093 .04479 L
.45975 .04518 L
Mistroke
.46812 .04564 L
.48406 .04675 L
.5 .04819 L
Mfstroke
.5 .04819 m
.5161 .04996 L
.53365 .05219 L
.55014 .05458 L
.566 .05711 L
.58288 .06006 L
.59913 .06312 L
.61639 .06661 L
.63303 .07019 L
.64904 .07381 L
.66607 .07784 L
.68246 .08188 L
.69823 .08591 L
.71501 .09034 L
.73117 .09471 L
.74834 .09948 L
.76489 .10416 L
.7808 .10874 L
.79774 .11369 L
.81404 .11849 L
.83137 .12365 L
.84806 .12863 L
.86413 .13344 L
.88121 .13855 L
.89683 .14321 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{705.75, 117.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .07932 L
.13683 .07503 L
.15332 .07111 L
.16917 .06744 L
.18605 .06368 L
.2023 .0602 L
.21957 .05668 L
.23621 .05347 L
.25221 .05057 L
.26924 .04771 L
.28564 .04518 L
.3014 .04297 L
.31819 .04088 L
.33434 .03914 L
.35152 .03759 L
.36806 .03641 L
.38398 .03558 L
.39217 .03527 L
.39673 .03514 L
.40091 .03504 L
.4052 .03496 L
.40745 .03493 L
.40983 .03491 L
.41083 .0349 L
.41191 .03489 L
.41283 .03488 L
.41384 .03488 L
.41445 .03488 L
.41502 .03488 L
.41557 .03487 L
.41584 .03487 L
.41614 .03487 L
.41666 .03487 L
.41696 .03487 L
.41722 .03487 L
.41772 .03487 L
.41824 .03488 L
.41875 .03488 L
.41931 .03488 L
.42032 .03488 L
.42131 .03489 L
.42222 .03489 L
.42428 .03491 L
.42646 .03494 L
.43011 .035 L
.43412 .03508 L
.44222 .03532 L
.45093 .03569 L
.45975 .03617 L
Mistroke
.46812 .03674 L
.48406 .03812 L
.5 .0399 L
Mfstroke
.5 .0399 m
.5161 .04208 L
.53365 .04484 L
.55014 .04779 L
.566 .05092 L
.58288 .05456 L
.59913 .05835 L
.61639 .06267 L
.63303 .06708 L
.64904 .07156 L
.66607 .07654 L
.68246 .08154 L
.69823 .08652 L
.71501 .09199 L
.73117 .0974 L
.74834 .10329 L
.76489 .10908 L
.7808 .11474 L
.79774 .12085 L
.81404 .1268 L
.83137 .13316 L
.84806 .13933 L
.86413 .14527 L
.88121 .15159 L
.89683 .15734 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{705.75, 117.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(animatUeEigen[3, Ne, \[CapitalGamma]e, TeT, Edata, nE, IndR, nR, 
        zFEigen, ZF0, 4];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .09106 L
.13683 .09851 L
.15332 .10459 L
.16917 .10964 L
.18605 .11417 L
.2023 .11772 L
.21957 .12066 L
.22822 .12181 L
.23621 .12269 L
.24398 .12338 L
.24794 .12367 L
.25221 .12393 L
.25646 .12415 L
.26035 .1243 L
.26222 .12436 L
.26426 .12442 L
.26605 .12446 L
.26798 .12449 L
.26913 .12451 L
.27019 .12452 L
.2712 .12453 L
.27172 .12453 L
.272 .12453 L
.27228 .12453 L
.27278 .12453 L
.27325 .12453 L
.27375 .12453 L
.27429 .12453 L
.27477 .12453 L
.27527 .12453 L
.2757 .12453 L
.27617 .12453 L
.27731 .12452 L
.27834 .12451 L
.28068 .12447 L
.28274 .12443 L
.28491 .12438 L
.28889 .12424 L
.29314 .12406 L
.30079 .12362 L
.30968 .12292 L
.31808 .1221 L
.33411 .12006 L
.35116 .11726 L
.36758 .11397 L
.38336 .11028 L
.40017 .10579 L
.41635 .10096 L
.43355 .09529 L
Mistroke
.45011 .08933 L
.46605 .08317 L
.48301 .07616 L
.49933 .069 L
.5 .0687 L
Mfstroke
.5 .0687 m
.5161 .06199 L
.53365 .05592 L
.55014 .05136 L
.566 .04798 L
.57484 .04652 L
.58288 .04544 L
.59123 .04457 L
.59913 .04398 L
.60316 .04376 L
.60538 .04367 L
.60745 .04359 L
.60936 .04354 L
.6111 .0435 L
.61203 .04348 L
.61304 .04347 L
.6136 .04346 L
.61411 .04346 L
.6146 .04345 L
.61513 .04345 L
.61567 .04345 L
.61596 .04345 L
.61623 .04344 L
.61672 .04344 L
.61725 .04344 L
.61754 .04345 L
.61786 .04345 L
.61816 .04345 L
.61844 .04345 L
.61897 .04345 L
.61953 .04346 L
.62055 .04347 L
.62151 .04348 L
.62368 .04352 L
.62563 .04358 L
.62741 .04363 L
.63143 .0438 L
.63552 .04403 L
.63932 .04428 L
.64795 .04504 L
.65647 .04601 L
.66421 .04709 L
.68087 .05001 L
.6969 .05356 L
.71395 .05809 L
.73037 .06316 L
.74615 .06866 L
.76296 .07513 L
.77914 .08194 L
.79634 .08975 L
Mistroke
.8129 .0978 L
.82884 .10599 L
.8458 .11514 L
.86212 .12436 L
.87947 .13453 L
.89619 .14466 L
.89683 .14506 L
Mfstroke
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{704, 117.312},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;00000MB000`400?l00000o`00003ooooooooo
oooool;ooooo002Xooooo`;o0000F_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
05[ooooo0ol0001Jooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000F?ooool5o`00
08_ooooo002Wooooo`04o`000?ooooooooooo`0005Sooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000005[ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool00000F?ooool01?l0003oooooooooool0002;ooooo`00
Yoooool01?l0003oooooooooool0001Hooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0Eoooool00ol0003oooooooooo`2;ooooo`00Yoooool01?l0003oooooooooool0001Hoooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`2:
ooooo`00Yoooool01?l0003oooooooooool0001Hooooo`04o`000?ooooooooooo`0000Oooooo1?l0
001Kooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01oooool4o`0005Sooooo00Go
0000ooooooooooooooooo`00002;ooooo`00Yoooool01?l0003oooooooooool0001Hooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0Foooool2o`0005_ooooo0_l00009ooooo`03
o`000?oooooooooo05Wooooo00Go0000ooooooooooooooooo`00002;ooooo`00Z?ooool2o`0005[o
oooo0_l00008ooooo`Go0000F_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Oo
oooo1Ol0001Hooooo`?o0000S?ooool00?ooooooooooooo2ooooo`00oooooooooooool;ooooo003o
oooooooooooo`_ooool00?ooooooooooooo2ooooo`00oooooooooooool;ooooo003ooooooooooooo
`_ooool00?ooooooooooooo2ooooo`00Goooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0
0007oooooooo0000m?l0001Hooooo`00G_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo05Kooooo001Gooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Oooooo1Ol00007ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo1?l0001Hooooo`00G_oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooo
okcooooo00?o0000ooooooooool0E_ooool005oooooo0_l00009ooooo`?o00002?ooool3o`00037o
oooo00?o003oooooooooool0oooooonjooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000ooooooooool0E_ooool007Gooooo00?o
0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000ooooooooool0E_oo
ool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000
ooooooooool0E_ooool007Gooooo0ol0000aooooo`03o`00oooooooooooo0?oooooo^_ooool3o`00
05Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonlooooo`03
o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0
oooooonlooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o
003oooooooooool0oooooonlooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool0
0ol00?ooooooooooo`3ooooook[ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aoooo
o`03o`00oooooooooooo0?oooooo_?ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003o
ooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_?ooool00ol0003oooooooooo`1Fooooo`00
MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_?ooool00ol0003ooooo
ooooo`1Fooooo`00MOooool3o`00037ooooo00?o003oooooooooool0oooooonjooooo`?o0000F?oo
ool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000
ooooooooool0E_ooool005oooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00008oooo
o`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonlooooo`03o`000?oooooooooo
05Kooooo001Nooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_?ooool00ol0003oooooooooo`1Foooo
o`00Eoooool5o`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07oooo
o`Go0000;oooool00ol00?ooooooooooo`3aoooooa[oo`00[Oooool4o`0005Sooooo001Nooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0aoooo
o`03o`00oooooooooooo0>Wooooo2?oo000Jooooo`Soo`00Z?ooool00ol0003oooooooooo`1Foooo
o`00G_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0<Oooool00ol00?ooooooooooo`3Qooooo`Soo`00:_ooool6ool00:;ooooo00?o0000oooo
ooooool0E_ooool005kooooo00Co0000oooooooooooo00002?ooool2o`0000Wooooo00?o0000oooo
ooooool0<Oooool00ol00?ooooooooooo`3Mooooo`Coo`00>?ooool6ool009cooooo00?o0000oooo
ooooool0E_ooool005oooooo0_l0000:ooooo`03o`000?oooooooooo00Oooooo0ol0000aooooo`03
o`00oooooooooooo0=Wooooo1?oo0012ooooo`Coo`00U_ooool3o`0005Sooooo001eooooo`03o`00
0?oooooooooo037ooooo00?o003oooooooooool0eOooool4ool004[ooooo1?oo001aooooo`;o003o
00?oooooo`00ool00?l07_ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003ooooooooo
o`0aooooo`03o`00oooooooooooo0=;ooooo0ooo001Booooo`Coo`00K_ooool00ol00?ooooooo`00
o`0Oooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003o
ooooooooool0coooool3ool005Wooooo1?oo001[ooooo`03o`00oooooooooooo01kooooo00?o0000
ooooooooool0E_ooool007Gooooo0ol0000aooooo`03o`00oooooooooooo0<cooooo0ooo001Poooo
o`?oo`00Ioooool00ol00?ooooooo`00o`0Mooooo`?o0000F?ooool007Gooooo00?o0000oooooooo
ool0<Oooool00ol00?ooooooooooo`39ooooo`?oo`00I_ooool3ool006?ooooo0_l00?l00ooooooo
003oo`00o`0Nooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo
00?o003oooooooooool0aoooool2ool006cooooo0_oo0024ooooo`03o`000?oooooooooo05Kooooo
001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0aOooool2ool0073ooooo0ooo
0021ooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`33
ooooo`;oo`00MOooool2ool007gooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aoooo
o`03o`00oooooooooooo0<7ooooo0_oo001iooooo`?oo`00O?ooool00ol0003oooooooooo`1Foooo
o`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0;kooooo0ooo001nooooo`?o
o`00NOooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo0;_ooooo0ooo0024ooooo`?oo`00M_ooool00ol0003oooooooooo`1Fooooo`00MOoo
ool3o`00033ooooo1?l0002iooooo`;oo`001_ooool4o`00083ooooo0_oo0010ooooo`?o0000;ooo
ool3o`0005Sooooo001[ooooo`;o00002?ooool00ol0003oooooooooo`0^ooooo`;o00001?l00?l0
0ol0003oooooooooo`2dooooo`;oo`001_ooool2o`0000Cooooo00?o0000ooooooooool0Ooooool3
ool003_ooooo0_l00003ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0E_ooool0
06[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0^ooooo`03o`000?l00?oo
003o00?o003o00?o0000ooooooooool0/Oooool3ool000Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`22ooooo`?oo`00>?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0E_ooool006[ooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`0]ooooo`03o`000?l00?oo003o00Go003o00?o0000ooooooooool0[_ooool2
ool000[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`24ooooo`;oo`00=Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0E_ooool0
06[ooooo00Co0000oooooooooooo00001oooool5o`0000Oooooo9?l00?l01?l0003o003oo`00ool0
0?l2ool00;7o00000_oo002Mo`0000;oo`00=ol00003o`00o`03o`000?l00?oo003o02;o003o2?oo
ool4o`0005Sooooo001Zooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0;Ooo
ool00ol0003o003oo`00o`03o`00o`;oo`0000?o0000ooooooooool0ZOooool3ool000kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`28ooooo`;oo`00<?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0E_ooool006[ooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`0^ooooo`03o`000?l00?oo003o00?o003o00?o
0000ool00?oo0000Yoooool3ool001;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`2;ooooo`;oo`00;oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0E_ooool006_ooooo0_l00008ooooo`03o`000?oooooooooo02kooooo0ol00000
0ol00?oo0000o`000003ooooo`;oo`00Xoooool2ool001Gooooo0ol00002ooooo`;o0000Soooool2
ool002gooooo0ol00002ooooo`;o0000<?ooool00ol0003oooooooooo`1Fooooo`00MOooool3o`00
037ooooo00?o0000ooooooooool01Oooool2ool009kooooo0ooo000Jooooo`;o0000Toooool2ool0
02kooooo0_l0000`ooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oo
ooooooooo`07ooooo`?oo`00V?ooool3ool00;Cooooo0ooo001Oooooo`03o`000?oooooooooo05Ko
oooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool02_ooool3ool009?ooooo
0_oo002jooooo`;oo`00GOooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003ooooooooo
o`0aooooo`03o`00oooooooooooo00gooooo0ooo002=ooooo`?oo`00__ooool2ool005_ooooo00?o
0000ooooooooool0E_ooool007Gooooo0ol0000aooooo`03o`00oooooooooooo013ooooo0ooo0027
ooooo`?oo`00`oooool2ool005Oooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aoooo
o`03o`00oooooooooooo01?ooooo0ooo0020ooooo`Coo`00b?ooool2ool005Oooooo00?o0000oooo
ooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`08ooooo`?o
00002oooool2ool007[ooooo1?oo000fooooo`Go0000Toooool2ool002gooooo0ol0000Uooooo`03
o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0
2Oooool00ol0003oooooooooo`0<ooooo`?oo`00Loooool4ool003_ooooo00Co0000oooooooooooo
0000UOooool2ool002[ooooo00Go0000ooooooooooooooooo`00000Tooooo`03o`000?oooooooooo
05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo00oo
oooo0ooo001/ooooo`Coo`00@?ooool00ol0003oooooooooo`2Gooooo`03ool00?oooooooooo02_o
oooo00?o0000ooooooooool08?ooool3o`0005Sooooo001eooooo`03o`000?oooooooooo037ooooo
00?o003oooooooooool02Oooool00ol0003oooooooooo`0Booooo`?oo`00IOooool4ool004Gooooo
00?o0000ooooooooool0Uoooool2ool002Wooooo0_l0000Uooooo`03o`000?oooooooooo05Kooooo
001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool02Oooool00ol0003ooooooooo
o`0Eooooo`Coo`00GOooool4ool004Kooooo00Go0000ooooooooooooooooo`00002Jooooo`;oo`00
:Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oo
oooooooo037ooooo00?o003oooooooooool02?ooool2o`0001_ooooo1?oo001Eooooo`Coo`00B_oo
ool01Ol0003ooooooooooooooooo000009cooooo00?oo`00ooooooooool08_ooool01Ol0003ooooo
oooooooooooo000002Cooooo00?o0000ooooooooool0E_ooool007Gooooo0ol0000aooooo`03o`00
oooooooooooo00Oooooo0_l00?l00ol0003oooooooooo`0Mooooo`Coo`00COooool4ool004oooooo
0ol0002Nooooo`;oo`008oooool3o`0002?ooooo0ol0001Hooooo`00Goooool2o`0000Cooooo00?o
0000ooooooooool00_ooool3o`0000Sooooo00?o0000ooooooooool0<Oooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo02;ooooo1ooo0010ooooo`Koo`00m_ooool2ool004Wooooo00?o
0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0Xooooo`Koo`00<_ooool8ool00?kooooo0_oo0017ooooo`03o`000?oooooooooo05Kooooo001N
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0;_ooool8ool002Cooooo1_oo
003oooooo`Wooooo0_oo0015ooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool01oooool5o`0002oooooo00?o003oooooooooool02?oo
ool00ol00?ooooooo`00o`0gooooobCoo`00oooooolAooooo`;oo`00@?ooool4o`0005Sooooo001N
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0aooooo`03o`00oooooooooooo00Sooooo00?o003oooooool00?l0oooooom^ooooo`;oo`00@Ooo
ool00ol0003oooooooooo`1Fooooo`00G_ooool01?l0003oooooooooool00008ooooo`;o00002Ooo
ool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Oooooo0_l00?l00ooooooo003oo`00
o`3oooooofoooooo0_oo000oooooo`03o`000?oooooooooo05Kooooo001Oooooo`;o00002_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooomm
ooooo`03ool00?oooooooooo03cooooo00?o0000ooooooooool0E_ooool007Gooooo0ol0000aoooo
o`03o`00oooooooooooo0?ooooooO_ooool2ool003[ooooo0ol0001Hooooo`00MOooool00ol0003o
ooooooooo`0aooooo`03o`00oooooooooooo0?ooooooP?ooool2ool003[ooooo00?o0000oooooooo
ool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooooh;ooooo
00?oo`00ooooooooool0=oooool00ol0003oooooooooo`1Fooooo`00MOooool3o`00037ooooo00?o
003oooooooooool0oooooon3ooooo`;oo`00=Oooool3o`0005Sooooo001eooooo`03o`000?oooooo
oooo037ooooo00?o003oooooooooool0oooooon5ooooo`;oo`00=Oooool00ol0003oooooooooo`1F
ooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?ooooooQoooool00ooo
003oooooooooo`0booooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037o
oooo00?o003oooooooooool0oooooon8ooooo`03ool00?oooooooooo037ooooo00?o0000oooooooo
ool0E_ooool007Gooooo0ol0000aooooo`03o`00oooooooooooo0?ooooooR?ooool00ooo003ooooo
ooooo`0_ooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oooooooooo
o`3ooooookcooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool0
0ol00?ooooooooooo`3ooooookcooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000oooo
ooooool0<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000ooooooooool0E_ooool007Go
oooo0ol0000aooooo`03o`00oooooooooooo0?oooooo^_ooool3o`0005Sooooo001eooooo`03o`00
0?oooooooooo037ooooo00?o003oooooooooool0oooooonlooooo`03o`000?oooooooooo05Kooooo
001Oooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Oooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000ooooooooool0E_ooool005kooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo037o
oooo00?o003oooooooooool0Goooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo05Ko
oooo001Nooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01oooool5o`0000Oo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo013o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01_ooool4o`0005Sooooo001Nooooo`04o`000?ooooooooooo`0000[o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Ooooooool0003do`0005Sooooo001Nooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00003oooooooooooooE?ooool005oooooo0_l00009oooo
o`?o0000oooooooooooooeGooooo003ooooooooooooo`_ooool00?ooooooooooooo2ooooo`00oooo
oooooooool;ooooo003ooooooooooooo`_ooool00?ooooooooooooo2ooooo`00V?ooool00ol0003o
ooooooooo`0<ooooo`?o0000;_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Co
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Zooooo`?o00008_ooool3o`0002Oo
oooo00?o0000ooooooooool0N_ooool009Oooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Q?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo07Wooooo002Gooooo`03o`000?oooooooooo00Go000000?o
ooooo`000?l000000ol00002ooooo`Co00000_ooool3o`0000;ooooo0ol000000ooooooo0000o`00
0006ooooo`05o`000?oooooo0000ooooool000000_ooool3o`0000?ooooo1?l00002ooooo`?o0000
1Oooool00ol0003oooooooooo`05ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`Go0000
00?oooooo`000?l000000_l00008ooooo`Co00000oooool4o`000003ooooool0003o000000?o0000
00Coooooo`000?l0003ooooo0_l00002ooooo`?o00000_ooool3o`000003ooooool0003o000000Ko
oooo1Ol00007ooooo`Go000000?oooooo`000?l000000ol00002ooooo`?o00000_ooool01Ol0003o
ooooo`000?oooooo000000;ooooo0ol00002ooooo`?o000000?oooooo`000?l000000_ooool2o`00
00?ooooo0ol00002ooooo`?o000000?oooooo`000?l000000oooool00ol0003oooooooooo`07oooo
o`?o00000oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Oooooo0ol00003oooo
o`?o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0000Cooooo00Co0000oooo
oooooooooooo1Ol00003ooooo`;o00001?ooool2o`0000Cooooo0_l00007ooooo`03o`000?oooooo
oooo00Oooooo1Ol000000ooooooo0000o`000003o`000005ooooool0003o0000o`000?ooool01_l0
0003ooooo`?o00000oooool4o`000005ooooool0003o0000o`000?ooool01Ol000000ooooooo0000
o`000002ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool4o`0000Oo
oooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o00001oooool3o`0000Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1iooooo`00Uoooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`07o`000?ooooooooooooooool0003ooooo
o`000006ooooo`04o`000?ooooooooooo`0000Oooooo00Oo0000ooooool0003oooooo`000?oooooo
000000?ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool0000?ooooo`05o`000?oo
ooooooooooooool000002oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Sooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000005ooooo`07o`000?oooooo0000ooooool0003ooooo
o`000006ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00006
ooooo`04o`000?ooooooooooo`0000gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooo0000013ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Ko
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`08ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`00017ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00
0002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000003
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0NOooool009Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooo`000004o`0000;ooooo00Co0000oooooooooooo00001oooool01ol0003ooooo
o`000?oooooo0000ooooool000000oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo
00Go00003oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00002ooooo`?o00001?ooool00ol0003ooooooooo
o`02ooooo`;o00000oooool5o`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooooooo1Ol000001ooooooo
0000ooooool0003oooooo`000?ooool01Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00_ooool5o`0000;ooooo00Co0000oooooooooooo00003Oooool02ol0003ooooo
oooooooooooo0000ooooool0003oooooo`000?oooooo000000oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`?o00000oooool01?l0003ooooooooo
ool00002ooooo`?o00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1hooooo`00Uoooool01?l0003ooooo
ooooooooool3o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo0000
00?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`07o`000?oooooo
0000ooooool0003oooooo`000003ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`0;ooooo`;o00003_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool01_ooool3o`0000;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01oooool3o`0000Cooooo
00Go0000ooooooooooooooooo`000003ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000=ooooo`0;o`000?oooooo
ooooooooool0003oooooo`000?oooooo0000ooooool000003oooool00ol0003oooooooooo`03oooo
o`;o00002Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00[ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`06
o`000?ooooooooooo`000?oooooo00001_ooool01_l0003oooooooooool0003oooooo`0000;ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1iooooo`00Uoooool01Ol0003ooooooooo
oooooooo000000Cooooo0ol00004ooooo`Go000000Coooooo`000?l0003o00000_ooool4o`0000So
oooo0_l000000ooooooo0000ooooo`02ooooo`?o00000oooool3o`0000?ooooo0ol0000@ooooo`03
o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000_ooool2o`0000Gooooo00?o0000ooooooooool00_oo
ool01?l0003oooooo`000?l00002ooooo`?o00000_ooool4o`0000Sooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool3o`0000;o
oooo0_l000000ooooooo0000ooooo`02ooooo`?o00000_ooool4o`0000;ooooo1?l00003ooooo`?o
00000_ooool4o`0000oooooo0ol00002ooooo`Ko00003_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`07oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00;ooooo0ol00003ooooo`Co00000oooool4o`000003ooooool0003o000000;o
00000oooool2o`0000?ooooo1?l00002ooooo`Co00000_ooool2o`000004ooooool0003o0000oooo
o`Co00000oooool5o`0000Kooooo0ol00003ooooo`Co00002_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0NOooool009Sooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo013ooooo00Go0000oooo
ooooooooooooo`00000:ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Dooooo`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0<oooool2o`0000?ooooo00Go0000
ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000;ooooo0_l00009ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00004Oooool01?l0003oooooooooool0001Fooooo`;o0000
2_ooool00ol0003oooooooooo`1jooooo`00V_ooool5o`0000?ooooo00?o0000ooooooooool09ooo
ool2o`0001?ooooo0ol0000<ooooo`?o00000_ooool4o`0000Sooooo1?l00008ooooo`?o00000ooo
ool2o`0001Oooooo0ol00008ooooo`Go000000Coooooo`000?l0003o00007?ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo00;ooooo0ol0000:ooooo`;o00001?ooool00ol0003ooooo
ooooo`08ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00004Oooool5o`0000?ooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08Gooooo
003ooooooooooooo`_ooool00?ooooooooooooo2ooooo`00\
\>"],
  ImageRangeCache->{{{0, 703}, {116.312, 0}} -> {-0.857537, -0.287112, \
0.00506768, 0.00506768}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .08958 L
.13683 .09561 L
.15332 .10053 L
.16917 .10462 L
.18605 .10828 L
.2023 .11115 L
.21957 .11353 L
.22822 .11446 L
.23621 .11518 L
.24398 .11573 L
.24794 .11597 L
.25221 .11618 L
.25646 .11635 L
.26035 .11648 L
.26222 .11653 L
.26426 .11657 L
.26605 .1166 L
.26798 .11663 L
.26913 .11664 L
.27019 .11665 L
.2712 .11666 L
.27172 .11666 L
.272 .11666 L
.27228 .11666 L
.27278 .11666 L
.27325 .11667 L
.27375 .11667 L
.27429 .11667 L
.27477 .11666 L
.27527 .11666 L
.2757 .11666 L
.27617 .11666 L
.27731 .11665 L
.27834 .11664 L
.28068 .11662 L
.28274 .11658 L
.28491 .11654 L
.28889 .11643 L
.29314 .11628 L
.30079 .11592 L
.30968 .11536 L
.31808 .11469 L
.33411 .11305 L
.35116 .11078 L
.36758 .10812 L
.38336 .10513 L
.40017 .1015 L
.41635 .09759 L
.43355 .093 L
Mistroke
.45011 .08819 L
.46605 .0832 L
.48301 .07753 L
.49933 .07174 L
.5 .07149 L
Mfstroke
.5 .07149 m
.5161 .06606 L
.53365 .06115 L
.55014 .05746 L
.566 .05473 L
.57484 .05355 L
.58288 .05268 L
.59123 .05197 L
.59913 .0515 L
.60316 .05132 L
.60538 .05124 L
.60745 .05118 L
.60936 .05114 L
.6111 .05111 L
.61203 .05109 L
.61304 .05108 L
.6136 .05108 L
.61411 .05107 L
.6146 .05107 L
.61513 .05107 L
.61567 .05106 L
.61596 .05106 L
.61623 .05106 L
.61672 .05106 L
.61725 .05106 L
.61754 .05106 L
.61786 .05106 L
.61816 .05107 L
.61844 .05107 L
.61897 .05107 L
.61953 .05107 L
.62055 .05108 L
.62151 .05109 L
.62368 .05113 L
.62563 .05117 L
.62741 .05122 L
.63143 .05135 L
.63552 .05153 L
.63932 .05174 L
.64795 .05235 L
.65647 .05314 L
.66421 .05401 L
.68087 .05637 L
.6969 .05924 L
.71395 .06291 L
.73037 .06702 L
.74615 .07146 L
.76296 .0767 L
.77914 .0822 L
.79634 .08852 L
Mistroke
.8129 .09504 L
.82884 .10166 L
.8458 .10907 L
.86212 .11652 L
.87947 .12475 L
.89619 .13295 L
.89683 .13327 L
Mfstroke
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{704, 117.312},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;00000MB000`400?l00000o`00003ooooooooo
oooool;ooooo002Xooooo`;o0000F_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
05[ooooo0ol0001Jooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000F?ooool5o`00
08_ooooo002Wooooo`04o`000?ooooooooooo`0005Sooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000005[ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool00000F?ooool01?l0003oooooooooool0002;ooooo`00
Yoooool01?l0003oooooooooool0001Hooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0Eoooool00ol0003oooooooooo`2;ooooo`00Yoooool01?l0003oooooooooool0001Hoooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`2:
ooooo`00Yoooool01?l0003oooooooooool0001Hooooo`04o`000?ooooooooooo`0000Oooooo1?l0
001Kooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01oooool4o`0005Sooooo00Go
0000ooooooooooooooooo`00002;ooooo`00Yoooool01?l0003oooooooooool0001Hooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0Foooool2o`0005_ooooo0_l00009ooooo`03
o`000?oooooooooo05Wooooo00Go0000ooooooooooooooooo`00002;ooooo`00Z?ooool2o`0005[o
oooo0_l00008ooooo`Go0000F_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Oo
oooo1Ol0001Hooooo`?o0000S?ooool00?ooooooooooooo2ooooo`00oooooooooooool;ooooo003o
oooooooooooo`_ooool00?ooooooooooooo2ooooo`00oooooooooooool;ooooo003ooooooooooooo
`_ooool00?ooooooooooooo2ooooo`00Goooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0
0007oooooooo0000m?l0001Hooooo`00G_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo05Kooooo001Gooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Oooooo1Ol00007ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo1?l0001Hooooo`00G_oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooo
okcooooo00?o0000ooooooooool0E_ooool005oooooo0_l00009ooooo`?o00002?ooool3o`00037o
oooo00?o003oooooooooool0oooooonjooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000ooooooooool0E_ooool007Gooooo00?o
0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000ooooooooool0E_oo
ool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000
ooooooooool0E_ooool007Gooooo0ol0000aooooo`03o`00oooooooooooo0?oooooo^_ooool3o`00
05Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonlooooo`03
o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0
oooooonlooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o
003oooooooooool0oooooonlooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool0
0ol00?ooooooooooo`3ooooook[ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aoooo
o`03o`00oooooooooooo0?oooooo_?ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003o
ooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_?ooool00ol0003oooooooooo`1Fooooo`00
MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_?ooool00ol0003ooooo
ooooo`1Fooooo`00MOooool3o`00037ooooo00?o003oooooooooool0oooooonjooooo`?o0000F?oo
ool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000
ooooooooool0E_ooool005oooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00008oooo
o`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonlooooo`03o`000?oooooooooo
05Kooooo001Nooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_?ooool00ol0003oooooooooo`1Foooo
o`00Eoooool5o`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07oooo
o`Go0000;oooool00ol00?ooooooooooo`3ooooookWooooo1?l0001Hooooo`00G_ooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Oooool00ol0
0?ooooooooooo`3ooooookcooooo00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003ooooo
ooooool0oooooonlooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?ooooooooooo`00
00Sooooo0_l00009ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonloooo
o`03o`000?oooooooooo05Kooooo001Oooooo`;o00002_ooool00ol0003oooooooooo`07ooooo`?o
0000<Oooool00ol00?ooooooooooo`3]ooooob;oo`00Z_ooool3o`0005Sooooo001eooooo`03o`00
0?oooooooooo037ooooo00?o003oooooooooool0iOooool8ool002;ooooo2_oo001oooooo`;o003o
00?oooooo`00ool00?l07_ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003ooooooooo
o`0aooooo`03o`00oooooooooooo0=oooooo1_oo000dooooo`Koo`00N_ooool00ol00?ooooooo`00
o`0Oooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003o
ooooooooool0fOooool6ool0043ooooo1?oo001gooooo`03o`00oooooooooooo01kooooo00?o0000
ooooooooool0E_ooool007Gooooo0ol0000aooooo`03o`00oooooooooooo0=Gooooo1?oo001:oooo
o`Coo`00L_ooool00ol00?ooooooo`00o`0Mooooo`?o0000F?ooool007Gooooo00?o0000oooooooo
ool0<Oooool00ol00?ooooooooooo`3Aooooo`Coo`00D_ooool4ool006gooooo0_l00?l00ooooooo
003oo`00o`0Nooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo
00?o003oooooooooool0c?ooool5ool005[ooooo1?oo002<ooooo`03o`000?oooooooooo05Kooooo
001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0bOooool3ool006?ooooo1Ooo
0027ooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`36
ooooo`?oo`00Joooool4ool0087ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aoooo
o`03o`00oooooooooooo0<?ooooo0ooo001booooo`?oo`00P?ooool00ol0003oooooooooo`1Foooo
o`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0<7ooooo0_oo001hooooo`Co
o`00O?ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo0;kooooo0ooo001nooooo`?oo`00NOooool00ol0003oooooooooo`1Fooooo`00MOoo
ool3o`00033ooooo1?l0002kooooo`?oo`000oooool4o`0007gooooo0ooo0012ooooo`?o0000;ooo
ool3o`0005Sooooo001[ooooo`;o00002?ooool00ol0003oooooooooo`0^ooooo`;o00001?l00?l0
0ol0003oooooooooo`2fooooo`;oo`001?ooool2o`0000Cooooo00?o0000ooooooooool0OOooool3
ool003gooooo0_l00003ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0E_ooool0
06[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0^ooooo`03o`000?l00?oo
003o00?o003o00?o0000ooooooooool0/oooool3ool000Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`20ooooo`Coo`00>Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0E_ooool006[ooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`0]ooooo`03o`000?l00?oo003o00Go003o00?o0000ooooooooool0[oooool3
ool000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`23ooooo`?oo`00=Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0E_ooool0
06[ooooo00Co0000oooooooooooo00001oooool5o`0000Oooooo9?l00?l01?l0003o003oo`00ool0
0?l2ool00;3o00001?oo002Lo`0000?oo`00=_l00003o`00o`03o`000?l00?oo003o02;o003o2?oo
ool4o`0005Sooooo001Zooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0;Ooo
ool00ol0003o003oo`00o`03o`00o`?oo`00ZOooool4ool000oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`29ooooo`?oo`00;_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0E_ooool006[ooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`0^ooooo`03o`000?l00?oo003o00?o003o00?o0000oooooooo00000_oo
002Sooooo`?oo`005?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08gooooo0_oo
000]ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`1Fooooo`00Joooool2o`0000Sooooo00?o0000ooooooooool0;_ooool3o`000003o`00ool0003o
000000Gooooo0_oo002Nooooo`?oo`005oooool3o`0000;ooooo0_l0002Aooooo`;oo`00:oooool3
o`0000;ooooo0_l0000`ooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol0
003oooooooooo`07ooooo`?oo`00V?ooool3ool001gooooo0_l0002Eooooo`?oo`00:oooool2o`00
033ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00[o
oooo0ooo002Booooo`?oo`00^_ooool2ool005gooooo00?o0000ooooooooool0E_ooool007Gooooo
00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`0=ooooo`?oo`00R_ooool5ool00;oooooo
0_oo001Kooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o
003oooooooooool04?ooool5ool0087ooooo1?oo0036ooooo`?oo`00F?ooool00ol0003ooooooooo
o`1Fooooo`00MOooool3o`00037ooooo00?o003oooooooooool05Oooool4ool007Wooooo1?oo003=
ooooo`?oo`00Doooool3o`0005Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooo
ooooool06Oooool4ool0077ooooo1?oo003Dooooo`;oo`00Doooool00ol0003oooooooooo`1Foooo
o`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Sooooo0ol0000Booooo`Co
o`00JOooool4ool003kooooo1Ol0002Gooooo`;oo`00:Oooool3o`0002Gooooo00?o0000oooooooo
ool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`09ooooo`03o`00
0?oooooooooo01Gooooo1?oo001Oooooo`Koo`00@oooool01?l0003oooooooooool0002Iooooo`;o
o`009_ooool01Ol0003ooooooooooooooooo000002Cooooo00?o0000ooooooooool0E_ooool007Go
oooo0ol0000aooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool06Oooool4ool005?o
oooo2?oo001:ooooo`03o`000?oooooooooo09_ooooo0_oo000Xooooo`03o`000?oooooooooo023o
oooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Wooooo
00?o0000ooooooooool07Oooool4ool004Wooooo1_oo001Cooooo`03o`000?oooooooooo09cooooo
0_oo000Tooooo`;o00009Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003ooooooooo
o`0aooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool08Oooool7ool003kooooo1?oo
001Fooooo`05o`000?ooooooooooooooool00000Woooool3ool002?ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooo
oooooooo00Sooooo0_l0000Zooooo`[oo`00:?ooool<ool005[ooooo00Go0000oooooooooooooooo
o`00002Rooooo`?oo`007?ooool01Ol0003ooooooooooooooooo000002Cooooo00?o0000oooooooo
ool0E_ooool007Gooooo0ol0000aooooo`03o`00oooooooooooo00Oooooo0_l00?l00ol0003ooooo
ooooo`0booooobSoo`00Ioooool3o`000:Kooooo0_oo000Kooooo`?o00008oooool3o`0005Sooooo
001Oooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00002?ooool00ol0003ooooooooo
o`0aooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0oooooom^ooooo`;oo`00@Ooo
ool00ol0003oooooooooo`1Fooooo`00G_ooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo0?ooooooKoooool3ool003kooooo00?o0000ooooooooool0E_ooool005kooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`3oooooog;ooooo0_oo000looooo`03o`000?oo
oooooooo05Kooooo001Nooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01ooo
ool5o`0002oooooo00?o003oooooooooool02?ooool00ol00?ooooooo`00o`3oooooogGooooo0_oo
000gooooo`Co0000F?ooool005kooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool02?ooool00ol00?ooooooo`00
o`3oooooogOooooo00?oo`00ooooooooool0=oooool00ol0003oooooooooo`1Fooooo`00G_ooool0
1?l0003oooooooooool00008ooooo`;o00002Oooool00ol0003oooooooooo`0aooooo`03o`00oooo
oooooooo00Oooooo0_l00?l00ooooooo003oo`00o`3oooooogOooooo0_oo000gooooo`03o`000?oo
oooooooo05Kooooo001Oooooo`;o00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo037ooooo00?o003oooooooooool0oooooon5ooooo`;oo`00=Oooool00ol0003oooooooooo`1F
ooooo`00MOooool3o`00037ooooo00?o003oooooooooool0oooooon7ooooo`03ool00?oooooooooo
033ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oo
ooooR?ooool00ooo003oooooooooo`0aooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`00
0?oooooooooo037ooooo00?o003oooooooooool0oooooonlooooo`03o`000?oooooooooo05Kooooo
001eooooo`?o0000<Oooool00ol00?ooooooooooo`3ooooook[ooooo0ol0001Hooooo`00MOooool0
0ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_?ooool00ol0003oooooooooo`1F
ooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_?ooool00ol0
003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oo
oooo_?ooool00ol0003oooooooooo`1Fooooo`00MOooool3o`00037ooooo00?o003oooooooooool0
oooooonjooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oooooooooo
o`3ooooookcooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool0
0ol00?ooooooooooo`3ooooookcooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000oooo
ooooool0<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000ooooooooool0E_ooool007Go
oooo0ol0000aooooo`03o`00oooooooooooo0?oooooo^_ooool3o`0005Sooooo001eooooo`03o`00
0?oooooooooo037ooooo00?o003oooooooooool0oooooonlooooo`03o`000?oooooooooo05Kooooo
001Oooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Oooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000ooooooooool0E_ooool005kooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo037o
oooo00?o003oooooooooool0Goooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo05Ko
oooo001Nooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01oooool5o`0000Oo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo013o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01_ooool4o`0005Sooooo001Nooooo`04o`000?ooooooooooo`0000[o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Ooooooool0003do`0005Sooooo001Nooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00003oooooooooooooE?ooool005oooooo0_l00009oooo
o`?o0000oooooooooooooeGooooo003ooooooooooooo`_ooool00?ooooooooooooo2ooooo`00oooo
oooooooool;ooooo003ooooooooooooo`_ooool00?ooooooooooooo2ooooo`00V?ooool00ol0003o
ooooooooo`0<ooooo`?o0000;_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Co
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Zooooo`?o00008_ooool3o`0002Oo
oooo00?o0000ooooooooool0N_ooool009Oooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Q?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo07Wooooo002Gooooo`03o`000?oooooooooo00Go000000?o
ooooo`000?l000000ol00002ooooo`Co00000_ooool3o`0000;ooooo0ol000000ooooooo0000o`00
0006ooooo`05o`000?oooooo0000ooooool000000_ooool3o`0000?ooooo1?l00002ooooo`?o0000
1Oooool00ol0003oooooooooo`05ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`Go0000
00?oooooo`000?l000000_l00008ooooo`Co00000oooool4o`000003ooooool0003o000000?o0000
00Coooooo`000?l0003ooooo0_l00002ooooo`?o00000_ooool3o`000003ooooool0003o000000Ko
oooo1Ol00007ooooo`Go000000?oooooo`000?l000000ol00002ooooo`?o00000_ooool01Ol0003o
ooooo`000?oooooo000000;ooooo0ol00002ooooo`?o000000?oooooo`000?l000000_ooool2o`00
00?ooooo0ol00002ooooo`?o000000?oooooo`000?l000000oooool00ol0003oooooooooo`07oooo
o`?o00000oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Oooooo0ol00003oooo
o`?o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0000Cooooo00Co0000oooo
oooooooooooo1Ol00003ooooo`;o00001?ooool2o`0000Cooooo0_l00007ooooo`03o`000?oooooo
oooo00Oooooo1Ol000000ooooooo0000o`000003o`000005ooooool0003o0000o`000?ooool01_l0
0003ooooo`?o00000oooool4o`000005ooooool0003o0000o`000?ooool01Ol000000ooooooo0000
o`000002ooooo`;o000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool4o`0000Oo
oooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o00001oooool3o`0000Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1iooooo`00Uoooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`07o`000?ooooooooooooooool0003ooooo
o`000006ooooo`04o`000?ooooooooooo`0000Oooooo00Oo0000ooooool0003oooooo`000?oooooo
000000?ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool0000?ooooo`05o`000?oo
ooooooooooooool000002oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Sooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000005ooooo`07o`000?oooooo0000ooooool0003ooooo
o`000006ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00006
ooooo`04o`000?ooooooooooo`0000gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooo0000013ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Ko
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`08ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`00017ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00
0002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000003
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0NOooool009Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooo`000004o`0000;ooooo00Co0000oooooooooooo00001oooool01ol0003ooooo
o`000?oooooo0000ooooool000000oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo
00Go00003oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00002ooooo`?o00001?ooool00ol0003ooooooooo
o`02ooooo`;o00000oooool5o`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooooooo1Ol000001ooooooo
0000ooooool0003oooooo`000?ooool01Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00_ooool5o`0000;ooooo00Co0000oooooooooooo00003Oooool02ol0003ooooo
oooooooooooo0000ooooool0003oooooo`000?oooooo000000oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`?o00000oooool01?l0003ooooooooo
ool00002ooooo`?o00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1hooooo`00Uoooool01?l0003ooooo
ooooooooool3o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo0000
00?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`07o`000?oooooo
0000ooooool0003oooooo`000003ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`0;ooooo`;o00003_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool01_ooool3o`0000;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01oooool3o`0000Cooooo
00Go0000ooooooooooooooooo`000003ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000=ooooo`0;o`000?oooooo
ooooooooool0003oooooo`000?oooooo0000ooooool000003oooool00ol0003oooooooooo`03oooo
o`;o00002Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00[ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`06
o`000?ooooooooooo`000?oooooo00001_ooool01_l0003oooooooooool0003oooooo`0000;ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1iooooo`00Uoooool01Ol0003ooooooooo
oooooooo000000Cooooo0ol00004ooooo`Go000000Coooooo`000?l0003o00000_ooool4o`0000So
oooo0_l000000ooooooo0000ooooo`02ooooo`?o00000oooool3o`0000?ooooo0ol0000@ooooo`03
o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000_ooool2o`0000Gooooo00?o0000ooooooooool00_oo
ool01?l0003oooooo`000?l00002ooooo`?o00000_ooool4o`0000Sooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool3o`0000;o
oooo0_l000000ooooooo0000ooooo`02ooooo`?o00000_ooool4o`0000;ooooo1?l00003ooooo`?o
00000_ooool4o`0000oooooo0ol00002ooooo`Ko00003_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`07oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00;ooooo0ol00003ooooo`Co00000oooool4o`000003ooooool0003o000000;o
00000oooool2o`0000?ooooo1?l00002ooooo`Co00000_ooool2o`000004ooooool0003o0000oooo
o`Co00000oooool5o`0000Kooooo0ol00003ooooo`Co00002_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0NOooool009Sooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo013ooooo00Go0000oooo
ooooooooooooo`00000:ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Dooooo`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0<oooool2o`0000?ooooo00Go0000
ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000;ooooo0_l00009ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00004Oooool01?l0003oooooooooool0001Fooooo`;o0000
2_ooool00ol0003oooooooooo`1jooooo`00V_ooool5o`0000?ooooo00?o0000ooooooooool09ooo
ool2o`0001?ooooo0ol0000<ooooo`?o00000_ooool4o`0000Sooooo1?l00008ooooo`?o00000ooo
ool2o`0001Oooooo0ol00008ooooo`Go000000Coooooo`000?l0003o00007?ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo00;ooooo0ol0000:ooooo`;o00001?ooool00ol0003ooooo
ooooo`08ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00004Oooool5o`0000?ooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08Gooooo
003ooooooooooooo`_ooool00?ooooooooooooo2ooooo`00\
\>"],
  ImageRangeCache->{{{0, 703}, {116.312, 0}} -> {-0.857537, -0.287112, \
0.00506768, 0.00506768}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .08572 L
.13683 .08802 L
.15332 .0899 L
.16917 .09146 L
.18605 .09286 L
.2023 .09396 L
.21957 .09487 L
.22822 .09522 L
.23621 .0955 L
.24398 .09571 L
.24794 .0958 L
.25221 .09588 L
.25646 .09595 L
.26035 .09599 L
.26222 .09601 L
.26426 .09603 L
.26605 .09604 L
.26798 .09605 L
.26913 .09606 L
.27019 .09606 L
.2712 .09606 L
.27172 .09606 L
.272 .09606 L
.27228 .09606 L
.27278 .09606 L
.27325 .09607 L
.27375 .09607 L
.27429 .09607 L
.27477 .09606 L
.27527 .09606 L
.2757 .09606 L
.27617 .09606 L
.27731 .09606 L
.27834 .09606 L
.28068 .09605 L
.28274 .09603 L
.28491 .09602 L
.28889 .09598 L
.29314 .09592 L
.30079 .09578 L
.30968 .09557 L
.31808 .09531 L
.33411 .09468 L
.35116 .09382 L
.36758 .0928 L
.38336 .09166 L
.40017 .09027 L
.41635 .08878 L
.43355 .08703 L
Mistroke
.45011 .08519 L
.46605 .08328 L
.48301 .08112 L
.49933 .0789 L
.5 .07881 L
Mfstroke
.5 .07881 m
.5161 .07674 L
.53365 .07486 L
.55014 .07345 L
.566 .07241 L
.57484 .07196 L
.58288 .07162 L
.59123 .07136 L
.59913 .07117 L
.60316 .0711 L
.60538 .07108 L
.60745 .07105 L
.60936 .07104 L
.6111 .07102 L
.61203 .07102 L
.61304 .07101 L
.6136 .07101 L
.61411 .07101 L
.6146 .07101 L
.61513 .07101 L
.61567 .07101 L
.61596 .07101 L
.61623 .07101 L
.61672 .07101 L
.61725 .07101 L
.61754 .07101 L
.61786 .07101 L
.61816 .07101 L
.61844 .07101 L
.61897 .07101 L
.61953 .07101 L
.62055 .07101 L
.62151 .07102 L
.62368 .07103 L
.62563 .07105 L
.62741 .07107 L
.63143 .07112 L
.63552 .07119 L
.63932 .07127 L
.64795 .0715 L
.65647 .0718 L
.66421 .07213 L
.68087 .07303 L
.6969 .07413 L
.71395 .07553 L
.73037 .0771 L
.74615 .0788 L
.76296 .0808 L
.77914 .0829 L
.79634 .08532 L
Mistroke
.8129 .0878 L
.82884 .09033 L
.8458 .09316 L
.86212 .09601 L
.87947 .09915 L
.89619 .10229 L
.89683 .10241 L
Mfstroke
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{704, 117.312},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;00000MB000`400?l00000o`00003ooooooooo
oooool;ooooo002Xooooo`;o0000F_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
05[ooooo0ol0001Jooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000F?ooool5o`00
08_ooooo002Wooooo`04o`000?ooooooooooo`0005Sooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000005[ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool00000F?ooool01?l0003oooooooooool0002;ooooo`00
Yoooool01?l0003oooooooooool0001Hooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0Eoooool00ol0003oooooooooo`2;ooooo`00Yoooool01?l0003oooooooooool0001Hoooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`2:
ooooo`00Yoooool01?l0003oooooooooool0001Hooooo`04o`000?ooooooooooo`0000Oooooo1?l0
001Kooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01oooool4o`0005Sooooo00Go
0000ooooooooooooooooo`00002;ooooo`00Yoooool01?l0003oooooooooool0001Hooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0Foooool2o`0005_ooooo0_l00009ooooo`03
o`000?oooooooooo05Wooooo00Go0000ooooooooooooooooo`00002;ooooo`00Z?ooool2o`0005[o
oooo0_l00008ooooo`Go0000F_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Oo
oooo1Ol0001Hooooo`?o0000S?ooool00?ooooooooooooo2ooooo`00oooooooooooool;ooooo003o
oooooooooooo`_ooool00?ooooooooooooo2ooooo`00oooooooooooool;ooooo003ooooooooooooo
`_ooool00?ooooooooooooo2ooooo`00Goooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0
0007oooooooo0000m?l0001Hooooo`00G_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo05Kooooo001Gooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Oooooo1Ol00007ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo1?l0001Hooooo`00G_oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooo
okcooooo00?o0000ooooooooool0E_ooool005oooooo0_l00009ooooo`?o00002?ooool3o`00037o
oooo00?o003oooooooooool0oooooonjooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000ooooooooool0E_ooool007Gooooo00?o
0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000ooooooooool0E_oo
ool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000
ooooooooool0E_ooool007Gooooo0ol0000aooooo`03o`00oooooooooooo0?oooooo^_ooool3o`00
05Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonlooooo`03
o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0
oooooonlooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o
003oooooooooool0oooooonlooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool0
0ol00?ooooooooooo`3ooooook[ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aoooo
o`03o`00oooooooooooo0?oooooo_?ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003o
ooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_?ooool00ol0003oooooooooo`1Fooooo`00
MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_?ooool00ol0003ooooo
ooooo`1Fooooo`00MOooool3o`00037ooooo00?o003oooooooooool0oooooonjooooo`?o0000F?oo
ool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000
ooooooooool0E_ooool005oooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00008oooo
o`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonlooooo`03o`000?oooooooooo
05Kooooo001Nooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_?ooool00ol0003oooooooooo`1Foooo
o`00Eoooool5o`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07oooo
o`Go0000;oooool00ol00?ooooooooooo`3ooooookWooooo1?l0001Hooooo`00G_ooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Oooool00ol0
0?ooooooooooo`3ooooookcooooo00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003ooooo
ooooool0oooooonlooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?ooooooooooo`00
00Sooooo0_l00009ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonloooo
o`03o`000?oooooooooo05Kooooo001Oooooo`;o00002_ooool00ol0003oooooooooo`07ooooo`?o
0000<Oooool00ol00?ooooooooooo`3ooooook[ooooo0ol0001Hooooo`00MOooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo0?ooooooVOooool2o`00o`03ooooool00?oo003o01kooooo
00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oooooooooo
o`3ooooooi[ooooo00?o003oooooool00?l07oooool00ol0003oooooooooo`1Fooooo`00MOooool0
0ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?ooooooVoooool00ol00?ooooooooooo`0N
ooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3ooooo
oi[ooooo00?o003oooooool00?l07Oooool3o`0005Sooooo001eooooo`03o`000?oooooooooo037o
oooo00?o003oooooooooool0oooooonIooooo`;o003o00?oooooo`00ool00?l07_ooool00ol0003o
ooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo
_?ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooo
oooooooo0?oooooo_?ooool00ol0003oooooooooo`1Fooooo`00MOooool3o`00037ooooo00?o003o
ooooooooool0oooooonjooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol0
0?ooooooooooo`3ooooookcooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000oooooooo
ool0<Oooool00ol00?ooooooooooo`3Ooooooc[oo`00X_ooool00ol0003oooooooooo`1Fooooo`00
MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0=Oooooo2?oo000joooooa3oo`00
T_ooool00ol0003oooooooooo`1Fooooo`00MOooool3o`00033ooooo1?l00031ooooo`Co00002_oo
ool8ool005;ooooo2Ooo001Eooooo`?o0000;oooool3o`0005Sooooo001[ooooo`;o00002?ooool0
0ol0003oooooooooo`0^ooooo`;o00001?l00?l00ol0003oooooooooo`2looooo`;o00001?ooool0
0ol0003oo`00ool00007ool006?ooooo2?oo001;ooooo`;o00000oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo05Kooooo001Zooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool0;_ooool00ol0003o003oo`00o`03o`00o`03o`000?oooooooooo0;_ooooo2?oo001d
ooooo`Soo`00@oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0E_ooool006[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0]
ooooo`03o`000?l00?oo003o00Go003o00?o0000ooooooooool0/_ooool8ool00003o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0NOooool8ool003[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo05Kooooo001Zooooo`04o`000?oooooooooo
o`0000Oooooo1Ol00007ooooobCo003o00Co0000o`00ool00?oo003o1Ooo002[o`0000Woo`00U?l0
0008ool003Ko00000ol00?l00ol0003o003oo`00o`0Ro`00o`Sooooo1?l0001Hooooo`00J_ooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo02gooooo00?o0000o`00ool00?l01Ol0
0?l00ol0003oo`00ool00006ool009_ooooo2?oo000Aooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0ROooool9ool002Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo05Kooooo001Zooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooooooool0;_ooool00ol0003o003oo`00o`03o`00o`03o`000?oooooooooo00Oooooo2Ooo
002:ooooo`Soo`006_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?ooooo2?oo
000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`1Fooooo`00Joooool2o`0000Sooooo00?o0000ooooooooool0;_ooool3o`000003o`00ool0003o
000001?ooooo2?oo001aoooooa7oo`008_ooool3o`0000;ooooo0_l0002Mooooo`Koo`006oooool3
o`0000;ooooo0_l0000`ooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol0
003oooooooooo`0Kooooo`Soo`00HOooool8ool003Kooooo0_l0002Uooooo`Coo`006_ooool2o`00
033ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo02?o
oooo4Ooo000hoooooaSoo`00jOooool6ool004Sooooo00?o0000ooooooooool0E_ooool007Gooooo
00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`0dooooocSoo`00ooooool8ooooo`Koo`00
@_ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooo
oooooooo0?ooooooN_ooool5ool003gooooo00?o0000ooooooooool0E_ooool007Gooooo0ol0000a
ooooo`03o`00oooooooooooo0?ooooooOoooool6ool003Gooooo0ol0001Hooooo`00MOooool00ol0
003oooooooooo`0aooooo`03o`00oooooooooooo0?ooooooQOooool4ool003?ooooo00?o0000oooo
ooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`08ooooo`?o
0000`Oooool5o`000<;ooooo0ol0000Uooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`00
0?oooooooooo037ooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`31ooooo`04o`00
0?ooooooooooo`000<7ooooo00Go0000ooooooooooooooooo`00000Tooooo`03o`000?oooooooooo
05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo0<;o
oooo00?o0000ooooooooool0aOooool00ol0003oooooooooo`0Pooooo`?o0000F?ooool007Gooooo
00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo0<?ooooo
00?o0000ooooooooool0`_ooool2o`0002Gooooo00?o0000ooooooooool0E_ooool007Gooooo00?o
0000ooooooooool0<Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo0<3ooooo00Go
0000ooooooooooooooooo`000035ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`08ooooo`;o0000`_oo
ool01Ol0003ooooooooooooooooo00000<7ooooo00Go0000ooooooooooooooooo`00000Tooooo`03
o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`07ooooo`;o003o
00?o0000ooooooooool0`Oooool3o`000<?ooooo0ol0000Sooooo`?o0000F?ooool005oooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo037ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`3ooooook7ooooo00?o0000ooooooooool0E_oo
ool005kooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo037ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`3ooooook3ooooo00?o
0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`3ooooook3ooooo00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`07ooooo`Go0000;oooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooo003o0?oooooo[_ooool4o`0005Sooooo001Nooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Sooooo00?o
003oooooool00?l0oooooonaooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?oooooo
ooooo`0000Sooooo0_l00009ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool01ooo
ool2o`00o`03ooooool00?oo003o0?oooooo/?ooool00ol0003oooooooooo`1Fooooo`00Goooool2
o`0000[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0aooooo`03o`00oooooooo
oooo0?oooooo_?ooool00ol0003oooooooooo`1Fooooo`00MOooool3o`00037ooooo00?o003ooooo
ooooool0oooooonjooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oo
ooooooooo`3ooooookcooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000ooooooooool0E_ooool007Gooooo0ol0
000aooooo`03o`00oooooooooooo0?oooooo^_ooool3o`0005Sooooo001eooooo`03o`000?oooooo
oooo037ooooo00?o003oooooooooool0oooooonlooooo`03o`000?oooooooooo05Kooooo001eoooo
o`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonlooooo`03o`000?oooooooooo
05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonlooooo`03
o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3ooooook[ooooo
0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_?oo
ool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooo
oooo0?oooooo_?ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aoooo
o`03o`00oooooooooooo0?oooooo_?ooool00ol0003oooooooooo`1Fooooo`00MOooool3o`00037o
oooo00?o003oooooooooool0oooooonjooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000ooooooooool0E_ooool005oooooo0_l0
0004ooooo`04o`000?ooooooooooooooo`Go00001oooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo0?oooooo_?ooool00ol0003oooooooooo`1Fooooo`00G_ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0<Oooool00ol00?oo
ooooooooo`1Oooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0E_ooool005kooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07ooooo`Go00001oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool04?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`06ooooo`Co0000F?ooool005kooooo00Co0000oooooooooooo00002_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1Fooooo`00G_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000001oooooooo`000?Co0000F?ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo00000?oooooooooooomDooooo`00Goooool2o`0000Wooooo0ol0003ooooo
ooooooooEOooool00?ooooooooooooo2ooooo`00oooooooooooool;ooooo003ooooooooooooo`_oo
ool00?ooooooooooooo2ooooo`00oooooooooooool;ooooo002Hooooo`03o`000?oooooooooo00co
oooo0ol0000^ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Q?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo06[ooooo0ol0000Rooooo`?o00009oooool00ol0003o
ooooooooo`1jooooo`00Uoooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0NOooool009Oooooo00?o0000ooooooooool01Ol000000ooooooo0000o`00
0003o`0000;ooooo1?l00002ooooo`?o00000_ooool3o`000003ooooool0003o000000Kooooo00Go
0000ooooool0003oooooo`000002ooooo`?o00000oooool4o`0000;ooooo0ol00005ooooo`03o`00
0?oooooooooo00Gooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo1Ol000000ooooooo0000
o`000002o`0000Sooooo1?l00003ooooo`Co000000?oooooo`000?l000000ol000001?oooooo0000
o`000?ooool2o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l000001_ooool5o`0000Oo
oooo1Ol000000ooooooo0000o`000003o`0000;ooooo0ol00002ooooo`05o`000?oooooo0000oooo
ool000000_ooool3o`0000;ooooo0ol000000ooooooo0000o`000002ooooo`;o00000oooool3o`00
00;ooooo0ol000000ooooooo0000o`000003ooooo`03o`000?oooooooooo00Oooooo0ol00003oooo
o`03o`000?oooooo000000Gooooo00?o0000ooooooooool01oooool3o`0000?ooooo0ol00004oooo
o`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001?ooool01?l0003oooooooooooooool5
o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000Oooooo00?o0000ooooooooool01oooool5
o`000003ooooool0003o000000?o000000Goooooo`000?l0003o0000ooooo`06o`0000?ooooo0ol0
0003ooooo`Co000000Goooooo`000?l0003o0000ooooo`05o`000003ooooool0003o000000;ooooo
0_l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`Co00001oooool5o`000005
ooooool0003o0000o`000?ooool00_l00007ooooo`?o00001?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo07Wooooo002Gooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Kooooo
00Co0000oooooooooooo00001oooool01ol0003oooooo`000?oooooo0000ooooool000000oooool0
0ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000Gooooo00Oo0000ooooool0003oooooo`000?oooooo000000Kooooo
00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Kooooo00Co0000
oooooooooooo00003Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool00000
4?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00004Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1iooooo`00U_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooo000000Co00000_ooool01?l0003oooooooooool00007ooooo`07o`000?oooooo0000ooooool0
003oooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01Ol0000?oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000;ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0_l0
0003ooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooooooool5o`000007ooooool0003oooooo`00
0?oooooo0000ooooo`05o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`02ooooo`Go00000_ooool01?l0003oooooooooool0000=ooooo`0;o`000?ooooooooooooooool0
003oooooo`000?oooooo0000ooooool000003oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`00017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo
0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo07Sooooo002Gooooo`04o`000?ooooooooooooooo`?o
00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo00Oo0000ooooool0003oooooo`00
0?oooooo000000?ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00_ooooo0_l0000>ooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooooooo`06ooooo`?o00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00002_ooool00ol0003oooooooooo`07ooooo`?o00001?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000000ooo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000gooooo00_o0000ooooooooooooooooo`00
0?oooooo0000ooooool0003oooooo`00000?ooooo`03o`000?oooooooooo00?ooooo0_l00009oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00oooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooo
oooo0000ooooool00006ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo07Wooooo002Gooooo`05o`000?ooooooooooooooool00000
1?ooool3o`0000Cooooo1Ol000001?oooooo0000o`000?l00002ooooo`Co00002?ooool2o`000003
ooooool0003ooooo00;ooooo0ol00003ooooo`?o00000oooool3o`00013ooooo00?o0000oooooooo
ool02?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00002ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`04o`000?oo
oooo0000o`0000;ooooo0ol00002ooooo`Co00002?ooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`?o00000_ooool2o`000003
ooooool0003ooooo00;ooooo0ol00002ooooo`Co00000_ooool4o`0000?ooooo0ol00002ooooo`Co
00003oooool3o`0000;ooooo1_l0000>ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Oooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool00_ooool3o`0000?ooooo1?l00003ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o
00000oooool4o`0000;ooooo1?l00002ooooo`;o000000Coooooo`000?l0003ooooo1?l00003oooo
o`Go00001_ooool3o`0000?ooooo1?l0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1iooooo`00V?ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo
000000[ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Co
oooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0cooooo`;o00000oooool01Ol0003ooooooooooooo
oooo000000Sooooo00Co0000oooooooooooo00000_ooool2o`0000Wooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool0000Aooooo`04o`000?ooooooooooo`0005Kooooo0_l0000:ooooo`03o`00
0?oooooooooo07[ooooo002Jooooo`Go00000oooool00ol0003oooooooooo`0Wooooo`;o00004ooo
ool3o`0000cooooo0ol00002ooooo`Co00002?ooool4o`0000Sooooo0ol00003ooooo`;o00005ooo
ool3o`0000Sooooo1Ol000001?oooooo0000o`000?l0000Looooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool00_ooool3o`0000[ooooo0_l00004ooooo`03o`000?oooooooooo00Sooooo
0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l0000Aooooo`Go00000oooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0QOooool00?oooooooooo
ooo2ooooo`00oooooooooooool;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 703}, {116.312, 0}} -> {-0.857537, -0.287112, \
0.00506768, 0.00506768}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .08095 L
.13683 .07864 L
.15332 .07676 L
.16917 .0752 L
.18605 .0738 L
.2023 .07271 L
.21957 .0718 L
.22822 .07144 L
.23621 .07117 L
.24398 .07096 L
.24794 .07087 L
.25221 .07079 L
.25646 .07072 L
.26035 .07067 L
.26222 .07065 L
.26426 .07064 L
.26605 .07062 L
.26798 .07061 L
.26913 .07061 L
.27019 .07061 L
.2712 .0706 L
.27172 .0706 L
.272 .0706 L
.27228 .0706 L
.27278 .0706 L
.27325 .0706 L
.27375 .0706 L
.27429 .0706 L
.27477 .0706 L
.27527 .0706 L
.2757 .0706 L
.27617 .0706 L
.27731 .07061 L
.27834 .07061 L
.28068 .07062 L
.28274 .07063 L
.28491 .07065 L
.28889 .07069 L
.29314 .07075 L
.30079 .07089 L
.30968 .0711 L
.31808 .07136 L
.33411 .07198 L
.35116 .07285 L
.36758 .07387 L
.38336 .07501 L
.40017 .07639 L
.41635 .07789 L
.43355 .07964 L
Mistroke
.45011 .08148 L
.46605 .08338 L
.48301 .08555 L
.49933 .08776 L
.5 .08786 L
Mfstroke
.5 .08786 m
.5161 .08993 L
.53365 .09181 L
.55014 .09321 L
.566 .09426 L
.57484 .09471 L
.58288 .09504 L
.59123 .09531 L
.59913 .09549 L
.60316 .09556 L
.60538 .09559 L
.60745 .09561 L
.60936 .09563 L
.6111 .09564 L
.61203 .09565 L
.61304 .09565 L
.6136 .09565 L
.61411 .09566 L
.6146 .09566 L
.61513 .09566 L
.61567 .09566 L
.61596 .09566 L
.61623 .09566 L
.61672 .09566 L
.61725 .09566 L
.61754 .09566 L
.61786 .09566 L
.61816 .09566 L
.61844 .09566 L
.61897 .09566 L
.61953 .09566 L
.62055 .09565 L
.62151 .09565 L
.62368 .09564 L
.62563 .09562 L
.62741 .0956 L
.63143 .09555 L
.63552 .09548 L
.63932 .0954 L
.64795 .09517 L
.65647 .09487 L
.66421 .09453 L
.68087 .09363 L
.6969 .09254 L
.71395 .09113 L
.73037 .08957 L
.74615 .08787 L
.76296 .08587 L
.77914 .08376 L
.79634 .08135 L
Mistroke
.8129 .07886 L
.82884 .07633 L
.8458 .0735 L
.86212 .07066 L
.87947 .06751 L
.89619 .06438 L
.89683 .06426 L
Mfstroke
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{704, 117.312},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;00000MB000`400?l00000o`00003ooooooooo
oooool;ooooo002Xooooo`;o0000F_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
05[ooooo0ol0001Jooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000F?ooool5o`00
08_ooooo002Wooooo`04o`000?ooooooooooo`0005Sooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000005[ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool00000F?ooool01?l0003oooooooooool0002;ooooo`00
Yoooool01?l0003oooooooooool0001Hooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0Eoooool00ol0003oooooooooo`2;ooooo`00Yoooool01?l0003oooooooooool0001Hoooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`2:
ooooo`00Yoooool01?l0003oooooooooool0001Hooooo`04o`000?ooooooooooo`0000Oooooo1?l0
001Kooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01oooool4o`0005Sooooo00Go
0000ooooooooooooooooo`00002;ooooo`00Yoooool01?l0003oooooooooool0001Hooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0Foooool2o`0005_ooooo0_l00009ooooo`03
o`000?oooooooooo05Wooooo00Go0000ooooooooooooooooo`00002;ooooo`00Z?ooool2o`0005[o
oooo0_l00008ooooo`Go0000F_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Oo
oooo1Ol0001Hooooo`?o0000S?ooool00?ooooooooooooo2ooooo`00oooooooooooool;ooooo003o
oooooooooooo`_ooool00?ooooooooooooo2ooooo`00oooooooooooool;ooooo003ooooooooooooo
`_ooool00?ooooooooooooo2ooooo`00Goooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0
0007oooooooo0000m?l0001Hooooo`00G_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo05Kooooo001Gooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Oooooo1Ol00007ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo1?l0001Hooooo`00G_oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooo
okcooooo00?o0000ooooooooool0E_ooool005oooooo0_l00009ooooo`?o00002?ooool3o`00037o
oooo00?o003oooooooooool0oooooonjooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000ooooooooool0E_ooool007Gooooo00?o
0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000ooooooooool0E_oo
ool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000
ooooooooool0E_ooool007Gooooo0ol0000aooooo`03o`00oooooooooooo0?oooooo^_ooool3o`00
05Sooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonlooooo`03
o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0
oooooonlooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o
003oooooooooool0oooooonlooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool0
0ol00?ooooooooooo`3ooooook[ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aoooo
o`03o`00oooooooooooo0?oooooo_?ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003o
ooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_?ooool00ol0003oooooooooo`1Fooooo`00
MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_?ooool00ol0003ooooo
ooooo`1Fooooo`00MOooool3o`00037ooooo00?o003oooooooooool0oooooonjooooo`?o0000F?oo
ool007Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000
ooooooooool0E_ooool005oooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00008oooo
o`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonlooooo`03o`000?oooooooooo
05Kooooo001Nooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_?ooool00ol0003oooooooooo`1Foooo
o`00Eoooool5o`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`07oooo
o`Go0000;oooool00ol00?ooooooooooo`3ooooookWooooo1?l0001Hooooo`00G_ooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Oooool00ol0
0?ooooooooooo`3ooooookcooooo00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003ooooo
ooooool0oooooonlooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?ooooooooooo`00
00Sooooo0_l00009ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonloooo
o`03o`000?oooooooooo05Kooooo001Oooooo`;o00002_ooool00ol0003oooooooooo`07ooooo`?o
0000<Oooool00ol00?ooooooooooo`3ooooook[ooooo0ol0001Hooooo`00MOooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo0?ooooooVOooool2o`00o`03ooooool00?oo003o01kooooo
00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Oooool00ol00?oooooooooo
o`3ooooooi[ooooo00?o003oooooool00?l07oooool00ol0003oooooooooo`1Fooooo`00MOooool0
0ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?ooooooVoooool00ol00?ooooooooooo`0N
ooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3ooooo
oi[ooooo00?o003oooooool00?l07Oooool3o`0005Sooooo001eooooo`03o`000?oooooooooo037o
oooo00?o003oooooooooool0oooooonIooooo`;o003o00?oooooo`00ool00?l07_ooool00ol0003o
ooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo
Q_ooool3ool003?ooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0<Ooo
ool00ol00?ooooooooooo`3ooooooh;ooooo1?oo000fooooo`03o`000?oooooooooo05Kooooo001e
ooooo`?o0000<Oooool00ol00?ooooooooooo`3oooooogkooooo1?oo000hooooo`?o0000F?ooool0
07Gooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3oooooogWooooo1Ooo000noooo
o`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooooooo
ool0<ooooom2ool00?gooooo1_oo0013ooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`00
0?oooooooooo037ooooo00?o003oooooooooool08_oooolAool004;ooooo4?oo003Uooooo`Soo`00
BOooool00ol0003oooooooooo`1Fooooo`00MOooool3o`00033ooooo1?l0000Jooooo`Soo`00Hooo
ool@ool002cooooo1?l0002Oooooo`Koo`007Oooool3o`0002oooooo0ol0001Hooooo`00Joooool2
o`0000Sooooo00?o0000ooooooooool0;_ooool2o`0000Co003o00?o0000ooooooooool03oooool8
ool007_ooooo2Ooo000Qooooo`;o00001?ooool00ol0003oooooooooo`2Hooooo`Coo`008Oooool2
o`0000?ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Fooooo`00J_ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo02kooooo00?o0000o`00ool00?l00ol00?l0
0ol0003oooooooooo`06ooooo`Woo`00S?ooool8ool001Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`2Booooo`Koo`009Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0E_ooool006[ooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`0]ooooo`03o`000?l00?oo003o00Go003o2?oo002Mooooo`Soo`004?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Sooooo2Ooo000Zooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Fooooo`00J_ooool01?l0
003oooooooooool00007ooooo`Go00001ooooolTo`00o`04o`000?l00?oo003oo`00o`Coo`00[Ol0
0009ool009;o00002?oo000go`0000?o003o00?o0000o`00ool00?l08_l00?l8ooooo`Co0000F?oo
ool006[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0]ooooo`03o`000?l0
0?oo003o00Go003o00?o0000ooooooooool0/oooool8ool000Oooooo00?o0000ooooooooool0N?oo
ool8ool003[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo05Kooooo001Zooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0;_oo
ool00ol0003o003oo`00o`03o`00o`03o`000?oooooooooo0;cooooo2?oo001booooo`Soo`00@ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0E_oo
ool006_ooooo0_l00008ooooo`03o`000?oooooooooo02kooooo0ol000000ol00?oo0000o`00002o
ooooo`?o00000_ooool2o`000003oooooooo003oo`0000Ooo`00HOooool8ool004_ooooo0ol00002
ooooo`;o0000<?ooool00ol0003oooooooooo`1Fooooo`00MOooool3o`00037ooooo00?o0000oooo
ooooool0`_ooool2o`0000cooooo2?oo0018oooooa7oo`00E_ooool2o`00033ooooo0ol0001Hoooo
o`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0=Sooooo4_oo000Xooooo`ko
o`00Voooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo0>[ooooo:?oo002Yooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oo
oooooooo037ooooo00?o003oooooooooool0oooooonlooooo`03o`000?oooooooooo05Kooooo001e
ooooo`?o0000<Oooool00ol00?ooooooooooo`3ooooook[ooooo0ol0001Hooooo`00MOooool00ol0
003oooooooooo`0aooooo`03o`00oooooooooooo0?oooooo_?ooool00ol0003oooooooooo`1Foooo
o`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Sooooo0ol00031ooooo`Go
0000`_ooool3o`0002Gooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000ooooooooool0
<Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo0<7ooooo00Co0000oooooooooooo
0000`Oooool01Ol0003ooooooooooooooooo000002Cooooo00?o0000ooooooooool0E_ooool007Go
oooo0ol0000aooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool0`_ooool00ol0003o
ooooooooo`35ooooo`03o`000?oooooooooo023ooooo0ol0001Hooooo`00MOooool00ol0003ooooo
ooooo`0aooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool0`oooool00ol0003ooooo
ooooo`32ooooo`;o00009Oooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003ooooooooo
o`0aooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool0`?ooool01Ol0003ooooooooo
oooooooo00000<Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Fooooo`00MOoo
ool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo00Sooooo0_l00032ooooo`05o`000?oo
ooooooooooooool00000`Oooool01Ol0003ooooooooooooooooo000002Cooooo00?o0000oooooooo
ool0E_ooool007Gooooo0ol0000aooooo`03o`00oooooooooooo00Oooooo0_l00?l00ol0003ooooo
ooooo`31ooooo`?o0000`oooool3o`0002?ooooo0ol0001Hooooo`00Goooool2o`0000Cooooo00?o
0000ooooooooool00_ooool3o`0000Sooooo00?o0000ooooooooool0<Oooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo0?oooooo/Oooool00ol0003oooooooooo`1Fooooo`00G_ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo0?oooooo/?ooool00ol0003ooooooooo
o`1Fooooo`00G_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0<Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo0?oooooo/?oo
ool00ol0003oooooooooo`1Fooooo`00G_ooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo00Oooooo1Ol0000_ooooo`03o`00oooooooooooo00Sooooo00?o003oooooool00?l0oooo
oon^ooooo`Co0000F?ooool005kooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool02?ooool00ol00?ooooooo`00
o`3ooooook7ooooo00?o0000ooooooooool0E_ooool005kooooo00Co0000oooooooooooo00002?oo
ool2o`0000Wooooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`07ooooo`;o003o00?o
ooooo`00ool00?l0oooooon`ooooo`03o`000?oooooooooo05Kooooo001Oooooo`;o00002_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonl
ooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?ooooooooooo`3ooooo
ok[ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo0?oo
oooo_?ooool00ol0003oooooooooo`1Fooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo0?oooooo_?ooool00ol0003oooooooooo`1Fooooo`00MOooool3o`00037ooooo00?o
003oooooooooool0oooooonjooooo`?o0000F?ooool007Gooooo00?o0000ooooooooool0<Oooool0
0ol00?ooooooooooo`3ooooookcooooo00?o0000ooooooooool0E_ooool007Gooooo00?o0000oooo
ooooool0<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000ooooooooool0E_ooool007Go
oooo00?o0000ooooooooool0<Oooool00ol00?ooooooooooo`3ooooookcooooo00?o0000oooooooo
ool0E_ooool007Gooooo0ol0000aooooo`03o`00oooooooooooo0?oooooo^_ooool3o`0005Sooooo
001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonlooooo`03o`000?oo
oooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0oooooonl
ooooo`03o`000?oooooooooo05Kooooo001eooooo`03o`000?oooooooooo037ooooo00?o003ooooo
ooooool0oooooonlooooo`03o`000?oooooooooo05Kooooo001eooooo`?o0000<Oooool00ol00?oo
ooooooooo`3ooooook[ooooo0ol0001Hooooo`00MOooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo0?oooooo_?ooool00ol0003oooooooooo`1Fooooo`00Goooool2o`0000Cooooo00Co
0000oooooooooooooooo1Ol00007ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool0
oooooonlooooo`03o`000?oooooooooo05Kooooo001Nooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo05oo
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo05oo
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1Fooooo`00G_ooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo00Oooooo1Ol00007ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Ko
oooo1?l0001Hooooo`00G_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Ko
oooo001Nooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007oooo
oooo0000m?l0001Hooooo`00G_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool00000oooooooooooooeCooooo001Oooooo`;o00002Oooool3o`000?oooooooooooomEoooo
o`00oooooooooooool;ooooo003ooooooooooooo`_ooool00?ooooooooooooo2ooooo`00oooooooo
oooool;ooooo003ooooooooooooo`_ooool009Sooooo00?o0000ooooooooool03?ooool3o`0002ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0J_ooool3o`0002;ooooo0ol0000Wooooo`03o`000?oooooooooo07[o
oooo002Gooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`1Zooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1iooooo`00Uoooool00ol0003oooooooooo`05o`000003ooooool0003o000000?o00000_oo
ool4o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l000001_ooool01Ol0003oooooo`00
0?oooooo000000;ooooo0ol00003ooooo`Co00000_ooool3o`0000Gooooo00?o0000ooooooooool0
1Oooool3o`0000Gooooo00?o0000ooooooooool00oooool5o`000003ooooool0003o000000;o0000
2?ooool4o`0000?ooooo1?l000000ooooooo0000o`000003o`000004ooooool0003o0000ooooo`;o
00000_ooool3o`0000;ooooo0ol000000ooooooo0000o`000006ooooo`Go00001oooool5o`000003
ooooool0003o000000?o00000_ooool3o`0000;ooooo00Go0000ooooool0003oooooo`000002oooo
o`?o00000_ooool3o`000003ooooool0003o000000;ooooo0_l00003ooooo`?o00000_ooool3o`00
0003ooooool0003o000000?ooooo00?o0000ooooooooool01oooool3o`0000?ooooo00?o0000oooo
ool000001Oooool00ol0003oooooooooo`07ooooo`?o00000oooool3o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000?ooooo0ol00004ooooo`04o`000?ooooooooooooooo`Go00000oooool2
o`0000Cooooo0_l00004ooooo`;o00001oooool00ol0003oooooooooo`07ooooo`Go000000?ooooo
o`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00Ko00000oooool3o`0000?ooooo1?l0
00001Ooooooo0000o`000?l0003ooooo00Go000000?oooooo`000?l000000_ooool2o`000003oooo
ool0003o000000;o000000Coooooo`000?l0003ooooo1?l00007ooooo`Go000000Goooooo`000?l0
003o0000ooooo`02o`0000Oooooo0ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0NOooool009Oooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000oooool01ol0003ooooooooooooooooo0000ooooool000001_ooool01?l0003ooooo
ooooool00007ooooo`07o`000?oooooo0000ooooool0003oooooo`000003ooooo`03o`000?oooooo
000000;ooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000_ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`06o`000?oooooooooo
o`000?oooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool000000_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000001Oooool01ol0003oooooo`000?oooooo0000ooooool000001_ooool01?l0003ooooo
ooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool01?l0003oooooooooool0
000=ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooo`00000@ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Aooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo07Wooooo002Fooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000001?l0
0002ooooo`04o`000?ooooooooooo`0000Oooooo00Oo0000ooooool0003oooooo`000?oooooo0000
00?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`05o`0000oooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool2o`0000?ooooo1Ol0
0002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooooooo`Go000000Ooooooo`000?oooooo0000ooooool0003o
oooo00Go00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo1Ol0
0002ooooo`04o`000?ooooooooooo`0000gooooo00_o0000ooooooooooooooooo`000?oooooo0000
ooooool0003oooooo`00000?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00004Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0N?ooool009Oooooo00Co0000oooooooooooooooo0ol00004ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooo`000003ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool01Oooool01ol0003oooooo`000?oooooo0000ooooool00000
0oooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool02oooool2o`0000kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
00Kooooo0ol00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool0000:ooooo`03o`000?oooooooooo00Oooooo0ol00004ooooo`05o`000?ooooooooooooooool0
00000oooool02Ol0003oooooo`000?oooooo0000ooooool0003oooooo`000003ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00003Oooool02ol0003ooooooooooooooooo0000ooooool0003o
ooooo`000?oooooo000000oooooo00?o0000ooooooooool00oooool2o`0000Wooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool03oooool3o`0000Cooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003ooooo
o`0000Kooooo00Ko0000oooooooooooo0000ooooool00002ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0NOooool009Oooooo00Go0000ooooooooooooooooo`000004ooooo`?o0000
1?ooool5o`000004ooooool0003o0000o`0000;ooooo1?l00008ooooo`;o000000?oooooo`000?oo
ool00_ooool3o`0000?ooooo0ol00003ooooo`?o00004?ooool00ol0003oooooooooo`08ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000;ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00Co0000ooooool0003o0000
0_ooool3o`0000;ooooo1?l00008ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`;o000000?oooooo`000?oo
ool00_ooool3o`0000;ooooo1?l00002ooooo`Co00000oooool3o`0000;ooooo1?l0000?ooooo`?o
00000_ooool6o`0000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`?o
00000oooool4o`0000?ooooo1?l000000ooooooo0000o`000002o`0000?ooooo0_l00003ooooo`Co
00000_ooool4o`0000;ooooo0_l000001?oooooo0000o`000?ooool4o`0000?ooooo1Ol00006oooo
o`?o00000oooool4o`0000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo07Wooooo002Hooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool000002_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool01Ol0003o
oooooooooooooooo000000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo03?ooooo0_l00003ooooo`05o`000?ooooooooooooooool000002?oo
ool01?l0003oooooooooool00002ooooo`;o00002Oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`00017ooooo00Co0000oooooooooooo0000E_ooool2o`0000[ooooo00?o0000ooooooooool0
N_ooool009[ooooo1Ol00003ooooo`03o`000?oooooooooo02Oooooo0_l0000Cooooo`?o00003?oo
ool3o`0000;ooooo1?l00008ooooo`Co00002?ooool3o`0000?ooooo0_l0000Gooooo`?o00002?oo
ool5o`000004ooooool0003o0000o`0001cooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`02ooooo`?o00002_ooool2o`0000Cooooo00?o0000ooooooooool02?ooool3o`0000Cooooo
0_l00004ooooo`;o00001?ooool2o`00017ooooo1Ol00003ooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`25ooooo`00oooooooooooool;ooooo003o
oooooooooooo`_ooool00001\
\>"],
  ImageRangeCache->{{{0, 703}, {116.312, 0}} -> {-0.857537, -0.287112, \
0.00506768, 0.00506768}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .07708 L
.13683 .07106 L
.15332 .06613 L
.16917 .06205 L
.18605 .05839 L
.2023 .05551 L
.21957 .05314 L
.22822 .0522 L
.23621 .05149 L
.24398 .05093 L
.24794 .0507 L
.25221 .05049 L
.25646 .05031 L
.26035 .05019 L
.26222 .05014 L
.26426 .05009 L
.26605 .05006 L
.26798 .05004 L
.26913 .05002 L
.27019 .05001 L
.2712 .05001 L
.27172 .05001 L
.272 .05 L
.27228 .05 L
.27278 .05 L
.27325 .05 L
.27375 .05 L
.27429 .05 L
.27477 .05 L
.27527 .05 L
.2757 .05001 L
.27617 .05001 L
.27731 .05001 L
.27834 .05002 L
.28068 .05005 L
.28274 .05008 L
.28491 .05013 L
.28889 .05024 L
.29314 .05038 L
.30079 .05074 L
.30968 .0513 L
.31808 .05197 L
.33411 .05362 L
.35116 .05588 L
.36758 .05855 L
.38336 .06154 L
.40017 .06517 L
.41635 .06908 L
.43355 .07366 L
Mistroke
.45011 .07848 L
.46605 .08347 L
.48301 .08914 L
.49933 .09493 L
.5 .09517 L
Mfstroke
.5 .09517 m
.5161 .1006 L
.53365 .10552 L
.55014 .1092 L
.566 .11193 L
.57484 .11312 L
.58288 .11399 L
.59123 .11469 L
.59913 .11517 L
.60316 .11535 L
.60538 .11542 L
.60745 .11548 L
.60936 .11553 L
.6111 .11556 L
.61203 .11557 L
.61304 .11558 L
.6136 .11559 L
.61411 .11559 L
.6146 .1156 L
.61513 .1156 L
.61567 .1156 L
.61596 .1156 L
.61623 .1156 L
.61672 .1156 L
.61725 .1156 L
.61754 .1156 L
.61786 .1156 L
.61816 .1156 L
.61844 .1156 L
.61897 .1156 L
.61953 .11559 L
.62055 .11559 L
.62151 .11557 L
.62368 .11554 L
.62563 .1155 L
.62741 .11545 L
.63143 .11532 L
.63552 .11513 L
.63932 .11492 L
.64795 .11431 L
.65647 .11353 L
.66421 .11265 L
.68087 .1103 L
.6969 .10742 L
.71395 .10375 L
.73037 .09965 L
.74615 .09521 L
.76296 .08997 L
.77914 .08446 L
.79634 .07814 L
Mistroke
.8129 .07163 L
.82884 .06501 L
.8458 .0576 L
.86212 .05014 L
.87947 .04192 L
.89619 .03372 L
.89683 .0334 L
Mfstroke
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{704, 117.312},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .07561 L
.13683 .06816 L
.15332 .06207 L
.16917 .05702 L
.18605 .0525 L
.2023 .04894 L
.21957 .04601 L
.22822 .04485 L
.23621 .04397 L
.24398 .04328 L
.24794 .043 L
.25221 .04273 L
.25646 .04252 L
.26035 .04236 L
.26222 .0423 L
.26426 .04225 L
.26605 .04221 L
.26798 .04217 L
.26913 .04216 L
.27019 .04215 L
.2712 .04214 L
.27172 .04214 L
.272 .04214 L
.27228 .04214 L
.27278 .04213 L
.27325 .04213 L
.27375 .04213 L
.27429 .04213 L
.27477 .04213 L
.27527 .04214 L
.2757 .04214 L
.27617 .04214 L
.27731 .04215 L
.27834 .04216 L
.28068 .04219 L
.28274 .04224 L
.28491 .04229 L
.28889 .04242 L
.29314 .04261 L
.30079 .04305 L
.30968 .04374 L
.31808 .04457 L
.33411 .0466 L
.35116 .0494 L
.36758 .05269 L
.38336 .05639 L
.40017 .06088 L
.41635 .06571 L
.43355 .07138 L
Mistroke
.45011 .07734 L
.46605 .0835 L
.48301 .09051 L
.49933 .09767 L
.5 .09797 L
Mfstroke
.5 .09797 m
.5161 .10468 L
.53365 .11075 L
.55014 .11531 L
.566 .11868 L
.57484 .12015 L
.58288 .12123 L
.59123 .1221 L
.59913 .12269 L
.60316 .12291 L
.60538 .123 L
.60745 .12307 L
.60936 .12313 L
.6111 .12317 L
.61203 .12318 L
.61304 .1232 L
.6136 .12321 L
.61411 .12321 L
.6146 .12321 L
.61513 .12322 L
.61567 .12322 L
.61596 .12322 L
.61623 .12322 L
.61672 .12322 L
.61725 .12322 L
.61754 .12322 L
.61786 .12322 L
.61816 .12322 L
.61844 .12322 L
.61897 .12321 L
.61953 .12321 L
.62055 .1232 L
.62151 .12319 L
.62368 .12314 L
.62563 .12309 L
.62741 .12303 L
.63143 .12286 L
.63552 .12264 L
.63932 .12238 L
.64795 .12163 L
.65647 .12065 L
.66421 .11958 L
.68087 .11666 L
.6969 .11311 L
.71395 .10857 L
.73037 .1035 L
.74615 .09801 L
.76296 .09153 L
.77914 .08473 L
.79634 .07692 L
Mistroke
.8129 .06887 L
.82884 .06068 L
.8458 .05152 L
.86212 .04231 L
.87947 .03214 L
.89619 .022 L
.89683 .02161 L
Mfstroke
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{704, 117.312},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .07708 L
.13683 .07106 L
.15332 .06613 L
.16917 .06205 L
.18605 .05839 L
.2023 .05551 L
.21957 .05314 L
.22822 .0522 L
.23621 .05149 L
.24398 .05093 L
.24794 .0507 L
.25221 .05049 L
.25646 .05031 L
.26035 .05019 L
.26222 .05014 L
.26426 .05009 L
.26605 .05006 L
.26798 .05004 L
.26913 .05002 L
.27019 .05001 L
.2712 .05001 L
.27172 .05001 L
.272 .05 L
.27228 .05 L
.27278 .05 L
.27325 .05 L
.27375 .05 L
.27429 .05 L
.27477 .05 L
.27527 .05 L
.2757 .05001 L
.27617 .05001 L
.27731 .05001 L
.27834 .05002 L
.28068 .05005 L
.28274 .05008 L
.28491 .05013 L
.28889 .05024 L
.29314 .05038 L
.30079 .05074 L
.30968 .0513 L
.31808 .05197 L
.33411 .05362 L
.35116 .05588 L
.36758 .05855 L
.38336 .06154 L
.40017 .06517 L
.41635 .06908 L
.43355 .07366 L
Mistroke
.45011 .07848 L
.46605 .08347 L
.48301 .08914 L
.49933 .09493 L
.5 .09517 L
Mfstroke
.5 .09517 m
.5161 .1006 L
.53365 .10552 L
.55014 .1092 L
.566 .11193 L
.57484 .11312 L
.58288 .11399 L
.59123 .11469 L
.59913 .11517 L
.60316 .11535 L
.60538 .11542 L
.60745 .11548 L
.60936 .11553 L
.6111 .11556 L
.61203 .11557 L
.61304 .11558 L
.6136 .11559 L
.61411 .11559 L
.6146 .1156 L
.61513 .1156 L
.61567 .1156 L
.61596 .1156 L
.61623 .1156 L
.61672 .1156 L
.61725 .1156 L
.61754 .1156 L
.61786 .1156 L
.61816 .1156 L
.61844 .1156 L
.61897 .1156 L
.61953 .11559 L
.62055 .11559 L
.62151 .11557 L
.62368 .11554 L
.62563 .1155 L
.62741 .11545 L
.63143 .11532 L
.63552 .11513 L
.63932 .11492 L
.64795 .11431 L
.65647 .11353 L
.66421 .11265 L
.68087 .1103 L
.6969 .10742 L
.71395 .10375 L
.73037 .09965 L
.74615 .09521 L
.76296 .08997 L
.77914 .08446 L
.79634 .07814 L
Mistroke
.8129 .07163 L
.82884 .06501 L
.8458 .0576 L
.86212 .05014 L
.87947 .04192 L
.89619 .03372 L
.89683 .0334 L
Mfstroke
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{704, 117.312},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .08095 L
.13683 .07864 L
.15332 .07676 L
.16917 .0752 L
.18605 .0738 L
.2023 .07271 L
.21957 .0718 L
.22822 .07144 L
.23621 .07117 L
.24398 .07096 L
.24794 .07087 L
.25221 .07079 L
.25646 .07072 L
.26035 .07067 L
.26222 .07065 L
.26426 .07064 L
.26605 .07062 L
.26798 .07061 L
.26913 .07061 L
.27019 .07061 L
.2712 .0706 L
.27172 .0706 L
.272 .0706 L
.27228 .0706 L
.27278 .0706 L
.27325 .0706 L
.27375 .0706 L
.27429 .0706 L
.27477 .0706 L
.27527 .0706 L
.2757 .0706 L
.27617 .0706 L
.27731 .07061 L
.27834 .07061 L
.28068 .07062 L
.28274 .07063 L
.28491 .07065 L
.28889 .07069 L
.29314 .07075 L
.30079 .07089 L
.30968 .0711 L
.31808 .07136 L
.33411 .07198 L
.35116 .07285 L
.36758 .07387 L
.38336 .07501 L
.40017 .07639 L
.41635 .07789 L
.43355 .07964 L
Mistroke
.45011 .08148 L
.46605 .08338 L
.48301 .08555 L
.49933 .08776 L
.5 .08786 L
Mfstroke
.5 .08786 m
.5161 .08993 L
.53365 .09181 L
.55014 .09321 L
.566 .09426 L
.57484 .09471 L
.58288 .09504 L
.59123 .09531 L
.59913 .09549 L
.60316 .09556 L
.60538 .09559 L
.60745 .09561 L
.60936 .09563 L
.6111 .09564 L
.61203 .09565 L
.61304 .09565 L
.6136 .09565 L
.61411 .09566 L
.6146 .09566 L
.61513 .09566 L
.61567 .09566 L
.61596 .09566 L
.61623 .09566 L
.61672 .09566 L
.61725 .09566 L
.61754 .09566 L
.61786 .09566 L
.61816 .09566 L
.61844 .09566 L
.61897 .09566 L
.61953 .09566 L
.62055 .09565 L
.62151 .09565 L
.62368 .09564 L
.62563 .09562 L
.62741 .0956 L
.63143 .09555 L
.63552 .09548 L
.63932 .0954 L
.64795 .09517 L
.65647 .09487 L
.66421 .09453 L
.68087 .09363 L
.6969 .09254 L
.71395 .09113 L
.73037 .08957 L
.74615 .08787 L
.76296 .08587 L
.77914 .08376 L
.79634 .08135 L
Mistroke
.8129 .07886 L
.82884 .07633 L
.8458 .0735 L
.86212 .07066 L
.87947 .06751 L
.89619 .06438 L
.89683 .06426 L
Mfstroke
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{704, 117.312},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .08572 L
.13683 .08802 L
.15332 .0899 L
.16917 .09146 L
.18605 .09286 L
.2023 .09396 L
.21957 .09487 L
.22822 .09522 L
.23621 .0955 L
.24398 .09571 L
.24794 .0958 L
.25221 .09588 L
.25646 .09595 L
.26035 .09599 L
.26222 .09601 L
.26426 .09603 L
.26605 .09604 L
.26798 .09605 L
.26913 .09606 L
.27019 .09606 L
.2712 .09606 L
.27172 .09606 L
.272 .09606 L
.27228 .09606 L
.27278 .09606 L
.27325 .09607 L
.27375 .09607 L
.27429 .09607 L
.27477 .09606 L
.27527 .09606 L
.2757 .09606 L
.27617 .09606 L
.27731 .09606 L
.27834 .09606 L
.28068 .09605 L
.28274 .09603 L
.28491 .09602 L
.28889 .09598 L
.29314 .09592 L
.30079 .09578 L
.30968 .09557 L
.31808 .09531 L
.33411 .09468 L
.35116 .09382 L
.36758 .0928 L
.38336 .09166 L
.40017 .09027 L
.41635 .08878 L
.43355 .08703 L
Mistroke
.45011 .08519 L
.46605 .08328 L
.48301 .08112 L
.49933 .0789 L
.5 .07881 L
Mfstroke
.5 .07881 m
.5161 .07674 L
.53365 .07486 L
.55014 .07345 L
.566 .07241 L
.57484 .07196 L
.58288 .07162 L
.59123 .07136 L
.59913 .07117 L
.60316 .0711 L
.60538 .07108 L
.60745 .07105 L
.60936 .07104 L
.6111 .07102 L
.61203 .07102 L
.61304 .07101 L
.6136 .07101 L
.61411 .07101 L
.6146 .07101 L
.61513 .07101 L
.61567 .07101 L
.61596 .07101 L
.61623 .07101 L
.61672 .07101 L
.61725 .07101 L
.61754 .07101 L
.61786 .07101 L
.61816 .07101 L
.61844 .07101 L
.61897 .07101 L
.61953 .07101 L
.62055 .07101 L
.62151 .07102 L
.62368 .07103 L
.62563 .07105 L
.62741 .07107 L
.63143 .07112 L
.63552 .07119 L
.63932 .07127 L
.64795 .0715 L
.65647 .0718 L
.66421 .07213 L
.68087 .07303 L
.6969 .07413 L
.71395 .07553 L
.73037 .0771 L
.74615 .0788 L
.76296 .0808 L
.77914 .0829 L
.79634 .08532 L
Mistroke
.8129 .0878 L
.82884 .09033 L
.8458 .09316 L
.86212 .09601 L
.87947 .09915 L
.89619 .10229 L
.89683 .10241 L
Mfstroke
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{704, 117.312},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .08958 L
.13683 .09561 L
.15332 .10053 L
.16917 .10462 L
.18605 .10828 L
.2023 .11115 L
.21957 .11353 L
.22822 .11446 L
.23621 .11518 L
.24398 .11573 L
.24794 .11597 L
.25221 .11618 L
.25646 .11635 L
.26035 .11648 L
.26222 .11653 L
.26426 .11657 L
.26605 .1166 L
.26798 .11663 L
.26913 .11664 L
.27019 .11665 L
.2712 .11666 L
.27172 .11666 L
.272 .11666 L
.27228 .11666 L
.27278 .11666 L
.27325 .11667 L
.27375 .11667 L
.27429 .11667 L
.27477 .11666 L
.27527 .11666 L
.2757 .11666 L
.27617 .11666 L
.27731 .11665 L
.27834 .11664 L
.28068 .11662 L
.28274 .11658 L
.28491 .11654 L
.28889 .11643 L
.29314 .11628 L
.30079 .11592 L
.30968 .11536 L
.31808 .11469 L
.33411 .11305 L
.35116 .11078 L
.36758 .10812 L
.38336 .10513 L
.40017 .1015 L
.41635 .09759 L
.43355 .093 L
Mistroke
.45011 .08819 L
.46605 .0832 L
.48301 .07753 L
.49933 .07174 L
.5 .07149 L
Mfstroke
.5 .07149 m
.5161 .06606 L
.53365 .06115 L
.55014 .05746 L
.566 .05473 L
.57484 .05355 L
.58288 .05268 L
.59123 .05197 L
.59913 .0515 L
.60316 .05132 L
.60538 .05124 L
.60745 .05118 L
.60936 .05114 L
.6111 .05111 L
.61203 .05109 L
.61304 .05108 L
.6136 .05108 L
.61411 .05107 L
.6146 .05107 L
.61513 .05107 L
.61567 .05106 L
.61596 .05106 L
.61623 .05106 L
.61672 .05106 L
.61725 .05106 L
.61754 .05106 L
.61786 .05106 L
.61816 .05107 L
.61844 .05107 L
.61897 .05107 L
.61953 .05107 L
.62055 .05108 L
.62151 .05109 L
.62368 .05113 L
.62563 .05117 L
.62741 .05122 L
.63143 .05135 L
.63552 .05153 L
.63932 .05174 L
.64795 .05235 L
.65647 .05314 L
.66421 .05401 L
.68087 .05637 L
.6969 .05924 L
.71395 .06291 L
.73037 .06702 L
.74615 .07146 L
.76296 .0767 L
.77914 .0822 L
.79634 .08852 L
Mistroke
.8129 .09504 L
.82884 .10166 L
.8458 .10907 L
.86212 .11652 L
.87947 .12475 L
.89619 .13295 L
.89683 .13327 L
Mfstroke
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{704, 117.312},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.11927 .09106 L
.13683 .09851 L
.15332 .10459 L
.16917 .10964 L
.18605 .11417 L
.2023 .11772 L
.21957 .12066 L
.22822 .12181 L
.23621 .12269 L
.24398 .12338 L
.24794 .12367 L
.25221 .12393 L
.25646 .12415 L
.26035 .1243 L
.26222 .12436 L
.26426 .12442 L
.26605 .12446 L
.26798 .12449 L
.26913 .12451 L
.27019 .12452 L
.2712 .12453 L
.27172 .12453 L
.272 .12453 L
.27228 .12453 L
.27278 .12453 L
.27325 .12453 L
.27375 .12453 L
.27429 .12453 L
.27477 .12453 L
.27527 .12453 L
.2757 .12453 L
.27617 .12453 L
.27731 .12452 L
.27834 .12451 L
.28068 .12447 L
.28274 .12443 L
.28491 .12438 L
.28889 .12424 L
.29314 .12406 L
.30079 .12362 L
.30968 .12292 L
.31808 .1221 L
.33411 .12006 L
.35116 .11726 L
.36758 .11397 L
.38336 .11028 L
.40017 .10579 L
.41635 .10096 L
.43355 .09529 L
Mistroke
.45011 .08933 L
.46605 .08317 L
.48301 .07616 L
.49933 .069 L
.5 .0687 L
Mfstroke
.5 .0687 m
.5161 .06199 L
.53365 .05592 L
.55014 .05136 L
.566 .04798 L
.57484 .04652 L
.58288 .04544 L
.59123 .04457 L
.59913 .04398 L
.60316 .04376 L
.60538 .04367 L
.60745 .04359 L
.60936 .04354 L
.6111 .0435 L
.61203 .04348 L
.61304 .04347 L
.6136 .04346 L
.61411 .04346 L
.6146 .04345 L
.61513 .04345 L
.61567 .04345 L
.61596 .04345 L
.61623 .04344 L
.61672 .04344 L
.61725 .04344 L
.61754 .04345 L
.61786 .04345 L
.61816 .04345 L
.61844 .04345 L
.61897 .04345 L
.61953 .04346 L
.62055 .04347 L
.62151 .04348 L
.62368 .04352 L
.62563 .04358 L
.62741 .04363 L
.63143 .0438 L
.63552 .04403 L
.63932 .04428 L
.64795 .04504 L
.65647 .04601 L
.66421 .04709 L
.68087 .05001 L
.6969 .05356 L
.71395 .05809 L
.73037 .06316 L
.74615 .06866 L
.76296 .07513 L
.77914 .08194 L
.79634 .08975 L
Mistroke
.8129 .0978 L
.82884 .10599 L
.8458 .11514 L
.86212 .12436 L
.87947 .13453 L
.89619 .14466 L
.89683 .14506 L
Mfstroke
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{704, 117.312},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(animatUeEigen[6, Ne, \[CapitalGamma]e, TeT, Edata, nE, IndR, nR, 
        zFEigen, ZF0, 4];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.10363 .08333 L
.10404 .08333 L
.10451 .08333 L
.10496 .08333 L
.10537 .08333 L
.10575 .08333 L
.10617 .08333 L
.10662 .08333 L
.10706 .08333 L
.10754 .08333 L
.10799 .08333 L
.10841 .08333 L
.10889 .08333 L
.10917 .08333 L
.10942 .08333 L
.10989 .08333 L
.11038 .08333 L
.11063 .08333 L
.1109 .08333 L
.11137 .08333 L
.11163 .08333 L
.11188 .08333 L
.11215 .08333 L
.11244 .08333 L
.11268 .08333 L
.11296 .08333 L
.11345 .08333 L
.11393 .08333 L
.11437 .08333 L
.1148 .08333 L
.1152 .08333 L
.11564 .08333 L
.11612 .08333 L
.11659 .08333 L
.11709 .08333 L
.11752 .08333 L
.11798 .08333 L
.11826 .08333 L
.11851 .08333 L
.11878 .08333 L
.11907 .08333 L
.11956 .08333 L
.11984 .08333 L
.1201 .08333 L
.12059 .08333 L
.12103 .08333 L
.12128 .08333 L
.12154 .08333 L
.12203 .08333 L
Mistroke
.12232 .08333 L
.1226 .08333 L
.12285 .08333 L
.12311 .08333 L
.12341 .08333 L
.12372 .08333 L
.12398 .08333 L
.12427 .08333 L
.12454 .08333 L
.12479 .08333 L
.12508 .08333 L
.12535 .08333 L
.12583 .08333 L
.1261 .08333 L
.12635 .08333 L
.1268 .08333 L
.12728 .08333 L
.12773 .08333 L
.12815 .08333 L
.12861 .08333 L
.12911 .08333 L
.12937 .08333 L
.12964 .08333 L
.13013 .08333 L
.1304 .08333 L
.13065 .08333 L
.13092 .08333 L
.13121 .08333 L
.13169 .08333 L
.13197 .08333 L
.13223 .08333 L
.13271 .08333 L
.13315 .08333 L
.13365 .08333 L
.13413 .08333 L
.13457 .08333 L
.13504 .08333 L
.13548 .08333 L
.13589 .08333 L
.13634 .08333 L
.13683 .08333 L
.13708 .08333 L
.13735 .08333 L
.13783 .08333 L
.13809 .08333 L
.13834 .08333 L
.1386 .08333 L
.13889 .08333 L
.13936 .08333 L
.13963 .08333 L
Mistroke
.13988 .08333 L
.14036 .08333 L
.14079 .08333 L
.14128 .08333 L
.14176 .08333 L
.1422 .08333 L
.1426 .08333 L
.14307 .08333 L
.14351 .08333 L
.14391 .08333 L
.14429 .08333 L
.1447 .08333 L
.14513 .08333 L
.14557 .08333 L
.14604 .08333 L
.14648 .08333 L
.14689 .08333 L
.14736 .08333 L
.14763 .08333 L
.14788 .08333 L
.14833 .08333 L
.14881 .08333 L
.14925 .08333 L
.14973 .08333 L
.15023 .08333 L
.15069 .08333 L
.15112 .08333 L
.15152 .08333 L
.15198 .08333 L
.15241 .08333 L
.15288 .08333 L
.15338 .08333 L
.1538 .08333 L
.15427 .08333 L
.15477 .08333 L
.15505 .08333 L
.15531 .08333 L
.15581 .08333 L
.15628 .08333 L
.15672 .08333 L
.15713 .08333 L
.15759 .08333 L
.15802 .08333 L
.15843 .08333 L
.1588 .08333 L
.15921 .08333 L
.15964 .08333 L
.16007 .08333 L
.16054 .08333 L
.16098 .08333 L
Mistroke
.16138 .08333 L
.16185 .08333 L
.16212 .08333 L
.16236 .08333 L
.16281 .08333 L
.16329 .08333 L
.16375 .08333 L
.16426 .08333 L
.16473 .08333 L
.16517 .08333 L
.16561 .08333 L
.16601 .08333 L
.16646 .08333 L
.1669 .08333 L
.16737 .08333 L
.16787 .08333 L
.16829 .08333 L
.16876 .08333 L
.16926 .08333 L
.16954 .08333 L
.1698 .08333 L
.1703 .08333 L
.17077 .08333 L
.17118 .08333 L
.17162 .08333 L
.17208 .08333 L
.17252 .08333 L
.17292 .08333 L
.1733 .08333 L
.1737 .08333 L
.17413 .08333 L
.17457 .08333 L
.17504 .08333 L
.17548 .08333 L
.17588 .08333 L
.17635 .08333 L
.17662 .08333 L
.17686 .08333 L
.17731 .08333 L
.17779 .08333 L
.17825 .08333 L
.17876 .08333 L
.17923 .08333 L
.17968 .08333 L
.18012 .08333 L
.18051 .08333 L
.18097 .08333 L
.1814 .08333 L
.18188 .08333 L
.18238 .08333 L
Mistroke
.1828 .08333 L
.18327 .08333 L
.18377 .08333 L
.18406 .08333 L
.18431 .08333 L
.18481 .08333 L
.18529 .08333 L
.18569 .08333 L
.18614 .08333 L
.1866 .08333 L
.18703 .08333 L
.18744 .08333 L
.18781 .08333 L
.18822 .08333 L
.18865 .08333 L
.18909 .08333 L
.18956 .08333 L
.19 .08333 L
.1904 .08333 L
.19087 .08333 L
.19113 .08333 L
.19138 .08333 L
.19183 .08333 L
.19231 .08333 L
.19277 .08333 L
.19328 .08333 L
.19376 .08333 L
.1942 .08333 L
.1946 .08333 L
.19504 .08333 L
.1955 .08333 L
.19593 .08333 L
.1964 .08333 L
.19691 .08333 L
.19733 .08333 L
.1978 .08333 L
.19831 .08333 L
.19859 .08333 L
.19885 .08333 L
.19935 .08333 L
.19982 .08333 L
.20022 .08333 L
.20067 .08333 L
.20114 .08333 L
.20157 .08333 L
.20198 .08333 L
.20235 .08333 L
.20278 .08333 L
.20319 .08333 L
.20363 .08333 L
Mistroke
.20409 .08333 L
.20454 .08333 L
.20494 .08333 L
.20541 .08333 L
.20567 .08333 L
.20592 .08333 L
.20637 .08333 L
.20684 .08333 L
.20731 .08333 L
.20757 .08333 L
.20782 .08333 L
.20827 .08333 L
.20874 .08333 L
.20917 .08333 L
.20957 .08333 L
.21001 .08333 L
.21048 .08333 L
.21095 .08333 L
.21122 .08333 L
.21147 .08333 L
.21197 .08333 L
.21225 .08333 L
.21251 .08333 L
.21297 .08333 L
.21347 .08333 L
.21394 .08333 L
.21437 .08333 L
.21478 .08333 L
.21521 .08333 L
.21562 .08333 L
.216 .08333 L
.21644 .08333 L
.21692 .08333 L
.21737 .08333 L
.21779 .08333 L
.21826 .08333 L
.21871 .08333 L
.21911 .08333 L
.21954 .08333 L
.22001 .08333 L
.22051 .08333 L
.22093 .08333 L
.2214 .08333 L
.2219 .08333 L
.22237 .08333 L
.22261 .08333 L
.22288 .08333 L
.22316 .08333 L
.22342 .08333 L
.2239 .08333 L
Mistroke
.22433 .08333 L
.22484 .08333 L
.22532 .08333 L
.22575 .08333 L
.22621 .08333 L
.22664 .08333 L
.22703 .08333 L
.22749 .08333 L
.22799 .08333 L
.22846 .08333 L
.2289 .08333 L
.22936 .08333 L
.22986 .08333 L
.23033 .08333 L
.23075 .08333 L
.23126 .08333 L
.23154 .08333 L
.2318 .08333 L
.23228 .08333 L
.23253 .08333 L
.2328 .08333 L
.23305 .08333 L
.23333 .08333 L
.23382 .08333 L
.23409 .08333 L
.23434 .08333 L
.23462 .08333 L
.23492 .08333 L
.23518 .08333 L
.23546 .08333 L
.23572 .08333 L
.23597 .08333 L
.23643 .08333 L
.23692 .08333 L
.23738 .08333 L
.23789 .08333 L
.23836 .08333 L
.2388 .08333 L
.23924 .08333 L
.23964 .08333 L
.2401 .08333 L
.24053 .08333 L
.241 .08333 L
.2415 .08333 L
.24193 .08333 L
.2424 .08333 L
.2429 .08333 L
.24318 .08333 L
.24344 .08333 L
.24394 .08333 L
Mistroke
.24441 .08333 L
.24482 .08333 L
.24526 .08333 L
.24572 .08333 L
.24616 .08333 L
.24657 .08333 L
.24694 .08333 L
.24735 .08333 L
.24778 .08333 L
.24821 .08333 L
.24868 .08333 L
.24912 .08333 L
.24952 .08333 L
.24999 .08333 L
.25026 .08333 L
.2505 .08333 L
.25095 .08333 L
.25143 .08333 L
.2519 .08333 L
.2524 .08333 L
.25288 .08333 L
.25332 .08333 L
.25376 .08333 L
.25416 .08333 L
.25462 .08333 L
.25505 .08333 L
.25553 .08333 L
.25603 .08333 L
.25645 .08333 L
.25692 .08333 L
.25743 .08333 L
.25771 .08333 L
.25797 .08333 L
.25847 .08333 L
.25894 .08333 L
.25935 .08333 L
.25979 .08333 L
.26026 .08333 L
.26069 .08333 L
.2611 .08333 L
.26147 .08333 L
.2619 .08333 L
.26231 .08333 L
.26275 .08333 L
.26321 .08333 L
.26366 .08333 L
.26406 .08333 L
.26453 .08333 L
.26479 .08333 L
.26504 .08333 L
Mistroke
.26549 .08333 L
.26596 .08333 L
.26643 .08333 L
.26669 .08333 L
.26694 .08333 L
.26739 .08333 L
.26786 .08333 L
.26829 .08333 L
.26869 .08333 L
.26912 .08333 L
.2696 .08333 L
.27007 .08333 L
.27034 .08333 L
.27058 .08333 L
.27109 .08333 L
.27137 .08333 L
.27163 .08333 L
.27209 .08333 L
.27258 .08333 L
.27306 .08333 L
.27349 .08333 L
.27389 .08333 L
.27433 .08333 L
.27474 .08333 L
.27511 .08333 L
.27555 .08333 L
.27603 .08333 L
.27648 .08333 L
.2769 .08333 L
.27738 .08333 L
.27782 .08333 L
.27822 .08333 L
.27865 .08333 L
.27912 .08333 L
.27962 .08333 L
.28005 .08333 L
.28052 .08333 L
.28102 .08333 L
.28148 .08333 L
.28172 .08333 L
.28199 .08333 L
.28227 .08333 L
.28253 .08333 L
.28301 .08333 L
.28345 .08333 L
.28393 .08333 L
.28444 .08333 L
.28486 .08333 L
.28532 .08333 L
.28575 .08333 L
Mistroke
.28614 .08333 L
.2866 .08333 L
.2871 .08333 L
.28757 .08333 L
.28801 .08333 L
.28847 .08333 L
.28897 .08333 L
.28944 .08333 L
.28987 .08333 L
.29037 .08333 L
.29065 .08333 L
.29091 .08333 L
.29139 .08333 L
.29164 .08333 L
.29191 .08333 L
.29217 .08333 L
.29244 .08333 L
.29293 .08333 L
.2932 .08333 L
.29346 .08333 L
.29373 .08333 L
.29403 .08333 L
.29429 .08333 L
.29457 .08333 L
.29483 .08333 L
.29508 .08333 L
.29554 .08333 L
.29603 .08333 L
.29649 .08333 L
.297 .08333 L
.29747 .08333 L
.29791 .08333 L
.29835 .08333 L
.29875 .08333 L
.29921 .08333 L
.29964 .08333 L
.30011 .08333 L
.30061 .08333 L
.30104 .08333 L
.3015 .08333 L
.30201 .08333 L
.30229 .08333 L
.30255 .08333 L
.30305 .08333 L
.30352 .08333 L
.30392 .08333 L
.30437 .08333 L
.30483 .08333 L
.30527 .08333 L
.30567 .08333 L
Mistroke
.30604 .08333 L
.30645 .08333 L
.30688 .08333 L
.30732 .08333 L
.30779 .08333 L
.30823 .08333 L
.30863 .08333 L
.3091 .08333 L
.30936 .08333 L
.30961 .08333 L
.31006 .08333 L
.31054 .08333 L
.311 .08333 L
.31151 .08333 L
.31199 .08333 L
.31243 .08333 L
.31287 .08333 L
.31327 .08333 L
.31372 .08333 L
.31416 .08333 L
.31463 .08333 L
.31513 .08333 L
.31556 .08333 L
.31603 .08333 L
.31653 .08333 L
.31681 .08333 L
.31707 .08333 L
.31757 .08333 L
.31804 .08333 L
.31845 .08333 L
.31889 .08333 L
.31936 .08333 L
.31979 .08333 L
.3202 .08333 L
.32057 .08333 L
.321 .08333 L
.32141 .08333 L
.32185 .08333 L
.32232 .08333 L
.32276 .08333 L
.32316 .08333 L
.32363 .08333 L
.32389 .08333 L
.32414 .08333 L
.32459 .08333 L
.32506 .08333 L
.32553 .08333 L
.3258 .08333 L
.32604 .08333 L
.32649 .08333 L
Mistroke
.32696 .08333 L
.32739 .08333 L
.32779 .08333 L
.32822 .08333 L
.32869 .08333 L
.32917 .08333 L
.32943 .08333 L
.32968 .08333 L
.33019 .08333 L
.33047 .08333 L
.33072 .08333 L
.33118 .08333 L
.33168 .08333 L
.33215 .08333 L
.33259 .08333 L
.33299 .08333 L
.33343 .08333 L
.33384 .08333 L
.33421 .08333 L
.33465 .08333 L
.33513 .08333 L
.33558 .08333 L
.336 .08333 L
.33647 .08333 L
.33692 .08333 L
.33732 .08333 L
.33775 .08333 L
.33822 .08333 L
.33872 .08333 L
.33915 .08333 L
.33961 .08333 L
.34011 .08333 L
.34058 .08333 L
.34082 .08333 L
.34109 .08333 L
.34136 .08333 L
.34163 .08333 L
.3421 .08333 L
.34254 .08333 L
.34302 .08333 L
.34353 .08333 L
.34396 .08333 L
.34442 .08333 L
.34485 .08333 L
.34524 .08333 L
.3457 .08333 L
.3462 .08333 L
.34667 .08333 L
.3471 .08333 L
.34756 .08333 L
Mistroke
.34806 .08333 L
.34853 .08333 L
.34896 .08333 L
.34946 .08333 L
.34974 .08333 L
.35 .08333 L
.35049 .08333 L
.35073 .08333 L
.351 .08333 L
.35126 .08333 L
.35153 .08333 L
.35202 .08333 L
.35229 .08333 L
.35255 .08333 L
.35283 .08333 L
.35312 .08333 L
.35338 .08333 L
.35366 .08333 L
.35393 .08333 L
.35417 .08333 L
.35463 .08333 L
.35512 .08333 L
.35558 .08333 L
.35609 .08333 L
.35656 .08333 L
.357 .08333 L
.35744 .08333 L
.35784 .08333 L
.3583 .08333 L
.35873 .08333 L
.3592 .08333 L
.3597 .08333 L
.36013 .08333 L
.36059 .08333 L
.3611 .08333 L
.36138 .08333 L
.36164 .08333 L
.36214 .08333 L
.36261 .08333 L
.36301 .08333 L
.36346 .08333 L
.36392 .08333 L
.36435 .08333 L
.36476 .08333 L
.36513 .08333 L
.36554 .08333 L
.36597 .08333 L
.36641 .08333 L
.36687 .08333 L
.36731 .08333 L
Mistroke
.36771 .08333 L
.36819 .08333 L
.36845 .08333 L
.3687 .08333 L
.36915 .08333 L
.36962 .08333 L
.37009 .08333 L
.37059 .08333 L
.37107 .08333 L
.37151 .08333 L
.37195 .08333 L
.37235 .08333 L
.37281 .08333 L
.37324 .08333 L
.37372 .08333 L
.37422 .08333 L
.37464 .08333 L
.37511 .08333 L
.37561 .08333 L
.3759 .08333 L
.37615 .08333 L
.37665 .08333 L
.37713 .08333 L
.37753 .08333 L
.37798 .08333 L
.37844 .08333 L
.37888 .08333 L
.37928 .08333 L
.37965 .08333 L
.38006 .08333 L
.38049 .08333 L
.38093 .08333 L
.3814 .08333 L
.38184 .08333 L
.38224 .08333 L
.38271 .08333 L
.38298 .08333 L
.38322 .08333 L
.38367 .08333 L
.38415 .08333 L
.38461 .08333 L
.38488 .08333 L
.38512 .08333 L
.38557 .08333 L
.38604 .08333 L
.38647 .08333 L
.38687 .08333 L
.3873 .08333 L
.38777 .08333 L
.38825 .08333 L
Mistroke
.38851 .08333 L
.38876 .08333 L
.38927 .08333 L
.38955 .08333 L
.3898 .08333 L
.39026 .08333 L
.39076 .08333 L
.39123 .08333 L
.39167 .08333 L
.39207 .08333 L
.3925 .08333 L
.39291 .08333 L
.39329 .08333 L
.39373 .08333 L
.39421 .08333 L
.39466 .08333 L
.39508 .08333 L
.39555 .08333 L
.39599 .08333 L
.39639 .08333 L
.39683 .08333 L
.3973 .08333 L
.3978 .08333 L
.39822 .08333 L
.39869 .08333 L
.39919 .08333 L
.39965 .08333 L
.3999 .08333 L
.40016 .08333 L
.40044 .08333 L
.4007 .08333 L
.40118 .08333 L
.40162 .08333 L
.4021 .08333 L
.40261 .08333 L
.40303 .08333 L
.40349 .08333 L
.40392 .08333 L
.40431 .08333 L
.40477 .08333 L
.40527 .08333 L
.40574 .08333 L
.40618 .08333 L
.40664 .08333 L
.40713 .08333 L
.4076 .08333 L
.40803 .08333 L
.40853 .08333 L
.40882 .08333 L
.40908 .08333 L
Mistroke
.40956 .08333 L
.40983 .08333 L
.41007 .08333 L
.41033 .08333 L
.4106 .08333 L
.41109 .08333 L
.41137 .08333 L
.41162 .08333 L
.4119 .08333 L
.4122 .08333 L
.41245 .08333 L
.41273 .08333 L
.413 .08333 L
.41324 .08333 L
.4137 .08333 L
.41419 .08333 L
.41466 .08333 L
.41516 .08333 L
.41563 .08333 L
.41608 .08333 L
.41651 .08333 L
.41691 .08333 L
.41737 .08333 L
.4178 .08333 L
.41827 .08333 L
.41877 .08333 L
.4192 .08333 L
.41966 .08333 L
.42017 .08333 L
.42045 .08333 L
.42071 .08333 L
.42121 .08333 L
.42168 .08333 L
.42208 .08333 L
.42252 .08333 L
.42299 .08333 L
.42342 .08333 L
.42383 .08333 L
.4242 .08333 L
.42461 .08333 L
.42504 .08333 L
.42547 .08333 L
.42594 .08333 L
.42638 .08333 L
.42678 .08333 L
.42725 .08333 L
.42752 .08333 L
.42777 .08333 L
.42822 .08333 L
.42869 .08333 L
Mistroke
.42916 .08333 L
.42966 .08333 L
.43014 .08333 L
.43058 .08333 L
.43102 .08333 L
.43142 .08333 L
.43188 .08333 L
.43231 .08333 L
.43278 .08333 L
.43328 .08333 L
.43371 .08333 L
.43418 .08333 L
.43468 .08333 L
.43496 .08333 L
.43522 .08333 L
.43572 .08333 L
.43619 .08333 L
.4366 .08333 L
.43704 .08333 L
.43751 .08333 L
.43794 .08333 L
.43835 .08333 L
.43872 .08333 L
.43913 .08333 L
.43956 .08333 L
.43999 .08333 L
.44046 .08333 L
.4409 .08333 L
.4413 .08333 L
.44177 .08333 L
.44204 .08333 L
.44228 .08333 L
.44274 .08333 L
.44321 .08333 L
.44368 .08333 L
.44394 .08333 L
.44418 .08333 L
.44463 .08333 L
.44511 .08333 L
.44553 .08333 L
.44593 .08333 L
.44636 .08333 L
.44684 .08333 L
.44731 .08333 L
.44757 .08333 L
.44782 .08333 L
.44833 .08333 L
.44861 .08333 L
.44886 .08333 L
.44932 .08333 L
Mistroke
.44982 .08333 L
.45029 .08333 L
.45073 .08333 L
.45113 .08333 L
.45156 .08333 L
.45197 .08333 L
.45235 .08333 L
.45279 .08333 L
.45327 .08333 L
.45372 .08333 L
.45414 .08333 L
.45461 .08333 L
.45505 .08333 L
.45545 .08333 L
.45589 .08333 L
.45636 .08333 L
.45686 .08333 L
.45728 .08333 L
.45775 .08333 L
.45809 .08333 L
.4584 .08333 L
.45874 .08333 L
.45911 .08333 L
.45942 .08333 L
.45972 .08333 L
.46004 .08333 L
.46039 .08333 L
.46069 .08333 L
.46101 .08333 L
.46134 .08333 L
.46165 .08333 L
.46194 .08333 L
.46221 .08333 L
.46252 .08333 L
.4628 .08333 L
.46312 .08333 L
.46346 .08333 L
.46382 .08333 L
.46416 .08333 L
.46447 .08333 L
.46476 .08333 L
.46509 .08333 L
.4654 .08333 L
.46574 .08333 L
.4661 .08333 L
.46644 .08333 L
.46675 .08333 L
.46712 .08333 L
.46751 .08333 L
.46788 .08333 L
Mistroke
.46822 .08333 L
Mfstroke
.46822 .08333 m
.46869 .08333 L
.46913 .08333 L
.46962 .08333 L
.47009 .08333 L
.47053 .08333 L
.47093 .08333 L
.47137 .08333 L
.47184 .08333 L
.47231 .08333 L
.47281 .08333 L
.47329 .08333 L
.47372 .08333 L
.47423 .08333 L
.47452 .08333 L
.47479 .08333 L
.47528 .08333 L
.4758 .08333 L
.47606 .08333 L
.47634 .08333 L
.47683 .08333 L
.47711 .08333 L
.47737 .08333 L
.47765 .08333 L
.47796 .08333 L
.47822 .08333 L
.4785 .08333 L
.47902 .08333 L
.47952 .08333 L
.47999 .08333 L
.48044 .08333 L
.48086 .08333 L
.48133 .08333 L
.48183 .08333 L
.48233 .08333 L
.48285 .08333 L
.4833 .08333 L
.48379 .08333 L
.48407 .08333 L
.48434 .08333 L
.48462 .08333 L
.48493 .08333 L
.48545 .08333 L
.48574 .08333 L
.48601 .08333 L
.48652 .08333 L
.48699 .08333 L
.48725 .08333 L
.48753 .08333 L
.48804 .08333 L
Mistroke
.48835 .08333 L
.48864 .08333 L
.4889 .08333 L
.48918 .08333 L
.48949 .08333 L
.48981 .08333 L
.49009 .08333 L
.49039 .08333 L
.49068 .08333 L
.49094 .08333 L
.49124 .08333 L
.49152 .08333 L
.49203 .08333 L
.49231 .08333 L
.49258 .08333 L
.49305 .08333 L
.49355 .08333 L
.49403 .08333 L
.49447 .08333 L
.49495 .08333 L
.49548 .08333 L
.49575 .08333 L
.49603 .08333 L
.49655 .08333 L
.49683 .08333 L
.49709 .08333 L
.49738 .08333 L
.49768 .08333 L
.49819 .08333 L
.49848 .08333 L
.49876 .08333 L
.49926 .08333 L
.49972 .08333 L
.50025 .08333 L
.50076 .08333 L
.50122 .08333 L
.50171 .08333 L
.50218 .08333 L
.5026 .08333 L
.50308 .08333 L
.5036 .08333 L
.50386 .08333 L
.50414 .08333 L
.50464 .08333 L
.50492 .08333 L
.50517 .08333 L
.50546 .08333 L
.50575 .08333 L
.50625 .08333 L
.50654 .08333 L
Mistroke
.5068 .08333 L
.5073 .08333 L
.50775 .08333 L
.50827 .08333 L
.50877 .08333 L
.50924 .08333 L
.50966 .08333 L
.51015 .08333 L
.51061 .08333 L
.51104 .08333 L
.51143 .08333 L
.51186 .08333 L
.51232 .08333 L
.51278 .08333 L
.51327 .08333 L
.51374 .08333 L
.51416 .08333 L
.51466 .08333 L
.51494 .08333 L
.5152 .08333 L
.51568 .08333 L
.51619 .08333 L
.51665 .08333 L
.51715 .08333 L
.51767 .08333 L
.51816 .08333 L
.51862 .08333 L
.51903 .08333 L
.51951 .08333 L
.51997 .08333 L
.52046 .08333 L
.52098 .08333 L
.52143 .08333 L
.52192 .08333 L
.52245 .08333 L
.52274 .08333 L
.52301 .08333 L
.52354 .08333 L
.52404 .08333 L
.5245 .08333 L
.52492 .08333 L
.52541 .08333 L
.52587 .08333 L
.52629 .08333 L
.52668 .08333 L
.52711 .08333 L
.52756 .08333 L
.52802 .08333 L
.52851 .08333 L
.52897 .08333 L
Mistroke
.52939 .08333 L
.52989 .08333 L
.53017 .08333 L
.53043 .08333 L
.5309 .08333 L
.5314 .08333 L
.53189 .08333 L
.53242 .08333 L
.53292 .08333 L
.53338 .08333 L
.53384 .08333 L
.53426 .08333 L
.53474 .08333 L
.53519 .08333 L
.53569 .08333 L
.53621 .08333 L
.53666 .08333 L
.53715 .08333 L
.53768 .08333 L
.53797 .08333 L
.53825 .08333 L
.53877 .08333 L
.53927 .08333 L
.53969 .08333 L
.54016 .08333 L
.54064 .08333 L
.5411 .08333 L
.54153 .08333 L
.54192 .08333 L
.54235 .08333 L
.5428 .08333 L
.54326 .08333 L
.54375 .08333 L
.54421 .08333 L
.54463 .08333 L
.54513 .08333 L
.54541 .08333 L
.54566 .08333 L
.54614 .08333 L
.54664 .08333 L
.54713 .08333 L
.54766 .08333 L
.54816 .08333 L
.54862 .08333 L
.54909 .08333 L
.5495 .08333 L
.54999 .08333 L
.55044 .08333 L
.55094 .08333 L
.55146 .08333 L
Mistroke
.55191 .08333 L
.5524 .08333 L
.55293 .08333 L
.55323 .08333 L
.5535 .08333 L
.55402 .08333 L
.55452 .08333 L
.55495 .08333 L
.55541 .08333 L
.5559 .08333 L
.55636 .08333 L
.55678 .08333 L
.55718 .08333 L
.5576 .08333 L
.55806 .08333 L
.55852 .08333 L
.55901 .08333 L
.55947 .08333 L
.55989 .08333 L
.56039 .08333 L
.56067 .08333 L
.56092 .08333 L
.5614 .08333 L
.5619 .08333 L
.56239 .08333 L
.56292 .08333 L
.56342 .08333 L
.56389 .08333 L
.56431 .08333 L
.56477 .08333 L
.56525 .08333 L
.56571 .08333 L
.56621 .08333 L
.56673 .08333 L
.56718 .08333 L
.56767 .08333 L
.5682 .08333 L
.5685 .08333 L
.56877 .08333 L
.5693 .08333 L
.56979 .08333 L
.57022 .08333 L
.57069 .08333 L
.57118 .08333 L
.57164 .08333 L
.57206 .08333 L
.57245 .08333 L
.57291 .08333 L
.57333 .08333 L
.5738 .08333 L
Mistroke
.57429 .08333 L
.57475 .08333 L
.57517 .08333 L
.57567 .08333 L
.57595 .08333 L
.5762 .08333 L
.57668 .08333 L
.57718 .08333 L
.57767 .08333 L
.57795 .08333 L
.5782 .08333 L
.57867 .08333 L
.57917 .08333 L
.57962 .08333 L
.58004 .08333 L
.5805 .08333 L
.581 .08333 L
.58149 .08333 L
.58177 .08333 L
.58204 .08333 L
.58257 .08333 L
.58286 .08333 L
.58313 .08333 L
.58361 .08333 L
.58414 .08333 L
.58463 .08333 L
.58509 .08333 L
.58552 .08333 L
.58597 .08333 L
.5864 .08333 L
.5868 .08333 L
.58726 .08333 L
.58776 .08333 L
.58824 .08333 L
.58868 .08333 L
.58918 .08333 L
.58964 .08333 L
.59006 .08333 L
.59052 .08333 L
.59101 .08333 L
.59154 .08333 L
.59199 .08333 L
.59248 .08333 L
.593 .08333 L
.59349 .08333 L
.59375 .08333 L
.59403 .08333 L
.59432 .08333 L
.59459 .08333 L
.5951 .08333 L
Mistroke
.59556 .08333 L
.59609 .08333 L
.5966 .08333 L
.59705 .08333 L
.59753 .08333 L
.59798 .08333 L
.59839 .08333 L
.59888 .08333 L
.5994 .08333 L
.5999 .08333 L
.60035 .08333 L
.60084 .08333 L
.60136 .08333 L
.60186 .08333 L
.60231 .08333 L
.60283 .08333 L
.60313 .08333 L
.60341 .08333 L
.60391 .08333 L
.60417 .08333 L
.60445 .08333 L
.60472 .08333 L
.60501 .08333 L
.60553 .08333 L
.60581 .08333 L
.60608 .08333 L
.60637 .08333 L
.60669 .08333 L
.60696 .08333 L
.60725 .08333 L
.60753 .08333 L
.60779 .08333 L
.60827 .08333 L
.60878 .08333 L
.60927 .08333 L
.6098 .08333 L
.6103 .08333 L
.61077 .08333 L
.61123 .08333 L
.61165 .08333 L
.61213 .08333 L
.61258 .08333 L
.61308 .08333 L
.6136 .08333 L
.61405 .08333 L
.61454 .08333 L
.61507 .08333 L
.61537 .08333 L
.61564 .08333 L
.61617 .08333 L
Mistroke
.61666 .08333 L
.61709 .08333 L
.61755 .08333 L
.61804 .08333 L
.6185 .08333 L
.61893 .08333 L
.61932 .08333 L
.61974 .08333 L
.6202 .08333 L
.62066 .08333 L
.62115 .08333 L
.62161 .08333 L
.62203 .08333 L
.62253 .08333 L
.62281 .08333 L
.62306 .08333 L
.62354 .08333 L
.62404 .08333 L
.62453 .08333 L
.62506 .08333 L
.62556 .08333 L
.62603 .08333 L
.62649 .08333 L
.62691 .08333 L
.62739 .08333 L
.62784 .08333 L
.62834 .08333 L
.62887 .08333 L
.62932 .08333 L
.62981 .08333 L
.63034 .08333 L
.63064 .08333 L
.63091 .08333 L
.63143 .08333 L
.63193 .08333 L
.63236 .08333 L
.63282 .08333 L
.63331 .08333 L
.63377 .08333 L
.6342 .08333 L
.63459 .08333 L
.63504 .08333 L
.63547 .08333 L
.63593 .08333 L
.63642 .08333 L
.63689 .08333 L
.63731 .08333 L
.6378 .08333 L
.63808 .08333 L
.63834 .08333 L
Mistroke
.63881 .08333 L
.63931 .08333 L
.6398 .08333 L
.64008 .08333 L
.64034 .08333 L
.64081 .08333 L
.64131 .08333 L
.64175 .08333 L
.64217 .08333 L
.64263 .08333 L
.64313 .08333 L
.64363 .08333 L
.64391 .08333 L
.64417 .08333 L
.6447 .08333 L
.64499 .08333 L
.64526 .08333 L
.64575 .08333 L
.64627 .08333 L
.64676 .08333 L
.64722 .08333 L
.64765 .08333 L
.6481 .08333 L
.64853 .08333 L
.64893 .08333 L
.64939 .08333 L
.64989 .08333 L
.65037 .08333 L
.65081 .08333 L
.65131 .08333 L
.65177 .08333 L
.65219 .08333 L
.65265 .08333 L
.65314 .08333 L
.65367 .08333 L
.65412 .08333 L
.65461 .08333 L
.65513 .08333 L
.65562 .08333 L
.65588 .08333 L
.65616 .08333 L
.65645 .08333 L
.65672 .08333 L
.65723 .08333 L
.65769 .08333 L
.65819 .08333 L
.65873 .08333 L
.65918 .08333 L
.65966 .08333 L
.66011 .08333 L
Mistroke
.66052 .08333 L
.661 .08333 L
.66153 .08333 L
.66202 .08333 L
.66248 .08333 L
.66297 .08333 L
.66349 .08333 L
.66398 .08333 L
.66443 .08333 L
.66496 .08333 L
.66526 .08333 L
.66553 .08333 L
.66604 .08333 L
.66629 .08333 L
.66658 .08333 L
.66685 .08333 L
.66714 .08333 L
.66765 .08333 L
.66794 .08333 L
.66821 .08333 L
.6685 .08333 L
.66881 .08333 L
.66908 .08333 L
.66938 .08333 L
.66965 .08333 L
.66991 .08333 L
.6704 .08333 L
.67091 .08333 L
.6714 .08333 L
.67193 .08333 L
.67243 .08333 L
.67289 .08333 L
.67335 .08333 L
.67377 .08333 L
.67425 .08333 L
.6747 .08333 L
.6752 .08333 L
.67573 .08333 L
.67617 .08333 L
.67666 .08333 L
.67719 .08333 L
.67749 .08333 L
.67776 .08333 L
.67829 .08333 L
.67878 .08333 L
.67921 .08333 L
.67967 .08333 L
.68016 .08333 L
.68062 .08333 L
.68105 .08333 L
Mistroke
.68144 .08333 L
.68187 .08333 L
.68232 .08333 L
.68278 .08333 L
.68327 .08333 L
.68373 .08333 L
.68415 .08333 L
.68465 .08333 L
.68493 .08333 L
.68518 .08333 L
.68566 .08333 L
.68616 .08333 L
.68665 .08333 L
.68718 .08333 L
.68768 .08333 L
.68815 .08333 L
.68861 .08333 L
.68903 .08333 L
.68951 .08333 L
.68996 .08333 L
.69046 .08333 L
.69099 .08333 L
.69143 .08333 L
.69193 .08333 L
.69246 .08333 L
.69275 .08333 L
.69302 .08333 L
.69355 .08333 L
.69405 .08333 L
.69447 .08333 L
.69494 .08333 L
.69543 .08333 L
.69589 .08333 L
.69631 .08333 L
.6967 .08333 L
.69716 .08333 L
.69759 .08333 L
.69805 .08333 L
.69854 .08333 L
.699 .08333 L
.69942 .08333 L
.69992 .08333 L
.7002 .08333 L
.70045 .08333 L
.70093 .08333 L
.70143 .08333 L
.70192 .08333 L
.70219 .08333 L
.70245 .08333 L
.70292 .08333 L
Mistroke
.70342 .08333 L
.70387 .08333 L
.70429 .08333 L
.70475 .08333 L
.70524 .08333 L
.70574 .08333 L
.70602 .08333 L
.70628 .08333 L
.70681 .08333 L
.70711 .08333 L
.70738 .08333 L
.70786 .08333 L
.70838 .08333 L
.70888 .08333 L
.70933 .08333 L
.70976 .08333 L
.71021 .08333 L
.71065 .08333 L
.71104 .08333 L
.7115 .08333 L
.712 .08333 L
.71248 .08333 L
.71292 .08333 L
.71342 .08333 L
.71388 .08333 L
.7143 .08333 L
.71476 .08333 L
.71525 .08333 L
.71578 .08333 L
.71623 .08333 L
.71672 .08333 L
.71724 .08333 L
.71773 .08333 L
.71798 .08333 L
.71827 .08333 L
.71856 .08333 L
.71883 .08333 L
.71934 .08333 L
.7198 .08333 L
.7203 .08333 L
.72083 .08333 L
.72128 .08333 L
.72176 .08333 L
.72222 .08333 L
.72263 .08333 L
.72311 .08333 L
.72364 .08333 L
.72413 .08333 L
.72459 .08333 L
.72507 .08333 L
Mistroke
.7256 .08333 L
.72609 .08333 L
.72654 .08333 L
.72706 .08333 L
.72736 .08333 L
.72764 .08333 L
.72814 .08333 L
.7284 .08333 L
.72868 .08333 L
.72896 .08333 L
.72924 .08333 L
.72976 .08333 L
.73004 .08333 L
.73031 .08333 L
.7306 .08333 L
.73092 .08333 L
.73119 .08333 L
.73148 .08333 L
.73176 .08333 L
.73202 .08333 L
.7325 .08333 L
.73302 .08333 L
.7335 .08333 L
.73403 .08333 L
.73453 .08333 L
.735 .08333 L
.73546 .08333 L
.73587 .08333 L
.73635 .08333 L
.73681 .08333 L
.7373 .08333 L
.73783 .08333 L
.73828 .08333 L
.73877 .08333 L
.7393 .08333 L
.73959 .08333 L
.73986 .08333 L
.74039 .08333 L
.74089 .08333 L
.74131 .08333 L
.74178 .08333 L
.74226 .08333 L
.74272 .08333 L
.74315 .08333 L
.74354 .08333 L
.74397 .08333 L
.74442 .08333 L
.74488 .08333 L
.74537 .08333 L
.74583 .08333 L
Mistroke
.74625 .08333 L
.74675 .08333 L
.74703 .08333 L
.74728 .08333 L
.74776 .08333 L
.74826 .08333 L
.74875 .08333 L
.74928 .08333 L
.74978 .08333 L
.75025 .08333 L
.75071 .08333 L
.75112 .08333 L
.75161 .08333 L
.75206 .08333 L
.75256 .08333 L
.75308 .08333 L
.75353 .08333 L
.75402 .08333 L
.75455 .08333 L
.75485 .08333 L
.75512 .08333 L
.75565 .08333 L
.75614 .08333 L
.75657 .08333 L
.75704 .08333 L
.75752 .08333 L
.75798 .08333 L
.75841 .08333 L
.7588 .08333 L
.75923 .08333 L
.75968 .08333 L
.76014 .08333 L
.76063 .08333 L
.7611 .08333 L
.76152 .08333 L
.76201 .08333 L
.76229 .08333 L
.76255 .08333 L
.76302 .08333 L
.76352 .08333 L
.76401 .08333 L
.76429 .08333 L
.76455 .08333 L
.76502 .08333 L
.76552 .08333 L
.76596 .08333 L
.76638 .08333 L
.76684 .08333 L
.76733 .08333 L
.76783 .08333 L
Mistroke
.76811 .08333 L
.76837 .08333 L
.7689 .08333 L
.7692 .08333 L
.76947 .08333 L
.76995 .08333 L
.77047 .08333 L
.77097 .08333 L
.77142 .08333 L
.77185 .08333 L
.77231 .08333 L
.77274 .08333 L
.77313 .08333 L
.77359 .08333 L
.77409 .08333 L
.77457 .08333 L
.77501 .08333 L
.77551 .08333 L
.77597 .08333 L
.77639 .08333 L
.77685 .08333 L
.77734 .08333 L
.77787 .08333 L
.77832 .08333 L
.77881 .08333 L
.77933 .08333 L
.77982 .08333 L
.78007 .08333 L
.78035 .08333 L
.78065 .08333 L
.78092 .08333 L
.78142 .08333 L
.78188 .08333 L
.78239 .08333 L
.78292 .08333 L
.78337 .08333 L
.78385 .08333 L
.7843 .08333 L
.78471 .08333 L
.7852 .08333 L
.78572 .08333 L
.78622 .08333 L
.78667 .08333 L
.78716 .08333 L
.78768 .08333 L
.78817 .08333 L
.78862 .08333 L
.78915 .08333 L
.78945 .08333 L
.78972 .08333 L
Mistroke
.79023 .08333 L
.79051 .08333 L
.79077 .08333 L
.79104 .08333 L
.79133 .08333 L
.79184 .08333 L
.79213 .08333 L
.7924 .08333 L
.79269 .08333 L
.793 .08333 L
.79327 .08333 L
.79357 .08333 L
.79384 .08333 L
.7941 .08333 L
.79459 .08333 L
.7951 .08333 L
.79559 .08333 L
.79612 .08333 L
.79662 .08333 L
.79708 .08333 L
.79754 .08333 L
.79796 .08333 L
.79844 .08333 L
.79889 .08333 L
.79939 .08333 L
.79991 .08333 L
.80036 .08333 L
.80085 .08333 L
.80138 .08333 L
.80167 .08333 L
.80194 .08333 L
.80247 .08333 L
.80297 .08333 L
.80339 .08333 L
.80386 .08333 L
.80434 .08333 L
.8048 .08333 L
.80523 .08333 L
.80562 .08333 L
.80605 .08333 L
.8065 .08333 L
.80696 .08333 L
.80745 .08333 L
.80791 .08333 L
.80833 .08333 L
.80883 .08333 L
.80911 .08333 L
.80936 .08333 L
.80984 .08333 L
.81034 .08333 L
Mistroke
.81083 .08333 L
.81136 .08333 L
.81186 .08333 L
.81232 .08333 L
.81279 .08333 L
.8132 .08333 L
.81369 .08333 L
.81414 .08333 L
.81464 .08333 L
.81516 .08333 L
.81561 .08333 L
.8161 .08333 L
.81663 .08333 L
.81693 .08333 L
.8172 .08333 L
.81772 .08333 L
.81822 .08333 L
.81865 .08333 L
.81911 .08333 L
.8196 .08333 L
.82006 .08333 L
.82049 .08333 L
.82088 .08333 L
.82131 .08333 L
.82176 .08333 L
.82222 .08333 L
.82271 .08333 L
.82317 .08333 L
.82359 .08333 L
.82409 .08333 L
.82437 .08333 L
.82462 .08333 L
.8251 .08333 L
.8256 .08333 L
.82609 .08333 L
.82636 .08333 L
.82662 .08333 L
.82709 .08333 L
.82759 .08333 L
.82804 .08333 L
.82845 .08333 L
.82891 .08333 L
.82941 .08333 L
.8299 .08333 L
.83018 .08333 L
.83045 .08333 L
.83097 .08333 L
.83127 .08333 L
.83154 .08333 L
.83202 .08333 L
Mistroke
.83255 .08333 L
.83304 .08333 L
.8335 .08333 L
.83392 .08333 L
.83438 .08333 L
.83481 .08333 L
.8352 .08333 L
.83566 .08333 L
.83616 .08333 L
.83664 .08333 L
.83708 .08333 L
.83758 .08333 L
.83804 .08333 L
.83846 .08333 L
.83892 .08333 L
.83941 .08333 L
.83994 .08333 L
.84039 .08333 L
.84088 .08333 L
.84123 .08333 L
.84156 .08333 L
.84192 .08333 L
.84231 .08333 L
.84264 .08333 L
.84295 .08333 L
.84329 .08333 L
.84366 .08333 L
.84396 .08333 L
.8443 .08333 L
.84465 .08333 L
.84498 .08333 L
.84529 .08333 L
.84556 .08333 L
.84589 .08333 L
.84619 .08333 L
.84652 .08333 L
.84688 .08333 L
.84726 .08333 L
.84761 .08333 L
.84794 .08333 L
.84824 .08333 L
.84859 .08333 L
.84892 .08333 L
.84928 .08333 L
.84966 .08333 L
.85002 .08333 L
.85034 .08333 L
.85072 .08333 L
.85114 .08333 L
.85153 .08333 L
Mistroke
.85188 .08333 L
Mfstroke
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{570, 95},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008j0000Gb000`400?l00000o`00003ooooooooo
oooooccooooo0024ooooo`;o0000@oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
04?ooooo0ol00013ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000@Oooool5o`00
08Gooooo0023ooooo`04o`000?ooooooooooo`00047ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000004?ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool00000@Oooool01?l0003oooooooooool00025ooooo`00
Poooool01?l0003oooooooooool00011ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`25ooooo`00Poooool01?l0003oooooooooool00011oooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`24
ooooo`00Poooool01?l0003oooooooooool00011ooooo`04o`000?ooooooooooo`0000Oooooo1?l0
0014ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool01oooool4o`00047ooooo00Go
0000ooooooooooooooooo`000025ooooo`00Poooool01?l0003oooooooooool00011ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0A?ooool2o`0004Cooooo0_l00009ooooo`03
o`000?oooooooooo04;ooooo00Go0000ooooooooooooooooo`000025ooooo`00Q?ooool2o`0004?o
oooo0_l00008ooooo`Go0000@oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Oo
oooo1Ol00011ooooo`?o0000Q_ooool00?oooooooooooollooooo`00oooooooooooooccooooo003o
oooooooooooo??ooool00?oooooooooooollooooo`00oooooooooooooccooooo0019ooooo`;o0000
1?ooool01?l0003oooooooooooooool5o`000?oooooohoooool004Sooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00006oooooooo0000O_l0001Oooooo`00@Oooool5o`0000;o
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Mooooo`00B?ooool01?l0003o
ooooooooool0000:ooooo`03o`000?oooooooooo00Gooooo0ol00006ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Cooooo0ol0001Oooooo`00B?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo04Sooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1Mooooo`00B?ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Tooooo`03o`00oooo
oooooooo0?ooooooDoooool00ol0003oooooooooo`1Mooooo`00BOooool2o`0000Wooooo0ol00007
ooooo`;o00009Oooool00ol00?ooooooooooo`3ooooooe;ooooo0_l0001Oooooo`00G_ooool00ol0
003oooooooooo`0Tooooo`03o`00oooooooooooo0?ooooooDoooool00ol0003oooooooooo`1Moooo
o`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo0?ooooooDoooool00ol0003o
ooooooooo`1Mooooo`00G_ooool2o`0002Gooooo00?o003oooooooooool0oooooomBooooo`;o0000
Goooool005kooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`3ooooooe?ooooo00?o
0000ooooooooool0GOooool005kooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`3o
oooooe?ooooo00?o0000ooooooooool0GOooool005kooooo0_l0000Uooooo`03o`00oooooooooooo
0?ooooooD_ooool2o`0005oooooo001Nooooo`03o`000?oooooooooo02Cooooo00?o003ooooooooo
ool0oooooomCooooo`03o`000?oooooooooo05gooooo001Nooooo`03o`000?oooooooooo02Cooooo
00?o003oooooooooool0oooooomCooooo`03o`000?oooooooooo05gooooo0019ooooo`;o00001?oo
ool00ol0003oooooooooo`02ooooo`?o00001oooool2o`0002Gooooo00?o003oooooooooool0oooo
oomBooooo`;o0000Goooool004Sooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool0oooooomCooooo`03o`000?oo
oooooooo05gooooo0011ooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`3ooooooe?ooooo00?o
0000ooooooooool0GOooool004Sooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`06ooooo`?o00009?ooool00ol00?ooooooooooo`3ooooooe7ooooo0ol0001Oooooo`00B?ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09?oo
ool00ol00?ooooooooooo`3ooooooe?ooooo00?o0000ooooooooool0GOooool004Sooooo00Co0000
oooooooooooo00002?ooool2o`0000Sooooo00?o0000ooooooooool09?ooool00ol00?oooooooooo
o`3ooooooe?ooooo00?o0000ooooooooool0GOooool004Wooooo0_l0000:ooooo`03o`000?oooooo
oooo00Kooooo0_l0000Uooooo`03o`00oooooooooooo0?oooooo>?ooool2o`00o`03ooooool00?oo
003o01Gooooo0_l0001Oooooo`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo
0?oooooo>Oooool00ol00?ooooooo`00o`0Gooooo`03o`000?oooooooooo05gooooo001Nooooo`03
o`000?oooooooooo02Cooooo00?o003oooooooooool0ooooooljooooo`03o`00oooooooooooo01Ko
oooo00?o0000ooooooooool0GOooool005kooooo0_l0000Uooooo`03o`00oooooooooooo0?oooooo
>Oooool00ol00?ooooooo`00o`0Fooooo`;o0000Goooool005kooooo00?o0000ooooooooool09?oo
ool00ol00?ooooooooooo`3oooooocSooooo0_l00?l00ooooooo003oo`00o`0Fooooo`03o`000?oo
oooooooo05gooooo001Nooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool0oooooomC
ooooo`03o`000?oooooooooo05gooooo001Nooooo`;o00009Oooool00ol00?ooooooooooo`3ooooo
oe;ooooo0_l0001Oooooo`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo0?oo
ooooDoooool00ol0003oooooooooo`1Mooooo`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00
oooooooooooo0?ooooooDoooool00ol0003oooooooooo`1Mooooo`00EOooool2o`0000Oooooo0_l0
000Tooooo`?o0000U?ooool3o`0009Cooooo0ol0000Tooooo`;o0000Goooool005Cooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooooooo`0Rooooo`05o`000?l00?oo003oo`00ool00000
T_ooool01Ol0003ooooooooooooooooo000009;ooooo00Go0000ooooooooooooooooo`00000Toooo
o`03o`000?oooooooooo05gooooo001Dooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool08_ooool01Ol0003o003oo`00ool00?oo000009;ooooo00Go0000ooooooooooooooooo`00
002Booooo`05o`000?ooooooooooooooool000009?ooool00ol0003oooooooooo`1Mooooo`00E?oo
ool01?l0003oooooooooool00006ooooo`?o00001_oooolKo`00o`03o`000?l00?oo003o0?ooo`00
7ooo000Ao`0000;o003o00?o0000o`00ool00?l06Ol00?l6ooooo`?o0000Goooool005Cooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooooooo`0Qooooo`03o`000?l00?oo003o00?o003o
00?o0000ooooooooool0S_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo05gooooo
001Dooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool08_ooool2o`000003o`00
ool0003o000009;ooooo0_l000000ooooooo0000o`00002Booooo`;o000000?oooooo`000?l00000
9?ooool00ol0003oooooooooo`1Mooooo`00EOooool2o`0000Oooooo0_l0000Uooooo`03o`000?oo
oooooooo09Cooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Sooooo`;o0000Gooo
ool005kooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`3ooooooe?ooooo00?o0000
ooooooooool0GOooool005kooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`3ooooo
oe?ooooo00?o0000ooooooooool0GOooool005kooooo0_l0000Uooooo`03o`00oooooooooooo0?oo
ooooD_ooool2o`0005oooooo001Nooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool0
oooooomCooooo`03o`000?oooooooooo05gooooo001Nooooo`03o`000?oooooooooo02Cooooo00?o
003oooooooooool01Oooool3o`0009?ooooo1Ol0002Cooooo`?o00007?ooool00ol0003ooooooooo
o`1Mooooo`00G_ooool2o`0002Gooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`2C
ooooo`04o`000?ooooooooooo`0009;ooooo00Go0000ooooooooooooooooo`00000Jooooo`;o0000
Goooool005kooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`06ooooo`03o`000?oo
oooooooo09Cooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo05gooooo001Nooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool01?ooool2
o`00o`03o`000?oooooooooo09Gooooo00?o0000ooooooooool0Toooool2o`0001cooooo00?o0000
ooooooooool0GOooool005kooooo0_l0000Uooooo`03o`00oooooooooooo00Gooooo00?o003oo`00
0?ooool0Toooool01Ol0003ooooooooooooooooo000009Kooooo00?o0000ooooooooool06?ooool2
o`0005oooooo0019ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001oooool00ol0
003oooooooooo`0Tooooo`03o`00oooooooooooo00Gooooo0_l0002Dooooo`05o`000?oooooooooo
ooooool00000T_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool0GOoo
ool004Sooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02Cooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`2Cooooo`?o0000U?oo
ool3o`0001cooooo00?o0000ooooooooool0GOooool004Sooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`06ooooo`?o00009?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooo003o0?ooooooBOooool3o`0005oooooo0018ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo00Gooooo00?o
003oooooool00?l0oooooom;ooooo`03o`000?oooooooooo05gooooo0018ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Tooooo`03o`00oooo
oooooooo00Cooooo0_l00?l00ooooooo003oo`00o`3ooooood[ooooo00?o0000ooooooooool0GOoo
ool004Sooooo00Co0000oooooooooooo00002?ooool2o`0000Sooooo0_l0000Uooooo`03o`00oooo
oooooooo0?ooooooD_ooool2o`0005oooooo0019ooooo`;o00002_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool0oooooomCooooo`03o`000?oooooo
oooo05gooooo001Nooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool0oooooomCoooo
o`03o`000?oooooooooo05gooooo001Nooooo`;o00009Oooool00ol00?ooooooooooo`3ooooooe;o
oooo0_l0001Oooooo`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo0?oooooo
Doooool00ol0003oooooooooo`1Mooooo`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00oooo
oooooooo0?ooooooDoooool00ol0003oooooooooo`1Mooooo`00G_ooool2o`0002Gooooo00?o003o
ooooooooool0oooooomBooooo`;o0000Goooool005kooooo00?o0000ooooooooool09?ooool00ol0
0?ooooooooooo`3ooooooe?ooooo00?o0000ooooooooool0GOooool005kooooo00?o0000oooooooo
ool09?ooool00ol00?ooooooooooo`3ooooooe?ooooo00?o0000ooooooooool0GOooool005kooooo
0_l0000Uooooo`03o`00oooooooooooo0?ooooooD_ooool2o`0005oooooo0019ooooo`;o00001?oo
ool01?l0003oooooooooooooool5o`0000Kooooo00?o0000ooooooooool09?ooool00ol00?oooooo
ooooo`3ooooooe?ooooo00?o0000ooooooooool0GOooool004Sooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo02Cooooo00?o003ooooooooo
ool0B?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05gooooo0018ooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool01_ooool3o`0000Kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01?ooool3o`0005oooooo0018ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0GOooool004Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Koooooool0001no`0005oooooo0018ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00003oooooon?ooooo0019ooooo`;o00002Oooool3o`000?ooooooi?ooool00?oo
oooooooooollooooo`00oooooooooooooccooooo003ooooooooooooo??ooool004Kooooo00?o0000
ooooooooool03?ooool3o`0002kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`24
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0J_ooool3o`0002;ooooo0ol0000W
ooooo`03o`000?oooooooooo04Kooooo0015ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Cooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`15ooooo`00AOooool00ol0003oooooooooo`05o`000003
ooooool0003o000000?o00000_ooool4o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l0
00001_ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol00003ooooo`Co00000_ooool3o`00
00Gooooo00?o0000ooooooooool01Oooool3o`0000Gooooo00?o0000ooooooooool00oooool5o`00
0003ooooool0003o000000;o00002?ooool4o`0000?ooooo1?l000000ooooooo0000o`000003o`00
0004ooooool0003o0000ooooo`;o00000_ooool3o`0000;ooooo0ol000000ooooooo0000o`000006
ooooo`Go00001oooool5o`000003ooooool0003o000000?o00000_ooool3o`0000;ooooo00Go0000
ooooool0003oooooo`000002ooooo`?o00000_ooool3o`000003ooooool0003o000000;ooooo0_l0
0003ooooo`?o00000_ooool3o`000003ooooool0003o000000?ooooo00?o0000ooooooooool01ooo
ool3o`0000?ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`07ooooo`?o00000ooo
ool3o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00004ooooo`04o`000?oo
ooooooooooooo`Go00000oooool2o`0000Cooooo0_l00004ooooo`;o00001oooool00ol0003ooooo
ooooo`07ooooo`Go000000?oooooo`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00Ko
00000oooool3o`0000?ooooo1?l000001Ooooooo0000o`000?l0003ooooo00Go000000?oooooo`00
0?l000000_ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo1?l00007
ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`0000Oooooo0ol00004ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0AOooool004Gooooo00Go0000ooooooooooooooooo`00
0002ooooo`05o`000?ooooooooooooooool000000oooool01ol0003ooooooooooooooooo0000oooo
ool000001_ooool01?l0003oooooooooool00007ooooo`07o`000?oooooo0000ooooool0003ooooo
o`000003ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00003oooool01Ol0003o
oooooooooooooooo000000_ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0008ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000001Oooool01ol0003oooooo`000?oooooo0000oooo
ool000001_ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo0000
1_ooool01?l0003oooooooooool0000=ooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooo`00000@ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`06
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02?ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool0000Aooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool0
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool00000
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Gooooo0014ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooool000001?l00002ooooo`04o`000?ooooooooooo`0000Oooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`05o`0000_ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`?o00001?ooool00ol0
003oooooooooo`02ooooo`;o00000oooool5o`0000;ooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooooooo1Ol0
00001ooooooo0000ooooool0003oooooo`000?ooool01Ol00002ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00_ooool5o`0000;ooooo00Co0000oooooooooooo00003Oooool0
2ol0003ooooooooooooooooo0000ooooool0003oooooo`000?oooooo000000oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`?o00000oooool01?l0
003oooooooooool00002ooooo`?o00000oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`14ooooo`00AOooool0
1?l0003oooooooooooooool3o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`07
o`000?oooooo0000ooooool0003oooooo`000003ooooo`03o`000?oooooo000000;ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`09ooooo`Co00003_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooooooool01_ooool3o`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01oooool3
o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`09o`000?oooooo0000ooooool0003o
ooooo`000?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0004ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000=ooooo`0;
o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000003oooool00ol0003ooooo
ooooo`03ooooo`;o00002Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00[o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0?ooooo`?o00001?ooool00ol0003ooooooooo
o`02ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool01_l0003oooooooooool0003ooooo
o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo0000
00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`15ooooo`00AOooool01Ol0
003ooooooooooooooooo000000Cooooo0ol00004ooooo`Go000000Coooooo`000?l0003o00000_oo
ool4o`0000Sooooo0_l000000ooooooo0000ooooo`02ooooo`?o00000oooool3o`0000?ooooo0ol0
000<ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool2o`0000Gooooo00?o0000oooo
ooooool00_ooool01?l0003oooooo`000?l00002ooooo`?o00000_ooool4o`0000Sooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool3o`0000;ooooo0_l000000ooooooo0000ooooo`02ooooo`?o00000_ooool4o`0000;ooooo1?l0
0003ooooo`?o00000_ooool4o`0000oooooo0ol00002ooooo`Ko00003_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`07ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`Co00000oooool4o`000003ooooool0
003o000000;o00000oooool2o`0000?ooooo1?l00002ooooo`Co00000_ooool2o`000004ooooool0
003o0000ooooo`Co00000oooool5o`0000Kooooo0ol00003ooooo`Co00002_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0AOooool004Kooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool05?ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03?ooooo0_l00003ooooo`05o`00
0?ooooooooooooooool000002?ooool01?l0003oooooooooool00002ooooo`;o00002Oooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`00017ooooo00Co0000oooooooooooo0000E_ooool2o`00
00[ooooo00?o0000ooooooooool0A_ooool004Sooooo1Ol00003ooooo`03o`000?oooooooooo02Oo
oooo0_l0000Dooooo`;o00003?ooool3o`0000;ooooo1?l00008ooooo`Co00002?ooool3o`0000?o
oooo0_l0000Gooooo`?o00002?ooool5o`000004ooooool0003o0000o`0001cooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`02ooooo`?o00002_ooool2o`0000Cooooo00?o0000oooo
ooooool02?ooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`00017ooooo1Ol00003oooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Aoooo
o`00oooooooooooooccooooo003ooooooooooooo??ooool00001\
\>"],
  ImageRangeCache->{{{0, 569}, {94, 0}} -> {-0.88243, -0.301052, 0.00661663, \
0.00661663}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.10363 .08333 L
.10405 .08333 L
.10453 .08333 L
.10499 .08333 L
.10541 .08333 L
.10579 .08333 L
.10622 .08333 L
.10667 .08333 L
.10713 .08333 L
.10761 .08333 L
.10807 .08333 L
.1085 .08333 L
.10899 .08333 L
.10927 .08333 L
.10952 .08333 L
.11 .08333 L
.1105 .08333 L
.11076 .08333 L
.11103 .08333 L
.11151 .08333 L
.11177 .08333 L
.11202 .08333 L
.1123 .08333 L
.11259 .08333 L
.11284 .08333 L
.11312 .08333 L
.11362 .08333 L
.11411 .08333 L
.11456 .08333 L
.11499 .08333 L
.1154 .08333 L
.11585 .08333 L
.11634 .08333 L
.11682 .08333 L
.11732 .08333 L
.11776 .08333 L
.11823 .08333 L
.11851 .08333 L
.11876 .08333 L
.11904 .08333 L
.11934 .08333 L
.11984 .08333 L
.12012 .08333 L
.12038 .08333 L
.12088 .08333 L
.12133 .08333 L
.12158 .08333 L
.12185 .08333 L
.12234 .08333 L
Mistroke
.12264 .08333 L
.12292 .08333 L
.12317 .08333 L
.12345 .08333 L
.12374 .08333 L
.12406 .08333 L
.12433 .08333 L
.12462 .08333 L
.1249 .08333 L
.12515 .08333 L
.12544 .08333 L
.12572 .08333 L
.1262 .08333 L
.12648 .08333 L
.12674 .08333 L
.12719 .08333 L
.12768 .08333 L
.12814 .08333 L
.12856 .08333 L
.12903 .08333 L
.12954 .08333 L
.1298 .08333 L
.13008 .08333 L
.13057 .08333 L
.13085 .08333 L
.1311 .08333 L
.13138 .08333 L
.13167 .08333 L
.13217 .08333 L
.13245 .08333 L
.13271 .08333 L
.1332 .08333 L
.13365 .08333 L
.13416 .08333 L
.13465 .08333 L
.13509 .08333 L
.13557 .08333 L
.13602 .08333 L
.13643 .08333 L
.13689 .08333 L
.13739 .08333 L
.13765 .08333 L
.13792 .08333 L
.1384 .08333 L
.13867 .08333 L
.13892 .08333 L
.13919 .08333 L
.13948 .08333 L
.13996 .08333 L
.14024 .08333 L
Mistroke
.1405 .08333 L
.14097 .08333 L
.14141 .08333 L
.14192 .08333 L
.1424 .08333 L
.14285 .08333 L
.14326 .08333 L
.14373 .08333 L
.14418 .08333 L
.14459 .08333 L
.14497 .08333 L
.14539 .08333 L
.14583 .08333 L
.14627 .08333 L
.14675 .08333 L
.1472 .08333 L
.14761 .08333 L
.1481 .08333 L
.14837 .08333 L
.14862 .08333 L
.14908 .08333 L
.14957 .08333 L
.15002 .08333 L
.1505 .08333 L
.15101 .08333 L
.15148 .08333 L
.15192 .08333 L
.15232 .08333 L
.15279 .08333 L
.15323 .08333 L
.1537 .08333 L
.15421 .08333 L
.15464 .08333 L
.15512 .08333 L
.15563 .08333 L
.15591 .08333 L
.15618 .08333 L
.15668 .08333 L
.15717 .08333 L
.15762 .08333 L
.15802 .08333 L
.15849 .08333 L
.15893 .08333 L
.15935 .08333 L
.15972 .08333 L
.16014 .08333 L
.16057 .08333 L
.16102 .08333 L
.16149 .08333 L
.16194 .08333 L
Mistroke
.16235 .08333 L
.16283 .08333 L
.1631 .08333 L
.16335 .08333 L
.1638 .08333 L
.16429 .08333 L
.16476 .08333 L
.16527 .08333 L
.16575 .08333 L
.1662 .08333 L
.16665 .08333 L
.16705 .08333 L
.16752 .08333 L
.16795 .08333 L
.16843 .08333 L
.16894 .08333 L
.16937 .08333 L
.16985 .08333 L
.17036 .08333 L
.17065 .08333 L
.17091 .08333 L
.17142 .08333 L
.1719 .08333 L
.17231 .08333 L
.17276 .08333 L
.17323 .08333 L
.17367 .08333 L
.17408 .08333 L
.17446 .08333 L
.17488 .08333 L
.17531 .08333 L
.17576 .08333 L
.17623 .08333 L
.17668 .08333 L
.17709 .08333 L
.17757 .08333 L
.17784 .08333 L
.17809 .08333 L
.17854 .08333 L
.17903 .08333 L
.1795 .08333 L
.18001 .08333 L
.1805 .08333 L
.18095 .08333 L
.18139 .08333 L
.1818 .08333 L
.18226 .08333 L
.1827 .08333 L
.18318 .08333 L
.18369 .08333 L
Mistroke
.18413 .08333 L
.1846 .08333 L
.18511 .08333 L
.1854 .08333 L
.18566 .08333 L
.18617 .08333 L
.18665 .08333 L
.18706 .08333 L
.18751 .08333 L
.18799 .08333 L
.18843 .08333 L
.18884 .08333 L
.18922 .08333 L
.18964 .08333 L
.19007 .08333 L
.19052 .08333 L
.19099 .08333 L
.19144 .08333 L
.19185 .08333 L
.19233 .08333 L
.1926 .08333 L
.19285 .08333 L
.1933 .08333 L
.19379 .08333 L
.19426 .08333 L
.19478 .08333 L
.19526 .08333 L
.19571 .08333 L
.19612 .08333 L
.19657 .08333 L
.19703 .08333 L
.19747 .08333 L
.19795 .08333 L
.19846 .08333 L
.1989 .08333 L
.19937 .08333 L
.19989 .08333 L
.20018 .08333 L
.20044 .08333 L
.20095 .08333 L
.20143 .08333 L
.20184 .08333 L
.20229 .08333 L
.20276 .08333 L
.20321 .08333 L
.20362 .08333 L
.204 .08333 L
.20444 .08333 L
.20485 .08333 L
.2053 .08333 L
Mistroke
.20577 .08333 L
.20622 .08333 L
.20663 .08333 L
.20711 .08333 L
.20738 .08333 L
.20763 .08333 L
.20808 .08333 L
.20857 .08333 L
.20904 .08333 L
.20931 .08333 L
.20956 .08333 L
.21001 .08333 L
.2105 .08333 L
.21093 .08333 L
.21134 .08333 L
.21178 .08333 L
.21226 .08333 L
.21274 .08333 L
.21301 .08333 L
.21327 .08333 L
.21378 .08333 L
.21407 .08333 L
.21433 .08333 L
.21479 .08333 L
.2153 .08333 L
.21578 .08333 L
.21622 .08333 L
.21663 .08333 L
.21708 .08333 L
.21749 .08333 L
.21787 .08333 L
.21832 .08333 L
.21881 .08333 L
.21927 .08333 L
.21969 .08333 L
.22017 .08333 L
.22063 .08333 L
.22103 .08333 L
.22147 .08333 L
.22195 .08333 L
.22246 .08333 L
.22289 .08333 L
.22337 .08333 L
.22388 .08333 L
.22435 .08333 L
.22459 .08333 L
.22487 .08333 L
.22515 .08333 L
.22542 .08333 L
.2259 .08333 L
Mistroke
.22635 .08333 L
.22686 .08333 L
.22735 .08333 L
.22779 .08333 L
.22825 .08333 L
.22869 .08333 L
.22909 .08333 L
.22956 .08333 L
.23007 .08333 L
.23054 .08333 L
.23099 .08333 L
.23146 .08333 L
.23196 .08333 L
.23244 .08333 L
.23287 .08333 L
.23339 .08333 L
.23367 .08333 L
.23394 .08333 L
.23443 .08333 L
.23468 .08333 L
.23495 .08333 L
.23521 .08333 L
.23549 .08333 L
.23599 .08333 L
.23627 .08333 L
.23653 .08333 L
.23681 .08333 L
.23711 .08333 L
.23737 .08333 L
.23766 .08333 L
.23793 .08333 L
.23817 .08333 L
.23864 .08333 L
.23914 .08333 L
.23961 .08333 L
.24013 .08333 L
.24061 .08333 L
.24106 .08333 L
.24151 .08333 L
.24191 .08333 L
.24238 .08333 L
.24281 .08333 L
.24329 .08333 L
.2438 .08333 L
.24424 .08333 L
.24471 .08333 L
.24522 .08333 L
.24551 .08333 L
.24577 .08333 L
.24628 .08333 L
Mistroke
.24676 .08333 L
.24717 .08333 L
.24762 .08333 L
.2481 .08333 L
.24854 .08333 L
.24895 .08333 L
.24933 .08333 L
.24974 .08333 L
.25018 .08333 L
.25062 .08333 L
.2511 .08333 L
.25155 .08333 L
.25195 .08333 L
.25243 .08333 L
.2527 .08333 L
.25295 .08333 L
.25341 .08333 L
.2539 .08333 L
.25437 .08333 L
.25488 .08333 L
.25537 .08333 L
.25582 .08333 L
.25627 .08333 L
.25667 .08333 L
.25714 .08333 L
.25758 .08333 L
.25806 .08333 L
.25857 .08333 L
.259 .08333 L
.25948 .08333 L
.25999 .08333 L
.26028 .08333 L
.26054 .08333 L
.26105 .08333 L
.26153 .08333 L
.26194 .08333 L
.26239 .08333 L
.26287 .08333 L
.26331 .08333 L
.26372 .08333 L
.2641 .08333 L
.26454 .08333 L
.26495 .08333 L
.2654 .08333 L
.26588 .08333 L
.26632 .08333 L
.26673 .08333 L
.26721 .08333 L
.26748 .08333 L
.26773 .08333 L
Mistroke
.26819 .08333 L
.26867 .08333 L
.26914 .08333 L
.26941 .08333 L
.26966 .08333 L
.27012 .08333 L
.2706 .08333 L
.27103 .08333 L
.27144 .08333 L
.27188 .08333 L
.27236 .08333 L
.27284 .08333 L
.27311 .08333 L
.27337 .08333 L
.27388 .08333 L
.27417 .08333 L
.27443 .08333 L
.27489 .08333 L
.2754 .08333 L
.27588 .08333 L
.27632 .08333 L
.27673 .08333 L
.27717 .08333 L
.27759 .08333 L
.27797 .08333 L
.27842 .08333 L
.27891 .08333 L
.27936 .08333 L
.27979 .08333 L
.28027 .08333 L
.28072 .08333 L
.28113 .08333 L
.28157 .08333 L
.28205 .08333 L
.28256 .08333 L
.28299 .08333 L
.28346 .08333 L
.28397 .08333 L
.28445 .08333 L
.28469 .08333 L
.28496 .08333 L
.28525 .08333 L
.28551 .08333 L
.286 .08333 L
.28645 .08333 L
.28694 .08333 L
.28745 .08333 L
.28789 .08333 L
.28835 .08333 L
.28879 .08333 L
Mistroke
.28919 .08333 L
.28965 .08333 L
.29016 .08333 L
.29064 .08333 L
.29108 .08333 L
.29155 .08333 L
.29206 .08333 L
.29253 .08333 L
.29297 .08333 L
.29348 .08333 L
.29377 .08333 L
.29403 .08333 L
.29452 .08333 L
.29477 .08333 L
.29504 .08333 L
.29531 .08333 L
.29559 .08333 L
.29608 .08333 L
.29636 .08333 L
.29662 .08333 L
.2969 .08333 L
.2972 .08333 L
.29747 .08333 L
.29775 .08333 L
.29802 .08333 L
.29827 .08333 L
.29874 .08333 L
.29924 .08333 L
.29971 .08333 L
.30022 .08333 L
.3007 .08333 L
.30115 .08333 L
.3016 .08333 L
.302 .08333 L
.30247 .08333 L
.30291 .08333 L
.30339 .08333 L
.30389 .08333 L
.30433 .08333 L
.3048 .08333 L
.30531 .08333 L
.3056 .08333 L
.30586 .08333 L
.30637 .08333 L
.30685 .08333 L
.30726 .08333 L
.30771 .08333 L
.30818 .08333 L
.30863 .08333 L
.30904 .08333 L
Mistroke
.30942 .08333 L
.30983 .08333 L
.31027 .08333 L
.31071 .08333 L
.31119 .08333 L
.31164 .08333 L
.31204 .08333 L
.31252 .08333 L
.31279 .08333 L
.31304 .08333 L
.3135 .08333 L
.31398 .08333 L
.31446 .08333 L
.31497 .08333 L
.31546 .08333 L
.31591 .08333 L
.31635 .08333 L
.31676 .08333 L
.31723 .08333 L
.31766 .08333 L
.31815 .08333 L
.31865 .08333 L
.31909 .08333 L
.31956 .08333 L
.32008 .08333 L
.32036 .08333 L
.32063 .08333 L
.32114 .08333 L
.32162 .08333 L
.32203 .08333 L
.32248 .08333 L
.32295 .08333 L
.3234 .08333 L
.32381 .08333 L
.32419 .08333 L
.32462 .08333 L
.32504 .08333 L
.32548 .08333 L
.32596 .08333 L
.32641 .08333 L
.32681 .08333 L
.32729 .08333 L
.32756 .08333 L
.32781 .08333 L
.32827 .08333 L
.32875 .08333 L
.32923 .08333 L
.3295 .08333 L
.32974 .08333 L
.3302 .08333 L
Mistroke
.33068 .08333 L
.33111 .08333 L
.33152 .08333 L
.33196 .08333 L
.33244 .08333 L
.33292 .08333 L
.3332 .08333 L
.33345 .08333 L
.33396 .08333 L
.33425 .08333 L
.33451 .08333 L
.33498 .08333 L
.33548 .08333 L
.33596 .08333 L
.3364 .08333 L
.33681 .08333 L
.33725 .08333 L
.33767 .08333 L
.33805 .08333 L
.3385 .08333 L
.33898 .08333 L
.33944 .08333 L
.33987 .08333 L
.34035 .08333 L
.3408 .08333 L
.34121 .08333 L
.34165 .08333 L
.34213 .08333 L
.34264 .08333 L
.34307 .08333 L
.34354 .08333 L
.34405 .08333 L
.34452 .08333 L
.34477 .08333 L
.34504 .08333 L
.34532 .08333 L
.34559 .08333 L
.34608 .08333 L
.34652 .08333 L
.34701 .08333 L
.34753 .08333 L
.34796 .08333 L
.34843 .08333 L
.34886 .08333 L
.34926 .08333 L
.34973 .08333 L
.35024 .08333 L
.35072 .08333 L
.35116 .08333 L
.35163 .08333 L
Mistroke
.35213 .08333 L
.35261 .08333 L
.35304 .08333 L
.35355 .08333 L
.35384 .08333 L
.35411 .08333 L
.3546 .08333 L
.35485 .08333 L
.35512 .08333 L
.35538 .08333 L
.35566 .08333 L
.35616 .08333 L
.35643 .08333 L
.35669 .08333 L
.35698 .08333 L
.35728 .08333 L
.35754 .08333 L
.35783 .08333 L
.35809 .08333 L
.35834 .08333 L
.35881 .08333 L
.35931 .08333 L
.35978 .08333 L
.36029 .08333 L
.36078 .08333 L
.36123 .08333 L
.36167 .08333 L
.36207 .08333 L
.36254 .08333 L
.36298 .08333 L
.36346 .08333 L
.36396 .08333 L
.3644 .08333 L
.36487 .08333 L
.36538 .08333 L
.36567 .08333 L
.36593 .08333 L
.36644 .08333 L
.36692 .08333 L
.36733 .08333 L
.36778 .08333 L
.36825 .08333 L
.3687 .08333 L
.36911 .08333 L
.36949 .08333 L
.3699 .08333 L
.37034 .08333 L
.37078 .08333 L
.37126 .08333 L
.37171 .08333 L
Mistroke
.37211 .08333 L
.37259 .08333 L
.37286 .08333 L
.37311 .08333 L
.37357 .08333 L
.37405 .08333 L
.37453 .08333 L
.37504 .08333 L
.37553 .08333 L
.37598 .08333 L
.37642 .08333 L
.37683 .08333 L
.37729 .08333 L
.37773 .08333 L
.37821 .08333 L
.37872 .08333 L
.37916 .08333 L
.37963 .08333 L
.38014 .08333 L
.38043 .08333 L
.38069 .08333 L
.3812 .08333 L
.38168 .08333 L
.38209 .08333 L
.38255 .08333 L
.38302 .08333 L
.38346 .08333 L
.38387 .08333 L
.38425 .08333 L
.38467 .08333 L
.3851 .08333 L
.38555 .08333 L
.38602 .08333 L
.38647 .08333 L
.38688 .08333 L
.38736 .08333 L
.38763 .08333 L
.38788 .08333 L
.38834 .08333 L
.38882 .08333 L
.38929 .08333 L
.38956 .08333 L
.38981 .08333 L
.39026 .08333 L
.39075 .08333 L
.39118 .08333 L
.39158 .08333 L
.39203 .08333 L
.39251 .08333 L
.39299 .08333 L
Mistroke
.39326 .08333 L
.39351 .08333 L
.39402 .08333 L
.39431 .08333 L
.39457 .08333 L
.39504 .08333 L
.39554 .08333 L
.39602 .08333 L
.39646 .08333 L
.39687 .08333 L
.39731 .08333 L
.39773 .08333 L
.39811 .08333 L
.39856 .08333 L
.39904 .08333 L
.3995 .08333 L
.39993 .08333 L
.40041 .08333 L
.40086 .08333 L
.40127 .08333 L
.40171 .08333 L
.40219 .08333 L
.4027 .08333 L
.40313 .08333 L
.4036 .08333 L
.40411 .08333 L
.40458 .08333 L
.40483 .08333 L
.4051 .08333 L
.40538 .08333 L
.40565 .08333 L
.40614 .08333 L
.40658 .08333 L
.40707 .08333 L
.40759 .08333 L
.40802 .08333 L
.40848 .08333 L
.40892 .08333 L
.40932 .08333 L
.40979 .08333 L
.41029 .08333 L
.41077 .08333 L
.41121 .08333 L
.41168 .08333 L
.41219 .08333 L
.41266 .08333 L
.4131 .08333 L
.41361 .08333 L
.4139 .08333 L
.41416 .08333 L
Mistroke
.41465 .08333 L
.41493 .08333 L
.41517 .08333 L
.41544 .08333 L
.41572 .08333 L
.41621 .08333 L
.41649 .08333 L
.41675 .08333 L
.41703 .08333 L
.41733 .08333 L
.4176 .08333 L
.41788 .08333 L
.41815 .08333 L
.4184 .08333 L
.41887 .08333 L
.41936 .08333 L
.41983 .08333 L
.42035 .08333 L
.42083 .08333 L
.42128 .08333 L
.42172 .08333 L
.42213 .08333 L
.42259 .08333 L
.42303 .08333 L
.42351 .08333 L
.42402 .08333 L
.42445 .08333 L
.42492 .08333 L
.42544 .08333 L
.42572 .08333 L
.42598 .08333 L
.42649 .08333 L
.42697 .08333 L
.42738 .08333 L
.42783 .08333 L
.42831 .08333 L
.42875 .08333 L
.42916 .08333 L
.42954 .08333 L
.42995 .08333 L
.43039 .08333 L
.43083 .08333 L
.43131 .08333 L
.43176 .08333 L
.43216 .08333 L
.43264 .08333 L
.43291 .08333 L
.43316 .08333 L
.43362 .08333 L
.4341 .08333 L
Mistroke
.43458 .08333 L
.43509 .08333 L
.43557 .08333 L
.43602 .08333 L
.43647 .08333 L
.43687 .08333 L
.43734 .08333 L
.43778 .08333 L
.43826 .08333 L
.43877 .08333 L
.4392 .08333 L
.43968 .08333 L
.44019 .08333 L
.44048 .08333 L
.44074 .08333 L
.44125 .08333 L
.44173 .08333 L
.44214 .08333 L
.44259 .08333 L
.44306 .08333 L
.44351 .08333 L
.44392 .08333 L
.4443 .08333 L
.44471 .08333 L
.44515 .08333 L
.44559 .08333 L
.44607 .08333 L
.44652 .08333 L
.44692 .08333 L
.4474 .08333 L
.44767 .08333 L
.44792 .08333 L
.44838 .08333 L
.44886 .08333 L
.44934 .08333 L
.44961 .08333 L
.44985 .08333 L
.45031 .08333 L
.45079 .08333 L
.45122 .08333 L
.45163 .08333 L
.45207 .08333 L
.45255 .08333 L
.45303 .08333 L
.4533 .08333 L
.45355 .08333 L
.45407 .08333 L
.45435 .08333 L
.45461 .08333 L
.45508 .08333 L
Mistroke
.45558 .08333 L
.45606 .08333 L
.4565 .08333 L
.45692 .08333 L
.45736 .08333 L
.45777 .08333 L
.45815 .08333 L
.4586 .08333 L
.45909 .08333 L
.45954 .08333 L
.45997 .08333 L
.46045 .08333 L
.4609 .08333 L
.46131 .08333 L
.46175 .08333 L
.46223 .08333 L
.46274 .08333 L
.46317 .08333 L
.46364 .08333 L
.46399 .08333 L
.46431 .08333 L
.46465 .08333 L
.46503 .08333 L
.46535 .08333 L
.46565 .08333 L
.46598 .08333 L
.46633 .08333 L
.46663 .08333 L
.46696 .08333 L
.4673 .08333 L
.46761 .08333 L
.46791 .08333 L
.46818 .08333 L
.46849 .08333 L
.46878 .08333 L
.4691 .08333 L
.46945 .08333 L
.46982 .08333 L
.47016 .08333 L
.47048 .08333 L
.47077 .08333 L
.47111 .08333 L
.47143 .08333 L
.47177 .08333 L
.47214 .08333 L
.47248 .08333 L
.4728 .08333 L
.47317 .08333 L
.47357 .08333 L
.47394 .08333 L
Mistroke
.47429 .08333 L
Mfstroke
.47429 .08333 m
.47477 .08333 L
.4752 .08333 L
.4757 .08333 L
.47617 .08333 L
.47661 .08333 L
.47702 .08333 L
.47746 .08333 L
.47793 .08333 L
.4784 .08333 L
.47891 .08333 L
.47939 .08333 L
.47983 .08333 L
.48034 .08333 L
.48063 .08333 L
.4809 .08333 L
.48139 .08333 L
.48192 .08333 L
.48218 .08333 L
.48246 .08333 L
.48296 .08333 L
.48324 .08333 L
.4835 .08333 L
.48378 .08333 L
.48409 .08333 L
.48435 .08333 L
.48464 .08333 L
.48516 .08333 L
.48566 .08333 L
.48613 .08333 L
.48659 .08333 L
.48701 .08333 L
.48748 .08333 L
.48799 .08333 L
.48849 .08333 L
.48901 .08333 L
.48946 .08333 L
.48996 .08333 L
.49024 .08333 L
.49051 .08333 L
.4908 .08333 L
.49111 .08333 L
.49163 .08333 L
.49192 .08333 L
.4922 .08333 L
.49271 .08333 L
.49318 .08333 L
.49344 .08333 L
.49372 .08333 L
.49424 .08333 L
Mistroke
.49455 .08333 L
.49484 .08333 L
.4951 .08333 L
.49538 .08333 L
.49569 .08333 L
.49602 .08333 L
.4963 .08333 L
.49661 .08333 L
.4969 .08333 L
.49716 .08333 L
.49746 .08333 L
.49775 .08333 L
.49825 .08333 L
.49854 .08333 L
.49881 .08333 L
.49928 .08333 L
.49979 .08333 L
.50027 .08333 L
.50071 .08333 L
.5012 .08333 L
.50173 .08333 L
.502 .08333 L
.50229 .08333 L
.5028 .08333 L
.50309 .08333 L
.50335 .08333 L
.50364 .08333 L
.50395 .08333 L
.50446 .08333 L
.50475 .08333 L
.50503 .08333 L
.50553 .08333 L
.506 .08333 L
.50653 .08333 L
.50704 .08333 L
.5075 .08333 L
.508 .08333 L
.50847 .08333 L
.5089 .08333 L
.50938 .08333 L
.5099 .08333 L
.51016 .08333 L
.51044 .08333 L
.51095 .08333 L
.51123 .08333 L
.51149 .08333 L
.51177 .08333 L
.51207 .08333 L
.51257 .08333 L
.51286 .08333 L
Mistroke
.51313 .08333 L
.51362 .08333 L
.51408 .08333 L
.51461 .08333 L
.5151 .08333 L
.51558 .08333 L
.516 .08333 L
.51649 .08333 L
.51696 .08333 L
.51739 .08333 L
.51778 .08333 L
.51822 .08333 L
.51868 .08333 L
.51914 .08333 L
.51964 .08333 L
.52011 .08333 L
.52053 .08333 L
.52103 .08333 L
.52132 .08333 L
.52158 .08333 L
.52206 .08333 L
.52257 .08333 L
.52303 .08333 L
.52354 .08333 L
.52406 .08333 L
.52456 .08333 L
.52502 .08333 L
.52543 .08333 L
.52592 .08333 L
.52637 .08333 L
.52687 .08333 L
.5274 .08333 L
.52785 .08333 L
.52834 .08333 L
.52887 .08333 L
.52917 .08333 L
.52944 .08333 L
.52997 .08333 L
.53047 .08333 L
.53094 .08333 L
.53136 .08333 L
.53185 .08333 L
.53231 .08333 L
.53274 .08333 L
.53313 .08333 L
.53357 .08333 L
.53402 .08333 L
.53448 .08333 L
.53497 .08333 L
.53544 .08333 L
Mistroke
.53586 .08333 L
.53636 .08333 L
.53664 .08333 L
.5369 .08333 L
.53738 .08333 L
.53789 .08333 L
.53837 .08333 L
.53891 .08333 L
.53941 .08333 L
.53988 .08333 L
.54034 .08333 L
.54076 .08333 L
.54124 .08333 L
.5417 .08333 L
.5422 .08333 L
.54273 .08333 L
.54318 .08333 L
.54367 .08333 L
.5442 .08333 L
.5445 .08333 L
.54477 .08333 L
.5453 .08333 L
.5458 .08333 L
.54623 .08333 L
.5467 .08333 L
.54719 .08333 L
.54765 .08333 L
.54808 .08333 L
.54847 .08333 L
.5489 .08333 L
.54936 .08333 L
.54982 .08333 L
.55031 .08333 L
.55078 .08333 L
.5512 .08333 L
.5517 .08333 L
.55198 .08333 L
.55224 .08333 L
.55272 .08333 L
.55322 .08333 L
.55371 .08333 L
.55425 .08333 L
.55475 .08333 L
.55522 .08333 L
.55568 .08333 L
.5561 .08333 L
.55659 .08333 L
.55705 .08333 L
.55755 .08333 L
.55808 .08333 L
Mistroke
.55853 .08333 L
.55902 .08333 L
.55955 .08333 L
.55985 .08333 L
.56013 .08333 L
.56066 .08333 L
.56116 .08333 L
.56158 .08333 L
.56205 .08333 L
.56254 .08333 L
.563 .08333 L
.56343 .08333 L
.56383 .08333 L
.56426 .08333 L
.56471 .08333 L
.56518 .08333 L
.56567 .08333 L
.56614 .08333 L
.56656 .08333 L
.56706 .08333 L
.56734 .08333 L
.5676 .08333 L
.56808 .08333 L
.56858 .08333 L
.56907 .08333 L
.56961 .08333 L
.57012 .08333 L
.57058 .08333 L
.57101 .08333 L
.57147 .08333 L
.57196 .08333 L
.57241 .08333 L
.57292 .08333 L
.57345 .08333 L
.5739 .08333 L
.57439 .08333 L
.57493 .08333 L
.57523 .08333 L
.5755 .08333 L
.57603 .08333 L
.57653 .08333 L
.57696 .08333 L
.57743 .08333 L
.57792 .08333 L
.57838 .08333 L
.57881 .08333 L
.57921 .08333 L
.57966 .08333 L
.58009 .08333 L
.58056 .08333 L
Mistroke
.58105 .08333 L
.58152 .08333 L
.58194 .08333 L
.58244 .08333 L
.58272 .08333 L
.58298 .08333 L
.58346 .08333 L
.58396 .08333 L
.58445 .08333 L
.58473 .08333 L
.58499 .08333 L
.58547 .08333 L
.58597 .08333 L
.58642 .08333 L
.58684 .08333 L
.5873 .08333 L
.5878 .08333 L
.5883 .08333 L
.58859 .08333 L
.58885 .08333 L
.58938 .08333 L
.58968 .08333 L
.58995 .08333 L
.59044 .08333 L
.59097 .08333 L
.59147 .08333 L
.59192 .08333 L
.59235 .08333 L
.59281 .08333 L
.59325 .08333 L
.59364 .08333 L
.59411 .08333 L
.59462 .08333 L
.59509 .08333 L
.59554 .08333 L
.59604 .08333 L
.59651 .08333 L
.59693 .08333 L
.59739 .08333 L
.59789 .08333 L
.59842 .08333 L
.59887 .08333 L
.59936 .08333 L
.59989 .08333 L
.60038 .08333 L
.60064 .08333 L
.60092 .08333 L
.60122 .08333 L
.60149 .08333 L
.602 .08333 L
Mistroke
.60246 .08333 L
.603 .08333 L
.60351 .08333 L
.60396 .08333 L
.60445 .08333 L
.6049 .08333 L
.60532 .08333 L
.6058 .08333 L
.60633 .08333 L
.60683 .08333 L
.60729 .08333 L
.60778 .08333 L
.6083 .08333 L
.6088 .08333 L
.60925 .08333 L
.60979 .08333 L
.61009 .08333 L
.61036 .08333 L
.61087 .08333 L
.61113 .08333 L
.61141 .08333 L
.61169 .08333 L
.61198 .08333 L
.6125 .08333 L
.61278 .08333 L
.61305 .08333 L
.61335 .08333 L
.61366 .08333 L
.61394 .08333 L
.61423 .08333 L
.61451 .08333 L
.61477 .08333 L
.61526 .08333 L
.61578 .08333 L
.61626 .08333 L
.6168 .08333 L
.6173 .08333 L
.61777 .08333 L
.61823 .08333 L
.61866 .08333 L
.61914 .08333 L
.6196 .08333 L
.6201 .08333 L
.62062 .08333 L
.62108 .08333 L
.62157 .08333 L
.6221 .08333 L
.6224 .08333 L
.62267 .08333 L
.6232 .08333 L
Mistroke
.6237 .08333 L
.62413 .08333 L
.6246 .08333 L
.62509 .08333 L
.62555 .08333 L
.62598 .08333 L
.62638 .08333 L
.62681 .08333 L
.62726 .08333 L
.62772 .08333 L
.62822 .08333 L
.62869 .08333 L
.62911 .08333 L
.62961 .08333 L
.62989 .08333 L
.63015 .08333 L
.63062 .08333 L
.63113 .08333 L
.63162 .08333 L
.63216 .08333 L
.63266 .08333 L
.63313 .08333 L
.6336 .08333 L
.63402 .08333 L
.6345 .08333 L
.63496 .08333 L
.63546 .08333 L
.63599 .08333 L
.63644 .08333 L
.63694 .08333 L
.63747 .08333 L
.63777 .08333 L
.63804 .08333 L
.63857 .08333 L
.63907 .08333 L
.6395 .08333 L
.63997 .08333 L
.64046 .08333 L
.64093 .08333 L
.64136 .08333 L
.64175 .08333 L
.6422 .08333 L
.64263 .08333 L
.6431 .08333 L
.64359 .08333 L
.64406 .08333 L
.64448 .08333 L
.64498 .08333 L
.64526 .08333 L
.64552 .08333 L
Mistroke
.646 .08333 L
.6465 .08333 L
.647 .08333 L
.64728 .08333 L
.64753 .08333 L
.64801 .08333 L
.64851 .08333 L
.64896 .08333 L
.64938 .08333 L
.64984 .08333 L
.65034 .08333 L
.65084 .08333 L
.65113 .08333 L
.65139 .08333 L
.65192 .08333 L
.65222 .08333 L
.65249 .08333 L
.65298 .08333 L
.65351 .08333 L
.654 .08333 L
.65446 .08333 L
.65489 .08333 L
.65535 .08333 L
.65579 .08333 L
.65618 .08333 L
.65665 .08333 L
.65715 .08333 L
.65763 .08333 L
.65807 .08333 L
.65857 .08333 L
.65905 .08333 L
.65947 .08333 L
.65993 .08333 L
.66043 .08333 L
.66095 .08333 L
.6614 .08333 L
.6619 .08333 L
.66243 .08333 L
.66292 .08333 L
.66317 .08333 L
.66346 .08333 L
.66375 .08333 L
.66403 .08333 L
.66453 .08333 L
.665 .08333 L
.66551 .08333 L
.66604 .08333 L
.6665 .08333 L
.66698 .08333 L
.66744 .08333 L
Mistroke
.66785 .08333 L
.66834 .08333 L
.66886 .08333 L
.66936 .08333 L
.66982 .08333 L
.67031 .08333 L
.67084 .08333 L
.67133 .08333 L
.67179 .08333 L
.67232 .08333 L
.67262 .08333 L
.6729 .08333 L
.6734 .08333 L
.67366 .08333 L
.67395 .08333 L
.67422 .08333 L
.67451 .08333 L
.67503 .08333 L
.67532 .08333 L
.67558 .08333 L
.67588 .08333 L
.67619 .08333 L
.67647 .08333 L
.67676 .08333 L
.67704 .08333 L
.6773 .08333 L
.67779 .08333 L
.67831 .08333 L
.6788 .08333 L
.67933 .08333 L
.67983 .08333 L
.6803 .08333 L
.68077 .08333 L
.68119 .08333 L
.68167 .08333 L
.68213 .08333 L
.68263 .08333 L
.68315 .08333 L
.68361 .08333 L
.6841 .08333 L
.68463 .08333 L
.68493 .08333 L
.6852 .08333 L
.68573 .08333 L
.68623 .08333 L
.68666 .08333 L
.68713 .08333 L
.68762 .08333 L
.68808 .08333 L
.68851 .08333 L
Mistroke
.6889 .08333 L
.68933 .08333 L
.68979 .08333 L
.69025 .08333 L
.69075 .08333 L
.69121 .08333 L
.69164 .08333 L
.69213 .08333 L
.69242 .08333 L
.69267 .08333 L
.69315 .08333 L
.69366 .08333 L
.69415 .08333 L
.69468 .08333 L
.69519 .08333 L
.69566 .08333 L
.69612 .08333 L
.69654 .08333 L
.69703 .08333 L
.69748 .08333 L
.69799 .08333 L
.69852 .08333 L
.69897 .08333 L
.69946 .08333 L
.7 .08333 L
.70029 .08333 L
.70057 .08333 L
.7011 .08333 L
.7016 .08333 L
.70202 .08333 L
.7025 .08333 L
.70299 .08333 L
.70345 .08333 L
.70388 .08333 L
.70427 .08333 L
.70473 .08333 L
.70516 .08333 L
.70562 .08333 L
.70612 .08333 L
.70658 .08333 L
.70701 .08333 L
.7075 .08333 L
.70779 .08333 L
.70804 .08333 L
.70852 .08333 L
.70902 .08333 L
.70952 .08333 L
.7098 .08333 L
.71006 .08333 L
.71053 .08333 L
Mistroke
.71103 .08333 L
.71148 .08333 L
.7119 .08333 L
.71237 .08333 L
.71286 .08333 L
.71336 .08333 L
.71365 .08333 L
.71391 .08333 L
.71444 .08333 L
.71474 .08333 L
.71501 .08333 L
.7155 .08333 L
.71602 .08333 L
.71652 .08333 L
.71698 .08333 L
.71741 .08333 L
.71787 .08333 L
.7183 .08333 L
.7187 .08333 L
.71916 .08333 L
.71967 .08333 L
.72015 .08333 L
.72059 .08333 L
.72109 .08333 L
.72156 .08333 L
.72199 .08333 L
.72244 .08333 L
.72294 .08333 L
.72347 .08333 L
.72392 .08333 L
.72441 .08333 L
.72494 .08333 L
.72543 .08333 L
.72569 .08333 L
.72597 .08333 L
.72627 .08333 L
.72654 .08333 L
.72705 .08333 L
.72751 .08333 L
.72802 .08333 L
.72856 .08333 L
.72901 .08333 L
.72949 .08333 L
.72995 .08333 L
.73036 .08333 L
.73085 .08333 L
.73138 .08333 L
.73188 .08333 L
.73234 .08333 L
.73283 .08333 L
Mistroke
.73335 .08333 L
.73385 .08333 L
.7343 .08333 L
.73483 .08333 L
.73513 .08333 L
.73541 .08333 L
.73592 .08333 L
.73617 .08333 L
.73646 .08333 L
.73673 .08333 L
.73702 .08333 L
.73754 .08333 L
.73783 .08333 L
.7381 .08333 L
.73839 .08333 L
.73871 .08333 L
.73898 .08333 L
.73928 .08333 L
.73956 .08333 L
.73981 .08333 L
.7403 .08333 L
.74082 .08333 L
.74131 .08333 L
.74184 .08333 L
.74235 .08333 L
.74281 .08333 L
.74328 .08333 L
.7437 .08333 L
.74418 .08333 L
.74464 .08333 L
.74514 .08333 L
.74566 .08333 L
.74611 .08333 L
.74661 .08333 L
.74714 .08333 L
.74744 .08333 L
.74771 .08333 L
.74824 .08333 L
.74874 .08333 L
.74917 .08333 L
.74964 .08333 L
.75013 .08333 L
.75059 .08333 L
.75102 .08333 L
.75141 .08333 L
.75184 .08333 L
.7523 .08333 L
.75276 .08333 L
.75325 .08333 L
.75372 .08333 L
Mistroke
.75414 .08333 L
.75464 .08333 L
.75492 .08333 L
.75518 .08333 L
.75566 .08333 L
.75616 .08333 L
.75665 .08333 L
.75719 .08333 L
.75769 .08333 L
.75816 .08333 L
.75863 .08333 L
.75905 .08333 L
.75953 .08333 L
.75999 .08333 L
.76049 .08333 L
.76102 .08333 L
.76147 .08333 L
.76197 .08333 L
.7625 .08333 L
.7628 .08333 L
.76307 .08333 L
.7636 .08333 L
.7641 .08333 L
.76453 .08333 L
.765 .08333 L
.76549 .08333 L
.76595 .08333 L
.76638 .08333 L
.76677 .08333 L
.76721 .08333 L
.76766 .08333 L
.76812 .08333 L
.76862 .08333 L
.76908 .08333 L
.76951 .08333 L
.77001 .08333 L
.77029 .08333 L
.77055 .08333 L
.77102 .08333 L
.77153 .08333 L
.77202 .08333 L
.7723 .08333 L
.77256 .08333 L
.77303 .08333 L
.77353 .08333 L
.77398 .08333 L
.7744 .08333 L
.77487 .08333 L
.77536 .08333 L
.77586 .08333 L
Mistroke
.77615 .08333 L
.77641 .08333 L
.77694 .08333 L
.77724 .08333 L
.77751 .08333 L
.778 .08333 L
.77852 .08333 L
.77902 .08333 L
.77948 .08333 L
.77991 .08333 L
.78037 .08333 L
.7808 .08333 L
.7812 .08333 L
.78166 .08333 L
.78217 .08333 L
.78265 .08333 L
.78309 .08333 L
.78359 .08333 L
.78406 .08333 L
.78448 .08333 L
.78494 .08333 L
.78544 .08333 L
.78597 .08333 L
.78642 .08333 L
.78691 .08333 L
.78744 .08333 L
.78793 .08333 L
.78819 .08333 L
.78847 .08333 L
.78876 .08333 L
.78904 .08333 L
.78955 .08333 L
.79001 .08333 L
.79052 .08333 L
.79105 .08333 L
.79151 .08333 L
.79199 .08333 L
.79244 .08333 L
.79286 .08333 L
.79334 .08333 L
.79387 .08333 L
.79437 .08333 L
.79483 .08333 L
.79532 .08333 L
.79584 .08333 L
.79634 .08333 L
.79679 .08333 L
.79732 .08333 L
.79762 .08333 L
.7979 .08333 L
Mistroke
.79841 .08333 L
.79869 .08333 L
.79895 .08333 L
.79923 .08333 L
.79951 .08333 L
.80003 .08333 L
.80032 .08333 L
.80059 .08333 L
.80088 .08333 L
.8012 .08333 L
.80147 .08333 L
.80177 .08333 L
.80205 .08333 L
.80231 .08333 L
.80279 .08333 L
.80331 .08333 L
.8038 .08333 L
.80433 .08333 L
.80484 .08333 L
.8053 .08333 L
.80577 .08333 L
.80619 .08333 L
.80667 .08333 L
.80713 .08333 L
.80763 .08333 L
.80815 .08333 L
.8086 .08333 L
.8091 .08333 L
.80963 .08333 L
.80993 .08333 L
.8102 .08333 L
.81073 .08333 L
.81123 .08333 L
.81166 .08333 L
.81213 .08333 L
.81262 .08333 L
.81308 .08333 L
.8135 .08333 L
.8139 .08333 L
.81433 .08333 L
.81478 .08333 L
.81525 .08333 L
.81574 .08333 L
.81621 .08333 L
.81663 .08333 L
.81713 .08333 L
.81741 .08333 L
.81767 .08333 L
.81815 .08333 L
.81865 .08333 L
Mistroke
.81914 .08333 L
.81967 .08333 L
.82018 .08333 L
.82065 .08333 L
.82111 .08333 L
.82153 .08333 L
.82202 .08333 L
.82247 .08333 L
.82298 .08333 L
.8235 .08333 L
.82395 .08333 L
.82445 .08333 L
.82498 .08333 L
.82528 .08333 L
.82555 .08333 L
.82608 .08333 L
.82658 .08333 L
.82701 .08333 L
.82748 .08333 L
.82797 .08333 L
.82843 .08333 L
.82886 .08333 L
.82926 .08333 L
.82969 .08333 L
.83014 .08333 L
.83061 .08333 L
.8311 .08333 L
.83157 .08333 L
.83199 .08333 L
.83249 .08333 L
.83277 .08333 L
.83303 .08333 L
.83351 .08333 L
.83401 .08333 L
.8345 .08333 L
.83478 .08333 L
.83504 .08333 L
.83551 .08333 L
.83601 .08333 L
.83646 .08333 L
.83688 .08333 L
.83735 .08333 L
.83784 .08333 L
.83834 .08333 L
.83863 .08333 L
.83889 .08333 L
.83942 .08333 L
.83972 .08333 L
.83999 .08333 L
.84048 .08333 L
Mistroke
.841 .08333 L
.8415 .08333 L
.84196 .08333 L
.84239 .08333 L
.84285 .08333 L
.84328 .08333 L
.84368 .08333 L
.84414 .08333 L
.84464 .08333 L
.84512 .08333 L
.84557 .08333 L
.84607 .08333 L
.84654 .08333 L
.84696 .08333 L
.84742 .08333 L
.84792 .08333 L
.84844 .08333 L
.84889 .08333 L
.84939 .08333 L
.84975 .08333 L
.85008 .08333 L
.85044 .08333 L
.85083 .08333 L
.85116 .08333 L
.85147 .08333 L
.85182 .08333 L
.85219 .08333 L
.8525 .08333 L
.85283 .08333 L
.85319 .08333 L
.85352 .08333 L
.85383 .08333 L
.85411 .08333 L
.85443 .08333 L
.85474 .08333 L
.85507 .08333 L
.85543 .08333 L
.85581 .08333 L
.85617 .08333 L
.8565 .08333 L
.8568 .08333 L
.85715 .08333 L
.85749 .08333 L
.85784 .08333 L
.85823 .08333 L
.85859 .08333 L
.85891 .08333 L
.8593 .08333 L
.85971 .08333 L
.86011 .08333 L
Mistroke
.86047 .08333 L
Mfstroke
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{570, 95},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008j0000Gb000`400?l00000o`00003ooooooooo
oooooccooooo0024ooooo`;o0000@oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
04?ooooo0ol00013ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000@Oooool5o`00
08Gooooo0023ooooo`04o`000?ooooooooooo`00047ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000004?ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool00000@Oooool01?l0003oooooooooool00025ooooo`00
Poooool01?l0003oooooooooool00011ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`25ooooo`00Poooool01?l0003oooooooooool00011oooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`24
ooooo`00Poooool01?l0003oooooooooool00011ooooo`04o`000?ooooooooooo`0000Oooooo1?l0
0014ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool01oooool4o`00047ooooo00Go
0000ooooooooooooooooo`000025ooooo`00Poooool01?l0003oooooooooool00011ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0A?ooool2o`0004Cooooo0_l00009ooooo`03
o`000?oooooooooo04;ooooo00Go0000ooooooooooooooooo`000025ooooo`00Q?ooool2o`0004?o
oooo0_l00008ooooo`Go0000@oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Oo
oooo1Ol00011ooooo`?o0000Q_ooool00?oooooooooooollooooo`00oooooooooooooccooooo003o
oooooooooooo??ooool00?oooooooooooollooooo`00oooooooooooooccooooo0019ooooo`;o0000
1?ooool01?l0003oooooooooooooool5o`000?oooooohoooool004Sooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00006oooooooo0000O_l0001Oooooo`00@Oooool5o`0000;o
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Mooooo`00B?ooool01?l0003o
ooooooooool0000:ooooo`03o`000?oooooooooo00Gooooo0ol00006ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Cooooo0ol0001Oooooo`00B?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo04Sooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1Mooooo`00B?ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Tooooo`03o`00oooo
oooooooo0?ooooooDoooool00ol0003oooooooooo`1Mooooo`00BOooool2o`0000Wooooo0ol00007
ooooo`;o00009Oooool00ol00?ooooooooooo`3ooooooe;ooooo0_l0001Oooooo`00G_ooool00ol0
003oooooooooo`0Tooooo`03o`00oooooooooooo0?ooooooDoooool00ol0003oooooooooo`1Moooo
o`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo0?ooooooDoooool00ol0003o
ooooooooo`1Mooooo`00G_ooool2o`0002Gooooo00?o003oooooooooool0oooooomBooooo`;o0000
Goooool005kooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`3ooooooe?ooooo00?o
0000ooooooooool0GOooool005kooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`3o
oooooe?ooooo00?o0000ooooooooool0GOooool005kooooo0_l0000Uooooo`03o`00oooooooooooo
0?ooooooD_ooool2o`0005oooooo001Nooooo`03o`000?oooooooooo02Cooooo00?o003ooooooooo
ool0oooooomCooooo`03o`000?oooooooooo05gooooo001Nooooo`03o`000?oooooooooo02Cooooo
00?o003oooooooooool0oooooomCooooo`03o`000?oooooooooo05gooooo0019ooooo`;o00001?oo
ool00ol0003oooooooooo`02ooooo`?o00001oooool2o`0002Gooooo00?o003oooooooooool0oooo
oomBooooo`;o0000Goooool004Sooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool0oooooomCooooo`03o`000?oo
oooooooo05gooooo0011ooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`3ooooooe?ooooo00?o
0000ooooooooool0GOooool004Sooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`06ooooo`?o00009?ooool00ol00?ooooooooooo`3ooooooe7ooooo0ol0001Oooooo`00B?ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09?oo
ool00ol00?ooooooooooo`3ooooooe?ooooo00?o0000ooooooooool0GOooool004Sooooo00Co0000
oooooooooooo00002?ooool2o`0000Sooooo00?o0000ooooooooool09?ooool00ol00?oooooooooo
o`3ooooooe?ooooo00?o0000ooooooooool0GOooool004Wooooo0_l0000:ooooo`03o`000?oooooo
oooo00Kooooo0_l0000Uooooo`03o`00oooooooooooo0?oooooo>?ooool2o`00o`03ooooool00?oo
003o01Gooooo0_l0001Oooooo`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo
0?oooooo>Oooool00ol00?ooooooo`00o`0Gooooo`03o`000?oooooooooo05gooooo001Nooooo`03
o`000?oooooooooo02Cooooo00?o003oooooooooool0ooooooljooooo`03o`00oooooooooooo01Ko
oooo00?o0000ooooooooool0GOooool005kooooo0_l0000Uooooo`03o`00oooooooooooo0?oooooo
>Oooool00ol00?ooooooo`00o`0Fooooo`;o0000Goooool005kooooo00?o0000ooooooooool09?oo
ool00ol00?ooooooooooo`3oooooocSooooo0_l00?l00ooooooo003oo`00o`0Fooooo`03o`000?oo
oooooooo05gooooo001Nooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool0oooooomC
ooooo`03o`000?oooooooooo05gooooo001Nooooo`;o00009Oooool00ol00?ooooooooooo`3ooooo
oe;ooooo0_l0001Oooooo`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo0?oo
ooooDoooool00ol0003oooooooooo`1Mooooo`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00
oooooooooooo0?ooooooDoooool00ol0003oooooooooo`1Mooooo`00EOooool2o`0000Oooooo0_l0
000Tooooo`?o0000U?ooool3o`0009Cooooo0ol0000Tooooo`;o0000Goooool005Cooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooooooo`0Rooooo`05o`000?l00?oo003oo`00ool00000
T_ooool01Ol0003ooooooooooooooooo000009;ooooo00Go0000ooooooooooooooooo`00000Toooo
o`03o`000?oooooooooo05gooooo001Dooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool08_ooool01Ol0003o003oo`00ool00?oo000009;ooooo00Go0000ooooooooooooooooo`00
002Booooo`05o`000?ooooooooooooooool000009?ooool00ol0003oooooooooo`1Mooooo`00E?oo
ool01?l0003oooooooooool00006ooooo`?o00001_oooolKo`00o`03o`000?l00?oo003o0?ooo`00
8_oo000>o`0000;o003o00?o0000o`00ool00?l06Ol00?l6ooooo`?o0000Goooool005Cooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooooooo`0Qooooo`03o`000?l00?oo003o00?o003o
00?o0000ooooooooool0S_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo05gooooo
001Dooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool08_ooool2o`000003o`00
ool0003o000009;ooooo0_l000000ooooooo0000o`00002Booooo`;o000000?oooooo`000?l00000
9?ooool00ol0003oooooooooo`1Mooooo`00EOooool2o`0000Oooooo0_l0000Uooooo`03o`000?oo
oooooooo09Cooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Sooooo`;o0000Gooo
ool005kooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`3ooooooe?ooooo00?o0000
ooooooooool0GOooool005kooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`3ooooo
oe?ooooo00?o0000ooooooooool0GOooool005kooooo0_l0000Uooooo`03o`00oooooooooooo0?oo
ooooD_ooool2o`0005oooooo001Nooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool0
oooooomCooooo`03o`000?oooooooooo05gooooo001Nooooo`03o`000?oooooooooo02Cooooo00?o
003oooooooooool01Oooool3o`0009?ooooo1Ol0002Cooooo`?o00007?ooool00ol0003ooooooooo
o`1Mooooo`00G_ooool2o`0002Gooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`2C
ooooo`04o`000?ooooooooooo`0009;ooooo00Go0000ooooooooooooooooo`00000Jooooo`;o0000
Goooool005kooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`06ooooo`03o`000?oo
oooooooo09Cooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo05gooooo001Nooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool01?ooool2
o`00o`03o`000?oooooooooo09Gooooo00?o0000ooooooooool0Toooool2o`0001cooooo00?o0000
ooooooooool0GOooool005kooooo0_l0000Uooooo`03o`00oooooooooooo00Gooooo00?o003oo`00
0?ooool0Toooool01Ol0003ooooooooooooooooo000009Kooooo00?o0000ooooooooool06?ooool2
o`0005oooooo0019ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001oooool00ol0
003oooooooooo`0Tooooo`03o`00oooooooooooo00Gooooo0_l0002Dooooo`05o`000?oooooooooo
ooooool00000T_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool0GOoo
ool004Sooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02Cooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`2Cooooo`?o0000U?oo
ool3o`0001cooooo00?o0000ooooooooool0GOooool004Sooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`06ooooo`?o00009?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooo003o0?ooooooBOooool3o`0005oooooo0018ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo00Gooooo00?o
003oooooool00?l0oooooom;ooooo`03o`000?oooooooooo05gooooo0018ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Tooooo`03o`00oooo
oooooooo00Cooooo0_l00?l00ooooooo003oo`00o`3ooooood[ooooo00?o0000ooooooooool0GOoo
ool004Sooooo00Co0000oooooooooooo00002?ooool2o`0000Sooooo0_l0000Uooooo`03o`00oooo
oooooooo0?ooooooD_ooool2o`0005oooooo0019ooooo`;o00002_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool0oooooomCooooo`03o`000?oooooo
oooo05gooooo001Nooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool0oooooomCoooo
o`03o`000?oooooooooo05gooooo001Nooooo`;o00009Oooool00ol00?ooooooooooo`3ooooooe;o
oooo0_l0001Oooooo`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo0?oooooo
Doooool00ol0003oooooooooo`1Mooooo`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00oooo
oooooooo0?ooooooDoooool00ol0003oooooooooo`1Mooooo`00G_ooool2o`0002Gooooo00?o003o
ooooooooool0oooooomBooooo`;o0000Goooool005kooooo00?o0000ooooooooool09?ooool00ol0
0?ooooooooooo`3ooooooe?ooooo00?o0000ooooooooool0GOooool005kooooo00?o0000oooooooo
ool09?ooool00ol00?ooooooooooo`3ooooooe?ooooo00?o0000ooooooooool0GOooool005kooooo
0_l0000Uooooo`03o`00oooooooooooo0?ooooooD_ooool2o`0005oooooo0019ooooo`;o00001?oo
ool01?l0003oooooooooooooool5o`0000Kooooo00?o0000ooooooooool09?ooool00ol00?oooooo
ooooo`3ooooooe?ooooo00?o0000ooooooooool0GOooool004Sooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo02Cooooo00?o003ooooooooo
ool0B?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05gooooo0018ooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool01_ooool3o`0000Kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01?ooool3o`0005oooooo0018ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0GOooool004Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Koooooool0001no`0005oooooo0018ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00003oooooon?ooooo0019ooooo`;o00002Oooool3o`000?ooooooi?ooool00?oo
oooooooooollooooo`00oooooooooooooccooooo003ooooooooooooo??ooool004Kooooo00?o0000
ooooooooool03?ooool3o`0002kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`24
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0J_ooool3o`0002;ooooo0ol0000W
ooooo`03o`000?oooooooooo04Kooooo0015ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Cooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`15ooooo`00AOooool00ol0003oooooooooo`05o`000003
ooooool0003o000000?o00000_ooool4o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l0
00001_ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol00003ooooo`Co00000_ooool3o`00
00Gooooo00?o0000ooooooooool01Oooool3o`0000Gooooo00?o0000ooooooooool00oooool5o`00
0003ooooool0003o000000;o00002?ooool4o`0000?ooooo1?l000000ooooooo0000o`000003o`00
0004ooooool0003o0000ooooo`;o00000_ooool3o`0000;ooooo0ol000000ooooooo0000o`000006
ooooo`Go00001oooool5o`000003ooooool0003o000000?o00000_ooool3o`0000;ooooo00Go0000
ooooool0003oooooo`000002ooooo`?o00000_ooool3o`000003ooooool0003o000000;ooooo0_l0
0003ooooo`?o00000_ooool3o`000003ooooool0003o000000?ooooo00?o0000ooooooooool01ooo
ool3o`0000?ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`07ooooo`?o00000ooo
ool3o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00004ooooo`04o`000?oo
ooooooooooooo`Go00000oooool2o`0000Cooooo0_l00004ooooo`;o00001oooool00ol0003ooooo
ooooo`07ooooo`Go000000?oooooo`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00Ko
00000oooool3o`0000?ooooo1?l000001Ooooooo0000o`000?l0003ooooo00Go000000?oooooo`00
0?l000000_ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo1?l00007
ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`0000Oooooo0ol00004ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0AOooool004Gooooo00Go0000ooooooooooooooooo`00
0002ooooo`05o`000?ooooooooooooooool000000oooool01ol0003ooooooooooooooooo0000oooo
ool000001_ooool01?l0003oooooooooool00007ooooo`07o`000?oooooo0000ooooool0003ooooo
o`000003ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00003oooool01Ol0003o
oooooooooooooooo000000_ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0008ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000001Oooool01ol0003oooooo`000?oooooo0000oooo
ool000001_ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo0000
1_ooool01?l0003oooooooooool0000=ooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooo`00000@ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`06
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02?ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool0000Aooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool0
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool00000
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Gooooo0014ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooool000001?l00002ooooo`04o`000?ooooooooooo`0000Oooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`05o`0000_ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`?o00001?ooool00ol0
003oooooooooo`02ooooo`;o00000oooool5o`0000;ooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooooooo1Ol0
00001ooooooo0000ooooool0003oooooo`000?ooool01Ol00002ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00_ooool5o`0000;ooooo00Co0000oooooooooooo00003Oooool0
2ol0003ooooooooooooooooo0000ooooool0003oooooo`000?oooooo000000oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`?o00000oooool01?l0
003oooooooooool00002ooooo`?o00000oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`14ooooo`00AOooool0
1?l0003oooooooooooooool3o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`07
o`000?oooooo0000ooooool0003oooooo`000003ooooo`03o`000?oooooo000000;ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`09ooooo`Co00003_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooooooool01_ooool3o`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01oooool3
o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`09o`000?oooooo0000ooooool0003o
ooooo`000?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0004ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000=ooooo`0;
o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000003oooool00ol0003ooooo
ooooo`03ooooo`;o00002Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00[o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0?ooooo`?o00001?ooool00ol0003ooooooooo
o`02ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool01_l0003oooooooooool0003ooooo
o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo0000
00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`15ooooo`00AOooool01Ol0
003ooooooooooooooooo000000Cooooo0ol00004ooooo`Go000000Coooooo`000?l0003o00000_oo
ool4o`0000Sooooo0_l000000ooooooo0000ooooo`02ooooo`?o00000oooool3o`0000?ooooo0ol0
000<ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool2o`0000Gooooo00?o0000oooo
ooooool00_ooool01?l0003oooooo`000?l00002ooooo`?o00000_ooool4o`0000Sooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool3o`0000;ooooo0_l000000ooooooo0000ooooo`02ooooo`?o00000_ooool4o`0000;ooooo1?l0
0003ooooo`?o00000_ooool4o`0000oooooo0ol00002ooooo`Ko00003_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`07ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`Co00000oooool4o`000003ooooool0
003o000000;o00000oooool2o`0000?ooooo1?l00002ooooo`Co00000_ooool2o`000004ooooool0
003o0000ooooo`Co00000oooool5o`0000Kooooo0ol00003ooooo`Co00002_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0AOooool004Kooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool05?ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03?ooooo0_l00003ooooo`05o`00
0?ooooooooooooooool000002?ooool01?l0003oooooooooool00002ooooo`;o00002Oooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`00017ooooo00Co0000oooooooooooo0000E_ooool2o`00
00[ooooo00?o0000ooooooooool0A_ooool004Sooooo1Ol00003ooooo`03o`000?oooooooooo02Oo
oooo0_l0000Dooooo`;o00003?ooool3o`0000;ooooo1?l00008ooooo`Co00002?ooool3o`0000?o
oooo0_l0000Gooooo`?o00002?ooool5o`000004ooooool0003o0000o`0001cooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`02ooooo`?o00002_ooool2o`0000Cooooo00?o0000oooo
ooooool02?ooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`00017ooooo1Ol00003oooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Aoooo
o`00oooooooooooooccooooo003ooooooooooooo??ooool00001\
\>"],
  ImageRangeCache->{{{0, 569}, {94, 0}} -> {-0.88243, -0.301052, 0.00661663, \
0.00661663}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.10365 .08333 L
.10409 .08333 L
.10459 .08333 L
.10506 .08333 L
.1055 .08333 L
.10591 .08333 L
.10635 .08333 L
.10682 .08333 L
.10729 .08333 L
.1078 .08333 L
.10828 .08333 L
.10872 .08333 L
.10924 .08333 L
.10953 .08333 L
.1098 .08333 L
.11029 .08333 L
.11082 .08333 L
.11108 .08333 L
.11136 .08333 L
.11186 .08333 L
.11214 .08333 L
.1124 .08333 L
.11269 .08333 L
.11299 .08333 L
.11326 .08333 L
.11354 .08333 L
.11407 .08333 L
.11457 .08333 L
.11504 .08333 L
.1155 .08333 L
.11593 .08333 L
.11639 .08333 L
.1169 .08333 L
.1174 .08333 L
.11793 .08333 L
.11838 .08333 L
.11887 .08333 L
.11916 .08333 L
.11943 .08333 L
.11972 .08333 L
.12003 .08333 L
.12055 .08333 L
.12084 .08333 L
.12112 .08333 L
.12164 .08333 L
.12211 .08333 L
.12236 .08333 L
.12265 .08333 L
.12316 .08333 L
Mistroke
.12347 .08333 L
.12377 .08333 L
.12403 .08333 L
.12431 .08333 L
.12462 .08333 L
.12495 .08333 L
.12523 .08333 L
.12554 .08333 L
.12583 .08333 L
.12609 .08333 L
.12639 .08333 L
.12668 .08333 L
.12719 .08333 L
.12748 .08333 L
.12774 .08333 L
.12822 .08333 L
.12873 .08333 L
.12921 .08333 L
.12965 .08333 L
.13014 .08333 L
.13067 .08333 L
.13094 .08333 L
.13123 .08333 L
.13175 .08333 L
.13203 .08333 L
.1323 .08333 L
.13259 .08333 L
.13289 .08333 L
.13341 .08333 L
.1337 .08333 L
.13398 .08333 L
.13448 .08333 L
.13495 .08333 L
.13549 .08333 L
.136 .08333 L
.13646 .08333 L
.13696 .08333 L
.13743 .08333 L
.13786 .08333 L
.13833 .08333 L
.13886 .08333 L
.13912 .08333 L
.1394 .08333 L
.13991 .08333 L
.14019 .08333 L
.14045 .08333 L
.14073 .08333 L
.14103 .08333 L
.14154 .08333 L
.14182 .08333 L
Mistroke
.14209 .08333 L
.14259 .08333 L
.14305 .08333 L
.14358 .08333 L
.14408 .08333 L
.14455 .08333 L
.14497 .08333 L
.14547 .08333 L
.14593 .08333 L
.14636 .08333 L
.14676 .08333 L
.1472 .08333 L
.14765 .08333 L
.14812 .08333 L
.14862 .08333 L
.14909 .08333 L
.14952 .08333 L
.15002 .08333 L
.1503 .08333 L
.15057 .08333 L
.15105 .08333 L
.15156 .08333 L
.15202 .08333 L
.15253 .08333 L
.15306 .08333 L
.15355 .08333 L
.15401 .08333 L
.15443 .08333 L
.15491 .08333 L
.15537 .08333 L
.15587 .08333 L
.1564 .08333 L
.15685 .08333 L
.15734 .08333 L
.15787 .08333 L
.15817 .08333 L
.15844 .08333 L
.15897 .08333 L
.15948 .08333 L
.15995 .08333 L
.16037 .08333 L
.16086 .08333 L
.16132 .08333 L
.16175 .08333 L
.16214 .08333 L
.16258 .08333 L
.16303 .08333 L
.16349 .08333 L
.16399 .08333 L
.16446 .08333 L
Mistroke
.16488 .08333 L
.16538 .08333 L
.16566 .08333 L
.16592 .08333 L
.1664 .08333 L
.16691 .08333 L
.1674 .08333 L
.16793 .08333 L
.16843 .08333 L
.1689 .08333 L
.16937 .08333 L
.16979 .08333 L
.17027 .08333 L
.17073 .08333 L
.17123 .08333 L
.17176 .08333 L
.17221 .08333 L
.1727 .08333 L
.17324 .08333 L
.17354 .08333 L
.17381 .08333 L
.17434 .08333 L
.17484 .08333 L
.17527 .08333 L
.17574 .08333 L
.17623 .08333 L
.17669 .08333 L
.17712 .08333 L
.17751 .08333 L
.17795 .08333 L
.1784 .08333 L
.17886 .08333 L
.17936 .08333 L
.17983 .08333 L
.18025 .08333 L
.18075 .08333 L
.18103 .08333 L
.18129 .08333 L
.18177 .08333 L
.18228 .08333 L
.18277 .08333 L
.1833 .08333 L
.18381 .08333 L
.18428 .08333 L
.18474 .08333 L
.18516 .08333 L
.18565 .08333 L
.18611 .08333 L
.18661 .08333 L
.18714 .08333 L
Mistroke
.18759 .08333 L
.18809 .08333 L
.18862 .08333 L
.18892 .08333 L
.18919 .08333 L
.18972 .08333 L
.19023 .08333 L
.19065 .08333 L
.19113 .08333 L
.19162 .08333 L
.19208 .08333 L
.19251 .08333 L
.1929 .08333 L
.19334 .08333 L
.19379 .08333 L
.19426 .08333 L
.19475 .08333 L
.19522 .08333 L
.19564 .08333 L
.19614 .08333 L
.19643 .08333 L
.19668 .08333 L
.19716 .08333 L
.19767 .08333 L
.19816 .08333 L
.1987 .08333 L
.19921 .08333 L
.19968 .08333 L
.2001 .08333 L
.20056 .08333 L
.20105 .08333 L
.20151 .08333 L
.20201 .08333 L
.20254 .08333 L
.203 .08333 L
.20349 .08333 L
.20403 .08333 L
.20433 .08333 L
.2046 .08333 L
.20513 .08333 L
.20563 .08333 L
.20606 .08333 L
.20653 .08333 L
.20703 .08333 L
.20749 .08333 L
.20792 .08333 L
.20832 .08333 L
.20877 .08333 L
.2092 .08333 L
.20967 .08333 L
Mistroke
.21016 .08333 L
.21063 .08333 L
.21106 .08333 L
.21156 .08333 L
.21184 .08333 L
.2121 .08333 L
.21257 .08333 L
.21308 .08333 L
.21357 .08333 L
.21385 .08333 L
.21411 .08333 L
.21459 .08333 L
.21509 .08333 L
.21554 .08333 L
.21597 .08333 L
.21643 .08333 L
.21693 .08333 L
.21743 .08333 L
.21772 .08333 L
.21798 .08333 L
.21852 .08333 L
.21881 .08333 L
.21909 .08333 L
.21957 .08333 L
.2201 .08333 L
.2206 .08333 L
.22106 .08333 L
.22149 .08333 L
.22195 .08333 L
.22239 .08333 L
.22278 .08333 L
.22325 .08333 L
.22376 .08333 L
.22424 .08333 L
.22468 .08333 L
.22518 .08333 L
.22565 .08333 L
.22608 .08333 L
.22654 .08333 L
.22704 .08333 L
.22757 .08333 L
.22802 .08333 L
.22851 .08333 L
.22904 .08333 L
.22954 .08333 L
.22979 .08333 L
.23008 .08333 L
.23037 .08333 L
.23065 .08333 L
.23116 .08333 L
Mistroke
.23162 .08333 L
.23216 .08333 L
.23267 .08333 L
.23313 .08333 L
.23361 .08333 L
.23407 .08333 L
.23448 .08333 L
.23497 .08333 L
.2355 .08333 L
.236 .08333 L
.23646 .08333 L
.23695 .08333 L
.23748 .08333 L
.23797 .08333 L
.23843 .08333 L
.23896 .08333 L
.23926 .08333 L
.23954 .08333 L
.24005 .08333 L
.24031 .08333 L
.24059 .08333 L
.24087 .08333 L
.24116 .08333 L
.24168 .08333 L
.24197 .08333 L
.24223 .08333 L
.24253 .08333 L
.24285 .08333 L
.24312 .08333 L
.24342 .08333 L
.2437 .08333 L
.24395 .08333 L
.24444 .08333 L
.24496 .08333 L
.24545 .08333 L
.24599 .08333 L
.24649 .08333 L
.24696 .08333 L
.24743 .08333 L
.24785 .08333 L
.24834 .08333 L
.24879 .08333 L
.24929 .08333 L
.24982 .08333 L
.25028 .08333 L
.25077 .08333 L
.2513 .08333 L
.2516 .08333 L
.25188 .08333 L
.25241 .08333 L
Mistroke
.25291 .08333 L
.25334 .08333 L
.25381 .08333 L
.2543 .08333 L
.25476 .08333 L
.25519 .08333 L
.25559 .08333 L
.25602 .08333 L
.25647 .08333 L
.25694 .08333 L
.25743 .08333 L
.2579 .08333 L
.25832 .08333 L
.25882 .08333 L
.25911 .08333 L
.25937 .08333 L
.25984 .08333 L
.26035 .08333 L
.26084 .08333 L
.26138 .08333 L
.26189 .08333 L
.26236 .08333 L
.26282 .08333 L
.26324 .08333 L
.26373 .08333 L
.26419 .08333 L
.26469 .08333 L
.26522 .08333 L
.26567 .08333 L
.26617 .08333 L
.26671 .08333 L
.26701 .08333 L
.26728 .08333 L
.26781 .08333 L
.26831 .08333 L
.26874 .08333 L
.26921 .08333 L
.2697 .08333 L
.27017 .08333 L
.2706 .08333 L
.27099 .08333 L
.27145 .08333 L
.27188 .08333 L
.27235 .08333 L
.27284 .08333 L
.27331 .08333 L
.27373 .08333 L
.27423 .08333 L
.27452 .08333 L
.27477 .08333 L
Mistroke
.27525 .08333 L
.27576 .08333 L
.27625 .08333 L
.27653 .08333 L
.27679 .08333 L
.27726 .08333 L
.27777 .08333 L
.27822 .08333 L
.27864 .08333 L
.27911 .08333 L
.27961 .08333 L
.28011 .08333 L
.28039 .08333 L
.28065 .08333 L
.28119 .08333 L
.28149 .08333 L
.28176 .08333 L
.28225 .08333 L
.28277 .08333 L
.28327 .08333 L
.28373 .08333 L
.28416 .08333 L
.28462 .08333 L
.28506 .08333 L
.28546 .08333 L
.28592 .08333 L
.28643 .08333 L
.28691 .08333 L
.28735 .08333 L
.28785 .08333 L
.28833 .08333 L
.28875 .08333 L
.28921 .08333 L
.28971 .08333 L
.29024 .08333 L
.29069 .08333 L
.29118 .08333 L
.29172 .08333 L
.29221 .08333 L
.29246 .08333 L
.29275 .08333 L
.29304 .08333 L
.29332 .08333 L
.29383 .08333 L
.29429 .08333 L
.2948 .08333 L
.29534 .08333 L
.29579 .08333 L
.29628 .08333 L
.29673 .08333 L
Mistroke
.29715 .08333 L
.29764 .08333 L
.29817 .08333 L
.29867 .08333 L
.29913 .08333 L
.29962 .08333 L
.30014 .08333 L
.30064 .08333 L
.3011 .08333 L
.30163 .08333 L
.30193 .08333 L
.30221 .08333 L
.30272 .08333 L
.30297 .08333 L
.30326 .08333 L
.30353 .08333 L
.30382 .08333 L
.30434 .08333 L
.30463 .08333 L
.3049 .08333 L
.3052 .08333 L
.30551 .08333 L
.30579 .08333 L
.30608 .08333 L
.30636 .08333 L
.30662 .08333 L
.30711 .08333 L
.30763 .08333 L
.30812 .08333 L
.30865 .08333 L
.30916 .08333 L
.30963 .08333 L
.31009 .08333 L
.31051 .08333 L
.311 .08333 L
.31146 .08333 L
.31196 .08333 L
.31249 .08333 L
.31294 .08333 L
.31343 .08333 L
.31397 .08333 L
.31427 .08333 L
.31454 .08333 L
.31507 .08333 L
.31557 .08333 L
.316 .08333 L
.31647 .08333 L
.31696 .08333 L
.31742 .08333 L
.31785 .08333 L
Mistroke
.31825 .08333 L
.31868 .08333 L
.31914 .08333 L
.3196 .08333 L
.32009 .08333 L
.32056 .08333 L
.32099 .08333 L
.32149 .08333 L
.32177 .08333 L
.32203 .08333 L
.3225 .08333 L
.32301 .08333 L
.3235 .08333 L
.32404 .08333 L
.32455 .08333 L
.32502 .08333 L
.32548 .08333 L
.3259 .08333 L
.32639 .08333 L
.32685 .08333 L
.32735 .08333 L
.32788 .08333 L
.32833 .08333 L
.32883 .08333 L
.32936 .08333 L
.32966 .08333 L
.32994 .08333 L
.33047 .08333 L
.33097 .08333 L
.3314 .08333 L
.33187 .08333 L
.33236 .08333 L
.33282 .08333 L
.33325 .08333 L
.33365 .08333 L
.3341 .08333 L
.33454 .08333 L
.335 .08333 L
.3355 .08333 L
.33597 .08333 L
.33639 .08333 L
.33689 .08333 L
.33717 .08333 L
.33743 .08333 L
.33791 .08333 L
.33841 .08333 L
.33891 .08333 L
.33919 .08333 L
.33945 .08333 L
.33992 .08333 L
Mistroke
.34042 .08333 L
.34087 .08333 L
.3413 .08333 L
.34176 .08333 L
.34226 .08333 L
.34276 .08333 L
.34304 .08333 L
.34331 .08333 L
.34384 .08333 L
.34414 .08333 L
.34441 .08333 L
.3449 .08333 L
.34543 .08333 L
.34593 .08333 L
.34639 .08333 L
.34682 .08333 L
.34728 .08333 L
.34771 .08333 L
.34811 .08333 L
.34857 .08333 L
.34908 .08333 L
.34956 .08333 L
.35 .08333 L
.35051 .08333 L
.35098 .08333 L
.3514 .08333 L
.35186 .08333 L
.35236 .08333 L
.35289 .08333 L
.35334 .08333 L
.35384 .08333 L
.35437 .08333 L
.35486 .08333 L
.35511 .08333 L
.3554 .08333 L
.35569 .08333 L
.35597 .08333 L
.35648 .08333 L
.35694 .08333 L
.35745 .08333 L
.35799 .08333 L
.35844 .08333 L
.35893 .08333 L
.35938 .08333 L
.3598 .08333 L
.36029 .08333 L
.36081 .08333 L
.36131 .08333 L
.36177 .08333 L
.36226 .08333 L
Mistroke
.36279 .08333 L
.36329 .08333 L
.36374 .08333 L
.36427 .08333 L
.36457 .08333 L
.36485 .08333 L
.36536 .08333 L
.36562 .08333 L
.36591 .08333 L
.36618 .08333 L
.36647 .08333 L
.36699 .08333 L
.36728 .08333 L
.36755 .08333 L
.36784 .08333 L
.36816 .08333 L
.36843 .08333 L
.36873 .08333 L
.36901 .08333 L
.36927 .08333 L
.36976 .08333 L
.37028 .08333 L
.37077 .08333 L
.3713 .08333 L
.3718 .08333 L
.37227 .08333 L
.37274 .08333 L
.37316 .08333 L
.37364 .08333 L
.3741 .08333 L
.3746 .08333 L
.37513 .08333 L
.37558 .08333 L
.37608 .08333 L
.37661 .08333 L
.37691 .08333 L
.37718 .08333 L
.37771 .08333 L
.37822 .08333 L
.37864 .08333 L
.37911 .08333 L
.3796 .08333 L
.38007 .08333 L
.3805 .08333 L
.38089 .08333 L
.38132 .08333 L
.38178 .08333 L
.38224 .08333 L
.38274 .08333 L
.3832 .08333 L
Mistroke
.38363 .08333 L
.38413 .08333 L
.38441 .08333 L
.38467 .08333 L
.38515 .08333 L
.38565 .08333 L
.38614 .08333 L
.38668 .08333 L
.38719 .08333 L
.38766 .08333 L
.38812 .08333 L
.38854 .08333 L
.38903 .08333 L
.38949 .08333 L
.38999 .08333 L
.39052 .08333 L
.39097 .08333 L
.39147 .08333 L
.392 .08333 L
.3923 .08333 L
.39257 .08333 L
.3931 .08333 L
.39361 .08333 L
.39403 .08333 L
.39451 .08333 L
.395 .08333 L
.39546 .08333 L
.39589 .08333 L
.39629 .08333 L
.39672 .08333 L
.39717 .08333 L
.39764 .08333 L
.39813 .08333 L
.3986 .08333 L
.39903 .08333 L
.39953 .08333 L
.39981 .08333 L
.40007 .08333 L
.40054 .08333 L
.40105 .08333 L
.40154 .08333 L
.40182 .08333 L
.40208 .08333 L
.40256 .08333 L
.40306 .08333 L
.40351 .08333 L
.40393 .08333 L
.40439 .08333 L
.40489 .08333 L
.40539 .08333 L
Mistroke
.40568 .08333 L
.40594 .08333 L
.40648 .08333 L
.40677 .08333 L
.40705 .08333 L
.40753 .08333 L
.40806 .08333 L
.40856 .08333 L
.40902 .08333 L
.40945 .08333 L
.40991 .08333 L
.41034 .08333 L
.41074 .08333 L
.41121 .08333 L
.41171 .08333 L
.41219 .08333 L
.41264 .08333 L
.41314 .08333 L
.41361 .08333 L
.41403 .08333 L
.41449 .08333 L
.41499 .08333 L
.41552 .08333 L
.41597 .08333 L
.41647 .08333 L
.417 .08333 L
.41749 .08333 L
.41774 .08333 L
.41803 .08333 L
.41832 .08333 L
.4186 .08333 L
.41911 .08333 L
.41957 .08333 L
.42008 .08333 L
.42062 .08333 L
.42107 .08333 L
.42155 .08333 L
.42201 .08333 L
.42243 .08333 L
.42291 .08333 L
.42344 .08333 L
.42394 .08333 L
.4244 .08333 L
.42489 .08333 L
.42542 .08333 L
.42592 .08333 L
.42637 .08333 L
.4269 .08333 L
.4272 .08333 L
.42748 .08333 L
Mistroke
.42799 .08333 L
.42827 .08333 L
.42853 .08333 L
.42881 .08333 L
.4291 .08333 L
.42962 .08333 L
.4299 .08333 L
.43017 .08333 L
.43047 .08333 L
.43078 .08333 L
.43106 .08333 L
.43135 .08333 L
.43163 .08333 L
.43189 .08333 L
.43238 .08333 L
.4329 .08333 L
.43339 .08333 L
.43393 .08333 L
.43443 .08333 L
.4349 .08333 L
.43536 .08333 L
.43578 .08333 L
.43627 .08333 L
.43673 .08333 L
.43723 .08333 L
.43775 .08333 L
.43821 .08333 L
.4387 .08333 L
.43923 .08333 L
.43953 .08333 L
.43981 .08333 L
.44034 .08333 L
.44084 .08333 L
.44126 .08333 L
.44173 .08333 L
.44223 .08333 L
.44269 .08333 L
.44312 .08333 L
.44351 .08333 L
.44394 .08333 L
.4444 .08333 L
.44486 .08333 L
.44536 .08333 L
.44582 .08333 L
.44625 .08333 L
.44675 .08333 L
.44703 .08333 L
.44729 .08333 L
.44777 .08333 L
.44827 .08333 L
Mistroke
.44876 .08333 L
.4493 .08333 L
.44981 .08333 L
.45028 .08333 L
.45074 .08333 L
.45116 .08333 L
.45165 .08333 L
.45211 .08333 L
.45261 .08333 L
.45314 .08333 L
.45359 .08333 L
.45409 .08333 L
.45462 .08333 L
.45492 .08333 L
.45519 .08333 L
.45572 .08333 L
.45622 .08333 L
.45665 .08333 L
.45712 .08333 L
.45762 .08333 L
.45808 .08333 L
.45851 .08333 L
.4589 .08333 L
.45934 .08333 L
.45979 .08333 L
.46025 .08333 L
.46075 .08333 L
.46122 .08333 L
.46164 .08333 L
.46214 .08333 L
.46242 .08333 L
.46268 .08333 L
.46316 .08333 L
.46367 .08333 L
.46416 .08333 L
.46444 .08333 L
.4647 .08333 L
.46517 .08333 L
.46567 .08333 L
.46612 .08333 L
.46655 .08333 L
.46701 .08333 L
.46751 .08333 L
.46801 .08333 L
.46829 .08333 L
.46856 .08333 L
.46909 .08333 L
.46939 .08333 L
.46966 .08333 L
.47015 .08333 L
Mistroke
.47067 .08333 L
.47117 .08333 L
.47163 .08333 L
.47206 .08333 L
.47252 .08333 L
.47296 .08333 L
.47335 .08333 L
.47382 .08333 L
.47432 .08333 L
.4748 .08333 L
.47525 .08333 L
.47575 .08333 L
.47622 .08333 L
.47664 .08333 L
.4771 .08333 L
.4776 .08333 L
.47813 .08333 L
.47858 .08333 L
.47908 .08333 L
.47944 .08333 L
.47977 .08333 L
.48013 .08333 L
.48052 .08333 L
.48085 .08333 L
.48117 .08333 L
.48151 .08333 L
.48188 .08333 L
.48219 .08333 L
.48253 .08333 L
.48289 .08333 L
.48321 .08333 L
.48352 .08333 L
.48381 .08333 L
.48413 .08333 L
.48444 .08333 L
.48477 .08333 L
.48513 .08333 L
.48551 .08333 L
.48587 .08333 L
.4862 .08333 L
.48651 .08333 L
.48686 .08333 L
.48719 .08333 L
.48755 .08333 L
.48793 .08333 L
.4883 .08333 L
.48862 .08333 L
.48901 .08333 L
.48942 .08333 L
.48982 .08333 L
Mistroke
.49018 .08333 L
Mfstroke
.49018 .08333 m
.49066 .08333 L
.49111 .08333 L
.49161 .08333 L
.4921 .08333 L
.49254 .08333 L
.49295 .08333 L
.4934 .08333 L
.49388 .08333 L
.49436 .08333 L
.49488 .08333 L
.49537 .08333 L
.49581 .08333 L
.49633 .08333 L
.49663 .08333 L
.4969 .08333 L
.4974 .08333 L
.49794 .08333 L
.4982 .08333 L
.49849 .08333 L
.499 .08333 L
.49928 .08333 L
.49954 .08333 L
.49983 .08333 L
.50014 .08333 L
.50041 .08333 L
.5007 .08333 L
.50123 .08333 L
.50175 .08333 L
.50222 .08333 L
.50269 .08333 L
.50312 .08333 L
.5036 .08333 L
.50411 .08333 L
.50462 .08333 L
.50515 .08333 L
.50561 .08333 L
.50611 .08333 L
.50641 .08333 L
.50668 .08333 L
.50697 .08333 L
.50729 .08333 L
.50781 .08333 L
.50811 .08333 L
.50839 .08333 L
.50892 .08333 L
.50939 .08333 L
.50966 .08333 L
.50994 .08333 L
.51046 .08333 L
Mistroke
.51078 .08333 L
.51108 .08333 L
.51135 .08333 L
.51163 .08333 L
.51195 .08333 L
.51228 .08333 L
.51257 .08333 L
.51288 .08333 L
.51317 .08333 L
.51344 .08333 L
.51374 .08333 L
.51404 .08333 L
.51455 .08333 L
.51484 .08333 L
.51511 .08333 L
.51559 .08333 L
.51611 .08333 L
.5166 .08333 L
.51705 .08333 L
.51754 .08333 L
.51809 .08333 L
.51836 .08333 L
.51865 .08333 L
.51918 .08333 L
.51947 .08333 L
.51974 .08333 L
.52003 .08333 L
.52034 .08333 L
.52086 .08333 L
.52116 .08333 L
.52144 .08333 L
.52196 .08333 L
.52243 .08333 L
.52297 .08333 L
.52349 .08333 L
.52396 .08333 L
.52446 .08333 L
.52494 .08333 L
.52538 .08333 L
.52586 .08333 L
.52639 .08333 L
.52666 .08333 L
.52695 .08333 L
.52746 .08333 L
.52775 .08333 L
.52801 .08333 L
.5283 .08333 L
.5286 .08333 L
.52911 .08333 L
.5294 .08333 L
Mistroke
.52968 .08333 L
.53018 .08333 L
.53065 .08333 L
.53118 .08333 L
.53169 .08333 L
.53217 .08333 L
.5326 .08333 L
.5331 .08333 L
.53357 .08333 L
.53401 .08333 L
.53441 .08333 L
.53485 .08333 L
.53532 .08333 L
.53579 .08333 L
.5363 .08333 L
.53678 .08333 L
.53721 .08333 L
.53772 .08333 L
.53801 .08333 L
.53827 .08333 L
.53876 .08333 L
.53928 .08333 L
.53975 .08333 L
.54027 .08333 L
.5408 .08333 L
.5413 .08333 L
.54177 .08333 L
.5422 .08333 L
.54269 .08333 L
.54315 .08333 L
.54366 .08333 L
.54419 .08333 L
.54465 .08333 L
.54515 .08333 L
.54569 .08333 L
.54599 .08333 L
.54627 .08333 L
.54681 .08333 L
.54732 .08333 L
.5478 .08333 L
.54823 .08333 L
.54872 .08333 L
.54919 .08333 L
.54963 .08333 L
.55003 .08333 L
.55046 .08333 L
.55093 .08333 L
.5514 .08333 L
.5519 .08333 L
.55237 .08333 L
Mistroke
.5528 .08333 L
.55331 .08333 L
.5536 .08333 L
.55386 .08333 L
.55435 .08333 L
.55486 .08333 L
.55536 .08333 L
.5559 .08333 L
.55641 .08333 L
.55688 .08333 L
.55735 .08333 L
.55778 .08333 L
.55827 .08333 L
.55874 .08333 L
.55925 .08333 L
.55978 .08333 L
.56024 .08333 L
.56074 .08333 L
.56128 .08333 L
.56159 .08333 L
.56186 .08333 L
.5624 .08333 L
.56291 .08333 L
.56334 .08333 L
.56382 .08333 L
.56432 .08333 L
.56479 .08333 L
.56522 .08333 L
.56562 .08333 L
.56606 .08333 L
.56653 .08333 L
.567 .08333 L
.5675 .08333 L
.56797 .08333 L
.5684 .08333 L
.56891 .08333 L
.5692 .08333 L
.56946 .08333 L
.56994 .08333 L
.57046 .08333 L
.57096 .08333 L
.5715 .08333 L
.57201 .08333 L
.57249 .08333 L
.57296 .08333 L
.57339 .08333 L
.57388 .08333 L
.57435 .08333 L
.57486 .08333 L
.57539 .08333 L
Mistroke
.57585 .08333 L
.57635 .08333 L
.5769 .08333 L
.5772 .08333 L
.57748 .08333 L
.57802 .08333 L
.57853 .08333 L
.57896 .08333 L
.57944 .08333 L
.57994 .08333 L
.58041 .08333 L
.58084 .08333 L
.58124 .08333 L
.58168 .08333 L
.58214 .08333 L
.58262 .08333 L
.58312 .08333 L
.58359 .08333 L
.58402 .08333 L
.58453 .08333 L
.58482 .08333 L
.58508 .08333 L
.58556 .08333 L
.58608 .08333 L
.58658 .08333 L
.58712 .08333 L
.58764 .08333 L
.58812 .08333 L
.58854 .08333 L
.58902 .08333 L
.58951 .08333 L
.58998 .08333 L
.59049 .08333 L
.59103 .08333 L
.59149 .08333 L
.59199 .08333 L
.59253 .08333 L
.59284 .08333 L
.59311 .08333 L
.59365 .08333 L
.59416 .08333 L
.5946 .08333 L
.59508 .08333 L
.59558 .08333 L
.59605 .08333 L
.59648 .08333 L
.59688 .08333 L
.59735 .08333 L
.59779 .08333 L
.59826 .08333 L
Mistroke
.59876 .08333 L
.59924 .08333 L
.59967 .08333 L
.60017 .08333 L
.60046 .08333 L
.60072 .08333 L
.60121 .08333 L
.60172 .08333 L
.60222 .08333 L
.60251 .08333 L
.60277 .08333 L
.60325 .08333 L
.60376 .08333 L
.60422 .08333 L
.60465 .08333 L
.60512 .08333 L
.60563 .08333 L
.60614 .08333 L
.60642 .08333 L
.60669 .08333 L
.60724 .08333 L
.60754 .08333 L
.60781 .08333 L
.60831 .08333 L
.60885 .08333 L
.60935 .08333 L
.60982 .08333 L
.61025 .08333 L
.61072 .08333 L
.61116 .08333 L
.61157 .08333 L
.61204 .08333 L
.61256 .08333 L
.61304 .08333 L
.61349 .08333 L
.614 .08333 L
.61448 .08333 L
.61491 .08333 L
.61538 .08333 L
.61588 .08333 L
.61642 .08333 L
.61688 .08333 L
.61738 .08333 L
.61792 .08333 L
.61842 .08333 L
.61868 .08333 L
.61897 .08333 L
.61927 .08333 L
.61955 .08333 L
.62007 .08333 L
Mistroke
.62054 .08333 L
.62108 .08333 L
.6216 .08333 L
.62206 .08333 L
.62255 .08333 L
.62302 .08333 L
.62344 .08333 L
.62393 .08333 L
.62447 .08333 L
.62498 .08333 L
.62544 .08333 L
.62594 .08333 L
.62648 .08333 L
.62698 .08333 L
.62744 .08333 L
.62798 .08333 L
.62829 .08333 L
.62857 .08333 L
.62909 .08333 L
.62935 .08333 L
.62964 .08333 L
.62992 .08333 L
.63021 .08333 L
.63074 .08333 L
.63103 .08333 L
.63131 .08333 L
.63161 .08333 L
.63193 .08333 L
.6322 .08333 L
.63251 .08333 L
.63279 .08333 L
.63305 .08333 L
.63355 .08333 L
.63408 .08333 L
.63457 .08333 L
.63512 .08333 L
.63563 .08333 L
.63611 .08333 L
.63658 .08333 L
.637 .08333 L
.6375 .08333 L
.63796 .08333 L
.63847 .08333 L
.63901 .08333 L
.63947 .08333 L
.63997 .08333 L
.64051 .08333 L
.64082 .08333 L
.64109 .08333 L
.64163 .08333 L
Mistroke
.64214 .08333 L
.64257 .08333 L
.64305 .08333 L
.64355 .08333 L
.64402 .08333 L
.64446 .08333 L
.64486 .08333 L
.6453 .08333 L
.64576 .08333 L
.64623 .08333 L
.64673 .08333 L
.64721 .08333 L
.64764 .08333 L
.64814 .08333 L
.64843 .08333 L
.64869 .08333 L
.64918 .08333 L
.64969 .08333 L
.65019 .08333 L
.65074 .08333 L
.65125 .08333 L
.65173 .08333 L
.6522 .08333 L
.65263 .08333 L
.65312 .08333 L
.65359 .08333 L
.6541 .08333 L
.65464 .08333 L
.6551 .08333 L
.6556 .08333 L
.65614 .08333 L
.65645 .08333 L
.65672 .08333 L
.65726 .08333 L
.65777 .08333 L
.65821 .08333 L
.65869 .08333 L
.65919 .08333 L
.65965 .08333 L
.66009 .08333 L
.66049 .08333 L
.66095 .08333 L
.66139 .08333 L
.66187 .08333 L
.66237 .08333 L
.66284 .08333 L
.66327 .08333 L
.66378 .08333 L
.66407 .08333 L
.66433 .08333 L
Mistroke
.66481 .08333 L
.66533 .08333 L
.66583 .08333 L
.66611 .08333 L
.66638 .08333 L
.66686 .08333 L
.66737 .08333 L
.66783 .08333 L
.66826 .08333 L
.66873 .08333 L
.66923 .08333 L
.66974 .08333 L
.67003 .08333 L
.6703 .08333 L
.67084 .08333 L
.67114 .08333 L
.67142 .08333 L
.67191 .08333 L
.67245 .08333 L
.67296 .08333 L
.67342 .08333 L
.67386 .08333 L
.67433 .08333 L
.67477 .08333 L
.67517 .08333 L
.67564 .08333 L
.67616 .08333 L
.67664 .08333 L
.6771 .08333 L
.6776 .08333 L
.67808 .08333 L
.67851 .08333 L
.67898 .08333 L
.67949 .08333 L
.68002 .08333 L
.68048 .08333 L
.68098 .08333 L
.68152 .08333 L
.68202 .08333 L
.68228 .08333 L
.68257 .08333 L
.68287 .08333 L
.68315 .08333 L
.68367 .08333 L
.68414 .08333 L
.68466 .08333 L
.6852 .08333 L
.68566 .08333 L
.68615 .08333 L
.68662 .08333 L
Mistroke
.68704 .08333 L
.68753 .08333 L
.68807 .08333 L
.68858 .08333 L
.68904 .08333 L
.68954 .08333 L
.69008 .08333 L
.69058 .08333 L
.69104 .08333 L
.69158 .08333 L
.69189 .08333 L
.69217 .08333 L
.69269 .08333 L
.69295 .08333 L
.69324 .08333 L
.69352 .08333 L
.69381 .08333 L
.69434 .08333 L
.69463 .08333 L
.6949 .08333 L
.6952 .08333 L
.69552 .08333 L
.6958 .08333 L
.6961 .08333 L
.69639 .08333 L
.69665 .08333 L
.69715 .08333 L
.69767 .08333 L
.69817 .08333 L
.69871 .08333 L
.69923 .08333 L
.6997 .08333 L
.70017 .08333 L
.7006 .08333 L
.70109 .08333 L
.70156 .08333 L
.70207 .08333 L
.7026 .08333 L
.70306 .08333 L
.70356 .08333 L
.70411 .08333 L
.70441 .08333 L
.70469 .08333 L
.70523 .08333 L
.70573 .08333 L
.70617 .08333 L
.70665 .08333 L
.70714 .08333 L
.70761 .08333 L
.70805 .08333 L
Mistroke
.70845 .08333 L
.70889 .08333 L
.70935 .08333 L
.70982 .08333 L
.71032 .08333 L
.7108 .08333 L
.71123 .08333 L
.71174 .08333 L
.71202 .08333 L
.71229 .08333 L
.71277 .08333 L
.71328 .08333 L
.71378 .08333 L
.71433 .08333 L
.71484 .08333 L
.71532 .08333 L
.71579 .08333 L
.71622 .08333 L
.71671 .08333 L
.71718 .08333 L
.71769 .08333 L
.71823 .08333 L
.71869 .08333 L
.71919 .08333 L
.71973 .08333 L
.72004 .08333 L
.72031 .08333 L
.72085 .08333 L
.72136 .08333 L
.72179 .08333 L
.72227 .08333 L
.72277 .08333 L
.72324 .08333 L
.72368 .08333 L
.72408 .08333 L
.72454 .08333 L
.72498 .08333 L
.72545 .08333 L
.72596 .08333 L
.72643 .08333 L
.72686 .08333 L
.72737 .08333 L
.72765 .08333 L
.72792 .08333 L
.7284 .08333 L
.72891 .08333 L
.72942 .08333 L
.7297 .08333 L
.72996 .08333 L
.73044 .08333 L
Mistroke
.73096 .08333 L
.73141 .08333 L
.73184 .08333 L
.73231 .08333 L
.73282 .08333 L
.73333 .08333 L
.73361 .08333 L
.73388 .08333 L
.73442 .08333 L
.73473 .08333 L
.735 .08333 L
.7355 .08333 L
.73603 .08333 L
.73654 .08333 L
.73701 .08333 L
.73744 .08333 L
.73791 .08333 L
.73835 .08333 L
.73875 .08333 L
.73923 .08333 L
.73974 .08333 L
.74023 .08333 L
.74068 .08333 L
.74119 .08333 L
.74167 .08333 L
.7421 .08333 L
.74256 .08333 L
.74307 .08333 L
.74361 .08333 L
.74406 .08333 L
.74457 .08333 L
.74511 .08333 L
.7456 .08333 L
.74586 .08333 L
.74615 .08333 L
.74645 .08333 L
.74673 .08333 L
.74725 .08333 L
.74772 .08333 L
.74824 .08333 L
.74878 .08333 L
.74924 .08333 L
.74973 .08333 L
.7502 .08333 L
.75062 .08333 L
.75111 .08333 L
.75165 .08333 L
.75216 .08333 L
.75262 .08333 L
.75312 .08333 L
Mistroke
.75366 .08333 L
.75416 .08333 L
.75462 .08333 L
.75516 .08333 L
.75546 .08333 L
.75575 .08333 L
.75627 .08333 L
.75653 .08333 L
.75682 .08333 L
.7571 .08333 L
.75739 .08333 L
.75792 .08333 L
.75821 .08333 L
.75848 .08333 L
.75878 .08333 L
.7591 .08333 L
.75938 .08333 L
.75968 .08333 L
.75997 .08333 L
.76023 .08333 L
.76072 .08333 L
.76125 .08333 L
.76175 .08333 L
.76229 .08333 L
.7628 .08333 L
.76328 .08333 L
.76375 .08333 L
.76418 .08333 L
.76467 .08333 L
.76513 .08333 L
.76564 .08333 L
.76618 .08333 L
.76664 .08333 L
.76714 .08333 L
.76768 .08333 L
.76798 .08333 L
.76826 .08333 L
.7688 .08333 L
.76931 .08333 L
.76974 .08333 L
.77022 .08333 L
.77072 .08333 L
.77119 .08333 L
.77162 .08333 L
.77202 .08333 L
.77246 .08333 L
.77292 .08333 L
.77339 .08333 L
.7739 .08333 L
.77437 .08333 L
Mistroke
.7748 .08333 L
.77531 .08333 L
.77559 .08333 L
.77586 .08333 L
.77634 .08333 L
.77686 .08333 L
.77736 .08333 L
.7779 .08333 L
.77841 .08333 L
.77889 .08333 L
.77936 .08333 L
.77979 .08333 L
.78028 .08333 L
.78075 .08333 L
.78126 .08333 L
.7818 .08333 L
.78225 .08333 L
.78276 .08333 L
.7833 .08333 L
.7836 .08333 L
.78388 .08333 L
.78442 .08333 L
.78493 .08333 L
.78536 .08333 L
.78584 .08333 L
.78634 .08333 L
.78681 .08333 L
.78725 .08333 L
.78765 .08333 L
.78809 .08333 L
.78855 .08333 L
.78902 .08333 L
.78952 .08333 L
.79 .08333 L
.79043 .08333 L
.79094 .08333 L
.79122 .08333 L
.79149 .08333 L
.79197 .08333 L
.79248 .08333 L
.79298 .08333 L
.79327 .08333 L
.79353 .08333 L
.79401 .08333 L
.79452 .08333 L
.79498 .08333 L
.79541 .08333 L
.79588 .08333 L
.79638 .08333 L
.79689 .08333 L
Mistroke
.79718 .08333 L
.79745 .08333 L
.79799 .08333 L
.79829 .08333 L
.79857 .08333 L
.79906 .08333 L
.7996 .08333 L
.8001 .08333 L
.80057 .08333 L
.80101 .08333 L
.80147 .08333 L
.80191 .08333 L
.80232 .08333 L
.80279 .08333 L
.8033 .08333 L
.80379 .08333 L
.80424 .08333 L
.80475 .08333 L
.80523 .08333 L
.80566 .08333 L
.80612 .08333 L
.80663 .08333 L
.80717 .08333 L
.80763 .08333 L
.80813 .08333 L
.80867 .08333 L
.80917 .08333 L
.80943 .08333 L
.80971 .08333 L
.81001 .08333 L
.81029 .08333 L
.81081 .08333 L
.81128 .08333 L
.8118 .08333 L
.81234 .08333 L
.8128 .08333 L
.81329 .08333 L
.81376 .08333 L
.81418 .08333 L
.81467 .08333 L
.81521 .08333 L
.81571 .08333 L
.81618 .08333 L
.81668 .08333 L
.81721 .08333 L
.81772 .08333 L
.81818 .08333 L
.81872 .08333 L
.81902 .08333 L
.8193 .08333 L
Mistroke
.81982 .08333 L
.82011 .08333 L
.82037 .08333 L
.82065 .08333 L
.82095 .08333 L
.82147 .08333 L
.82177 .08333 L
.82204 .08333 L
.82234 .08333 L
.82266 .08333 L
.82294 .08333 L
.82324 .08333 L
.82352 .08333 L
.82378 .08333 L
.82428 .08333 L
.82481 .08333 L
.82531 .08333 L
.82585 .08333 L
.82636 .08333 L
.82683 .08333 L
.82731 .08333 L
.82773 .08333 L
.82822 .08333 L
.82869 .08333 L
.8292 .08333 L
.82973 .08333 L
.83019 .08333 L
.83069 .08333 L
.83123 .08333 L
.83154 .08333 L
.83181 .08333 L
.83235 .08333 L
.83286 .08333 L
.83329 .08333 L
.83377 .08333 L
.83427 .08333 L
.83474 .08333 L
.83518 .08333 L
.83557 .08333 L
.83601 .08333 L
.83648 .08333 L
.83695 .08333 L
.83745 .08333 L
.83792 .08333 L
.83835 .08333 L
.83886 .08333 L
.83915 .08333 L
.83941 .08333 L
.8399 .08333 L
.84041 .08333 L
Mistroke
.84091 .08333 L
.84145 .08333 L
.84196 .08333 L
.84244 .08333 L
.84291 .08333 L
.84334 .08333 L
.84383 .08333 L
.8443 .08333 L
.84481 .08333 L
.84534 .08333 L
.8458 .08333 L
.84631 .08333 L
.84685 .08333 L
.84715 .08333 L
.84743 .08333 L
.84797 .08333 L
.84848 .08333 L
.84891 .08333 L
.84939 .08333 L
.84989 .08333 L
.85036 .08333 L
.8508 .08333 L
.8512 .08333 L
.85163 .08333 L
.8521 .08333 L
.85257 .08333 L
.85307 .08333 L
.85354 .08333 L
.85398 .08333 L
.85448 .08333 L
.85477 .08333 L
.85503 .08333 L
.85552 .08333 L
.85603 .08333 L
.85653 .08333 L
.85681 .08333 L
.85708 .08333 L
.85756 .08333 L
.85807 .08333 L
.85852 .08333 L
.85895 .08333 L
.85942 .08333 L
.85993 .08333 L
.86044 .08333 L
.86072 .08333 L
.86099 .08333 L
.86153 .08333 L
.86184 .08333 L
.86211 .08333 L
.86261 .08333 L
Mistroke
.86314 .08333 L
.86365 .08333 L
.86411 .08333 L
.86455 .08333 L
.86502 .08333 L
.86546 .08333 L
.86586 .08333 L
.86633 .08333 L
.86685 .08333 L
.86733 .08333 L
.86778 .08333 L
.86829 .08333 L
.86877 .08333 L
.8692 .08333 L
.86967 .08333 L
.87017 .08333 L
.87071 .08333 L
.87117 .08333 L
.87167 .08333 L
.87203 .08333 L
.87237 .08333 L
.87274 .08333 L
.87313 .08333 L
.87347 .08333 L
.87379 .08333 L
.87414 .08333 L
.87452 .08333 L
.87483 .08333 L
.87518 .08333 L
.87553 .08333 L
.87587 .08333 L
.87618 .08333 L
.87647 .08333 L
.8768 .08333 L
.87711 .08333 L
.87745 .08333 L
.87782 .08333 L
.8782 .08333 L
.87856 .08333 L
.8789 .08333 L
.87921 .08333 L
.87957 .08333 L
.87991 .08333 L
.88027 .08333 L
.88066 .08333 L
.88103 .08333 L
.88136 .08333 L
.88175 .08333 L
.88217 .08333 L
.88257 .08333 L
Mistroke
.88294 .08333 L
Mfstroke
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{570, 95},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008j0000Gb000`400?l00000o`00003ooooooooo
oooooccooooo0024ooooo`;o0000@oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
04?ooooo0ol00013ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000@Oooool5o`00
08Gooooo0023ooooo`04o`000?ooooooooooo`00047ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000004?ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool00000@Oooool01?l0003oooooooooool00025ooooo`00
Poooool01?l0003oooooooooool00011ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`25ooooo`00Poooool01?l0003oooooooooool00011oooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`24
ooooo`00Poooool01?l0003oooooooooool00011ooooo`04o`000?ooooooooooo`0000Oooooo1?l0
0014ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool01oooool4o`00047ooooo00Go
0000ooooooooooooooooo`000025ooooo`00Poooool01?l0003oooooooooool00011ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0A?ooool2o`0004Cooooo0_l00009ooooo`03
o`000?oooooooooo04;ooooo00Go0000ooooooooooooooooo`000025ooooo`00Q?ooool2o`0004?o
oooo0_l00008ooooo`Go0000@oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Oo
oooo1Ol00011ooooo`?o0000Q_ooool00?oooooooooooollooooo`00oooooooooooooccooooo003o
oooooooooooo??ooool00?oooooooooooollooooo`00oooooooooooooccooooo0019ooooo`;o0000
1?ooool01?l0003oooooooooooooool5o`000?oooooohoooool004Sooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00006oooooooo0000O_l0001Oooooo`00@Oooool5o`0000;o
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Mooooo`00B?ooool01?l0003o
ooooooooool0000:ooooo`03o`000?oooooooooo00Gooooo0ol00006ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Cooooo0ol0001Oooooo`00B?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo04Sooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1Mooooo`00B?ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Tooooo`03o`00oooo
oooooooo0?ooooooDoooool00ol0003oooooooooo`1Mooooo`00BOooool2o`0000Wooooo0ol00007
ooooo`;o00009Oooool00ol00?ooooooooooo`3ooooooe;ooooo0_l0001Oooooo`00G_ooool00ol0
003oooooooooo`0Tooooo`03o`00oooooooooooo0?ooooooDoooool00ol0003oooooooooo`1Moooo
o`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo0?ooooooDoooool00ol0003o
ooooooooo`1Mooooo`00G_ooool2o`0002Gooooo00?o003oooooooooool0oooooomBooooo`;o0000
Goooool005kooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`3ooooooe?ooooo00?o
0000ooooooooool0GOooool005kooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`3o
oooooe?ooooo00?o0000ooooooooool0GOooool005kooooo0_l0000Uooooo`03o`00oooooooooooo
0?ooooooD_ooool2o`0005oooooo001Nooooo`03o`000?oooooooooo02Cooooo00?o003ooooooooo
ool0oooooomCooooo`03o`000?oooooooooo05gooooo001Nooooo`03o`000?oooooooooo02Cooooo
00?o003oooooooooool0oooooomCooooo`03o`000?oooooooooo05gooooo0019ooooo`;o00001?oo
ool00ol0003oooooooooo`02ooooo`?o00001oooool2o`0002Gooooo00?o003oooooooooool0oooo
oomBooooo`;o0000Goooool004Sooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool0oooooomCooooo`03o`000?oo
oooooooo05gooooo0011ooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`3ooooooe?ooooo00?o
0000ooooooooool0GOooool004Sooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`06ooooo`?o00009?ooool00ol00?ooooooooooo`3ooooooe7ooooo0ol0001Oooooo`00B?ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09?oo
ool00ol00?ooooooooooo`3ooooooe?ooooo00?o0000ooooooooool0GOooool004Sooooo00Co0000
oooooooooooo00002?ooool2o`0000Sooooo00?o0000ooooooooool09?ooool00ol00?oooooooooo
o`3ooooooe?ooooo00?o0000ooooooooool0GOooool004Wooooo0_l0000:ooooo`03o`000?oooooo
oooo00Kooooo0_l0000Uooooo`03o`00oooooooooooo0?oooooo>?ooool2o`00o`03ooooool00?oo
003o01Gooooo0_l0001Oooooo`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo
0?oooooo>Oooool00ol00?ooooooo`00o`0Gooooo`03o`000?oooooooooo05gooooo001Nooooo`03
o`000?oooooooooo02Cooooo00?o003oooooooooool0ooooooljooooo`03o`00oooooooooooo01Ko
oooo00?o0000ooooooooool0GOooool005kooooo0_l0000Uooooo`03o`00oooooooooooo0?oooooo
>Oooool00ol00?ooooooo`00o`0Fooooo`;o0000Goooool005kooooo00?o0000ooooooooool09?oo
ool00ol00?ooooooooooo`3oooooocSooooo0_l00?l00ooooooo003oo`00o`0Fooooo`03o`000?oo
oooooooo05gooooo001Nooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool0oooooomC
ooooo`03o`000?oooooooooo05gooooo001Nooooo`;o00009Oooool00ol00?ooooooooooo`3ooooo
oe;ooooo0_l0001Oooooo`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo0?oo
ooooDoooool00ol0003oooooooooo`1Mooooo`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00
oooooooooooo0?ooooooDoooool00ol0003oooooooooo`1Mooooo`00EOooool2o`0000Oooooo0_l0
000Tooooo`?o0000U?ooool3o`0009Cooooo0ol0000Tooooo`;o0000Goooool005Cooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooooooo`0Rooooo`05o`000?l00?oo003oo`00ool00000
T_ooool01Ol0003ooooooooooooooooo000009;ooooo00Go0000ooooooooooooooooo`00000Toooo
o`03o`000?oooooooooo05gooooo001Dooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool08_ooool01Ol0003o003oo`00ool00?oo000009;ooooo00Go0000ooooooooooooooooo`00
002Booooo`05o`000?ooooooooooooooool000009?ooool00ol0003oooooooooo`1Mooooo`00E?oo
ool01?l0003oooooooooool00006ooooo`?o00001_oooolKo`00o`03o`000?l00?oo003o0?ooo`00
:ooo0005o`0000;o003o00?o0000o`00ool00?l06Ol00?l6ooooo`?o0000Goooool005Cooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooooooo`0Qooooo`03o`000?l00?oo003o00?o003o
00?o0000ooooooooool0S_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo05gooooo
001Dooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool08_ooool2o`000003o`00
ool0003o000009;ooooo0_l000000ooooooo0000o`00002Booooo`;o000000?oooooo`000?l00000
9?ooool00ol0003oooooooooo`1Mooooo`00EOooool2o`0000Oooooo0_l0000Uooooo`03o`000?oo
oooooooo09Cooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Sooooo`;o0000Gooo
ool005kooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`3ooooooe?ooooo00?o0000
ooooooooool0GOooool005kooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`3ooooo
oe?ooooo00?o0000ooooooooool0GOooool005kooooo0_l0000Uooooo`03o`00oooooooooooo0?oo
ooooD_ooool2o`0005oooooo001Nooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool0
oooooomCooooo`03o`000?oooooooooo05gooooo001Nooooo`03o`000?oooooooooo02Cooooo00?o
003oooooooooool01Oooool3o`0009?ooooo1Ol0002Cooooo`?o00007?ooool00ol0003ooooooooo
o`1Mooooo`00G_ooool2o`0002Gooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`2C
ooooo`04o`000?ooooooooooo`0009;ooooo00Go0000ooooooooooooooooo`00000Jooooo`;o0000
Goooool005kooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`06ooooo`03o`000?oo
oooooooo09Cooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo05gooooo001Nooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool01?ooool2
o`00o`03o`000?oooooooooo09Gooooo00?o0000ooooooooool0Toooool2o`0001cooooo00?o0000
ooooooooool0GOooool005kooooo0_l0000Uooooo`03o`00oooooooooooo00Gooooo00?o003oo`00
0?ooool0Toooool01Ol0003ooooooooooooooooo000009Kooooo00?o0000ooooooooool06?ooool2
o`0005oooooo0019ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001oooool00ol0
003oooooooooo`0Tooooo`03o`00oooooooooooo00Gooooo0_l0002Dooooo`05o`000?oooooooooo
ooooool00000T_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool0GOoo
ool004Sooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02Cooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`2Cooooo`?o0000U?oo
ool3o`0001cooooo00?o0000ooooooooool0GOooool004Sooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`06ooooo`?o00009?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooo003o0?ooooooBOooool3o`0005oooooo0018ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo00Gooooo00?o
003oooooool00?l0oooooom;ooooo`03o`000?oooooooooo05gooooo0018ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Tooooo`03o`00oooo
oooooooo00Cooooo0_l00?l00ooooooo003oo`00o`3ooooood[ooooo00?o0000ooooooooool0GOoo
ool004Sooooo00Co0000oooooooooooo00002?ooool2o`0000Sooooo0_l0000Uooooo`03o`00oooo
oooooooo0?ooooooD_ooool2o`0005oooooo0019ooooo`;o00002_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool0oooooomCooooo`03o`000?oooooo
oooo05gooooo001Nooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool0oooooomCoooo
o`03o`000?oooooooooo05gooooo001Nooooo`;o00009Oooool00ol00?ooooooooooo`3ooooooe;o
oooo0_l0001Oooooo`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo0?oooooo
Doooool00ol0003oooooooooo`1Mooooo`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00oooo
oooooooo0?ooooooDoooool00ol0003oooooooooo`1Mooooo`00G_ooool2o`0002Gooooo00?o003o
ooooooooool0oooooomBooooo`;o0000Goooool005kooooo00?o0000ooooooooool09?ooool00ol0
0?ooooooooooo`3ooooooe?ooooo00?o0000ooooooooool0GOooool005kooooo00?o0000oooooooo
ool09?ooool00ol00?ooooooooooo`3ooooooe?ooooo00?o0000ooooooooool0GOooool005kooooo
0_l0000Uooooo`03o`00oooooooooooo0?ooooooD_ooool2o`0005oooooo0019ooooo`;o00001?oo
ool01?l0003oooooooooooooool5o`0000Kooooo00?o0000ooooooooool09?ooool00ol00?oooooo
ooooo`3ooooooe?ooooo00?o0000ooooooooool0GOooool004Sooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo02Cooooo00?o003ooooooooo
ool0B?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05gooooo0018ooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool01_ooool3o`0000Kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01?ooool3o`0005oooooo0018ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0GOooool004Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Koooooool0001no`0005oooooo0018ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00003oooooon?ooooo0019ooooo`;o00002Oooool3o`000?ooooooi?ooool00?oo
oooooooooollooooo`00oooooooooooooccooooo003ooooooooooooo??ooool004Kooooo00?o0000
ooooooooool03?ooool3o`0002kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`24
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0J_ooool3o`0002;ooooo0ol0000W
ooooo`03o`000?oooooooooo04Kooooo0015ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Cooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`15ooooo`00AOooool00ol0003oooooooooo`05o`000003
ooooool0003o000000?o00000_ooool4o`0000;ooooo0ol00002ooooo`?o000000?oooooo`000?l0
00001_ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol00003ooooo`Co00000_ooool3o`00
00Gooooo00?o0000ooooooooool01Oooool3o`0000Gooooo00?o0000ooooooooool00oooool5o`00
0003ooooool0003o000000;o00002?ooool4o`0000?ooooo1?l000000ooooooo0000o`000003o`00
0004ooooool0003o0000ooooo`;o00000_ooool3o`0000;ooooo0ol000000ooooooo0000o`000006
ooooo`Go00001oooool5o`000003ooooool0003o000000?o00000_ooool3o`0000;ooooo00Go0000
ooooool0003oooooo`000002ooooo`?o00000_ooool3o`000003ooooool0003o000000;ooooo0_l0
0003ooooo`?o00000_ooool3o`000003ooooool0003o000000?ooooo00?o0000ooooooooool01ooo
ool3o`0000?ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`07ooooo`?o00000ooo
ool3o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00004ooooo`04o`000?oo
ooooooooooooo`Go00000oooool2o`0000Cooooo0_l00004ooooo`;o00001oooool00ol0003ooooo
ooooo`07ooooo`Go000000?oooooo`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00Ko
00000oooool3o`0000?ooooo1?l000001Ooooooo0000o`000?l0003ooooo00Go000000?oooooo`00
0?l000000_ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo1?l00007
ooooo`Go000000Goooooo`000?l0003o0000ooooo`02o`0000Oooooo0ol00004ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0AOooool004Gooooo00Go0000ooooooooooooooooo`00
0002ooooo`05o`000?ooooooooooooooool000000oooool01ol0003ooooooooooooooooo0000oooo
ool000001_ooool01?l0003oooooooooool00007ooooo`07o`000?oooooo0000ooooool0003ooooo
o`000003ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00003oooool01Ol0003o
oooooooooooooooo000000_ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0008ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000001Oooool01ol0003oooooo`000?oooooo0000oooo
ool000001_ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo0000
1_ooool01?l0003oooooooooool0000=ooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooo`00000@ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`06
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02?ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool0000Aooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool0
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool00000
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Gooooo0014ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooool000001?l00002ooooo`04o`000?ooooooooooo`0000Oooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`05o`0000_ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`?o00001?ooool00ol0
003oooooooooo`02ooooo`;o00000oooool5o`0000;ooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooooooo1Ol0
00001ooooooo0000ooooool0003oooooo`000?ooool01Ol00002ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00_ooool5o`0000;ooooo00Co0000oooooooooooo00003Oooool0
2ol0003ooooooooooooooooo0000ooooool0003oooooo`000?oooooo000000oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`?o00000oooool01?l0
003oooooooooool00002ooooo`?o00000oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`14ooooo`00AOooool0
1?l0003oooooooooooooool3o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`07
o`000?oooooo0000ooooool0003oooooo`000003ooooo`03o`000?oooooo000000;ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`09ooooo`Co00003_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooooooool01_ooool3o`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01oooool3
o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`09o`000?oooooo0000ooooool0003o
ooooo`000?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0004ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000=ooooo`0;
o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000003oooool00ol0003ooooo
ooooo`03ooooo`;o00002Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00[o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0?ooooo`?o00001?ooool00ol0003ooooooooo
o`02ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool01_l0003oooooooooool0003ooooo
o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo0000
00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`15ooooo`00AOooool01Ol0
003ooooooooooooooooo000000Cooooo0ol00004ooooo`Go000000Coooooo`000?l0003o00000_oo
ool4o`0000Sooooo0_l000000ooooooo0000ooooo`02ooooo`?o00000oooool3o`0000?ooooo0ol0
000<ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool2o`0000Gooooo00?o0000oooo
ooooool00_ooool01?l0003oooooo`000?l00002ooooo`?o00000_ooool4o`0000Sooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool3o`0000;ooooo0_l000000ooooooo0000ooooo`02ooooo`?o00000_ooool4o`0000;ooooo1?l0
0003ooooo`?o00000_ooool4o`0000oooooo0ol00002ooooo`Ko00003_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`07ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`Co00000oooool4o`000003ooooool0
003o000000;o00000oooool2o`0000?ooooo1?l00002ooooo`Co00000_ooool2o`000004ooooool0
003o0000ooooo`Co00000oooool5o`0000Kooooo0ol00003ooooo`Co00002_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0AOooool004Kooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool05?ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03?ooooo0_l00003ooooo`05o`00
0?ooooooooooooooool000002?ooool01?l0003oooooooooool00002ooooo`;o00002Oooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`00017ooooo00Co0000oooooooooooo0000E_ooool2o`00
00[ooooo00?o0000ooooooooool0A_ooool004Sooooo1Ol00003ooooo`03o`000?oooooooooo02Oo
oooo0_l0000Dooooo`;o00003?ooool3o`0000;ooooo1?l00008ooooo`Co00002?ooool3o`0000?o
oooo0_l0000Gooooo`?o00002?ooool5o`000004ooooool0003o0000o`0001cooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`02ooooo`?o00002_ooool2o`0000Cooooo00?o0000oooo
ooooool02?ooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`00017ooooo1Ol00003oooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Aoooo
o`00oooooooooooooccooooo003ooooooooooooo??ooool00001\
\>"],
  ImageRangeCache->{{{0, 569}, {94, 0}} -> {-0.88243, -0.301052, 0.00661663, \
0.00661663}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.10368 .08333 L
.10413 .08333 L
.10466 .08333 L
.10516 .08333 L
.10562 .08333 L
.10605 .08333 L
.10651 .08333 L
.10701 .08333 L
.1075 .08333 L
.10804 .08333 L
.10854 .08333 L
.109 .08333 L
.10954 .08333 L
.10985 .08333 L
.11013 .08333 L
.11065 .08333 L
.11121 .08333 L
.11148 .08333 L
.11178 .08333 L
.1123 .08333 L
.1126 .08333 L
.11287 .08333 L
.11317 .08333 L
.11349 .08333 L
.11377 .08333 L
.11407 .08333 L
.11462 .08333 L
.11515 .08333 L
.11565 .08333 L
.11612 .08333 L
.11657 .08333 L
.11707 .08333 L
.1176 .08333 L
.11812 .08333 L
.11868 .08333 L
.11915 .08333 L
.11967 .08333 L
.11997 .08333 L
.12025 .08333 L
.12056 .08333 L
.12089 .08333 L
.12143 .08333 L
.12174 .08333 L
.12203 .08333 L
.12257 .08333 L
.12307 .08333 L
.12334 .08333 L
.12364 .08333 L
.12418 .08333 L
Mistroke
.1245 .08333 L
.12481 .08333 L
.12509 .08333 L
.12539 .08333 L
.12571 .08333 L
.12606 .08333 L
.12635 .08333 L
.12667 .08333 L
.12698 .08333 L
.12725 .08333 L
.12757 .08333 L
.12787 .08333 L
.12841 .08333 L
.12871 .08333 L
.12899 .08333 L
.12949 .08333 L
.13002 .08333 L
.13053 .08333 L
.13099 .08333 L
.13151 .08333 L
.13207 .08333 L
.13235 .08333 L
.13265 .08333 L
.1332 .08333 L
.1335 .08333 L
.13378 .08333 L
.13408 .08333 L
.1344 .08333 L
.13494 .08333 L
.13525 .08333 L
.13554 .08333 L
.13607 .08333 L
.13656 .08333 L
.13713 .08333 L
.13766 .08333 L
.13815 .08333 L
.13867 .08333 L
.13916 .08333 L
.13962 .08333 L
.14012 .08333 L
.14067 .08333 L
.14095 .08333 L
.14124 .08333 L
.14178 .08333 L
.14207 .08333 L
.14234 .08333 L
.14264 .08333 L
.14296 .08333 L
.14348 .08333 L
.14379 .08333 L
Mistroke
.14407 .08333 L
.14459 .08333 L
.14507 .08333 L
.14563 .08333 L
.14615 .08333 L
.14665 .08333 L
.1471 .08333 L
.14761 .08333 L
.1481 .08333 L
.14856 .08333 L
.14897 .08333 L
.14943 .08333 L
.14991 .08333 L
.1504 .08333 L
.15092 .08333 L
.15142 .08333 L
.15187 .08333 L
.1524 .08333 L
.15269 .08333 L
.15297 .08333 L
.15348 .08333 L
.15401 .08333 L
.1545 .08333 L
.15503 .08333 L
.15559 .08333 L
.1561 .08333 L
.15659 .08333 L
.15703 .08333 L
.15754 .08333 L
.15802 .08333 L
.15854 .08333 L
.1591 .08333 L
.15957 .08333 L
.16009 .08333 L
.16065 .08333 L
.16096 .08333 L
.16125 .08333 L
.16181 .08333 L
.16233 .08333 L
.16283 .08333 L
.16327 .08333 L
.16379 .08333 L
.16427 .08333 L
.16472 .08333 L
.16514 .08333 L
.16559 .08333 L
.16607 .08333 L
.16656 .08333 L
.16708 .08333 L
.16757 .08333 L
Mistroke
.16801 .08333 L
.16854 .08333 L
.16883 .08333 L
.16911 .08333 L
.16961 .08333 L
.17014 .08333 L
.17065 .08333 L
.17122 .08333 L
.17175 .08333 L
.17224 .08333 L
.17272 .08333 L
.17317 .08333 L
.17368 .08333 L
.17416 .08333 L
.17468 .08333 L
.17524 .08333 L
.17571 .08333 L
.17623 .08333 L
.17679 .08333 L
.17711 .08333 L
.17739 .08333 L
.17795 .08333 L
.17848 .08333 L
.17893 .08333 L
.17942 .08333 L
.17994 .08333 L
.18042 .08333 L
.18087 .08333 L
.18129 .08333 L
.18174 .08333 L
.18222 .08333 L
.18271 .08333 L
.18323 .08333 L
.18372 .08333 L
.18416 .08333 L
.18469 .08333 L
.18498 .08333 L
.18526 .08333 L
.18576 .08333 L
.18629 .08333 L
.18681 .08333 L
.18737 .08333 L
.1879 .08333 L
.18839 .08333 L
.18888 .08333 L
.18933 .08333 L
.18984 .08333 L
.19032 .08333 L
.19084 .08333 L
.1914 .08333 L
Mistroke
.19188 .08333 L
.1924 .08333 L
.19296 .08333 L
.19327 .08333 L
.19356 .08333 L
.19412 .08333 L
.19464 .08333 L
.19509 .08333 L
.19559 .08333 L
.19611 .08333 L
.19659 .08333 L
.19704 .08333 L
.19746 .08333 L
.19791 .08333 L
.19839 .08333 L
.19888 .08333 L
.1994 .08333 L
.19989 .08333 L
.20034 .08333 L
.20086 .08333 L
.20116 .08333 L
.20143 .08333 L
.20193 .08333 L
.20246 .08333 L
.20298 .08333 L
.20355 .08333 L
.20408 .08333 L
.20457 .08333 L
.20502 .08333 L
.20551 .08333 L
.20602 .08333 L
.2065 .08333 L
.20703 .08333 L
.20759 .08333 L
.20806 .08333 L
.20858 .08333 L
.20915 .08333 L
.20946 .08333 L
.20975 .08333 L
.21031 .08333 L
.21083 .08333 L
.21128 .08333 L
.21178 .08333 L
.2123 .08333 L
.21278 .08333 L
.21324 .08333 L
.21365 .08333 L
.21413 .08333 L
.21458 .08333 L
.21507 .08333 L
Mistroke
.21559 .08333 L
.21609 .08333 L
.21653 .08333 L
.21706 .08333 L
.21735 .08333 L
.21763 .08333 L
.21813 .08333 L
.21866 .08333 L
.21918 .08333 L
.21947 .08333 L
.21974 .08333 L
.22024 .08333 L
.22077 .08333 L
.22125 .08333 L
.22169 .08333 L
.22218 .08333 L
.2227 .08333 L
.22323 .08333 L
.22353 .08333 L
.22381 .08333 L
.22437 .08333 L
.22468 .08333 L
.22497 .08333 L
.22548 .08333 L
.22604 .08333 L
.22656 .08333 L
.22704 .08333 L
.22749 .08333 L
.22798 .08333 L
.22844 .08333 L
.22885 .08333 L
.22934 .08333 L
.22988 .08333 L
.23038 .08333 L
.23085 .08333 L
.23137 .08333 L
.23187 .08333 L
.23232 .08333 L
.2328 .08333 L
.23332 .08333 L
.23388 .08333 L
.23435 .08333 L
.23487 .08333 L
.23543 .08333 L
.23595 .08333 L
.23622 .08333 L
.23652 .08333 L
.23683 .08333 L
.23712 .08333 L
.23765 .08333 L
Mistroke
.23814 .08333 L
.23871 .08333 L
.23924 .08333 L
.23972 .08333 L
.24023 .08333 L
.24071 .08333 L
.24114 .08333 L
.24166 .08333 L
.24221 .08333 L
.24274 .08333 L
.24322 .08333 L
.24374 .08333 L
.24429 .08333 L
.24482 .08333 L
.24529 .08333 L
.24585 .08333 L
.24617 .08333 L
.24646 .08333 L
.247 .08333 L
.24727 .08333 L
.24757 .08333 L
.24786 .08333 L
.24816 .08333 L
.24871 .08333 L
.24901 .08333 L
.24929 .08333 L
.2496 .08333 L
.24993 .08333 L
.25022 .08333 L
.25053 .08333 L
.25083 .08333 L
.2511 .08333 L
.25161 .08333 L
.25216 .08333 L
.25267 .08333 L
.25324 .08333 L
.25377 .08333 L
.25426 .08333 L
.25475 .08333 L
.25519 .08333 L
.2557 .08333 L
.25618 .08333 L
.25671 .08333 L
.25727 .08333 L
.25774 .08333 L
.25826 .08333 L
.25882 .08333 L
.25914 .08333 L
.25942 .08333 L
.25998 .08333 L
Mistroke
.26051 .08333 L
.26096 .08333 L
.26145 .08333 L
.26197 .08333 L
.26245 .08333 L
.26291 .08333 L
.26332 .08333 L
.26378 .08333 L
.26425 .08333 L
.26474 .08333 L
.26526 .08333 L
.26575 .08333 L
.2662 .08333 L
.26672 .08333 L
.26702 .08333 L
.26729 .08333 L
.26779 .08333 L
.26833 .08333 L
.26884 .08333 L
.26941 .08333 L
.26994 .08333 L
.27043 .08333 L
.27092 .08333 L
.27137 .08333 L
.27188 .08333 L
.27236 .08333 L
.27289 .08333 L
.27345 .08333 L
.27392 .08333 L
.27444 .08333 L
.27501 .08333 L
.27532 .08333 L
.27561 .08333 L
.27616 .08333 L
.27669 .08333 L
.27714 .08333 L
.27764 .08333 L
.27816 .08333 L
.27864 .08333 L
.27909 .08333 L
.27951 .08333 L
.27999 .08333 L
.28044 .08333 L
.28093 .08333 L
.28145 .08333 L
.28194 .08333 L
.28239 .08333 L
.28291 .08333 L
.28321 .08333 L
.28348 .08333 L
Mistroke
.28398 .08333 L
.28451 .08333 L
.28503 .08333 L
.28533 .08333 L
.2856 .08333 L
.2861 .08333 L
.28663 .08333 L
.2871 .08333 L
.28755 .08333 L
.28803 .08333 L
.28856 .08333 L
.28909 .08333 L
.28938 .08333 L
.28966 .08333 L
.29022 .08333 L
.29054 .08333 L
.29082 .08333 L
.29133 .08333 L
.29189 .08333 L
.29241 .08333 L
.2929 .08333 L
.29335 .08333 L
.29383 .08333 L
.29429 .08333 L
.29471 .08333 L
.2952 .08333 L
.29573 .08333 L
.29623 .08333 L
.2967 .08333 L
.29723 .08333 L
.29772 .08333 L
.29817 .08333 L
.29865 .08333 L
.29918 .08333 L
.29973 .08333 L
.3002 .08333 L
.30072 .08333 L
.30128 .08333 L
.3018 .08333 L
.30207 .08333 L
.30237 .08333 L
.30268 .08333 L
.30297 .08333 L
.3035 .08333 L
.30399 .08333 L
.30453 .08333 L
.30509 .08333 L
.30557 .08333 L
.30608 .08333 L
.30656 .08333 L
Mistroke
.30699 .08333 L
.30751 .08333 L
.30806 .08333 L
.30859 .08333 L
.30907 .08333 L
.30959 .08333 L
.31014 .08333 L
.31066 .08333 L
.31114 .08333 L
.3117 .08333 L
.31201 .08333 L
.31231 .08333 L
.31284 .08333 L
.31311 .08333 L
.31341 .08333 L
.3137 .08333 L
.31401 .08333 L
.31455 .08333 L
.31486 .08333 L
.31514 .08333 L
.31545 .08333 L
.31578 .08333 L
.31607 .08333 L
.31638 .08333 L
.31667 .08333 L
.31695 .08333 L
.31746 .08333 L
.31801 .08333 L
.31852 .08333 L
.31908 .08333 L
.31961 .08333 L
.32011 .08333 L
.32059 .08333 L
.32104 .08333 L
.32155 .08333 L
.32203 .08333 L
.32255 .08333 L
.32311 .08333 L
.32358 .08333 L
.3241 .08333 L
.32467 .08333 L
.32498 .08333 L
.32527 .08333 L
.32582 .08333 L
.32635 .08333 L
.3268 .08333 L
.32729 .08333 L
.32781 .08333 L
.3283 .08333 L
.32875 .08333 L
Mistroke
.32916 .08333 L
.32962 .08333 L
.3301 .08333 L
.33058 .08333 L
.3311 .08333 L
.33159 .08333 L
.33204 .08333 L
.33257 .08333 L
.33286 .08333 L
.33313 .08333 L
.33364 .08333 L
.33417 .08333 L
.33468 .08333 L
.33525 .08333 L
.33578 .08333 L
.33627 .08333 L
.33676 .08333 L
.33721 .08333 L
.33772 .08333 L
.3382 .08333 L
.33873 .08333 L
.33928 .08333 L
.33976 .08333 L
.34028 .08333 L
.34084 .08333 L
.34116 .08333 L
.34144 .08333 L
.342 .08333 L
.34253 .08333 L
.34298 .08333 L
.34348 .08333 L
.34399 .08333 L
.34448 .08333 L
.34493 .08333 L
.34535 .08333 L
.34582 .08333 L
.34628 .08333 L
.34677 .08333 L
.34729 .08333 L
.34778 .08333 L
.34822 .08333 L
.34875 .08333 L
.34905 .08333 L
.34932 .08333 L
.34982 .08333 L
.35035 .08333 L
.35087 .08333 L
.35116 .08333 L
.35144 .08333 L
.35193 .08333 L
Mistroke
.35246 .08333 L
.35294 .08333 L
.35338 .08333 L
.35387 .08333 L
.35439 .08333 L
.35492 .08333 L
.35522 .08333 L
.35549 .08333 L
.35606 .08333 L
.35637 .08333 L
.35666 .08333 L
.35717 .08333 L
.35772 .08333 L
.35825 .08333 L
.35873 .08333 L
.35918 .08333 L
.35966 .08333 L
.36012 .08333 L
.36054 .08333 L
.36103 .08333 L
.36156 .08333 L
.36206 .08333 L
.36253 .08333 L
.36306 .08333 L
.36355 .08333 L
.364 .08333 L
.36448 .08333 L
.36501 .08333 L
.36556 .08333 L
.36604 .08333 L
.36656 .08333 L
.36711 .08333 L
.36763 .08333 L
.3679 .08333 L
.3682 .08333 L
.36851 .08333 L
.3688 .08333 L
.36933 .08333 L
.36982 .08333 L
.37036 .08333 L
.37092 .08333 L
.3714 .08333 L
.37191 .08333 L
.37239 .08333 L
.37282 .08333 L
.37333 .08333 L
.37389 .08333 L
.37441 .08333 L
.3749 .08333 L
.37541 .08333 L
Mistroke
.37597 .08333 L
.37649 .08333 L
.37697 .08333 L
.37752 .08333 L
.37784 .08333 L
.37813 .08333 L
.37867 .08333 L
.37894 .08333 L
.37924 .08333 L
.37953 .08333 L
.37983 .08333 L
.38038 .08333 L
.38068 .08333 L
.38096 .08333 L
.38127 .08333 L
.38161 .08333 L
.38189 .08333 L
.38221 .08333 L
.3825 .08333 L
.38277 .08333 L
.38329 .08333 L
.38383 .08333 L
.38435 .08333 L
.38491 .08333 L
.38544 .08333 L
.38593 .08333 L
.38642 .08333 L
.38686 .08333 L
.38737 .08333 L
.38785 .08333 L
.38838 .08333 L
.38893 .08333 L
.38941 .08333 L
.38993 .08333 L
.39049 .08333 L
.3908 .08333 L
.39109 .08333 L
.39165 .08333 L
.39217 .08333 L
.39262 .08333 L
.39312 .08333 L
.39363 .08333 L
.39412 .08333 L
.39457 .08333 L
.39498 .08333 L
.39544 .08333 L
.39592 .08333 L
.3964 .08333 L
.39692 .08333 L
.39741 .08333 L
Mistroke
.39786 .08333 L
.39839 .08333 L
.39868 .08333 L
.39895 .08333 L
.39946 .08333 L
.39999 .08333 L
.4005 .08333 L
.40107 .08333 L
.4016 .08333 L
.40209 .08333 L
.40258 .08333 L
.40303 .08333 L
.40354 .08333 L
.40402 .08333 L
.40454 .08333 L
.4051 .08333 L
.40558 .08333 L
.4061 .08333 L
.40666 .08333 L
.40697 .08333 L
.40726 .08333 L
.40782 .08333 L
.40835 .08333 L
.4088 .08333 L
.40929 .08333 L
.40981 .08333 L
.41029 .08333 L
.41075 .08333 L
.41116 .08333 L
.41162 .08333 L
.41209 .08333 L
.41258 .08333 L
.4131 .08333 L
.41359 .08333 L
.41404 .08333 L
.41457 .08333 L
.41486 .08333 L
.41513 .08333 L
.41564 .08333 L
.41617 .08333 L
.41668 .08333 L
.41698 .08333 L
.41725 .08333 L
.41775 .08333 L
.41828 .08333 L
.41875 .08333 L
.41919 .08333 L
.41968 .08333 L
.42021 .08333 L
.42073 .08333 L
Mistroke
.42103 .08333 L
.42131 .08333 L
.42187 .08333 L
.42218 .08333 L
.42247 .08333 L
.42298 .08333 L
.42353 .08333 L
.42406 .08333 L
.42454 .08333 L
.42499 .08333 L
.42548 .08333 L
.42593 .08333 L
.42635 .08333 L
.42684 .08333 L
.42737 .08333 L
.42787 .08333 L
.42834 .08333 L
.42887 .08333 L
.42936 .08333 L
.42981 .08333 L
.43029 .08333 L
.43082 .08333 L
.43137 .08333 L
.43185 .08333 L
.43237 .08333 L
.43292 .08333 L
.43344 .08333 L
.43371 .08333 L
.43401 .08333 L
.43432 .08333 L
.43461 .08333 L
.43514 .08333 L
.43563 .08333 L
.43616 .08333 L
.43673 .08333 L
.4372 .08333 L
.43771 .08333 L
.43819 .08333 L
.43863 .08333 L
.43914 .08333 L
.4397 .08333 L
.44022 .08333 L
.4407 .08333 L
.44122 .08333 L
.44177 .08333 L
.44229 .08333 L
.44277 .08333 L
.44333 .08333 L
.44364 .08333 L
.44394 .08333 L
Mistroke
.44447 .08333 L
.44477 .08333 L
.44504 .08333 L
.44533 .08333 L
.44564 .08333 L
.44618 .08333 L
.44649 .08333 L
.44677 .08333 L
.44708 .08333 L
.44741 .08333 L
.4477 .08333 L
.44801 .08333 L
.4483 .08333 L
.44858 .08333 L
.44909 .08333 L
.44964 .08333 L
.45015 .08333 L
.45071 .08333 L
.45124 .08333 L
.45173 .08333 L
.45222 .08333 L
.45266 .08333 L
.45317 .08333 L
.45365 .08333 L
.45418 .08333 L
.45473 .08333 L
.45521 .08333 L
.45573 .08333 L
.45629 .08333 L
.4566 .08333 L
.45689 .08333 L
.45745 .08333 L
.45797 .08333 L
.45842 .08333 L
.45892 .08333 L
.45943 .08333 L
.45992 .08333 L
.46037 .08333 L
.46078 .08333 L
.46124 .08333 L
.46172 .08333 L
.4622 .08333 L
.46272 .08333 L
.46321 .08333 L
.46366 .08333 L
.46418 .08333 L
.46448 .08333 L
.46475 .08333 L
.46526 .08333 L
.46579 .08333 L
Mistroke
.4663 .08333 L
.46687 .08333 L
.4674 .08333 L
.46789 .08333 L
.46838 .08333 L
.46882 .08333 L
.46933 .08333 L
.46981 .08333 L
.47034 .08333 L
.4709 .08333 L
.47137 .08333 L
.47189 .08333 L
.47246 .08333 L
.47277 .08333 L
.47306 .08333 L
.47361 .08333 L
.47414 .08333 L
.47459 .08333 L
.47509 .08333 L
.4756 .08333 L
.47609 .08333 L
.47654 .08333 L
.47696 .08333 L
.47741 .08333 L
.47789 .08333 L
.47838 .08333 L
.4789 .08333 L
.47939 .08333 L
.47983 .08333 L
.48036 .08333 L
.48066 .08333 L
.48093 .08333 L
.48143 .08333 L
.48196 .08333 L
.48248 .08333 L
.48277 .08333 L
.48304 .08333 L
.48354 .08333 L
.48407 .08333 L
.48454 .08333 L
.48499 .08333 L
.48547 .08333 L
.486 .08333 L
.48652 .08333 L
.48682 .08333 L
.4871 .08333 L
.48766 .08333 L
.48797 .08333 L
.48826 .08333 L
.48877 .08333 L
Mistroke
.48932 .08333 L
.48985 .08333 L
.49033 .08333 L
.49078 .08333 L
.49126 .08333 L
.49172 .08333 L
.49214 .08333 L
.49263 .08333 L
.49316 .08333 L
.49366 .08333 L
.49413 .08333 L
.49466 .08333 L
.49515 .08333 L
.4956 .08333 L
.49608 .08333 L
.4966 .08333 L
.49716 .08333 L
.49763 .08333 L
.49816 .08333 L
.49853 .08333 L
.49888 .08333 L
.49926 .08333 L
.49967 .08333 L
.50002 .08333 L
.50035 .08333 L
.50071 .08333 L
.5011 .08333 L
.50143 .08333 L
.50178 .08333 L
.50216 .08333 L
.5025 .08333 L
.50283 .08333 L
.50312 .08333 L
.50346 .08333 L
.50379 .08333 L
.50413 .08333 L
.50452 .08333 L
.50492 .08333 L
.50529 .08333 L
.50564 .08333 L
.50596 .08333 L
.50633 .08333 L
.50668 .08333 L
.50706 .08333 L
.50746 .08333 L
.50784 .08333 L
.50818 .08333 L
.50859 .08333 L
.50903 .08333 L
.50944 .08333 L
Mistroke
.50982 .08333 L
Mfstroke
.50982 .08333 m
.51032 .08333 L
.51077 .08333 L
.51128 .08333 L
.51178 .08333 L
.51223 .08333 L
.51265 .08333 L
.51311 .08333 L
.5136 .08333 L
.51409 .08333 L
.51462 .08333 L
.51511 .08333 L
.51557 .08333 L
.5161 .08333 L
.5164 .08333 L
.51668 .08333 L
.51719 .08333 L
.51774 .08333 L
.51801 .08333 L
.5183 .08333 L
.51882 .08333 L
.51911 .08333 L
.51938 .08333 L
.51967 .08333 L
.51999 .08333 L
.52026 .08333 L
.52056 .08333 L
.5211 .08333 L
.52163 .08333 L
.52211 .08333 L
.52259 .08333 L
.52303 .08333 L
.52351 .08333 L
.52404 .08333 L
.52456 .08333 L
.52511 .08333 L
.52557 .08333 L
.52608 .08333 L
.52638 .08333 L
.52666 .08333 L
.52696 .08333 L
.52728 .08333 L
.52782 .08333 L
.52812 .08333 L
.52841 .08333 L
.52894 .08333 L
.52943 .08333 L
.5297 .08333 L
.52999 .08333 L
.53053 .08333 L
Mistroke
.53085 .08333 L
.53115 .08333 L
.53142 .08333 L
.53172 .08333 L
.53204 .08333 L
.53238 .08333 L
.53267 .08333 L
.53299 .08333 L
.53329 .08333 L
.53356 .08333 L
.53387 .08333 L
.53417 .08333 L
.5347 .08333 L
.535 .08333 L
.53527 .08333 L
.53576 .08333 L
.53629 .08333 L
.53679 .08333 L
.53724 .08333 L
.53775 .08333 L
.5383 .08333 L
.53858 .08333 L
.53888 .08333 L
.53942 .08333 L
.53972 .08333 L
.53999 .08333 L
.54029 .08333 L
.54061 .08333 L
.54114 .08333 L
.54144 .08333 L
.54173 .08333 L
.54225 .08333 L
.54274 .08333 L
.54329 .08333 L
.54382 .08333 L
.5443 .08333 L
.54481 .08333 L
.5453 .08333 L
.54575 .08333 L
.54624 .08333 L
.54678 .08333 L
.54706 .08333 L
.54735 .08333 L
.54788 .08333 L
.54817 .08333 L
.54843 .08333 L
.54873 .08333 L
.54904 .08333 L
.54956 .08333 L
.54986 .08333 L
Mistroke
.55014 .08333 L
.55065 .08333 L
.55113 .08333 L
.55167 .08333 L
.55219 .08333 L
.55268 .08333 L
.55312 .08333 L
.55363 .08333 L
.55411 .08333 L
.55456 .08333 L
.55497 .08333 L
.55542 .08333 L
.5559 .08333 L
.55638 .08333 L
.55689 .08333 L
.55738 .08333 L
.55782 .08333 L
.55835 .08333 L
.55864 .08333 L
.55891 .08333 L
.55941 .08333 L
.55994 .08333 L
.56042 .08333 L
.56094 .08333 L
.56149 .08333 L
.562 .08333 L
.56248 .08333 L
.56291 .08333 L
.56342 .08333 L
.56389 .08333 L
.5644 .08333 L
.56495 .08333 L
.56542 .08333 L
.56593 .08333 L
.56648 .08333 L
.56679 .08333 L
.56707 .08333 L
.56762 .08333 L
.56814 .08333 L
.56863 .08333 L
.56907 .08333 L
.56958 .08333 L
.57005 .08333 L
.5705 .08333 L
.57091 .08333 L
.57135 .08333 L
.57183 .08333 L
.5723 .08333 L
.57282 .08333 L
.5733 .08333 L
Mistroke
.57374 .08333 L
.57426 .08333 L
.57455 .08333 L
.57482 .08333 L
.57531 .08333 L
.57584 .08333 L
.57635 .08333 L
.5769 .08333 L
.57742 .08333 L
.57791 .08333 L
.57839 .08333 L
.57882 .08333 L
.57932 .08333 L
.5798 .08333 L
.58032 .08333 L
.58086 .08333 L
.58133 .08333 L
.58184 .08333 L
.5824 .08333 L
.58271 .08333 L
.58299 .08333 L
.58354 .08333 L
.58406 .08333 L
.5845 .08333 L
.58499 .08333 L
.5855 .08333 L
.58597 .08333 L
.58642 .08333 L
.58683 .08333 L
.58727 .08333 L
.58775 .08333 L
.58823 .08333 L
.58874 .08333 L
.58922 .08333 L
.58966 .08333 L
.59018 .08333 L
.59047 .08333 L
.59074 .08333 L
.59124 .08333 L
.59176 .08333 L
.59227 .08333 L
.59282 .08333 L
.59335 .08333 L
.59383 .08333 L
.59432 .08333 L
.59475 .08333 L
.59526 .08333 L
.59573 .08333 L
.59625 .08333 L
.5968 .08333 L
Mistroke
.59727 .08333 L
.59778 .08333 L
.59833 .08333 L
.59864 .08333 L
.59893 .08333 L
.59948 .08333 L
.6 .08333 L
.60044 .08333 L
.60093 .08333 L
.60144 .08333 L
.60192 .08333 L
.60236 .08333 L
.60277 .08333 L
.60322 .08333 L
.60369 .08333 L
.60417 .08333 L
.60468 .08333 L
.60517 .08333 L
.60561 .08333 L
.60613 .08333 L
.60642 .08333 L
.60669 .08333 L
.60718 .08333 L
.6077 .08333 L
.60821 .08333 L
.60877 .08333 L
.6093 .08333 L
.60978 .08333 L
.61022 .08333 L
.6107 .08333 L
.61121 .08333 L
.61168 .08333 L
.61221 .08333 L
.61275 .08333 L
.61322 .08333 L
.61374 .08333 L
.61429 .08333 L
.6146 .08333 L
.61489 .08333 L
.61544 .08333 L
.61596 .08333 L
.6164 .08333 L
.61689 .08333 L
.6174 .08333 L
.61788 .08333 L
.61833 .08333 L
.61873 .08333 L
.61921 .08333 L
.61965 .08333 L
.62014 .08333 L
Mistroke
.62065 .08333 L
.62113 .08333 L
.62157 .08333 L
.62209 .08333 L
.62238 .08333 L
.62265 .08333 L
.62315 .08333 L
.62367 .08333 L
.62418 .08333 L
.62447 .08333 L
.62474 .08333 L
.62523 .08333 L
.62576 .08333 L
.62622 .08333 L
.62666 .08333 L
.62714 .08333 L
.62766 .08333 L
.62818 .08333 L
.62847 .08333 L
.62875 .08333 L
.6293 .08333 L
.62961 .08333 L
.62989 .08333 L
.6304 .08333 L
.63094 .08333 L
.63146 .08333 L
.63194 .08333 L
.63238 .08333 L
.63286 .08333 L
.63331 .08333 L
.63372 .08333 L
.6342 .08333 L
.63473 .08333 L
.63523 .08333 L
.63569 .08333 L
.63621 .08333 L
.6367 .08333 L
.63713 .08333 L
.63761 .08333 L
.63813 .08333 L
.63868 .08333 L
.63914 .08333 L
.63966 .08333 L
.64021 .08333 L
.64072 .08333 L
.64098 .08333 L
.64128 .08333 L
.64158 .08333 L
.64187 .08333 L
.6424 .08333 L
Mistroke
.64288 .08333 L
.64343 .08333 L
.64396 .08333 L
.64443 .08333 L
.64494 .08333 L
.64541 .08333 L
.64584 .08333 L
.64634 .08333 L
.64689 .08333 L
.64741 .08333 L
.64789 .08333 L
.6484 .08333 L
.64894 .08333 L
.64946 .08333 L
.64993 .08333 L
.65048 .08333 L
.65079 .08333 L
.65108 .08333 L
.65161 .08333 L
.65187 .08333 L
.65217 .08333 L
.65245 .08333 L
.65275 .08333 L
.65329 .08333 L
.65359 .08333 L
.65387 .08333 L
.65418 .08333 L
.6545 .08333 L
.65479 .08333 L
.65509 .08333 L
.65538 .08333 L
.65565 .08333 L
.65616 .08333 L
.6567 .08333 L
.6572 .08333 L
.65776 .08333 L
.65828 .08333 L
.65877 .08333 L
.65925 .08333 L
.65969 .08333 L
.66019 .08333 L
.66066 .08333 L
.66118 .08333 L
.66173 .08333 L
.6622 .08333 L
.66271 .08333 L
.66327 .08333 L
.66358 .08333 L
.66386 .08333 L
.66441 .08333 L
Mistroke
.66493 .08333 L
.66537 .08333 L
.66586 .08333 L
.66637 .08333 L
.66685 .08333 L
.66729 .08333 L
.6677 .08333 L
.66815 .08333 L
.66862 .08333 L
.6691 .08333 L
.66961 .08333 L
.6701 .08333 L
.67054 .08333 L
.67106 .08333 L
.67135 .08333 L
.67162 .08333 L
.67211 .08333 L
.67263 .08333 L
.67314 .08333 L
.6737 .08333 L
.67423 .08333 L
.67471 .08333 L
.6752 .08333 L
.67563 .08333 L
.67614 .08333 L
.67661 .08333 L
.67713 .08333 L
.67768 .08333 L
.67815 .08333 L
.67867 .08333 L
.67922 .08333 L
.67953 .08333 L
.67981 .08333 L
.68036 .08333 L
.68088 .08333 L
.68133 .08333 L
.68182 .08333 L
.68233 .08333 L
.6828 .08333 L
.68325 .08333 L
.68366 .08333 L
.68413 .08333 L
.68458 .08333 L
.68506 .08333 L
.68558 .08333 L
.68606 .08333 L
.6865 .08333 L
.68702 .08333 L
.68731 .08333 L
.68758 .08333 L
Mistroke
.68807 .08333 L
.68859 .08333 L
.68911 .08333 L
.6894 .08333 L
.68967 .08333 L
.69016 .08333 L
.69068 .08333 L
.69115 .08333 L
.69158 .08333 L
.69206 .08333 L
.69258 .08333 L
.6931 .08333 L
.6934 .08333 L
.69367 .08333 L
.69422 .08333 L
.69453 .08333 L
.69481 .08333 L
.69532 .08333 L
.69587 .08333 L
.69638 .08333 L
.69686 .08333 L
.6973 .08333 L
.69778 .08333 L
.69823 .08333 L
.69864 .08333 L
.69913 .08333 L
.69965 .08333 L
.70015 .08333 L
.70061 .08333 L
.70113 .08333 L
.70162 .08333 L
.70205 .08333 L
.70253 .08333 L
.70305 .08333 L
.7036 .08333 L
.70406 .08333 L
.70458 .08333 L
.70513 .08333 L
.70564 .08333 L
.7059 .08333 L
.7062 .08333 L
.7065 .08333 L
.70679 .08333 L
.70731 .08333 L
.7078 .08333 L
.70833 .08333 L
.70888 .08333 L
.70935 .08333 L
.70985 .08333 L
.71033 .08333 L
Mistroke
.71076 .08333 L
.71126 .08333 L
.71181 .08333 L
.71233 .08333 L
.7128 .08333 L
.71331 .08333 L
.71386 .08333 L
.71437 .08333 L
.71484 .08333 L
.71539 .08333 L
.71571 .08333 L
.71599 .08333 L
.71652 .08333 L
.71679 .08333 L
.71708 .08333 L
.71737 .08333 L
.71767 .08333 L
.71821 .08333 L
.71851 .08333 L
.71879 .08333 L
.71909 .08333 L
.71942 .08333 L
.7197 .08333 L
.72001 .08333 L
.7203 .08333 L
.72057 .08333 L
.72107 .08333 L
.72161 .08333 L
.72212 .08333 L
.72267 .08333 L
.7232 .08333 L
.72368 .08333 L
.72416 .08333 L
.7246 .08333 L
.7251 .08333 L
.72558 .08333 L
.7261 .08333 L
.72664 .08333 L
.72711 .08333 L
.72762 .08333 L
.72818 .08333 L
.72849 .08333 L
.72877 .08333 L
.72932 .08333 L
.72984 .08333 L
.73028 .08333 L
.73077 .08333 L
.73128 .08333 L
.73176 .08333 L
.7322 .08333 L
Mistroke
.73261 .08333 L
.73306 .08333 L
.73353 .08333 L
.73401 .08333 L
.73452 .08333 L
.73501 .08333 L
.73545 .08333 L
.73597 .08333 L
.73626 .08333 L
.73653 .08333 L
.73702 .08333 L
.73754 .08333 L
.73805 .08333 L
.73861 .08333 L
.73914 .08333 L
.73962 .08333 L
.7401 .08333 L
.74054 .08333 L
.74105 .08333 L
.74152 .08333 L
.74204 .08333 L
.74259 .08333 L
.74306 .08333 L
.74357 .08333 L
.74413 .08333 L
.74444 .08333 L
.74472 .08333 L
.74527 .08333 L
.74579 .08333 L
.74623 .08333 L
.74672 .08333 L
.74723 .08333 L
.74771 .08333 L
.74816 .08333 L
.74857 .08333 L
.74904 .08333 L
.74949 .08333 L
.74997 .08333 L
.75048 .08333 L
.75096 .08333 L
.7514 .08333 L
.75192 .08333 L
.75221 .08333 L
.75248 .08333 L
.75298 .08333 L
.7535 .08333 L
.75401 .08333 L
.7543 .08333 L
.75457 .08333 L
.75506 .08333 L
Mistroke
.75558 .08333 L
.75605 .08333 L
.75649 .08333 L
.75697 .08333 L
.75749 .08333 L
.758 .08333 L
.7583 .08333 L
.75857 .08333 L
.75912 .08333 L
.75943 .08333 L
.75971 .08333 L
.76022 .08333 L
.76077 .08333 L
.76128 .08333 L
.76176 .08333 L
.7622 .08333 L
.76268 .08333 L
.76313 .08333 L
.76354 .08333 L
.76403 .08333 L
.76455 .08333 L
.76505 .08333 L
.76551 .08333 L
.76603 .08333 L
.76652 .08333 L
.76695 .08333 L
.76743 .08333 L
.76795 .08333 L
.7685 .08333 L
.76896 .08333 L
.76948 .08333 L
.77003 .08333 L
.77054 .08333 L
.7708 .08333 L
.77109 .08333 L
.7714 .08333 L
.77169 .08333 L
.77221 .08333 L
.77269 .08333 L
.77322 .08333 L
.77378 .08333 L
.77425 .08333 L
.77475 .08333 L
.77522 .08333 L
.77565 .08333 L
.77616 .08333 L
.77671 .08333 L
.77722 .08333 L
.7777 .08333 L
.77821 .08333 L
Mistroke
.77875 .08333 L
.77927 .08333 L
.77974 .08333 L
.78029 .08333 L
.7806 .08333 L
.78089 .08333 L
.78142 .08333 L
.78168 .08333 L
.78198 .08333 L
.78226 .08333 L
.78256 .08333 L
.7831 .08333 L
.7834 .08333 L
.78368 .08333 L
.78399 .08333 L
.78431 .08333 L
.7846 .08333 L
.7849 .08333 L
.78519 .08333 L
.78546 .08333 L
.78597 .08333 L
.78651 .08333 L
.78701 .08333 L
.78757 .08333 L
.78809 .08333 L
.78858 .08333 L
.78906 .08333 L
.78949 .08333 L
.78999 .08333 L
.79047 .08333 L
.79099 .08333 L
.79154 .08333 L
.792 .08333 L
.79252 .08333 L
.79307 .08333 L
.79338 .08333 L
.79366 .08333 L
.79421 .08333 L
.79473 .08333 L
.79517 .08333 L
.79566 .08333 L
.79617 .08333 L
.79665 .08333 L
.79709 .08333 L
.7975 .08333 L
.79795 .08333 L
.79842 .08333 L
.7989 .08333 L
.79941 .08333 L
.7999 .08333 L
Mistroke
.80034 .08333 L
.80085 .08333 L
.80115 .08333 L
.80142 .08333 L
.80191 .08333 L
.80243 .08333 L
.80294 .08333 L
.8035 .08333 L
.80402 .08333 L
.80451 .08333 L
.80499 .08333 L
.80543 .08333 L
.80593 .08333 L
.80641 .08333 L
.80693 .08333 L
.80748 .08333 L
.80794 .08333 L
.80846 .08333 L
.80901 .08333 L
.80932 .08333 L
.80961 .08333 L
.81015 .08333 L
.81067 .08333 L
.81112 .08333 L
.81161 .08333 L
.81212 .08333 L
.8126 .08333 L
.81304 .08333 L
.81345 .08333 L
.8139 .08333 L
.81437 .08333 L
.81485 .08333 L
.81536 .08333 L
.81585 .08333 L
.81629 .08333 L
.81681 .08333 L
.8171 .08333 L
.81737 .08333 L
.81786 .08333 L
.81838 .08333 L
.8189 .08333 L
.81918 .08333 L
.81945 .08333 L
.81994 .08333 L
.82047 .08333 L
.82093 .08333 L
.82137 .08333 L
.82185 .08333 L
.82237 .08333 L
.82289 .08333 L
Mistroke
.82318 .08333 L
.82345 .08333 L
.824 .08333 L
.82431 .08333 L
.8246 .08333 L
.8251 .08333 L
.82565 .08333 L
.82616 .08333 L
.82664 .08333 L
.82708 .08333 L
.82756 .08333 L
.82801 .08333 L
.82842 .08333 L
.8289 .08333 L
.82943 .08333 L
.82993 .08333 L
.83039 .08333 L
.83091 .08333 L
.83139 .08333 L
.83183 .08333 L
.83231 .08333 L
.83283 .08333 L
.83337 .08333 L
.83384 .08333 L
.83435 .08333 L
.8349 .08333 L
.83541 .08333 L
.83568 .08333 L
.83597 .08333 L
.83628 .08333 L
.83656 .08333 L
.83709 .08333 L
.83757 .08333 L
.8381 .08333 L
.83866 .08333 L
.83912 .08333 L
.83963 .08333 L
.8401 .08333 L
.84053 .08333 L
.84103 .08333 L
.84158 .08333 L
.8421 .08333 L
.84257 .08333 L
.84308 .08333 L
.84363 .08333 L
.84414 .08333 L
.84461 .08333 L
.84516 .08333 L
.84547 .08333 L
.84576 .08333 L
Mistroke
.84629 .08333 L
.84659 .08333 L
.84685 .08333 L
.84714 .08333 L
.84744 .08333 L
.84798 .08333 L
.84827 .08333 L
.84855 .08333 L
.84886 .08333 L
.84919 .08333 L
.84947 .08333 L
.84978 .08333 L
.85007 .08333 L
.85034 .08333 L
.85084 .08333 L
.85138 .08333 L
.85189 .08333 L
.85244 .08333 L
.85296 .08333 L
.85345 .08333 L
.85393 .08333 L
.85436 .08333 L
.85487 .08333 L
.85534 .08333 L
.85586 .08333 L
.85641 .08333 L
.85687 .08333 L
.85739 .08333 L
.85794 .08333 L
.85825 .08333 L
.85853 .08333 L
.85908 .08333 L
.8596 .08333 L
.86004 .08333 L
.86053 .08333 L
.86104 .08333 L
.86152 .08333 L
.86196 .08333 L
.86237 .08333 L
.86282 .08333 L
.86329 .08333 L
.86377 .08333 L
.86428 .08333 L
.86477 .08333 L
.86521 .08333 L
.86572 .08333 L
.86602 .08333 L
.86628 .08333 L
.86678 .08333 L
.8673 .08333 L
Mistroke
.86781 .08333 L
.86837 .08333 L
.86889 .08333 L
.86938 .08333 L
.86986 .08333 L
.8703 .08333 L
.8708 .08333 L
.87127 .08333 L
.87179 .08333 L
.87234 .08333 L
.87281 .08333 L
.87332 .08333 L
.87388 .08333 L
.87419 .08333 L
.87447 .08333 L
.87502 .08333 L
.87554 .08333 L
.87598 .08333 L
.87647 .08333 L
.87698 .08333 L
.87746 .08333 L
.8779 .08333 L
.87831 .08333 L
.87876 .08333 L
.87923 .08333 L
.87971 .08333 L
.88023 .08333 L
.88071 .08333 L
.88115 .08333 L
.88167 .08333 L
.88196 .08333 L
.88223 .08333 L
.88272 .08333 L
.88325 .08333 L
.88376 .08333 L
.88405 .08333 L
.88432 .08333 L
.88481 .08333 L
.88533 .08333 L
.88579 .08333 L
.88623 .08333 L
.88671 .08333 L
.88723 .08333 L
.88775 .08333 L
.88804 .08333 L
.88831 .08333 L
.88886 .08333 L
.88917 .08333 L
.88946 .08333 L
.88996 .08333 L
Mistroke
.89051 .08333 L
.89102 .08333 L
.8915 .08333 L
.89194 .08333 L
.89242 .08333 L
.89287 .08333 L
.89328 .08333 L
.89376 .08333 L
.89429 .08333 L
.89478 .08333 L
.89524 .08333 L
.89576 .08333 L
.89625 .08333 L
.89669 .08333 L
.89717 .08333 L
.89768 .08333 L
.89823 .08333 L
.8987 .08333 L
.89921 .08333 L
.89958 .08333 L
.89993 .08333 L
.9003 .08333 L
.9007 .08333 L
.90105 .08333 L
.90138 .08333 L
.90173 .08333 L
.90212 .08333 L
.90244 .08333 L
.90279 .08333 L
.90316 .08333 L
.9035 .08333 L
.90382 .08333 L
.90411 .08333 L
.90445 .08333 L
.90476 .08333 L
.90511 .08333 L
.90549 .08333 L
.90588 .08333 L
.90625 .08333 L
.90659 .08333 L
.90691 .08333 L
.90727 .08333 L
.90762 .08333 L
.90799 .08333 L
.90839 .08333 L
.90876 .08333 L
.9091 .08333 L
.9095 .08333 L
.90993 .08333 L
.91034 .08333 L
Mistroke
.91071 .08333 L
Mfstroke
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{570, 95},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008j0000Gb000`400?l00000o`00003ooooooooo
oooooccooooo0024ooooo`;o0000@oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
04?ooooo0ol00013ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000@Oooool5o`00
08Gooooo0023ooooo`04o`000?ooooooooooo`00047ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000004?ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool00000@Oooool01?l0003oooooooooool00025ooooo`00
Poooool01?l0003oooooooooool00011ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`25ooooo`00Poooool01?l0003oooooooooool00011oooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`24
ooooo`00Poooool01?l0003oooooooooool00011ooooo`04o`000?ooooooooooo`0000Oooooo1?l0
0014ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool01oooool4o`00047ooooo00Go
0000ooooooooooooooooo`000025ooooo`00Poooool01?l0003oooooooooool00011ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0A?ooool2o`0004Cooooo0_l00009ooooo`03
o`000?oooooooooo04;ooooo00Go0000ooooooooooooooooo`000025ooooo`00Q?ooool2o`0004?o
oooo0_l00008ooooo`Go0000@oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Oo
oooo1Ol00011ooooo`?o0000Q_ooool00?oooooooooooollooooo`00oooooooooooooccooooo003o
oooooooooooo??ooool00?oooooooooooollooooo`00oooooooooooooccooooo0019ooooo`;o0000
1?ooool01?l0003oooooooooooooool5o`000?oooooohoooool004Sooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00006oooooooo0000O_l0001Oooooo`00@Oooool5o`0000;o
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Mooooo`00B?ooool01?l0003o
ooooooooool0000:ooooo`03o`000?oooooooooo00Gooooo0ol00006ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Cooooo0ol0001Oooooo`00B?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo04Sooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1Mooooo`00B?ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Tooooo`03o`00oooo
oooooooo0?ooooooDoooool00ol0003oooooooooo`1Mooooo`00BOooool2o`0000Wooooo0ol00007
ooooo`;o00009Oooool00ol00?ooooooooooo`3ooooooe;ooooo0_l0001Oooooo`00G_ooool00ol0
003oooooooooo`0Tooooo`03o`00oooooooooooo0?ooooooDoooool00ol0003oooooooooo`1Moooo
o`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo0?ooooooDoooool00ol0003o
ooooooooo`1Mooooo`00G_ooool2o`0002Gooooo00?o003oooooooooool0oooooomBooooo`;o0000
Goooool005kooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`3ooooooe?ooooo00?o
0000ooooooooool0GOooool005kooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`3o
oooooe?ooooo00?o0000ooooooooool0GOooool005kooooo0_l0000Uooooo`03o`00oooooooooooo
0?ooooooD_ooool2o`0005oooooo001Nooooo`03o`000?oooooooooo02Cooooo00?o003ooooooooo
ool0oooooomCooooo`03o`000?oooooooooo05gooooo001Nooooo`03o`000?oooooooooo02Cooooo
00?o003oooooooooool0oooooomCooooo`03o`000?oooooooooo05gooooo0019ooooo`;o00001?oo
ool00ol0003oooooooooo`02ooooo`?o00001oooool2o`0002Gooooo00?o003oooooooooool0oooo
oomBooooo`;o0000Goooool004Sooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool0oooooomCooooo`03o`000?oo
oooooooo05gooooo0011ooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`3ooooooe?ooooo00?o
0000ooooooooool0GOooool004Sooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`06ooooo`?o00009?ooool00ol00?ooooooooooo`3ooooooe7ooooo0ol0001Oooooo`00B?ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09?oo
ool00ol00?ooooooooooo`3ooooooe?ooooo00?o0000ooooooooool0GOooool004Sooooo00Co0000
oooooooooooo00002?ooool2o`0000Sooooo00?o0000ooooooooool09?ooool00ol00?oooooooooo
o`3ooooooe?ooooo00?o0000ooooooooool0GOooool004Wooooo0_l0000:ooooo`03o`000?oooooo
oooo00Kooooo0_l0000Uooooo`03o`00oooooooooooo0?oooooo>?ooool2o`00o`03ooooool00?oo
003o01Gooooo0_l0001Oooooo`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo
0?oooooo>Oooool00ol00?ooooooo`00o`0Gooooo`03o`000?oooooooooo05gooooo001Nooooo`03
o`000?oooooooooo02Cooooo00?o003oooooooooool0ooooooljooooo`03o`00oooooooooooo01Ko
oooo00?o0000ooooooooool0GOooool005kooooo0_l0000Uooooo`03o`00oooooooooooo0?oooooo
>Oooool00ol00?ooooooo`00o`0Fooooo`;o0000Goooool005kooooo00?o0000ooooooooool09?oo
ool00ol00?ooooooooooo`3oooooocSooooo0_l00?l00ooooooo003oo`00o`0Fooooo`03o`000?oo
oooooooo05gooooo001Nooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool0oooooomC
ooooo`03o`000?oooooooooo05gooooo001Nooooo`;o00009Oooool00ol00?ooooooooooo`3ooooo
oe;ooooo0_l0001Oooooo`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo0?oo
ooooDoooool00ol0003oooooooooo`1Mooooo`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00
oooooooooooo0?ooooooDoooool00ol0003oooooooooo`1Mooooo`00EOooool2o`0000Oooooo0_l0
000Tooooo`?o0000U?ooool3o`0009Cooooo0ol0000Tooooo`;o0000Goooool005Cooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooooooo`0Rooooo`05o`000?l00?oo003oo`00ool00000
T_ooool01Ol0003ooooooooooooooooo000009;ooooo00Go0000ooooooooooooooooo`00000Toooo
o`03o`000?oooooooooo05gooooo001Dooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool08_ooool01Ol0003o003oo`00ool00?oo000009;ooooo00Go0000ooooooooooooooooo`00
002Booooo`05o`000?ooooooooooooooool000009?ooool00ol0003oooooooooo`1Mooooo`00E?oo
ool01?l0003oooooooooool00006ooooo`?o00001_oooolKo`00o`03o`000?l00?oo003o0?ooo`00
=Ooo000Io`00o`Kooooo0ol0001Oooooo`00E?ooool01?l0003oooooooooool00006ooooo`03o`00
0?oooooooooo027ooooo00?o0000o`00ool00?l00ol00?l00ol0003oooooooooo`2>ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0GOooool005Cooooo00Co0000oooooooooooo0000
1_ooool00ol0003oooooooooo`0Rooooo`;o000000?o003oo`000?l00000T_ooool2o`000003oooo
ool0003o000009;ooooo0_l000000ooooooo0000o`00000Tooooo`03o`000?oooooooooo05gooooo
001Eooooo`;o00001oooool2o`0002Gooooo00?o0000ooooooooool0U?ooool00ol0003ooooooooo
o`2Dooooo`03o`000?oooooooooo02?ooooo0_l0001Oooooo`00G_ooool00ol0003oooooooooo`0T
ooooo`03o`00oooooooooooo0?ooooooDoooool00ol0003oooooooooo`1Mooooo`00G_ooool00ol0
003oooooooooo`0Tooooo`03o`00oooooooooooo0?ooooooDoooool00ol0003oooooooooo`1Moooo
o`00G_ooool2o`0002Gooooo00?o003oooooooooool0oooooomBooooo`;o0000Goooool005kooooo
00?o0000ooooooooool09?ooool00ol00?ooooooooooo`3ooooooe?ooooo00?o0000ooooooooool0
GOooool005kooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`05ooooo`?o0000Tooo
ool5o`0009?ooooo0ol0000Looooo`03o`000?oooooooooo05gooooo001Nooooo`;o00009Oooool0
0ol00?ooooooooooo`06ooooo`03o`000?oooooooooo09?ooooo00Co0000oooooooooooo0000T_oo
ool01Ol0003ooooooooooooooooo000001[ooooo0_l0001Oooooo`00G_ooool00ol0003ooooooooo
o`0Tooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool0U?ooool00ol0003ooooooooo
o`2Fooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0GOooool005kooooo00?o0000
ooooooooool09?ooool00ol00?ooooooooooo`04ooooo`;o003o00?o0000ooooooooool0UOooool0
0ol0003oooooooooo`2Cooooo`;o00007?ooool00ol0003oooooooooo`1Mooooo`00G_ooool2o`00
02Gooooo00?o003oooooooooool01Oooool00ol00?oo0000ooooo`2Cooooo`05o`000?oooooooooo
ooooool00000U_ooool00ol0003oooooooooo`0Hooooo`;o0000Goooool004Wooooo0_l00004oooo
o`03o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooooooo02Cooooo00?o003ooooo
ooooool01Oooool2o`0009Cooooo00Go0000ooooooooooooooooo`00002Booooo`05o`000?oooooo
ooooooooool000006oooool00ol0003oooooooooo`1Mooooo`00B?ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09?ooool00ol00?oooooooooo
o`06ooooo`03o`000?oooooooooo09?ooooo0ol0002Dooooo`?o00007?ooool00ol0003ooooooooo
o`1Mooooo`00B?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Kooooo0ol0
000Tooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l0oooooom9ooooo`?o0000Gooo
ool004Sooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02Cooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`3ooooood_ooooo00?o
0000ooooooooool0GOooool004Sooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool01?ooool2o`00o`03ooooool0
0?oo003o0?ooooooB_ooool00ol0003oooooooooo`1Mooooo`00B?ooool01?l0003oooooooooool0
0008ooooo`;o00002?ooool2o`0002Gooooo00?o003oooooooooool0oooooomBooooo`;o0000Gooo
ool004Wooooo0_l0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09?ooool0
0ol00?ooooooooooo`3ooooooe?ooooo00?o0000ooooooooool0GOooool005kooooo00?o0000oooo
ooooool09?ooool00ol00?ooooooooooo`3ooooooe?ooooo00?o0000ooooooooool0GOooool005ko
oooo0_l0000Uooooo`03o`00oooooooooooo0?ooooooD_ooool2o`0005oooooo001Nooooo`03o`00
0?oooooooooo02Cooooo00?o003oooooooooool0oooooomCooooo`03o`000?oooooooooo05gooooo
001Nooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool0oooooomCooooo`03o`000?oo
oooooooo05gooooo001Nooooo`;o00009Oooool00ol00?ooooooooooo`3ooooooe;ooooo0_l0001O
ooooo`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo0?ooooooDoooool00ol0
003oooooooooo`1Mooooo`00G_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo0?oo
ooooDoooool00ol0003oooooooooo`1Mooooo`00G_ooool2o`0002Gooooo00?o003oooooooooool0
oooooomBooooo`;o0000Goooool004Wooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000
1_ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo0?ooooooDoooool00ol0003ooooo
ooooo`1Mooooo`00B?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Ko
oooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`18ooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0GOooool004Sooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`06ooooo`?o00001_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o003oooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`?o0000Goooool004Sooooo
00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Mooooo`00B?ooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000001_ooooooo`0007ko0000Goooool004So
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo00000?oooooohoooool0
04Wooooo0_l00009ooooo`?o0000oooooooTooooo`00oooooooooooooccooooo003ooooooooooooo
??ooool00?oooooooooooollooooo`00A_ooool00ol0003oooooooooo`0<ooooo`?o0000;_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`1Zooooo`?o00008_ooool3o`0002Oooooo00?o0000ooooooooool0A_ooool0
04Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
06[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
04Gooooo0015ooooo`03o`000?oooooooooo00Go000000?oooooo`000?l000000ol00002ooooo`Co
00000_ooool3o`0000;ooooo0ol000000ooooooo0000o`000006ooooo`05o`000?oooooo0000oooo
ool000000_ooool3o`0000?ooooo1?l00002ooooo`?o00001Oooool00ol0003oooooooooo`05oooo
o`?o00001Oooool00ol0003oooooooooo`03ooooo`Go000000?oooooo`000?l000000_l00008oooo
o`Co00000oooool4o`000003ooooool0003o000000?o000000Coooooo`000?l0003ooooo0_l00002
ooooo`?o00000_ooool3o`000003ooooool0003o000000Kooooo1Ol00007ooooo`Go000000?ooooo
o`000?l000000ol00002ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol0
0002ooooo`?o000000?oooooo`000?l000000_ooool2o`0000?ooooo0ol00002ooooo`?o000000?o
ooooo`000?l000000oooool00ol0003oooooooooo`07ooooo`?o00000oooool00ol0003oooooo`00
0005ooooo`03o`000?oooooooooo00Oooooo0ol00003ooooo`?o00001?ooool00ol0003ooooooooo
o`03ooooo`;o00000oooool3o`0000Cooooo00Co0000oooooooooooooooo1Ol00003ooooo`;o0000
1?ooool2o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo00Oooooo1Ol000000ooooooo0000
o`000003o`000005ooooool0003o0000o`000?ooool01_l00003ooooo`?o00000oooool4o`000005
ooooool0003o0000o`000?ooool01Ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`00
0?l000000_l000001?oooooo0000o`000?ooool4o`0000Oooooo1Ol000001Ooooooo0000o`000?l0
003ooooo00;o00001oooool3o`0000Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`15ooooo`00AOooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`07o`000?ooooooooooooooool0003oooooo`000006ooooo`04o`000?oooooooooo
o`0000Oooooo00Oo0000ooooool0003oooooo`000?oooooo000000?ooooo00?o0000ooooool00000
0_ooool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000002oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000
ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooo`000002ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000005ooooo`07o`000?oooooo0000ooooool0003oooooo`000006ooooo`04o`000?oooooooooo
o`0000;ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`04o`000?ooooooooooo`0000go
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo0000013ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00017ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooo`000002ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0AOooool004Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000004o`0000;o
oooo00Co0000oooooooooooo00001oooool01ol0003oooooo`000?oooooo0000ooooool000000ooo
ool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Go00002oooool01Ol0003ooooooooo
oooooooo000000cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000;ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0_l00003oooo
o`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooooooool5o`000007ooooool0003oooooo`000?oooooo
0000ooooo`05o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`Go00000_ooool01?l0003oooooooooool0000=ooooo`0;o`000?ooooooooooooooool0003ooooo
o`000?oooooo0000ooooool000003oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`00017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo0ol00003
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo04Cooooo0015ooooo`04o`000?ooooooooooooooo`?o00001?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00Gooooo00Oo0000ooooool0003oooooo`000?oooooo
000000?ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00Wooooo1?l0000>ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`06ooooo`?o00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00002_ooool00ol0003oooooooooo`07ooooo`?o00001?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000000oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000gooooo00_o0000ooooooooooooooooo`000?oooooo
0000ooooool0003oooooo`00000?ooooo`03o`000?oooooooooo00?ooooo0_l00009ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00oooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000
ooooool00006ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo04Gooooo0015ooooo`05o`000?ooooooooooooooool000001?ooool3
o`0000Cooooo1Ol000001?oooooo0000o`000?l00002ooooo`Co00002?ooool2o`000003ooooool0
003ooooo00;ooooo0ol00003ooooo`?o00000oooool3o`0000cooooo00?o0000ooooooooool03?oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00002ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo0000
o`0000;ooooo0ol00002ooooo`Co00002?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`?o00000_ooool2o`000003ooooool0
003ooooo00;ooooo0ol00002ooooo`Co00000_ooool4o`0000?ooooo0ol00002ooooo`Co00003ooo
ool3o`0000;ooooo1_l0000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_oo
ool3o`0000?ooooo1?l00003ooooo`Co000000?oooooo`000?l000000_l00003ooooo`;o00000ooo
ool4o`0000;ooooo1?l00002ooooo`;o000000Coooooo`000?l0003ooooo1?l00003ooooo`Go0000
1_ooool3o`0000?ooooo1?l0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`15ooooo`00A_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0;ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`05o`000?oooooo
ooooooooool000002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0<oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000008ooooo`04
o`000?ooooooooooo`0000;ooooo0_l00009ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00004Oooool01?l0003oooooooooool0001Fooooo`;o00002_ooool00ol0003oooooooooo`16oooo
o`00B?ooool5o`0000?ooooo00?o0000ooooooooool09oooool2o`0001Cooooo0_l0000<ooooo`?o
00000_ooool4o`0000Sooooo1?l00008ooooo`?o00000oooool2o`0001Oooooo0ol00008ooooo`Go
000000Coooooo`000?l0003o00007?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00;ooooo0ol0000:ooooo`;o00001?ooool00ol0003oooooooooo`08ooooo`?o00001?ooool2o`00
00Cooooo0_l00004ooooo`;o00004Oooool5o`0000?ooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo057ooooo003ooooooooooooo??ooool00?oooooo
oooooollooooo`00\
\>"],
  ImageRangeCache->{{{0, 569}, {94, 0}} -> {-0.88243, -0.301052, 0.00661663, \
0.00661663}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.1037 .08333 L
.10417 .08333 L
.10472 .08333 L
.10524 .08333 L
.10572 .08333 L
.10616 .08333 L
.10664 .08333 L
.10716 .08333 L
.10767 .08333 L
.10823 .08333 L
.10875 .08333 L
.10923 .08333 L
.10979 .08333 L
.11011 .08333 L
.1104 .08333 L
.11094 .08333 L
.11152 .08333 L
.11181 .08333 L
.11211 .08333 L
.11266 .08333 L
.11296 .08333 L
.11325 .08333 L
.11356 .08333 L
.11389 .08333 L
.11418 .08333 L
.1145 .08333 L
.11507 .08333 L
.11562 .08333 L
.11613 .08333 L
.11663 .08333 L
.1171 .08333 L
.11761 .08333 L
.11816 .08333 L
.11871 .08333 L
.11928 .08333 L
.11978 .08333 L
.12032 .08333 L
.12063 .08333 L
.12092 .08333 L
.12124 .08333 L
.12158 .08333 L
.12214 .08333 L
.12247 .08333 L
.12277 .08333 L
.12333 .08333 L
.12384 .08333 L
.12413 .08333 L
.12444 .08333 L
.125 .08333 L
Mistroke
.12534 .08333 L
.12566 .08333 L
.12594 .08333 L
.12625 .08333 L
.12659 .08333 L
.12695 .08333 L
.12726 .08333 L
.12759 .08333 L
.12791 .08333 L
.12819 .08333 L
.12853 .08333 L
.12884 .08333 L
.12939 .08333 L
.12971 .08333 L
.13 .08333 L
.13052 .08333 L
.13107 .08333 L
.1316 .08333 L
.13208 .08333 L
.13261 .08333 L
.1332 .08333 L
.13349 .08333 L
.13381 .08333 L
.13437 .08333 L
.13468 .08333 L
.13497 .08333 L
.13529 .08333 L
.13562 .08333 L
.13619 .08333 L
.1365 .08333 L
.1368 .08333 L
.13736 .08333 L
.13787 .08333 L
.13845 .08333 L
.13901 .08333 L
.13951 .08333 L
.14006 .08333 L
.14057 .08333 L
.14104 .08333 L
.14156 .08333 L
.14213 .08333 L
.14242 .08333 L
.14273 .08333 L
.14329 .08333 L
.14359 .08333 L
.14387 .08333 L
.14418 .08333 L
.14451 .08333 L
.14506 .08333 L
.14537 .08333 L
Mistroke
.14567 .08333 L
.14621 .08333 L
.14671 .08333 L
.14728 .08333 L
.14783 .08333 L
.14835 .08333 L
.14881 .08333 L
.14935 .08333 L
.14986 .08333 L
.15033 .08333 L
.15076 .08333 L
.15124 .08333 L
.15174 .08333 L
.15225 .08333 L
.15279 .08333 L
.1533 .08333 L
.15377 .08333 L
.15432 .08333 L
.15463 .08333 L
.15492 .08333 L
.15544 .08333 L
.156 .08333 L
.15651 .08333 L
.15706 .08333 L
.15764 .08333 L
.15817 .08333 L
.15868 .08333 L
.15913 .08333 L
.15966 .08333 L
.16016 .08333 L
.16071 .08333 L
.16128 .08333 L
.16177 .08333 L
.16231 .08333 L
.16289 .08333 L
.16322 .08333 L
.16352 .08333 L
.1641 .08333 L
.16465 .08333 L
.16516 .08333 L
.16562 .08333 L
.16616 .08333 L
.16666 .08333 L
.16713 .08333 L
.16756 .08333 L
.16803 .08333 L
.16853 .08333 L
.16903 .08333 L
.16957 .08333 L
.17008 .08333 L
Mistroke
.17055 .08333 L
.17109 .08333 L
.1714 .08333 L
.17168 .08333 L
.1722 .08333 L
.17276 .08333 L
.17329 .08333 L
.17387 .08333 L
.17443 .08333 L
.17494 .08333 L
.17544 .08333 L
.1759 .08333 L
.17643 .08333 L
.17693 .08333 L
.17748 .08333 L
.17805 .08333 L
.17855 .08333 L
.17909 .08333 L
.17967 .08333 L
.18 .08333 L
.18029 .08333 L
.18087 .08333 L
.18142 .08333 L
.18189 .08333 L
.1824 .08333 L
.18294 .08333 L
.18344 .08333 L
.18391 .08333 L
.18434 .08333 L
.18481 .08333 L
.18531 .08333 L
.18581 .08333 L
.18635 .08333 L
.18686 .08333 L
.18733 .08333 L
.18787 .08333 L
.18818 .08333 L
.18846 .08333 L
.18899 .08333 L
.18954 .08333 L
.19007 .08333 L
.19066 .08333 L
.19121 .08333 L
.19172 .08333 L
.19223 .08333 L
.19269 .08333 L
.19322 .08333 L
.19372 .08333 L
.19427 .08333 L
.19485 .08333 L
Mistroke
.19534 .08333 L
.19588 .08333 L
.19647 .08333 L
.19679 .08333 L
.19709 .08333 L
.19767 .08333 L
.19822 .08333 L
.19869 .08333 L
.1992 .08333 L
.19974 .08333 L
.20024 .08333 L
.20071 .08333 L
.20114 .08333 L
.20161 .08333 L
.20211 .08333 L
.20262 .08333 L
.20316 .08333 L
.20367 .08333 L
.20413 .08333 L
.20468 .08333 L
.20499 .08333 L
.20527 .08333 L
.20579 .08333 L
.20634 .08333 L
.20688 .08333 L
.20747 .08333 L
.20802 .08333 L
.20854 .08333 L
.209 .08333 L
.20951 .08333 L
.21004 .08333 L
.21054 .08333 L
.21109 .08333 L
.21167 .08333 L
.21216 .08333 L
.2127 .08333 L
.21329 .08333 L
.21361 .08333 L
.21391 .08333 L
.21449 .08333 L
.21504 .08333 L
.21551 .08333 L
.21602 .08333 L
.21656 .08333 L
.21707 .08333 L
.21754 .08333 L
.21797 .08333 L
.21847 .08333 L
.21894 .08333 L
.21945 .08333 L
Mistroke
.21999 .08333 L
.2205 .08333 L
.22096 .08333 L
.22151 .08333 L
.22181 .08333 L
.2221 .08333 L
.22262 .08333 L
.22317 .08333 L
.22371 .08333 L
.22402 .08333 L
.2243 .08333 L
.22482 .08333 L
.22537 .08333 L
.22586 .08333 L
.22632 .08333 L
.22683 .08333 L
.22738 .08333 L
.22792 .08333 L
.22823 .08333 L
.22852 .08333 L
.2291 .08333 L
.22943 .08333 L
.22973 .08333 L
.23026 .08333 L
.23084 .08333 L
.23138 .08333 L
.23188 .08333 L
.23235 .08333 L
.23286 .08333 L
.23333 .08333 L
.23377 .08333 L
.23427 .08333 L
.23483 .08333 L
.23535 .08333 L
.23584 .08333 L
.23638 .08333 L
.2369 .08333 L
.23736 .08333 L
.23786 .08333 L
.23841 .08333 L
.23899 .08333 L
.23948 .08333 L
.24002 .08333 L
.2406 .08333 L
.24114 .08333 L
.24142 .08333 L
.24173 .08333 L
.24205 .08333 L
.24235 .08333 L
.24291 .08333 L
Mistroke
.24342 .08333 L
.244 .08333 L
.24456 .08333 L
.24506 .08333 L
.24558 .08333 L
.24608 .08333 L
.24654 .08333 L
.24707 .08333 L
.24765 .08333 L
.24819 .08333 L
.24869 .08333 L
.24923 .08333 L
.24981 .08333 L
.25035 .08333 L
.25085 .08333 L
.25143 .08333 L
.25175 .08333 L
.25206 .08333 L
.25262 .08333 L
.2529 .08333 L
.25321 .08333 L
.25351 .08333 L
.25383 .08333 L
.25439 .08333 L
.25471 .08333 L
.255 .08333 L
.25532 .08333 L
.25567 .08333 L
.25597 .08333 L
.25629 .08333 L
.2566 .08333 L
.25688 .08333 L
.25741 .08333 L
.25798 .08333 L
.25852 .08333 L
.2591 .08333 L
.25965 .08333 L
.26016 .08333 L
.26067 .08333 L
.26113 .08333 L
.26166 .08333 L
.26216 .08333 L
.26271 .08333 L
.26329 .08333 L
.26378 .08333 L
.26432 .08333 L
.2649 .08333 L
.26523 .08333 L
.26553 .08333 L
.26611 .08333 L
Mistroke
.26666 .08333 L
.26712 .08333 L
.26764 .08333 L
.26817 .08333 L
.26868 .08333 L
.26915 .08333 L
.26958 .08333 L
.27005 .08333 L
.27055 .08333 L
.27105 .08333 L
.2716 .08333 L
.27211 .08333 L
.27257 .08333 L
.27311 .08333 L
.27342 .08333 L
.27371 .08333 L
.27423 .08333 L
.27478 .08333 L
.27532 .08333 L
.2759 .08333 L
.27646 .08333 L
.27697 .08333 L
.27748 .08333 L
.27794 .08333 L
.27847 .08333 L
.27897 .08333 L
.27952 .08333 L
.2801 .08333 L
.28059 .08333 L
.28114 .08333 L
.28172 .08333 L
.28205 .08333 L
.28234 .08333 L
.28292 .08333 L
.28347 .08333 L
.28394 .08333 L
.28446 .08333 L
.28499 .08333 L
.2855 .08333 L
.28597 .08333 L
.2864 .08333 L
.2869 .08333 L
.28737 .08333 L
.28788 .08333 L
.28842 .08333 L
.28893 .08333 L
.28939 .08333 L
.28994 .08333 L
.29025 .08333 L
.29053 .08333 L
Mistroke
.29105 .08333 L
.2916 .08333 L
.29214 .08333 L
.29245 .08333 L
.29273 .08333 L
.29325 .08333 L
.2938 .08333 L
.29429 .08333 L
.29475 .08333 L
.29526 .08333 L
.2958 .08333 L
.29635 .08333 L
.29666 .08333 L
.29695 .08333 L
.29753 .08333 L
.29786 .08333 L
.29815 .08333 L
.29869 .08333 L
.29926 .08333 L
.29981 .08333 L
.30031 .08333 L
.30078 .08333 L
.30128 .08333 L
.30176 .08333 L
.30219 .08333 L
.3027 .08333 L
.30325 .08333 L
.30378 .08333 L
.30426 .08333 L
.30481 .08333 L
.30532 .08333 L
.30579 .08333 L
.30629 .08333 L
.30683 .08333 L
.30741 .08333 L
.3079 .08333 L
.30844 .08333 L
.30902 .08333 L
.30956 .08333 L
.30984 .08333 L
.31015 .08333 L
.31047 .08333 L
.31078 .08333 L
.31133 .08333 L
.31184 .08333 L
.3124 .08333 L
.31298 .08333 L
.31348 .08333 L
.31401 .08333 L
.3145 .08333 L
Mistroke
.31496 .08333 L
.31549 .08333 L
.31607 .08333 L
.31661 .08333 L
.31712 .08333 L
.31765 .08333 L
.31823 .08333 L
.31877 .08333 L
.31927 .08333 L
.31985 .08333 L
.32017 .08333 L
.32048 .08333 L
.32104 .08333 L
.32132 .08333 L
.32163 .08333 L
.32193 .08333 L
.32224 .08333 L
.32281 .08333 L
.32313 .08333 L
.32342 .08333 L
.32374 .08333 L
.32409 .08333 L
.32439 .08333 L
.32471 .08333 L
.32502 .08333 L
.3253 .08333 L
.32583 .08333 L
.3264 .08333 L
.32693 .08333 L
.32752 .08333 L
.32807 .08333 L
.32858 .08333 L
.32909 .08333 L
.32955 .08333 L
.33008 .08333 L
.33058 .08333 L
.33113 .08333 L
.3317 .08333 L
.3322 .08333 L
.33274 .08333 L
.33332 .08333 L
.33365 .08333 L
.33394 .08333 L
.33452 .08333 L
.33507 .08333 L
.33554 .08333 L
.33605 .08333 L
.33659 .08333 L
.33709 .08333 L
.33756 .08333 L
Mistroke
.33799 .08333 L
.33846 .08333 L
.33896 .08333 L
.33947 .08333 L
.34001 .08333 L
.34052 .08333 L
.34098 .08333 L
.34153 .08333 L
.34184 .08333 L
.34212 .08333 L
.34264 .08333 L
.34319 .08333 L
.34373 .08333 L
.34432 .08333 L
.34487 .08333 L
.34538 .08333 L
.34589 .08333 L
.34635 .08333 L
.34688 .08333 L
.34738 .08333 L
.34793 .08333 L
.34851 .08333 L
.349 .08333 L
.34955 .08333 L
.35013 .08333 L
.35046 .08333 L
.35075 .08333 L
.35133 .08333 L
.35188 .08333 L
.35235 .08333 L
.35286 .08333 L
.3534 .08333 L
.35391 .08333 L
.35438 .08333 L
.35481 .08333 L
.35531 .08333 L
.35578 .08333 L
.35629 .08333 L
.35683 .08333 L
.35734 .08333 L
.3578 .08333 L
.35835 .08333 L
.35865 .08333 L
.35894 .08333 L
.35946 .08333 L
.36001 .08333 L
.36055 .08333 L
.36085 .08333 L
.36114 .08333 L
.36165 .08333 L
Mistroke
.36221 .08333 L
.3627 .08333 L
.36316 .08333 L
.36366 .08333 L
.36421 .08333 L
.36476 .08333 L
.36507 .08333 L
.36535 .08333 L
.36594 .08333 L
.36626 .08333 L
.36656 .08333 L
.36709 .08333 L
.36767 .08333 L
.36821 .08333 L
.36872 .08333 L
.36918 .08333 L
.36969 .08333 L
.37016 .08333 L
.3706 .08333 L
.3711 .08333 L
.37166 .08333 L
.37218 .08333 L
.37266 .08333 L
.37321 .08333 L
.37373 .08333 L
.37419 .08333 L
.37469 .08333 L
.37524 .08333 L
.37581 .08333 L
.37631 .08333 L
.37685 .08333 L
.37743 .08333 L
.37796 .08333 L
.37824 .08333 L
.37855 .08333 L
.37888 .08333 L
.37918 .08333 L
.37973 .08333 L
.38024 .08333 L
.3808 .08333 L
.38138 .08333 L
.38188 .08333 L
.38241 .08333 L
.3829 .08333 L
.38336 .08333 L
.38389 .08333 L
.38447 .08333 L
.38501 .08333 L
.38551 .08333 L
.38605 .08333 L
Mistroke
.38663 .08333 L
.38717 .08333 L
.38766 .08333 L
.38824 .08333 L
.38857 .08333 L
.38888 .08333 L
.38943 .08333 L
.38971 .08333 L
.39003 .08333 L
.39033 .08333 L
.39064 .08333 L
.39121 .08333 L
.39152 .08333 L
.39182 .08333 L
.39214 .08333 L
.39249 .08333 L
.39278 .08333 L
.39311 .08333 L
.39341 .08333 L
.3937 .08333 L
.39423 .08333 L
.3948 .08333 L
.39533 .08333 L
.39592 .08333 L
.39647 .08333 L
.39698 .08333 L
.39749 .08333 L
.39794 .08333 L
.39847 .08333 L
.39897 .08333 L
.39952 .08333 L
.4001 .08333 L
.40059 .08333 L
.40113 .08333 L
.40171 .08333 L
.40204 .08333 L
.40234 .08333 L
.40292 .08333 L
.40347 .08333 L
.40393 .08333 L
.40445 .08333 L
.40498 .08333 L
.40549 .08333 L
.40595 .08333 L
.40639 .08333 L
.40686 .08333 L
.40735 .08333 L
.40786 .08333 L
.4084 .08333 L
.40891 .08333 L
Mistroke
.40938 .08333 L
.40992 .08333 L
.41023 .08333 L
.41051 .08333 L
.41103 .08333 L
.41159 .08333 L
.41212 .08333 L
.41271 .08333 L
.41326 .08333 L
.41377 .08333 L
.41428 .08333 L
.41474 .08333 L
.41527 .08333 L
.41577 .08333 L
.41632 .08333 L
.4169 .08333 L
.41739 .08333 L
.41793 .08333 L
.41852 .08333 L
.41885 .08333 L
.41914 .08333 L
.41972 .08333 L
.42027 .08333 L
.42074 .08333 L
.42125 .08333 L
.42179 .08333 L
.42229 .08333 L
.42276 .08333 L
.4232 .08333 L
.42367 .08333 L
.42416 .08333 L
.42467 .08333 L
.42521 .08333 L
.42572 .08333 L
.42619 .08333 L
.42673 .08333 L
.42704 .08333 L
.42732 .08333 L
.42784 .08333 L
.4284 .08333 L
.42894 .08333 L
.42924 .08333 L
.42952 .08333 L
.43004 .08333 L
.43059 .08333 L
.43108 .08333 L
.43154 .08333 L
.43205 .08333 L
.43259 .08333 L
.43314 .08333 L
Mistroke
.43345 .08333 L
.43374 .08333 L
.43432 .08333 L
.43465 .08333 L
.43494 .08333 L
.43547 .08333 L
.43605 .08333 L
.4366 .08333 L
.4371 .08333 L
.43757 .08333 L
.43807 .08333 L
.43854 .08333 L
.43898 .08333 L
.43948 .08333 L
.44004 .08333 L
.44056 .08333 L
.44105 .08333 L
.44159 .08333 L
.44211 .08333 L
.44257 .08333 L
.44307 .08333 L
.44362 .08333 L
.4442 .08333 L
.44469 .08333 L
.44523 .08333 L
.44581 .08333 L
.44634 .08333 L
.44662 .08333 L
.44693 .08333 L
.44726 .08333 L
.44756 .08333 L
.44811 .08333 L
.44862 .08333 L
.44918 .08333 L
.44976 .08333 L
.45026 .08333 L
.45078 .08333 L
.45128 .08333 L
.45174 .08333 L
.45227 .08333 L
.45284 .08333 L
.45339 .08333 L
.45389 .08333 L
.45443 .08333 L
.455 .08333 L
.45554 .08333 L
.45604 .08333 L
.45662 .08333 L
.45695 .08333 L
.45725 .08333 L
Mistroke
.45781 .08333 L
.45812 .08333 L
.4584 .08333 L
.4587 .08333 L
.45902 .08333 L
.45958 .08333 L
.4599 .08333 L
.46019 .08333 L
.46052 .08333 L
.46086 .08333 L
.46116 .08333 L
.46148 .08333 L
.46179 .08333 L
.46207 .08333 L
.46261 .08333 L
.46317 .08333 L
.46371 .08333 L
.46429 .08333 L
.46484 .08333 L
.46535 .08333 L
.46586 .08333 L
.46632 .08333 L
.46685 .08333 L
.46735 .08333 L
.46789 .08333 L
.46847 .08333 L
.46896 .08333 L
.4695 .08333 L
.47009 .08333 L
.47041 .08333 L
.47071 .08333 L
.47129 .08333 L
.47184 .08333 L
.4723 .08333 L
.47282 .08333 L
.47335 .08333 L
.47386 .08333 L
.47433 .08333 L
.47476 .08333 L
.47523 .08333 L
.47573 .08333 L
.47623 .08333 L
.47677 .08333 L
.47728 .08333 L
.47775 .08333 L
.47829 .08333 L
.4786 .08333 L
.47888 .08333 L
.4794 .08333 L
.47996 .08333 L
Mistroke
.48049 .08333 L
.48108 .08333 L
.48163 .08333 L
.48214 .08333 L
.48265 .08333 L
.48311 .08333 L
.48364 .08333 L
.48414 .08333 L
.48469 .08333 L
.48527 .08333 L
.48576 .08333 L
.4863 .08333 L
.48689 .08333 L
.48721 .08333 L
.48751 .08333 L
.48809 .08333 L
.48864 .08333 L
.4891 .08333 L
.48962 .08333 L
.49016 .08333 L
.49066 .08333 L
.49113 .08333 L
.49156 .08333 L
.49203 .08333 L
.49253 .08333 L
.49304 .08333 L
.49358 .08333 L
.49409 .08333 L
.49455 .08333 L
.4951 .08333 L
.49541 .08333 L
.49569 .08333 L
.49621 .08333 L
.49676 .08333 L
.4973 .08333 L
.4976 .08333 L
.49789 .08333 L
.4984 .08333 L
.49895 .08333 L
.49944 .08333 L
.49991 .08333 L
.50041 .08333 L
.50096 .08333 L
.5015 .08333 L
.50181 .08333 L
.5021 .08333 L
.50268 .08333 L
.50301 .08333 L
.5033 .08333 L
.50384 .08333 L
Mistroke
.50441 .08333 L
.50496 .08333 L
.50546 .08333 L
.50593 .08333 L
.50643 .08333 L
.5069 .08333 L
.50734 .08333 L
.50784 .08333 L
.5084 .08333 L
.50892 .08333 L
.50941 .08333 L
.50995 .08333 L
.51047 .08333 L
.51093 .08333 L
.51143 .08333 L
.51198 .08333 L
.51255 .08333 L
.51305 .08333 L
.51359 .08333 L
.51398 .08333 L
.51434 .08333 L
.51474 .08333 L
.51516 .08333 L
.51553 .08333 L
.51587 .08333 L
.51624 .08333 L
.51665 .08333 L
.51699 .08333 L
.51736 .08333 L
.51775 .08333 L
.51811 .08333 L
.51844 .08333 L
.51875 .08333 L
.5191 .08333 L
.51944 .08333 L
.5198 .08333 L
.5202 .08333 L
.52062 .08333 L
.52101 .08333 L
.52137 .08333 L
.5217 .08333 L
.52208 .08333 L
.52245 .08333 L
.52284 .08333 L
.52326 .08333 L
.52365 .08333 L
.52401 .08333 L
.52443 .08333 L
.52489 .08333 L
.52531 .08333 L
Mistroke
.52571 .08333 L
Mfstroke
.52571 .08333 m
.52621 .08333 L
.52667 .08333 L
.5272 .08333 L
.5277 .08333 L
.52816 .08333 L
.52859 .08333 L
.52905 .08333 L
.52955 .08333 L
.53005 .08333 L
.53058 .08333 L
.53109 .08333 L
.53155 .08333 L
.53209 .08333 L
.5324 .08333 L
.53268 .08333 L
.5332 .08333 L
.53376 .08333 L
.53404 .08333 L
.53433 .08333 L
.53486 .08333 L
.53515 .08333 L
.53542 .08333 L
.53573 .08333 L
.53605 .08333 L
.53632 .08333 L
.53663 .08333 L
.53718 .08333 L
.53771 .08333 L
.53821 .08333 L
.53869 .08333 L
.53914 .08333 L
.53963 .08333 L
.54016 .08333 L
.54069 .08333 L
.54125 .08333 L
.54172 .08333 L
.54224 .08333 L
.54254 .08333 L
.54282 .08333 L
.54313 .08333 L
.54346 .08333 L
.544 .08333 L
.54431 .08333 L
.54461 .08333 L
.54515 .08333 L
.54564 .08333 L
.54591 .08333 L
.54621 .08333 L
.54675 .08333 L
Mistroke
.54708 .08333 L
.54739 .08333 L
.54767 .08333 L
.54797 .08333 L
.54829 .08333 L
.54864 .08333 L
.54893 .08333 L
.54926 .08333 L
.54956 .08333 L
.54984 .08333 L
.55016 .08333 L
.55046 .08333 L
.551 .08333 L
.5513 .08333 L
.55158 .08333 L
.55208 .08333 L
.55261 .08333 L
.55312 .08333 L
.55358 .08333 L
.5541 .08333 L
.55466 .08333 L
.55495 .08333 L
.55525 .08333 L
.55579 .08333 L
.5561 .08333 L
.55637 .08333 L
.55668 .08333 L
.557 .08333 L
.55754 .08333 L
.55785 .08333 L
.55814 .08333 L
.55868 .08333 L
.55917 .08333 L
.55973 .08333 L
.56027 .08333 L
.56075 .08333 L
.56128 .08333 L
.56177 .08333 L
.56223 .08333 L
.56273 .08333 L
.56328 .08333 L
.56356 .08333 L
.56385 .08333 L
.56439 .08333 L
.56468 .08333 L
.56496 .08333 L
.56525 .08333 L
.56557 .08333 L
.5661 .08333 L
.5664 .08333 L
Mistroke
.56669 .08333 L
.56721 .08333 L
.56769 .08333 L
.56825 .08333 L
.56877 .08333 L
.56927 .08333 L
.56972 .08333 L
.57024 .08333 L
.57073 .08333 L
.57118 .08333 L
.5716 .08333 L
.57206 .08333 L
.57254 .08333 L
.57303 .08333 L
.57356 .08333 L
.57405 .08333 L
.5745 .08333 L
.57503 .08333 L
.57533 .08333 L
.57561 .08333 L
.57611 .08333 L
.57665 .08333 L
.57714 .08333 L
.57767 .08333 L
.57823 .08333 L
.57875 .08333 L
.57923 .08333 L
.57967 .08333 L
.58018 .08333 L
.58067 .08333 L
.58119 .08333 L
.58175 .08333 L
.58222 .08333 L
.58274 .08333 L
.5833 .08333 L
.58362 .08333 L
.5839 .08333 L
.58446 .08333 L
.58499 .08333 L
.58548 .08333 L
.58593 .08333 L
.58645 .08333 L
.58693 .08333 L
.58738 .08333 L
.5878 .08333 L
.58825 .08333 L
.58873 .08333 L
.58922 .08333 L
.58974 .08333 L
.59023 .08333 L
Mistroke
.59068 .08333 L
.59121 .08333 L
.5915 .08333 L
.59178 .08333 L
.59228 .08333 L
.59281 .08333 L
.59333 .08333 L
.59389 .08333 L
.59442 .08333 L
.59491 .08333 L
.5954 .08333 L
.59584 .08333 L
.59635 .08333 L
.59684 .08333 L
.59736 .08333 L
.59792 .08333 L
.59839 .08333 L
.59892 .08333 L
.59948 .08333 L
.59979 .08333 L
.60008 .08333 L
.60064 .08333 L
.60117 .08333 L
.60161 .08333 L
.60211 .08333 L
.60263 .08333 L
.60311 .08333 L
.60357 .08333 L
.60398 .08333 L
.60444 .08333 L
.60492 .08333 L
.6054 .08333 L
.60592 .08333 L
.60642 .08333 L
.60686 .08333 L
.60739 .08333 L
.60769 .08333 L
.60796 .08333 L
.60846 .08333 L
.60899 .08333 L
.60951 .08333 L
.61008 .08333 L
.61061 .08333 L
.6111 .08333 L
.61159 .08333 L
.61204 .08333 L
.61255 .08333 L
.61303 .08333 L
.61356 .08333 L
.61412 .08333 L
Mistroke
.61459 .08333 L
.61511 .08333 L
.61568 .08333 L
.61599 .08333 L
.61628 .08333 L
.61684 .08333 L
.61737 .08333 L
.61782 .08333 L
.61831 .08333 L
.61883 .08333 L
.61932 .08333 L
.61977 .08333 L
.62018 .08333 L
.62064 .08333 L
.62112 .08333 L
.62161 .08333 L
.62213 .08333 L
.62262 .08333 L
.62307 .08333 L
.6236 .08333 L
.62389 .08333 L
.62417 .08333 L
.62467 .08333 L
.6252 .08333 L
.62572 .08333 L
.62629 .08333 L
.62682 .08333 L
.62731 .08333 L
.62776 .08333 L
.62825 .08333 L
.62876 .08333 L
.62925 .08333 L
.62978 .08333 L
.63033 .08333 L
.63081 .08333 L
.63133 .08333 L
.6319 .08333 L
.63221 .08333 L
.6325 .08333 L
.63306 .08333 L
.63359 .08333 L
.63404 .08333 L
.63454 .08333 L
.63506 .08333 L
.63554 .08333 L
.636 .08333 L
.63641 .08333 L
.63689 .08333 L
.63735 .08333 L
.63784 .08333 L
Mistroke
.63836 .08333 L
.63885 .08333 L
.6393 .08333 L
.63982 .08333 L
.64012 .08333 L
.64039 .08333 L
.6409 .08333 L
.64143 .08333 L
.64195 .08333 L
.64224 .08333 L
.64252 .08333 L
.64302 .08333 L
.64355 .08333 L
.64402 .08333 L
.64447 .08333 L
.64496 .08333 L
.64548 .08333 L
.64601 .08333 L
.64631 .08333 L
.64659 .08333 L
.64715 .08333 L
.64747 .08333 L
.64775 .08333 L
.64827 .08333 L
.64882 .08333 L
.64935 .08333 L
.64983 .08333 L
.65028 .08333 L
.65077 .08333 L
.65123 .08333 L
.65165 .08333 L
.65214 .08333 L
.65267 .08333 L
.65317 .08333 L
.65364 .08333 L
.65417 .08333 L
.65467 .08333 L
.65511 .08333 L
.6556 .08333 L
.65612 .08333 L
.65668 .08333 L
.65716 .08333 L
.65768 .08333 L
.65824 .08333 L
.65875 .08333 L
.65903 .08333 L
.65932 .08333 L
.65963 .08333 L
.65993 .08333 L
.66046 .08333 L
Mistroke
.66095 .08333 L
.66152 .08333 L
.66206 .08333 L
.66253 .08333 L
.66304 .08333 L
.66352 .08333 L
.66396 .08333 L
.66448 .08333 L
.66503 .08333 L
.66556 .08333 L
.66604 .08333 L
.66656 .08333 L
.66711 .08333 L
.66764 .08333 L
.66812 .08333 L
.66868 .08333 L
.66899 .08333 L
.66929 .08333 L
.66982 .08333 L
.6701 .08333 L
.6704 .08333 L
.67069 .08333 L
.67099 .08333 L
.67154 .08333 L
.67184 .08333 L
.67212 .08333 L
.67244 .08333 L
.67277 .08333 L
.67306 .08333 L
.67337 .08333 L
.67366 .08333 L
.67394 .08333 L
.67445 .08333 L
.675 .08333 L
.67551 .08333 L
.67608 .08333 L
.67661 .08333 L
.6771 .08333 L
.67759 .08333 L
.67804 .08333 L
.67855 .08333 L
.67903 .08333 L
.67956 .08333 L
.68011 .08333 L
.68059 .08333 L
.68111 .08333 L
.68167 .08333 L
.68199 .08333 L
.68228 .08333 L
.68284 .08333 L
Mistroke
.68336 .08333 L
.68381 .08333 L
.68431 .08333 L
.68483 .08333 L
.68531 .08333 L
.68577 .08333 L
.68618 .08333 L
.68664 .08333 L
.68712 .08333 L
.68761 .08333 L
.68813 .08333 L
.68862 .08333 L
.68907 .08333 L
.68959 .08333 L
.68989 .08333 L
.69016 .08333 L
.69066 .08333 L
.6912 .08333 L
.69172 .08333 L
.69228 .08333 L
.69282 .08333 L
.69331 .08333 L
.6938 .08333 L
.69424 .08333 L
.69476 .08333 L
.69524 .08333 L
.69577 .08333 L
.69633 .08333 L
.6968 .08333 L
.69733 .08333 L
.69789 .08333 L
.69821 .08333 L
.69849 .08333 L
.69905 .08333 L
.69958 .08333 L
.70003 .08333 L
.70053 .08333 L
.70105 .08333 L
.70153 .08333 L
.70199 .08333 L
.7024 .08333 L
.70288 .08333 L
.70334 .08333 L
.70383 .08333 L
.70435 .08333 L
.70484 .08333 L
.70529 .08333 L
.70582 .08333 L
.70611 .08333 L
.70639 .08333 L
Mistroke
.70689 .08333 L
.70742 .08333 L
.70794 .08333 L
.70823 .08333 L
.70851 .08333 L
.70901 .08333 L
.70954 .08333 L
.71001 .08333 L
.71046 .08333 L
.71095 .08333 L
.71147 .08333 L
.712 .08333 L
.7123 .08333 L
.71258 .08333 L
.71314 .08333 L
.71345 .08333 L
.71374 .08333 L
.71425 .08333 L
.71481 .08333 L
.71533 .08333 L
.71582 .08333 L
.71627 .08333 L
.71676 .08333 L
.71721 .08333 L
.71763 .08333 L
.71812 .08333 L
.71866 .08333 L
.71916 .08333 L
.71963 .08333 L
.72016 .08333 L
.72065 .08333 L
.7211 .08333 L
.72158 .08333 L
.72211 .08333 L
.72267 .08333 L
.72314 .08333 L
.72366 .08333 L
.72422 .08333 L
.72474 .08333 L
.72501 .08333 L
.72531 .08333 L
.72562 .08333 L
.72591 .08333 L
.72645 .08333 L
.72694 .08333 L
.72747 .08333 L
.72804 .08333 L
.72852 .08333 L
.72903 .08333 L
.72951 .08333 L
Mistroke
.72994 .08333 L
.73046 .08333 L
.73101 .08333 L
.73154 .08333 L
.73202 .08333 L
.73254 .08333 L
.7331 .08333 L
.73362 .08333 L
.7341 .08333 L
.73466 .08333 L
.73497 .08333 L
.73527 .08333 L
.73581 .08333 L
.73608 .08333 L
.73638 .08333 L
.73667 .08333 L
.73697 .08333 L
.73752 .08333 L
.73782 .08333 L
.73811 .08333 L
.73842 .08333 L
.73875 .08333 L
.73904 .08333 L
.73935 .08333 L
.73964 .08333 L
.73992 .08333 L
.74043 .08333 L
.74098 .08333 L
.74149 .08333 L
.74206 .08333 L
.74259 .08333 L
.74308 .08333 L
.74357 .08333 L
.74401 .08333 L
.74453 .08333 L
.74501 .08333 L
.74554 .08333 L
.74609 .08333 L
.74657 .08333 L
.74709 .08333 L
.74765 .08333 L
.74797 .08333 L
.74825 .08333 L
.74881 .08333 L
.74934 .08333 L
.74979 .08333 L
.75029 .08333 L
.7508 .08333 L
.75129 .08333 L
.75174 .08333 L
Mistroke
.75216 .08333 L
.75261 .08333 L
.75309 .08333 L
.75358 .08333 L
.7541 .08333 L
.75459 .08333 L
.75504 .08333 L
.75557 .08333 L
.75586 .08333 L
.75614 .08333 L
.75664 .08333 L
.75717 .08333 L
.75769 .08333 L
.75826 .08333 L
.75879 .08333 L
.75928 .08333 L
.75977 .08333 L
.76022 .08333 L
.76073 .08333 L
.76121 .08333 L
.76174 .08333 L
.7623 .08333 L
.76278 .08333 L
.7633 .08333 L
.76386 .08333 L
.76418 .08333 L
.76447 .08333 L
.76502 .08333 L
.76555 .08333 L
.766 .08333 L
.7665 .08333 L
.76702 .08333 L
.76751 .08333 L
.76796 .08333 L
.76837 .08333 L
.76885 .08333 L
.76931 .08333 L
.7698 .08333 L
.77032 .08333 L
.77081 .08333 L
.77126 .08333 L
.77179 .08333 L
.77208 .08333 L
.77236 .08333 L
.77286 .08333 L
.77339 .08333 L
.77391 .08333 L
.7742 .08333 L
.77448 .08333 L
.77498 .08333 L
Mistroke
.77551 .08333 L
.77598 .08333 L
.77643 .08333 L
.77691 .08333 L
.77744 .08333 L
.77797 .08333 L
.77827 .08333 L
.77854 .08333 L
.77911 .08333 L
.77942 .08333 L
.77971 .08333 L
.78022 .08333 L
.78078 .08333 L
.7813 .08333 L
.78179 .08333 L
.78224 .08333 L
.78272 .08333 L
.78318 .08333 L
.7836 .08333 L
.78409 .08333 L
.78462 .08333 L
.78513 .08333 L
.78559 .08333 L
.78612 .08333 L
.78662 .08333 L
.78707 .08333 L
.78755 .08333 L
.78807 .08333 L
.78863 .08333 L
.78911 .08333 L
.78963 .08333 L
.79019 .08333 L
.7907 .08333 L
.79097 .08333 L
.79127 .08333 L
.79158 .08333 L
.79187 .08333 L
.79241 .08333 L
.7929 .08333 L
.79344 .08333 L
.794 .08333 L
.79448 .08333 L
.79499 .08333 L
.79547 .08333 L
.79591 .08333 L
.79642 .08333 L
.79698 .08333 L
.7975 .08333 L
.79799 .08333 L
.7985 .08333 L
Mistroke
.79906 .08333 L
.79958 .08333 L
.80006 .08333 L
.80062 .08333 L
.80093 .08333 L
.80123 .08333 L
.80177 .08333 L
.80204 .08333 L
.80234 .08333 L
.80263 .08333 L
.80293 .08333 L
.80348 .08333 L
.80378 .08333 L
.80407 .08333 L
.80438 .08333 L
.80471 .08333 L
.805 .08333 L
.80531 .08333 L
.8056 .08333 L
.80588 .08333 L
.80639 .08333 L
.80694 .08333 L
.80745 .08333 L
.80802 .08333 L
.80855 .08333 L
.80904 .08333 L
.80953 .08333 L
.80997 .08333 L
.81048 .08333 L
.81097 .08333 L
.81149 .08333 L
.81205 .08333 L
.81252 .08333 L
.81305 .08333 L
.81361 .08333 L
.81392 .08333 L
.81421 .08333 L
.81477 .08333 L
.8153 .08333 L
.81575 .08333 L
.81624 .08333 L
.81676 .08333 L
.81725 .08333 L
.8177 .08333 L
.81811 .08333 L
.81857 .08333 L
.81905 .08333 L
.81954 .08333 L
.82006 .08333 L
.82055 .08333 L
Mistroke
.821 .08333 L
.82152 .08333 L
.82182 .08333 L
.82209 .08333 L
.8226 .08333 L
.82313 .08333 L
.82365 .08333 L
.82421 .08333 L
.82474 .08333 L
.82524 .08333 L
.82573 .08333 L
.82617 .08333 L
.82668 .08333 L
.82717 .08333 L
.82769 .08333 L
.82825 .08333 L
.82873 .08333 L
.82925 .08333 L
.82981 .08333 L
.83013 .08333 L
.83042 .08333 L
.83097 .08333 L
.8315 .08333 L
.83195 .08333 L
.83245 .08333 L
.83297 .08333 L
.83346 .08333 L
.83391 .08333 L
.83432 .08333 L
.83478 .08333 L
.83526 .08333 L
.83575 .08333 L
.83627 .08333 L
.83676 .08333 L
.83721 .08333 L
.83774 .08333 L
.83803 .08333 L
.83831 .08333 L
.83881 .08333 L
.83934 .08333 L
.83986 .08333 L
.84015 .08333 L
.84043 .08333 L
.84092 .08333 L
.84146 .08333 L
.84193 .08333 L
.84237 .08333 L
.84286 .08333 L
.84339 .08333 L
.84391 .08333 L
Mistroke
.84421 .08333 L
.84449 .08333 L
.84505 .08333 L
.84537 .08333 L
.84565 .08333 L
.84617 .08333 L
.84672 .08333 L
.84725 .08333 L
.84773 .08333 L
.84818 .08333 L
.84867 .08333 L
.84912 .08333 L
.84954 .08333 L
.85003 .08333 L
.85057 .08333 L
.85107 .08333 L
.85154 .08333 L
.85207 .08333 L
.85256 .08333 L
.85301 .08333 L
.85349 .08333 L
.85402 .08333 L
.85458 .08333 L
.85505 .08333 L
.85557 .08333 L
.85613 .08333 L
.85665 .08333 L
.85692 .08333 L
.85722 .08333 L
.85753 .08333 L
.85782 .08333 L
.85835 .08333 L
.85884 .08333 L
.85938 .08333 L
.85994 .08333 L
.86042 .08333 L
.86093 .08333 L
.86141 .08333 L
.86185 .08333 L
.86236 .08333 L
.86292 .08333 L
.86344 .08333 L
.86393 .08333 L
.86444 .08333 L
.865 .08333 L
.86552 .08333 L
.866 .08333 L
.86656 .08333 L
.86687 .08333 L
.86717 .08333 L
Mistroke
.8677 .08333 L
.868 .08333 L
.86828 .08333 L
.86857 .08333 L
.86887 .08333 L
.86942 .08333 L
.86972 .08333 L
.87 .08333 L
.87031 .08333 L
.87065 .08333 L
.87094 .08333 L
.87125 .08333 L
.87154 .08333 L
.87181 .08333 L
.87233 .08333 L
.87288 .08333 L
.87339 .08333 L
.87395 .08333 L
.87449 .08333 L
.87498 .08333 L
.87547 .08333 L
.87591 .08333 L
.87642 .08333 L
.8769 .08333 L
.87743 .08333 L
.87799 .08333 L
.87846 .08333 L
.87898 .08333 L
.87954 .08333 L
.87986 .08333 L
.88015 .08333 L
.8807 .08333 L
.88123 .08333 L
.88168 .08333 L
.88218 .08333 L
.88269 .08333 L
.88318 .08333 L
.88363 .08333 L
.88405 .08333 L
.8845 .08333 L
.88498 .08333 L
.88547 .08333 L
.88599 .08333 L
.88648 .08333 L
.88693 .08333 L
.88746 .08333 L
.88775 .08333 L
.88803 .08333 L
.88853 .08333 L
.88906 .08333 L
Mistroke
.88958 .08333 L
.89014 .08333 L
.89068 .08333 L
.89117 .08333 L
.89166 .08333 L
.8921 .08333 L
.89261 .08333 L
.8931 .08333 L
.89362 .08333 L
.89418 .08333 L
.89466 .08333 L
.89518 .08333 L
.89574 .08333 L
.89606 .08333 L
.89635 .08333 L
.8969 .08333 L
.89743 .08333 L
.89788 .08333 L
.89838 .08333 L
.8989 .08333 L
.89938 .08333 L
.89984 .08333 L
.90025 .08333 L
.90071 .08333 L
.90119 .08333 L
.90168 .08333 L
.9022 .08333 L
.90269 .08333 L
.90314 .08333 L
.90366 .08333 L
.90396 .08333 L
.90423 .08333 L
.90474 .08333 L
.90527 .08333 L
.90579 .08333 L
.90608 .08333 L
.90635 .08333 L
.90685 .08333 L
.90738 .08333 L
.90786 .08333 L
.9083 .08333 L
.90879 .08333 L
.90931 .08333 L
.90984 .08333 L
.91014 .08333 L
.91042 .08333 L
.91098 .08333 L
.91129 .08333 L
.91158 .08333 L
.91209 .08333 L
Mistroke
.91265 .08333 L
.91317 .08333 L
.91366 .08333 L
.91411 .08333 L
.91459 .08333 L
.91505 .08333 L
.91547 .08333 L
.91596 .08333 L
.91649 .08333 L
.91699 .08333 L
.91746 .08333 L
.91799 .08333 L
.91849 .08333 L
.91893 .08333 L
.91941 .08333 L
.91994 .08333 L
.9205 .08333 L
.92097 .08333 L
.9215 .08333 L
.92187 .08333 L
.92222 .08333 L
.9226 .08333 L
.92301 .08333 L
.92336 .08333 L
.92369 .08333 L
.92406 .08333 L
.92445 .08333 L
.92477 .08333 L
.92513 .08333 L
.9255 .08333 L
.92585 .08333 L
.92618 .08333 L
.92647 .08333 L
.92681 .08333 L
.92714 .08333 L
.92749 .08333 L
.92787 .08333 L
.92827 .08333 L
.92865 .08333 L
.929 .08333 L
.92932 .08333 L
.92969 .08333 L
.93004 .08333 L
.93042 .08333 L
.93082 .08333 L
.9312 .08333 L
.93154 .08333 L
.93195 .08333 L
.93239 .08333 L
.9328 .08333 L
Mistroke
.93318 .08333 L
Mfstroke
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{570, 95},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.1037 .08333 L
.10419 .08333 L
.10474 .08333 L
.10527 .08333 L
.10575 .08333 L
.1062 .08333 L
.10669 .08333 L
.10721 .08333 L
.10774 .08333 L
.1083 .08333 L
.10883 .08333 L
.10932 .08333 L
.10989 .08333 L
.11021 .08333 L
.11051 .08333 L
.11106 .08333 L
.11164 .08333 L
.11193 .08333 L
.11224 .08333 L
.1128 .08333 L
.11311 .08333 L
.11339 .08333 L
.11371 .08333 L
.11405 .08333 L
.11434 .08333 L
.11466 .08333 L
.11524 .08333 L
.1158 .08333 L
.11632 .08333 L
.11682 .08333 L
.1173 .08333 L
.11782 .08333 L
.11838 .08333 L
.11893 .08333 L
.11952 .08333 L
.12002 .08333 L
.12056 .08333 L
.12088 .08333 L
.12118 .08333 L
.1215 .08333 L
.12184 .08333 L
.12242 .08333 L
.12274 .08333 L
.12305 .08333 L
.12362 .08333 L
.12414 .08333 L
.12443 .08333 L
.12474 .08333 L
.12531 .08333 L
Mistroke
.12566 .08333 L
.12598 .08333 L
.12627 .08333 L
.12659 .08333 L
.12693 .08333 L
.12729 .08333 L
.1276 .08333 L
.12794 .08333 L
.12826 .08333 L
.12855 .08333 L
.12889 .08333 L
.12921 .08333 L
.12977 .08333 L
.13009 .08333 L
.13038 .08333 L
.13091 .08333 L
.13147 .08333 L
.13201 .08333 L
.13249 .08333 L
.13304 .08333 L
.13363 .08333 L
.13393 .08333 L
.13425 .08333 L
.13482 .08333 L
.13514 .08333 L
.13543 .08333 L
.13575 .08333 L
.13609 .08333 L
.13666 .08333 L
.13698 .08333 L
.13729 .08333 L
.13785 .08333 L
.13837 .08333 L
.13896 .08333 L
.13952 .08333 L
.14004 .08333 L
.14059 .08333 L
.14111 .08333 L
.14158 .08333 L
.14211 .08333 L
.14269 .08333 L
.14299 .08333 L
.1433 .08333 L
.14386 .08333 L
.14417 .08333 L
.14446 .08333 L
.14477 .08333 L
.1451 .08333 L
.14566 .08333 L
.14598 .08333 L
Mistroke
.14628 .08333 L
.14683 .08333 L
.14733 .08333 L
.14792 .08333 L
.14847 .08333 L
.14899 .08333 L
.14947 .08333 L
.15001 .08333 L
.15053 .08333 L
.15101 .08333 L
.15144 .08333 L
.15193 .08333 L
.15244 .08333 L
.15295 .08333 L
.1535 .08333 L
.15402 .08333 L
.1545 .08333 L
.15505 .08333 L
.15537 .08333 L
.15566 .08333 L
.15619 .08333 L
.15676 .08333 L
.15727 .08333 L
.15783 .08333 L
.15842 .08333 L
.15896 .08333 L
.15947 .08333 L
.15994 .08333 L
.16047 .08333 L
.16098 .08333 L
.16153 .08333 L
.16212 .08333 L
.16262 .08333 L
.16316 .08333 L
.16375 .08333 L
.16408 .08333 L
.16439 .08333 L
.16497 .08333 L
.16553 .08333 L
.16605 .08333 L
.16652 .08333 L
.16706 .08333 L
.16757 .08333 L
.16805 .08333 L
.16848 .08333 L
.16896 .08333 L
.16947 .08333 L
.16998 .08333 L
.17053 .08333 L
.17104 .08333 L
Mistroke
.17151 .08333 L
.17207 .08333 L
.17238 .08333 L
.17267 .08333 L
.1732 .08333 L
.17376 .08333 L
.1743 .08333 L
.17489 .08333 L
.17545 .08333 L
.17597 .08333 L
.17648 .08333 L
.17695 .08333 L
.17748 .08333 L
.17799 .08333 L
.17854 .08333 L
.17913 .08333 L
.17963 .08333 L
.18018 .08333 L
.18077 .08333 L
.1811 .08333 L
.1814 .08333 L
.18199 .08333 L
.18254 .08333 L
.18302 .08333 L
.18354 .08333 L
.18408 .08333 L
.18459 .08333 L
.18507 .08333 L
.1855 .08333 L
.18598 .08333 L
.18649 .08333 L
.187 .08333 L
.18755 .08333 L
.18807 .08333 L
.18854 .08333 L
.18909 .08333 L
.1894 .08333 L
.18969 .08333 L
.19022 .08333 L
.19078 .08333 L
.19132 .08333 L
.19192 .08333 L
.19248 .08333 L
.193 .08333 L
.19351 .08333 L
.19398 .08333 L
.19452 .08333 L
.19502 .08333 L
.19558 .08333 L
.19616 .08333 L
Mistroke
.19667 .08333 L
.19721 .08333 L
.19781 .08333 L
.19814 .08333 L
.19844 .08333 L
.19903 .08333 L
.19958 .08333 L
.20006 .08333 L
.20058 .08333 L
.20112 .08333 L
.20164 .08333 L
.20211 .08333 L
.20255 .08333 L
.20303 .08333 L
.20353 .08333 L
.20405 .08333 L
.2046 .08333 L
.20511 .08333 L
.20558 .08333 L
.20614 .08333 L
.20645 .08333 L
.20674 .08333 L
.20726 .08333 L
.20782 .08333 L
.20837 .08333 L
.20897 .08333 L
.20953 .08333 L
.21005 .08333 L
.21052 .08333 L
.21103 .08333 L
.21157 .08333 L
.21208 .08333 L
.21264 .08333 L
.21322 .08333 L
.21373 .08333 L
.21428 .08333 L
.21487 .08333 L
.2152 .08333 L
.2155 .08333 L
.21609 .08333 L
.21665 .08333 L
.21712 .08333 L
.21764 .08333 L
.21819 .08333 L
.2187 .08333 L
.21918 .08333 L
.21962 .08333 L
.22012 .08333 L
.2206 .08333 L
.22112 .08333 L
Mistroke
.22166 .08333 L
.22218 .08333 L
.22265 .08333 L
.22321 .08333 L
.22352 .08333 L
.22381 .08333 L
.22433 .08333 L
.22489 .08333 L
.22544 .08333 L
.22575 .08333 L
.22604 .08333 L
.22657 .08333 L
.22712 .08333 L
.22762 .08333 L
.22809 .08333 L
.22861 .08333 L
.22916 .08333 L
.22971 .08333 L
.23003 .08333 L
.23032 .08333 L
.23091 .08333 L
.23124 .08333 L
.23155 .08333 L
.23209 .08333 L
.23267 .08333 L
.23322 .08333 L
.23373 .08333 L
.23421 .08333 L
.23472 .08333 L
.2352 .08333 L
.23564 .08333 L
.23616 .08333 L
.23672 .08333 L
.23725 .08333 L
.23774 .08333 L
.2383 .08333 L
.23882 .08333 L
.23929 .08333 L
.2398 .08333 L
.24035 .08333 L
.24094 .08333 L
.24144 .08333 L
.24198 .08333 L
.24257 .08333 L
.24312 .08333 L
.2434 .08333 L
.24372 .08333 L
.24404 .08333 L
.24435 .08333 L
.24491 .08333 L
Mistroke
.24543 .08333 L
.24602 .08333 L
.24659 .08333 L
.24709 .08333 L
.24763 .08333 L
.24814 .08333 L
.24859 .08333 L
.24914 .08333 L
.24972 .08333 L
.25027 .08333 L
.25078 .08333 L
.25133 .08333 L
.25191 .08333 L
.25246 .08333 L
.25297 .08333 L
.25356 .08333 L
.25389 .08333 L
.2542 .08333 L
.25476 .08333 L
.25505 .08333 L
.25536 .08333 L
.25567 .08333 L
.25599 .08333 L
.25656 .08333 L
.25688 .08333 L
.25718 .08333 L
.25751 .08333 L
.25786 .08333 L
.25816 .08333 L
.25849 .08333 L
.2588 .08333 L
.25909 .08333 L
.25963 .08333 L
.2602 .08333 L
.26075 .08333 L
.26134 .08333 L
.2619 .08333 L
.26242 .08333 L
.26293 .08333 L
.2634 .08333 L
.26394 .08333 L
.26444 .08333 L
.265 .08333 L
.26559 .08333 L
.26609 .08333 L
.26664 .08333 L
.26723 .08333 L
.26756 .08333 L
.26786 .08333 L
.26845 .08333 L
Mistroke
.269 .08333 L
.26948 .08333 L
.27 .08333 L
.27054 .08333 L
.27106 .08333 L
.27153 .08333 L
.27197 .08333 L
.27245 .08333 L
.27295 .08333 L
.27347 .08333 L
.27401 .08333 L
.27453 .08333 L
.275 .08333 L
.27556 .08333 L
.27587 .08333 L
.27616 .08333 L
.27668 .08333 L
.27724 .08333 L
.27779 .08333 L
.27838 .08333 L
.27895 .08333 L
.27947 .08333 L
.27998 .08333 L
.28045 .08333 L
.28099 .08333 L
.2815 .08333 L
.28205 .08333 L
.28264 .08333 L
.28314 .08333 L
.28369 .08333 L
.28428 .08333 L
.28462 .08333 L
.28492 .08333 L
.28551 .08333 L
.28606 .08333 L
.28654 .08333 L
.28706 .08333 L
.28761 .08333 L
.28812 .08333 L
.28859 .08333 L
.28903 .08333 L
.28954 .08333 L
.29001 .08333 L
.29053 .08333 L
.29108 .08333 L
.2916 .08333 L
.29207 .08333 L
.29262 .08333 L
.29293 .08333 L
.29322 .08333 L
Mistroke
.29375 .08333 L
.29431 .08333 L
.29485 .08333 L
.29516 .08333 L
.29545 .08333 L
.29598 .08333 L
.29654 .08333 L
.29703 .08333 L
.2975 .08333 L
.29802 .08333 L
.29857 .08333 L
.29913 .08333 L
.29944 .08333 L
.29973 .08333 L
.30032 .08333 L
.30065 .08333 L
.30096 .08333 L
.30149 .08333 L
.30208 .08333 L
.30263 .08333 L
.30314 .08333 L
.30362 .08333 L
.30413 .08333 L
.30461 .08333 L
.30505 .08333 L
.30557 .08333 L
.30613 .08333 L
.30666 .08333 L
.30715 .08333 L
.3077 .08333 L
.30823 .08333 L
.3087 .08333 L
.3092 .08333 L
.30976 .08333 L
.31034 .08333 L
.31084 .08333 L
.31139 .08333 L
.31198 .08333 L
.31253 .08333 L
.31281 .08333 L
.31312 .08333 L
.31345 .08333 L
.31376 .08333 L
.31432 .08333 L
.31484 .08333 L
.3154 .08333 L
.316 .08333 L
.3165 .08333 L
.31703 .08333 L
.31754 .08333 L
Mistroke
.318 .08333 L
.31854 .08333 L
.31913 .08333 L
.31968 .08333 L
.32019 .08333 L
.32073 .08333 L
.32132 .08333 L
.32187 .08333 L
.32237 .08333 L
.32296 .08333 L
.32329 .08333 L
.3236 .08333 L
.32416 .08333 L
.32445 .08333 L
.32477 .08333 L
.32507 .08333 L
.32539 .08333 L
.32597 .08333 L
.32629 .08333 L
.32658 .08333 L
.32691 .08333 L
.32726 .08333 L
.32756 .08333 L
.32789 .08333 L
.3282 .08333 L
.32849 .08333 L
.32903 .08333 L
.32961 .08333 L
.33015 .08333 L
.33074 .08333 L
.3313 .08333 L
.33182 .08333 L
.33233 .08333 L
.3328 .08333 L
.33334 .08333 L
.33384 .08333 L
.3344 .08333 L
.33499 .08333 L
.33549 .08333 L
.33603 .08333 L
.33663 .08333 L
.33696 .08333 L
.33726 .08333 L
.33785 .08333 L
.3384 .08333 L
.33888 .08333 L
.3394 .08333 L
.33994 .08333 L
.34045 .08333 L
.34093 .08333 L
Mistroke
.34137 .08333 L
.34184 .08333 L
.34235 .08333 L
.34286 .08333 L
.34341 .08333 L
.34393 .08333 L
.3444 .08333 L
.34495 .08333 L
.34526 .08333 L
.34555 .08333 L
.34608 .08333 L
.34664 .08333 L
.34719 .08333 L
.34778 .08333 L
.34834 .08333 L
.34886 .08333 L
.34938 .08333 L
.34984 .08333 L
.35038 .08333 L
.35089 .08333 L
.35145 .08333 L
.35203 .08333 L
.35254 .08333 L
.35308 .08333 L
.35368 .08333 L
.35401 .08333 L
.35431 .08333 L
.3549 .08333 L
.35545 .08333 L
.35593 .08333 L
.35645 .08333 L
.357 .08333 L
.35751 .08333 L
.35799 .08333 L
.35842 .08333 L
.35893 .08333 L
.35941 .08333 L
.35992 .08333 L
.36047 .08333 L
.36099 .08333 L
.36146 .08333 L
.36201 .08333 L
.36232 .08333 L
.36261 .08333 L
.36314 .08333 L
.3637 .08333 L
.36425 .08333 L
.36456 .08333 L
.36484 .08333 L
.36537 .08333 L
Mistroke
.36593 .08333 L
.36642 .08333 L
.36689 .08333 L
.36741 .08333 L
.36796 .08333 L
.36851 .08333 L
.36883 .08333 L
.36912 .08333 L
.36971 .08333 L
.37004 .08333 L
.37034 .08333 L
.37088 .08333 L
.37147 .08333 L
.37202 .08333 L
.37253 .08333 L
.373 .08333 L
.37351 .08333 L
.374 .08333 L
.37444 .08333 L
.37495 .08333 L
.37551 .08333 L
.37604 .08333 L
.37654 .08333 L
.37709 .08333 L
.37761 .08333 L
.37808 .08333 L
.37859 .08333 L
.37914 .08333 L
.37973 .08333 L
.38023 .08333 L
.38078 .08333 L
.38137 .08333 L
.38191 .08333 L
.3822 .08333 L
.38251 .08333 L
.38284 .08333 L
.38314 .08333 L
.3837 .08333 L
.38422 .08333 L
.38478 .08333 L
.38538 .08333 L
.38588 .08333 L
.38642 .08333 L
.38692 .08333 L
.38738 .08333 L
.38792 .08333 L
.38851 .08333 L
.38906 .08333 L
.38957 .08333 L
.39011 .08333 L
Mistroke
.3907 .08333 L
.39125 .08333 L
.39175 .08333 L
.39234 .08333 L
.39267 .08333 L
.39298 .08333 L
.39354 .08333 L
.39383 .08333 L
.39415 .08333 L
.39445 .08333 L
.39477 .08333 L
.39535 .08333 L
.39567 .08333 L
.39596 .08333 L
.39629 .08333 L
.39664 .08333 L
.39694 .08333 L
.39727 .08333 L
.39758 .08333 L
.39787 .08333 L
.39841 .08333 L
.39899 .08333 L
.39953 .08333 L
.40012 .08333 L
.40068 .08333 L
.4012 .08333 L
.40171 .08333 L
.40218 .08333 L
.40272 .08333 L
.40322 .08333 L
.40378 .08333 L
.40436 .08333 L
.40486 .08333 L
.40541 .08333 L
.406 .08333 L
.40633 .08333 L
.40664 .08333 L
.40722 .08333 L
.40778 .08333 L
.40825 .08333 L
.40877 .08333 L
.40932 .08333 L
.40983 .08333 L
.4103 .08333 L
.41074 .08333 L
.41122 .08333 L
.41172 .08333 L
.41224 .08333 L
.41279 .08333 L
.4133 .08333 L
Mistroke
.41377 .08333 L
.41433 .08333 L
.41464 .08333 L
.41493 .08333 L
.41546 .08333 L
.41601 .08333 L
.41656 .08333 L
.41715 .08333 L
.41771 .08333 L
.41823 .08333 L
.41875 .08333 L
.41922 .08333 L
.41976 .08333 L
.42026 .08333 L
.42082 .08333 L
.42141 .08333 L
.42191 .08333 L
.42246 .08333 L
.42305 .08333 L
.42338 .08333 L
.42368 .08333 L
.42427 .08333 L
.42482 .08333 L
.4253 .08333 L
.42582 .08333 L
.42637 .08333 L
.42688 .08333 L
.42736 .08333 L
.42779 .08333 L
.42827 .08333 L
.42878 .08333 L
.42929 .08333 L
.42984 .08333 L
.43036 .08333 L
.43083 .08333 L
.43138 .08333 L
.43169 .08333 L
.43198 .08333 L
.43251 .08333 L
.43307 .08333 L
.43361 .08333 L
.43392 .08333 L
.43421 .08333 L
.43474 .08333 L
.43529 .08333 L
.43579 .08333 L
.43626 .08333 L
.43677 .08333 L
.43733 .08333 L
.43788 .08333 L
Mistroke
.43819 .08333 L
.43849 .08333 L
.43908 .08333 L
.43941 .08333 L
.43971 .08333 L
.44025 .08333 L
.44083 .08333 L
.44138 .08333 L
.44189 .08333 L
.44237 .08333 L
.44288 .08333 L
.44336 .08333 L
.4438 .08333 L
.44432 .08333 L
.44488 .08333 L
.44541 .08333 L
.4459 .08333 L
.44645 .08333 L
.44698 .08333 L
.44745 .08333 L
.44795 .08333 L
.44851 .08333 L
.44909 .08333 L
.44959 .08333 L
.45014 .08333 L
.45073 .08333 L
.45127 .08333 L
.45156 .08333 L
.45187 .08333 L
.4522 .08333 L
.4525 .08333 L
.45307 .08333 L
.45358 .08333 L
.45415 .08333 L
.45474 .08333 L
.45524 .08333 L
.45578 .08333 L
.45628 .08333 L
.45674 .08333 L
.45728 .08333 L
.45787 .08333 L
.45842 .08333 L
.45893 .08333 L
.45947 .08333 L
.46006 .08333 L
.46061 .08333 L
.46111 .08333 L
.4617 .08333 L
.46203 .08333 L
.46234 .08333 L
Mistroke
.4629 .08333 L
.46322 .08333 L
.4635 .08333 L
.46381 .08333 L
.46413 .08333 L
.4647 .08333 L
.46502 .08333 L
.46532 .08333 L
.46565 .08333 L
.466 .08333 L
.4663 .08333 L
.46663 .08333 L
.46694 .08333 L
.46723 .08333 L
.46777 .08333 L
.46834 .08333 L
.46889 .08333 L
.46948 .08333 L
.47004 .08333 L
.47056 .08333 L
.47107 .08333 L
.47153 .08333 L
.47207 .08333 L
.47258 .08333 L
.47313 .08333 L
.47372 .08333 L
.47422 .08333 L
.47477 .08333 L
.47536 .08333 L
.47569 .08333 L
.47599 .08333 L
.47658 .08333 L
.47713 .08333 L
.4776 .08333 L
.47813 .08333 L
.47867 .08333 L
.47918 .08333 L
.47966 .08333 L
.48009 .08333 L
.48057 .08333 L
.48108 .08333 L
.48159 .08333 L
.48214 .08333 L
.48266 .08333 L
.48313 .08333 L
.48368 .08333 L
.48399 .08333 L
.48428 .08333 L
.48481 .08333 L
.48537 .08333 L
Mistroke
.48591 .08333 L
.48651 .08333 L
.48707 .08333 L
.48759 .08333 L
.4881 .08333 L
.48857 .08333 L
.48911 .08333 L
.48961 .08333 L
.49017 .08333 L
.49075 .08333 L
.49126 .08333 L
.4918 .08333 L
.4924 .08333 L
.49273 .08333 L
.49303 .08333 L
.49362 .08333 L
.49417 .08333 L
.49465 .08333 L
.49517 .08333 L
.49571 .08333 L
.49623 .08333 L
.4967 .08333 L
.49714 .08333 L
.49762 .08333 L
.49812 .08333 L
.49864 .08333 L
.49919 .08333 L
.4997 .08333 L
.50017 .08333 L
.50073 .08333 L
.50104 .08333 L
.50133 .08333 L
.50186 .08333 L
.50241 .08333 L
.50296 .08333 L
.50327 .08333 L
.50356 .08333 L
.50408 .08333 L
.50464 .08333 L
.50514 .08333 L
.5056 .08333 L
.50612 .08333 L
.50667 .08333 L
.50722 .08333 L
.50754 .08333 L
.50783 .08333 L
.50842 .08333 L
.50875 .08333 L
.50905 .08333 L
.50959 .08333 L
Mistroke
.51018 .08333 L
.51073 .08333 L
.51124 .08333 L
.51171 .08333 L
.51222 .08333 L
.5127 .08333 L
.51314 .08333 L
.51366 .08333 L
.51422 .08333 L
.51475 .08333 L
.51524 .08333 L
.5158 .08333 L
.51632 .08333 L
.51679 .08333 L
.51729 .08333 L
.51785 .08333 L
.51844 .08333 L
.51894 .08333 L
.51948 .08333 L
.51988 .08333 L
.52025 .08333 L
.52065 .08333 L
.52108 .08333 L
.52145 .08333 L
.5218 .08333 L
.52218 .08333 L
.52259 .08333 L
.52293 .08333 L
.52331 .08333 L
.5237 .08333 L
.52406 .08333 L
.52441 .08333 L
.52472 .08333 L
.52508 .08333 L
.52542 .08333 L
.52579 .08333 L
.52619 .08333 L
.52661 .08333 L
.52701 .08333 L
.52738 .08333 L
.52771 .08333 L
.5281 .08333 L
.52847 .08333 L
.52887 .08333 L
.52929 .08333 L
.52969 .08333 L
.53005 .08333 L
.53048 .08333 L
.53094 .08333 L
.53138 .08333 L
Mistroke
.53178 .08333 L
Mfstroke
.53178 .08333 m
.53228 .08333 L
.53275 .08333 L
.53328 .08333 L
.53378 .08333 L
.53424 .08333 L
.53467 .08333 L
.53514 .08333 L
.53564 .08333 L
.53614 .08333 L
.53668 .08333 L
.53719 .08333 L
.53766 .08333 L
.5382 .08333 L
.53851 .08333 L
.53879 .08333 L
.53932 .08333 L
.53988 .08333 L
.54016 .08333 L
.54045 .08333 L
.54098 .08333 L
.54128 .08333 L
.54155 .08333 L
.54186 .08333 L
.54218 .08333 L
.54246 .08333 L
.54276 .08333 L
.54332 .08333 L
.54385 .08333 L
.54435 .08333 L
.54483 .08333 L
.54529 .08333 L
.54578 .08333 L
.54632 .08333 L
.54685 .08333 L
.54741 .08333 L
.54789 .08333 L
.54841 .08333 L
.54872 .08333 L
.549 .08333 L
.54931 .08333 L
.54964 .08333 L
.55019 .08333 L
.5505 .08333 L
.55079 .08333 L
.55134 .08333 L
.55183 .08333 L
.55211 .08333 L
.55241 .08333 L
.55295 .08333 L
Mistroke
.55328 .08333 L
.55359 .08333 L
.55387 .08333 L
.55417 .08333 L
.5545 .08333 L
.55485 .08333 L
.55515 .08333 L
.55547 .08333 L
.55578 .08333 L
.55606 .08333 L
.55638 .08333 L
.55668 .08333 L
.55722 .08333 L
.55753 .08333 L
.55781 .08333 L
.55831 .08333 L
.55885 .08333 L
.55936 .08333 L
.55982 .08333 L
.56034 .08333 L
.56091 .08333 L
.56119 .08333 L
.5615 .08333 L
.56205 .08333 L
.56235 .08333 L
.56263 .08333 L
.56294 .08333 L
.56326 .08333 L
.56381 .08333 L
.56412 .08333 L
.56441 .08333 L
.56495 .08333 L
.56544 .08333 L
.56601 .08333 L
.56655 .08333 L
.56704 .08333 L
.56757 .08333 L
.56806 .08333 L
.56852 .08333 L
.56903 .08333 L
.56958 .08333 L
.56986 .08333 L
.57016 .08333 L
.5707 .08333 L
.57099 .08333 L
.57127 .08333 L
.57157 .08333 L
.57189 .08333 L
.57242 .08333 L
.57272 .08333 L
Mistroke
.57301 .08333 L
.57354 .08333 L
.57402 .08333 L
.57458 .08333 L
.57511 .08333 L
.57561 .08333 L
.57606 .08333 L
.57658 .08333 L
.57708 .08333 L
.57753 .08333 L
.57795 .08333 L
.57841 .08333 L
.5789 .08333 L
.57939 .08333 L
.57992 .08333 L
.58042 .08333 L
.58087 .08333 L
.5814 .08333 L
.58171 .08333 L
.58198 .08333 L
.58249 .08333 L
.58304 .08333 L
.58353 .08333 L
.58406 .08333 L
.58462 .08333 L
.58514 .08333 L
.58563 .08333 L
.58608 .08333 L
.58659 .08333 L
.58707 .08333 L
.5876 .08333 L
.58816 .08333 L
.58864 .08333 L
.58916 .08333 L
.58973 .08333 L
.59004 .08333 L
.59033 .08333 L
.59089 .08333 L
.59142 .08333 L
.59192 .08333 L
.59237 .08333 L
.59289 .08333 L
.59338 .08333 L
.59383 .08333 L
.59425 .08333 L
.59471 .08333 L
.59519 .08333 L
.59568 .08333 L
.59621 .08333 L
.5967 .08333 L
Mistroke
.59715 .08333 L
.59768 .08333 L
.59798 .08333 L
.59825 .08333 L
.59876 .08333 L
.5993 .08333 L
.59981 .08333 L
.60038 .08333 L
.60091 .08333 L
.60141 .08333 L
.6019 .08333 L
.60235 .08333 L
.60286 .08333 L
.60334 .08333 L
.60387 .08333 L
.60443 .08333 L
.60491 .08333 L
.60544 .08333 L
.606 .08333 L
.60632 .08333 L
.60661 .08333 L
.60717 .08333 L
.6077 .08333 L
.60815 .08333 L
.60865 .08333 L
.60917 .08333 L
.60966 .08333 L
.61012 .08333 L
.61053 .08333 L
.61099 .08333 L
.61147 .08333 L
.61196 .08333 L
.61249 .08333 L
.61298 .08333 L
.61343 .08333 L
.61396 .08333 L
.61426 .08333 L
.61454 .08333 L
.61504 .08333 L
.61558 .08333 L
.6161 .08333 L
.61667 .08333 L
.6172 .08333 L
.6177 .08333 L
.61819 .08333 L
.61864 .08333 L
.61915 .08333 L
.61964 .08333 L
.62017 .08333 L
.62073 .08333 L
Mistroke
.62121 .08333 L
.62173 .08333 L
.6223 .08333 L
.62262 .08333 L
.62291 .08333 L
.62347 .08333 L
.624 .08333 L
.62445 .08333 L
.62495 .08333 L
.62547 .08333 L
.62596 .08333 L
.62642 .08333 L
.62684 .08333 L
.6273 .08333 L
.62778 .08333 L
.62827 .08333 L
.62879 .08333 L
.62929 .08333 L
.62974 .08333 L
.63027 .08333 L
.63057 .08333 L
.63084 .08333 L
.63135 .08333 L
.63188 .08333 L
.63241 .08333 L
.63297 .08333 L
.63351 .08333 L
.63401 .08333 L
.63446 .08333 L
.63495 .08333 L
.63547 .08333 L
.63595 .08333 L
.63649 .08333 L
.63705 .08333 L
.63753 .08333 L
.63805 .08333 L
.63862 .08333 L
.63894 .08333 L
.63923 .08333 L
.63979 .08333 L
.64032 .08333 L
.64078 .08333 L
.64128 .08333 L
.6418 .08333 L
.64229 .08333 L
.64275 .08333 L
.64316 .08333 L
.64365 .08333 L
.6441 .08333 L
.6446 .08333 L
Mistroke
.64512 .08333 L
.64562 .08333 L
.64607 .08333 L
.6466 .08333 L
.6469 .08333 L
.64717 .08333 L
.64768 .08333 L
.64821 .08333 L
.64874 .08333 L
.64903 .08333 L
.64931 .08333 L
.64981 .08333 L
.65034 .08333 L
.65082 .08333 L
.65127 .08333 L
.65176 .08333 L
.65229 .08333 L
.65282 .08333 L
.65312 .08333 L
.6534 .08333 L
.65397 .08333 L
.65429 .08333 L
.65457 .08333 L
.65509 .08333 L
.65565 .08333 L
.65618 .08333 L
.65667 .08333 L
.65712 .08333 L
.65761 .08333 L
.65807 .08333 L
.65849 .08333 L
.65899 .08333 L
.65952 .08333 L
.66003 .08333 L
.6605 .08333 L
.66103 .08333 L
.66153 .08333 L
.66198 .08333 L
.66247 .08333 L
.663 .08333 L
.66356 .08333 L
.66404 .08333 L
.66456 .08333 L
.66512 .08333 L
.66564 .08333 L
.66592 .08333 L
.66622 .08333 L
.66653 .08333 L
.66682 .08333 L
.66736 .08333 L
Mistroke
.66786 .08333 L
.66842 .08333 L
.66897 .08333 L
.66945 .08333 L
.66996 .08333 L
.67044 .08333 L
.67088 .08333 L
.6714 .08333 L
.67196 .08333 L
.67249 .08333 L
.67298 .08333 L
.6735 .08333 L
.67406 .08333 L
.67458 .08333 L
.67506 .08333 L
.67563 .08333 L
.67595 .08333 L
.67624 .08333 L
.67678 .08333 L
.67706 .08333 L
.67736 .08333 L
.67765 .08333 L
.67796 .08333 L
.67851 .08333 L
.67881 .08333 L
.6791 .08333 L
.67941 .08333 L
.67974 .08333 L
.68003 .08333 L
.68035 .08333 L
.68065 .08333 L
.68092 .08333 L
.68144 .08333 L
.68199 .08333 L
.68251 .08333 L
.68307 .08333 L
.68361 .08333 L
.68411 .08333 L
.6846 .08333 L
.68504 .08333 L
.68556 .08333 L
.68604 .08333 L
.68658 .08333 L
.68714 .08333 L
.68762 .08333 L
.68814 .08333 L
.68871 .08333 L
.68902 .08333 L
.68931 .08333 L
.68987 .08333 L
Mistroke
.69041 .08333 L
.69086 .08333 L
.69136 .08333 L
.69188 .08333 L
.69237 .08333 L
.69282 .08333 L
.69324 .08333 L
.6937 .08333 L
.69418 .08333 L
.69467 .08333 L
.6952 .08333 L
.69569 .08333 L
.69614 .08333 L
.69667 .08333 L
.69697 .08333 L
.69725 .08333 L
.69775 .08333 L
.69829 .08333 L
.69881 .08333 L
.69938 .08333 L
.69992 .08333 L
.70041 .08333 L
.70091 .08333 L
.70135 .08333 L
.70187 .08333 L
.70235 .08333 L
.70289 .08333 L
.70345 .08333 L
.70393 .08333 L
.70445 .08333 L
.70502 .08333 L
.70534 .08333 L
.70563 .08333 L
.70619 .08333 L
.70672 .08333 L
.70718 .08333 L
.70768 .08333 L
.7082 .08333 L
.70869 .08333 L
.70914 .08333 L
.70956 .08333 L
.71005 .08333 L
.7105 .08333 L
.711 .08333 L
.71152 .08333 L
.71202 .08333 L
.71247 .08333 L
.713 .08333 L
.71329 .08333 L
.71357 .08333 L
Mistroke
.71407 .08333 L
.71461 .08333 L
.71513 .08333 L
.71543 .08333 L
.7157 .08333 L
.71621 .08333 L
.71674 .08333 L
.71722 .08333 L
.71767 .08333 L
.71816 .08333 L
.71869 .08333 L
.71922 .08333 L
.71952 .08333 L
.7198 .08333 L
.72036 .08333 L
.72068 .08333 L
.72097 .08333 L
.72149 .08333 L
.72205 .08333 L
.72257 .08333 L
.72306 .08333 L
.72352 .08333 L
.724 .08333 L
.72446 .08333 L
.72489 .08333 L
.72538 .08333 L
.72592 .08333 L
.72642 .08333 L
.72689 .08333 L
.72743 .08333 L
.72793 .08333 L
.72837 .08333 L
.72886 .08333 L
.72939 .08333 L
.72995 .08333 L
.73043 .08333 L
.73095 .08333 L
.73152 .08333 L
.73204 .08333 L
.73231 .08333 L
.73261 .08333 L
.73292 .08333 L
.73322 .08333 L
.73375 .08333 L
.73425 .08333 L
.73479 .08333 L
.73536 .08333 L
.73584 .08333 L
.73635 .08333 L
.73683 .08333 L
Mistroke
.73727 .08333 L
.73779 .08333 L
.73835 .08333 L
.73888 .08333 L
.73937 .08333 L
.73989 .08333 L
.74045 .08333 L
.74097 .08333 L
.74145 .08333 L
.74202 .08333 L
.74233 .08333 L
.74263 .08333 L
.74317 .08333 L
.74344 .08333 L
.74375 .08333 L
.74404 .08333 L
.74434 .08333 L
.74489 .08333 L
.7452 .08333 L
.74548 .08333 L
.7458 .08333 L
.74613 .08333 L
.74642 .08333 L
.74674 .08333 L
.74703 .08333 L
.74731 .08333 L
.74783 .08333 L
.74838 .08333 L
.74889 .08333 L
.74946 .08333 L
.75 .08333 L
.75049 .08333 L
.75099 .08333 L
.75143 .08333 L
.75195 .08333 L
.75243 .08333 L
.75296 .08333 L
.75352 .08333 L
.754 .08333 L
.75452 .08333 L
.75509 .08333 L
.75541 .08333 L
.7557 .08333 L
.75626 .08333 L
.75679 .08333 L
.75724 .08333 L
.75774 .08333 L
.75826 .08333 L
.75875 .08333 L
.75921 .08333 L
Mistroke
.75962 .08333 L
.76008 .08333 L
.76056 .08333 L
.76106 .08333 L
.76158 .08333 L
.76208 .08333 L
.76253 .08333 L
.76306 .08333 L
.76335 .08333 L
.76363 .08333 L
.76413 .08333 L
.76467 .08333 L
.76519 .08333 L
.76576 .08333 L
.7663 .08333 L
.76679 .08333 L
.76729 .08333 L
.76773 .08333 L
.76825 .08333 L
.76874 .08333 L
.76927 .08333 L
.76983 .08333 L
.77031 .08333 L
.77083 .08333 L
.7714 .08333 L
.77172 .08333 L
.77201 .08333 L
.77257 .08333 L
.7731 .08333 L
.77355 .08333 L
.77405 .08333 L
.77458 .08333 L
.77507 .08333 L
.77552 .08333 L
.77594 .08333 L
.77642 .08333 L
.77688 .08333 L
.77737 .08333 L
.7779 .08333 L
.77839 .08333 L
.77884 .08333 L
.77937 .08333 L
.77967 .08333 L
.77995 .08333 L
.78045 .08333 L
.78099 .08333 L
.78151 .08333 L
.78181 .08333 L
.78208 .08333 L
.78258 .08333 L
Mistroke
.78312 .08333 L
.78359 .08333 L
.78404 .08333 L
.78453 .08333 L
.78506 .08333 L
.78559 .08333 L
.78589 .08333 L
.78617 .08333 L
.78674 .08333 L
.78706 .08333 L
.78734 .08333 L
.78786 .08333 L
.78842 .08333 L
.78895 .08333 L
.78943 .08333 L
.78989 .08333 L
.79038 .08333 L
.79084 .08333 L
.79126 .08333 L
.79175 .08333 L
.79229 .08333 L
.7928 .08333 L
.79327 .08333 L
.7938 .08333 L
.7943 .08333 L
.79475 .08333 L
.79523 .08333 L
.79576 .08333 L
.79632 .08333 L
.7968 .08333 L
.79733 .08333 L
.79789 .08333 L
.79841 .08333 L
.79868 .08333 L
.79898 .08333 L
.79929 .08333 L
.79959 .08333 L
.80012 .08333 L
.80062 .08333 L
.80116 .08333 L
.80173 .08333 L
.80221 .08333 L
.80272 .08333 L
.8032 .08333 L
.80364 .08333 L
.80416 .08333 L
.80472 .08333 L
.80525 .08333 L
.80574 .08333 L
.80626 .08333 L
Mistroke
.80681 .08333 L
.80734 .08333 L
.80782 .08333 L
.80838 .08333 L
.8087 .08333 L
.809 .08333 L
.80954 .08333 L
.80981 .08333 L
.81011 .08333 L
.8104 .08333 L
.81071 .08333 L
.81126 .08333 L
.81157 .08333 L
.81185 .08333 L
.81216 .08333 L
.8125 .08333 L
.81279 .08333 L
.8131 .08333 L
.8134 .08333 L
.81367 .08333 L
.81419 .08333 L
.81474 .08333 L
.81526 .08333 L
.81583 .08333 L
.81636 .08333 L
.81686 .08333 L
.81735 .08333 L
.8178 .08333 L
.81831 .08333 L
.81879 .08333 L
.81932 .08333 L
.81989 .08333 L
.82036 .08333 L
.82089 .08333 L
.82145 .08333 L
.82177 .08333 L
.82206 .08333 L
.82262 .08333 L
.82315 .08333 L
.8236 .08333 L
.8241 .08333 L
.82462 .08333 L
.82511 .08333 L
.82557 .08333 L
.82599 .08333 L
.82644 .08333 L
.82693 .08333 L
.82742 .08333 L
.82794 .08333 L
.82844 .08333 L
Mistroke
.82889 .08333 L
.82942 .08333 L
.82971 .08333 L
.82999 .08333 L
.8305 .08333 L
.83103 .08333 L
.83155 .08333 L
.83212 .08333 L
.83266 .08333 L
.83315 .08333 L
.83365 .08333 L
.83409 .08333 L
.83461 .08333 L
.83509 .08333 L
.83563 .08333 L
.83619 .08333 L
.83667 .08333 L
.83719 .08333 L
.83776 .08333 L
.83808 .08333 L
.83837 .08333 L
.83893 .08333 L
.83946 .08333 L
.83991 .08333 L
.84041 .08333 L
.84093 .08333 L
.84142 .08333 L
.84188 .08333 L
.8423 .08333 L
.84276 .08333 L
.84324 .08333 L
.84373 .08333 L
.84425 .08333 L
.84475 .08333 L
.8452 .08333 L
.84573 .08333 L
.84603 .08333 L
.8463 .08333 L
.84681 .08333 L
.84734 .08333 L
.84787 .08333 L
.84816 .08333 L
.84844 .08333 L
.84894 .08333 L
.84947 .08333 L
.84995 .08333 L
.8504 .08333 L
.85089 .08333 L
.85142 .08333 L
.85195 .08333 L
Mistroke
.85225 .08333 L
.85253 .08333 L
.85309 .08333 L
.85341 .08333 L
.8537 .08333 L
.85421 .08333 L
.85477 .08333 L
.8553 .08333 L
.85579 .08333 L
.85624 .08333 L
.85673 .08333 L
.85719 .08333 L
.85761 .08333 L
.8581 .08333 L
.85864 .08333 L
.85915 .08333 L
.85962 .08333 L
.86015 .08333 L
.86065 .08333 L
.8611 .08333 L
.86158 .08333 L
.86211 .08333 L
.86267 .08333 L
.86315 .08333 L
.86368 .08333 L
.86424 .08333 L
.86476 .08333 L
.86503 .08333 L
.86533 .08333 L
.86564 .08333 L
.86594 .08333 L
.86647 .08333 L
.86697 .08333 L
.86751 .08333 L
.86807 .08333 L
.86855 .08333 L
.86907 .08333 L
.86955 .08333 L
.86999 .08333 L
.87051 .08333 L
.87107 .08333 L
.8716 .08333 L
.87208 .08333 L
.8726 .08333 L
.87316 .08333 L
.87369 .08333 L
.87417 .08333 L
.87473 .08333 L
.87505 .08333 L
.87534 .08333 L
Mistroke
.87588 .08333 L
.87619 .08333 L
.87646 .08333 L
.87675 .08333 L
.87706 .08333 L
.87761 .08333 L
.87791 .08333 L
.8782 .08333 L
.87851 .08333 L
.87884 .08333 L
.87913 .08333 L
.87945 .08333 L
.87975 .08333 L
.88002 .08333 L
.88054 .08333 L
.88109 .08333 L
.88161 .08333 L
.88217 .08333 L
.88271 .08333 L
.8832 .08333 L
.88369 .08333 L
.88414 .08333 L
.88465 .08333 L
.88514 .08333 L
.88567 .08333 L
.88623 .08333 L
.88671 .08333 L
.88723 .08333 L
.8878 .08333 L
.88811 .08333 L
.8884 .08333 L
.88896 .08333 L
.88949 .08333 L
.88995 .08333 L
.89044 .08333 L
.89097 .08333 L
.89145 .08333 L
.89191 .08333 L
.89233 .08333 L
.89278 .08333 L
.89327 .08333 L
.89376 .08333 L
.89428 .08333 L
.89478 .08333 L
.89523 .08333 L
.89576 .08333 L
.89606 .08333 L
.89633 .08333 L
.89684 .08333 L
.89737 .08333 L
Mistroke
.89789 .08333 L
.89846 .08333 L
.899 .08333 L
.89949 .08333 L
.89999 .08333 L
.90043 .08333 L
.90095 .08333 L
.90143 .08333 L
.90196 .08333 L
.90253 .08333 L
.903 .08333 L
.90353 .08333 L
.9041 .08333 L
.90441 .08333 L
.9047 .08333 L
.90526 .08333 L
.9058 .08333 L
.90625 .08333 L
.90675 .08333 L
.90727 .08333 L
.90776 .08333 L
.90821 .08333 L
.90863 .08333 L
.90909 .08333 L
.90957 .08333 L
.91006 .08333 L
.91059 .08333 L
.91109 .08333 L
.91153 .08333 L
.91206 .08333 L
.91236 .08333 L
.91264 .08333 L
.91314 .08333 L
.91368 .08333 L
.9142 .08333 L
.9145 .08333 L
.91477 .08333 L
.91527 .08333 L
.91581 .08333 L
.91628 .08333 L
.91673 .08333 L
.91722 .08333 L
.91775 .08333 L
.91828 .08333 L
.91858 .08333 L
.91886 .08333 L
.91942 .08333 L
.91974 .08333 L
.92003 .08333 L
.92054 .08333 L
Mistroke
.9211 .08333 L
.92163 .08333 L
.92212 .08333 L
.92257 .08333 L
.92306 .08333 L
.92352 .08333 L
.92394 .08333 L
.92443 .08333 L
.92497 .08333 L
.92548 .08333 L
.92595 .08333 L
.92648 .08333 L
.92698 .08333 L
.92743 .08333 L
.92791 .08333 L
.92844 .08333 L
.929 .08333 L
.92948 .08333 L
.93001 .08333 L
.93039 .08333 L
.93074 .08333 L
.93112 .08333 L
.93153 .08333 L
.93189 .08333 L
.93222 .08333 L
.93258 .08333 L
.93298 .08333 L
.9333 .08333 L
.93366 .08333 L
.93404 .08333 L
.93439 .08333 L
.93472 .08333 L
.93501 .08333 L
.93536 .08333 L
.93568 .08333 L
.93603 .08333 L
.93642 .08333 L
.93682 .08333 L
.9372 .08333 L
.93756 .08333 L
.93788 .08333 L
.93825 .08333 L
.9386 .08333 L
.93898 .08333 L
.93939 .08333 L
.93977 .08333 L
.94012 .08333 L
.94053 .08333 L
.94097 .08333 L
.94138 .08333 L
Mistroke
.94177 .08333 L
Mfstroke
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{570, 95},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.1037 .08333 L
.10417 .08333 L
.10472 .08333 L
.10524 .08333 L
.10572 .08333 L
.10616 .08333 L
.10664 .08333 L
.10716 .08333 L
.10767 .08333 L
.10823 .08333 L
.10875 .08333 L
.10923 .08333 L
.10979 .08333 L
.11011 .08333 L
.1104 .08333 L
.11094 .08333 L
.11152 .08333 L
.11181 .08333 L
.11211 .08333 L
.11266 .08333 L
.11296 .08333 L
.11325 .08333 L
.11356 .08333 L
.11389 .08333 L
.11418 .08333 L
.1145 .08333 L
.11507 .08333 L
.11562 .08333 L
.11613 .08333 L
.11663 .08333 L
.1171 .08333 L
.11761 .08333 L
.11816 .08333 L
.11871 .08333 L
.11928 .08333 L
.11978 .08333 L
.12032 .08333 L
.12063 .08333 L
.12092 .08333 L
.12124 .08333 L
.12158 .08333 L
.12214 .08333 L
.12247 .08333 L
.12277 .08333 L
.12333 .08333 L
.12384 .08333 L
.12413 .08333 L
.12444 .08333 L
.125 .08333 L
Mistroke
.12534 .08333 L
.12566 .08333 L
.12594 .08333 L
.12625 .08333 L
.12659 .08333 L
.12695 .08333 L
.12726 .08333 L
.12759 .08333 L
.12791 .08333 L
.12819 .08333 L
.12853 .08333 L
.12884 .08333 L
.12939 .08333 L
.12971 .08333 L
.13 .08333 L
.13052 .08333 L
.13107 .08333 L
.1316 .08333 L
.13208 .08333 L
.13261 .08333 L
.1332 .08333 L
.13349 .08333 L
.13381 .08333 L
.13437 .08333 L
.13468 .08333 L
.13497 .08333 L
.13529 .08333 L
.13562 .08333 L
.13619 .08333 L
.1365 .08333 L
.1368 .08333 L
.13736 .08333 L
.13787 .08333 L
.13845 .08333 L
.13901 .08333 L
.13951 .08333 L
.14006 .08333 L
.14057 .08333 L
.14104 .08333 L
.14156 .08333 L
.14213 .08333 L
.14242 .08333 L
.14273 .08333 L
.14329 .08333 L
.14359 .08333 L
.14387 .08333 L
.14418 .08333 L
.14451 .08333 L
.14506 .08333 L
.14537 .08333 L
Mistroke
.14567 .08333 L
.14621 .08333 L
.14671 .08333 L
.14728 .08333 L
.14783 .08333 L
.14835 .08333 L
.14881 .08333 L
.14935 .08333 L
.14986 .08333 L
.15033 .08333 L
.15076 .08333 L
.15124 .08333 L
.15174 .08333 L
.15225 .08333 L
.15279 .08333 L
.1533 .08333 L
.15377 .08333 L
.15432 .08333 L
.15463 .08333 L
.15492 .08333 L
.15544 .08333 L
.156 .08333 L
.15651 .08333 L
.15706 .08333 L
.15764 .08333 L
.15817 .08333 L
.15868 .08333 L
.15913 .08333 L
.15966 .08333 L
.16016 .08333 L
.16071 .08333 L
.16128 .08333 L
.16177 .08333 L
.16231 .08333 L
.16289 .08333 L
.16322 .08333 L
.16352 .08333 L
.1641 .08333 L
.16465 .08333 L
.16516 .08333 L
.16562 .08333 L
.16616 .08333 L
.16666 .08333 L
.16713 .08333 L
.16756 .08333 L
.16803 .08333 L
.16853 .08333 L
.16903 .08333 L
.16957 .08333 L
.17008 .08333 L
Mistroke
.17055 .08333 L
.17109 .08333 L
.1714 .08333 L
.17168 .08333 L
.1722 .08333 L
.17276 .08333 L
.17329 .08333 L
.17387 .08333 L
.17443 .08333 L
.17494 .08333 L
.17544 .08333 L
.1759 .08333 L
.17643 .08333 L
.17693 .08333 L
.17748 .08333 L
.17805 .08333 L
.17855 .08333 L
.17909 .08333 L
.17967 .08333 L
.18 .08333 L
.18029 .08333 L
.18087 .08333 L
.18142 .08333 L
.18189 .08333 L
.1824 .08333 L
.18294 .08333 L
.18344 .08333 L
.18391 .08333 L
.18434 .08333 L
.18481 .08333 L
.18531 .08333 L
.18581 .08333 L
.18635 .08333 L
.18686 .08333 L
.18733 .08333 L
.18787 .08333 L
.18818 .08333 L
.18846 .08333 L
.18899 .08333 L
.18954 .08333 L
.19007 .08333 L
.19066 .08333 L
.19121 .08333 L
.19172 .08333 L
.19223 .08333 L
.19269 .08333 L
.19322 .08333 L
.19372 .08333 L
.19427 .08333 L
.19485 .08333 L
Mistroke
.19534 .08333 L
.19588 .08333 L
.19647 .08333 L
.19679 .08333 L
.19709 .08333 L
.19767 .08333 L
.19822 .08333 L
.19869 .08333 L
.1992 .08333 L
.19974 .08333 L
.20024 .08333 L
.20071 .08333 L
.20114 .08333 L
.20161 .08333 L
.20211 .08333 L
.20262 .08333 L
.20316 .08333 L
.20367 .08333 L
.20413 .08333 L
.20468 .08333 L
.20499 .08333 L
.20527 .08333 L
.20579 .08333 L
.20634 .08333 L
.20688 .08333 L
.20747 .08333 L
.20802 .08333 L
.20854 .08333 L
.209 .08333 L
.20951 .08333 L
.21004 .08333 L
.21054 .08333 L
.21109 .08333 L
.21167 .08333 L
.21216 .08333 L
.2127 .08333 L
.21329 .08333 L
.21361 .08333 L
.21391 .08333 L
.21449 .08333 L
.21504 .08333 L
.21551 .08333 L
.21602 .08333 L
.21656 .08333 L
.21707 .08333 L
.21754 .08333 L
.21797 .08333 L
.21847 .08333 L
.21894 .08333 L
.21945 .08333 L
Mistroke
.21999 .08333 L
.2205 .08333 L
.22096 .08333 L
.22151 .08333 L
.22181 .08333 L
.2221 .08333 L
.22262 .08333 L
.22317 .08333 L
.22371 .08333 L
.22402 .08333 L
.2243 .08333 L
.22482 .08333 L
.22537 .08333 L
.22586 .08333 L
.22632 .08333 L
.22683 .08333 L
.22738 .08333 L
.22792 .08333 L
.22823 .08333 L
.22852 .08333 L
.2291 .08333 L
.22943 .08333 L
.22973 .08333 L
.23026 .08333 L
.23084 .08333 L
.23138 .08333 L
.23188 .08333 L
.23235 .08333 L
.23286 .08333 L
.23333 .08333 L
.23377 .08333 L
.23427 .08333 L
.23483 .08333 L
.23535 .08333 L
.23584 .08333 L
.23638 .08333 L
.2369 .08333 L
.23736 .08333 L
.23786 .08333 L
.23841 .08333 L
.23899 .08333 L
.23948 .08333 L
.24002 .08333 L
.2406 .08333 L
.24114 .08333 L
.24142 .08333 L
.24173 .08333 L
.24205 .08333 L
.24235 .08333 L
.24291 .08333 L
Mistroke
.24342 .08333 L
.244 .08333 L
.24456 .08333 L
.24506 .08333 L
.24558 .08333 L
.24608 .08333 L
.24654 .08333 L
.24707 .08333 L
.24765 .08333 L
.24819 .08333 L
.24869 .08333 L
.24923 .08333 L
.24981 .08333 L
.25035 .08333 L
.25085 .08333 L
.25143 .08333 L
.25175 .08333 L
.25206 .08333 L
.25262 .08333 L
.2529 .08333 L
.25321 .08333 L
.25351 .08333 L
.25383 .08333 L
.25439 .08333 L
.25471 .08333 L
.255 .08333 L
.25532 .08333 L
.25567 .08333 L
.25597 .08333 L
.25629 .08333 L
.2566 .08333 L
.25688 .08333 L
.25741 .08333 L
.25798 .08333 L
.25852 .08333 L
.2591 .08333 L
.25965 .08333 L
.26016 .08333 L
.26067 .08333 L
.26113 .08333 L
.26166 .08333 L
.26216 .08333 L
.26271 .08333 L
.26329 .08333 L
.26378 .08333 L
.26432 .08333 L
.2649 .08333 L
.26523 .08333 L
.26553 .08333 L
.26611 .08333 L
Mistroke
.26666 .08333 L
.26712 .08333 L
.26764 .08333 L
.26817 .08333 L
.26868 .08333 L
.26915 .08333 L
.26958 .08333 L
.27005 .08333 L
.27055 .08333 L
.27105 .08333 L
.2716 .08333 L
.27211 .08333 L
.27257 .08333 L
.27311 .08333 L
.27342 .08333 L
.27371 .08333 L
.27423 .08333 L
.27478 .08333 L
.27532 .08333 L
.2759 .08333 L
.27646 .08333 L
.27697 .08333 L
.27748 .08333 L
.27794 .08333 L
.27847 .08333 L
.27897 .08333 L
.27952 .08333 L
.2801 .08333 L
.28059 .08333 L
.28114 .08333 L
.28172 .08333 L
.28205 .08333 L
.28234 .08333 L
.28292 .08333 L
.28347 .08333 L
.28394 .08333 L
.28446 .08333 L
.28499 .08333 L
.2855 .08333 L
.28597 .08333 L
.2864 .08333 L
.2869 .08333 L
.28737 .08333 L
.28788 .08333 L
.28842 .08333 L
.28893 .08333 L
.28939 .08333 L
.28994 .08333 L
.29025 .08333 L
.29053 .08333 L
Mistroke
.29105 .08333 L
.2916 .08333 L
.29214 .08333 L
.29245 .08333 L
.29273 .08333 L
.29325 .08333 L
.2938 .08333 L
.29429 .08333 L
.29475 .08333 L
.29526 .08333 L
.2958 .08333 L
.29635 .08333 L
.29666 .08333 L
.29695 .08333 L
.29753 .08333 L
.29786 .08333 L
.29815 .08333 L
.29869 .08333 L
.29926 .08333 L
.29981 .08333 L
.30031 .08333 L
.30078 .08333 L
.30128 .08333 L
.30176 .08333 L
.30219 .08333 L
.3027 .08333 L
.30325 .08333 L
.30378 .08333 L
.30426 .08333 L
.30481 .08333 L
.30532 .08333 L
.30579 .08333 L
.30629 .08333 L
.30683 .08333 L
.30741 .08333 L
.3079 .08333 L
.30844 .08333 L
.30902 .08333 L
.30956 .08333 L
.30984 .08333 L
.31015 .08333 L
.31047 .08333 L
.31078 .08333 L
.31133 .08333 L
.31184 .08333 L
.3124 .08333 L
.31298 .08333 L
.31348 .08333 L
.31401 .08333 L
.3145 .08333 L
Mistroke
.31496 .08333 L
.31549 .08333 L
.31607 .08333 L
.31661 .08333 L
.31712 .08333 L
.31765 .08333 L
.31823 .08333 L
.31877 .08333 L
.31927 .08333 L
.31985 .08333 L
.32017 .08333 L
.32048 .08333 L
.32104 .08333 L
.32132 .08333 L
.32163 .08333 L
.32193 .08333 L
.32224 .08333 L
.32281 .08333 L
.32313 .08333 L
.32342 .08333 L
.32374 .08333 L
.32409 .08333 L
.32439 .08333 L
.32471 .08333 L
.32502 .08333 L
.3253 .08333 L
.32583 .08333 L
.3264 .08333 L
.32693 .08333 L
.32752 .08333 L
.32807 .08333 L
.32858 .08333 L
.32909 .08333 L
.32955 .08333 L
.33008 .08333 L
.33058 .08333 L
.33113 .08333 L
.3317 .08333 L
.3322 .08333 L
.33274 .08333 L
.33332 .08333 L
.33365 .08333 L
.33394 .08333 L
.33452 .08333 L
.33507 .08333 L
.33554 .08333 L
.33605 .08333 L
.33659 .08333 L
.33709 .08333 L
.33756 .08333 L
Mistroke
.33799 .08333 L
.33846 .08333 L
.33896 .08333 L
.33947 .08333 L
.34001 .08333 L
.34052 .08333 L
.34098 .08333 L
.34153 .08333 L
.34184 .08333 L
.34212 .08333 L
.34264 .08333 L
.34319 .08333 L
.34373 .08333 L
.34432 .08333 L
.34487 .08333 L
.34538 .08333 L
.34589 .08333 L
.34635 .08333 L
.34688 .08333 L
.34738 .08333 L
.34793 .08333 L
.34851 .08333 L
.349 .08333 L
.34955 .08333 L
.35013 .08333 L
.35046 .08333 L
.35075 .08333 L
.35133 .08333 L
.35188 .08333 L
.35235 .08333 L
.35286 .08333 L
.3534 .08333 L
.35391 .08333 L
.35438 .08333 L
.35481 .08333 L
.35531 .08333 L
.35578 .08333 L
.35629 .08333 L
.35683 .08333 L
.35734 .08333 L
.3578 .08333 L
.35835 .08333 L
.35865 .08333 L
.35894 .08333 L
.35946 .08333 L
.36001 .08333 L
.36055 .08333 L
.36085 .08333 L
.36114 .08333 L
.36165 .08333 L
Mistroke
.36221 .08333 L
.3627 .08333 L
.36316 .08333 L
.36366 .08333 L
.36421 .08333 L
.36476 .08333 L
.36507 .08333 L
.36535 .08333 L
.36594 .08333 L
.36626 .08333 L
.36656 .08333 L
.36709 .08333 L
.36767 .08333 L
.36821 .08333 L
.36872 .08333 L
.36918 .08333 L
.36969 .08333 L
.37016 .08333 L
.3706 .08333 L
.3711 .08333 L
.37166 .08333 L
.37218 .08333 L
.37266 .08333 L
.37321 .08333 L
.37373 .08333 L
.37419 .08333 L
.37469 .08333 L
.37524 .08333 L
.37581 .08333 L
.37631 .08333 L
.37685 .08333 L
.37743 .08333 L
.37796 .08333 L
.37824 .08333 L
.37855 .08333 L
.37888 .08333 L
.37918 .08333 L
.37973 .08333 L
.38024 .08333 L
.3808 .08333 L
.38138 .08333 L
.38188 .08333 L
.38241 .08333 L
.3829 .08333 L
.38336 .08333 L
.38389 .08333 L
.38447 .08333 L
.38501 .08333 L
.38551 .08333 L
.38605 .08333 L
Mistroke
.38663 .08333 L
.38717 .08333 L
.38766 .08333 L
.38824 .08333 L
.38857 .08333 L
.38888 .08333 L
.38943 .08333 L
.38971 .08333 L
.39003 .08333 L
.39033 .08333 L
.39064 .08333 L
.39121 .08333 L
.39152 .08333 L
.39182 .08333 L
.39214 .08333 L
.39249 .08333 L
.39278 .08333 L
.39311 .08333 L
.39341 .08333 L
.3937 .08333 L
.39423 .08333 L
.3948 .08333 L
.39533 .08333 L
.39592 .08333 L
.39647 .08333 L
.39698 .08333 L
.39749 .08333 L
.39794 .08333 L
.39847 .08333 L
.39897 .08333 L
.39952 .08333 L
.4001 .08333 L
.40059 .08333 L
.40113 .08333 L
.40171 .08333 L
.40204 .08333 L
.40234 .08333 L
.40292 .08333 L
.40347 .08333 L
.40393 .08333 L
.40445 .08333 L
.40498 .08333 L
.40549 .08333 L
.40595 .08333 L
.40639 .08333 L
.40686 .08333 L
.40735 .08333 L
.40786 .08333 L
.4084 .08333 L
.40891 .08333 L
Mistroke
.40938 .08333 L
.40992 .08333 L
.41023 .08333 L
.41051 .08333 L
.41103 .08333 L
.41159 .08333 L
.41212 .08333 L
.41271 .08333 L
.41326 .08333 L
.41377 .08333 L
.41428 .08333 L
.41474 .08333 L
.41527 .08333 L
.41577 .08333 L
.41632 .08333 L
.4169 .08333 L
.41739 .08333 L
.41793 .08333 L
.41852 .08333 L
.41885 .08333 L
.41914 .08333 L
.41972 .08333 L
.42027 .08333 L
.42074 .08333 L
.42125 .08333 L
.42179 .08333 L
.42229 .08333 L
.42276 .08333 L
.4232 .08333 L
.42367 .08333 L
.42416 .08333 L
.42467 .08333 L
.42521 .08333 L
.42572 .08333 L
.42619 .08333 L
.42673 .08333 L
.42704 .08333 L
.42732 .08333 L
.42784 .08333 L
.4284 .08333 L
.42894 .08333 L
.42924 .08333 L
.42952 .08333 L
.43004 .08333 L
.43059 .08333 L
.43108 .08333 L
.43154 .08333 L
.43205 .08333 L
.43259 .08333 L
.43314 .08333 L
Mistroke
.43345 .08333 L
.43374 .08333 L
.43432 .08333 L
.43465 .08333 L
.43494 .08333 L
.43547 .08333 L
.43605 .08333 L
.4366 .08333 L
.4371 .08333 L
.43757 .08333 L
.43807 .08333 L
.43854 .08333 L
.43898 .08333 L
.43948 .08333 L
.44004 .08333 L
.44056 .08333 L
.44105 .08333 L
.44159 .08333 L
.44211 .08333 L
.44257 .08333 L
.44307 .08333 L
.44362 .08333 L
.4442 .08333 L
.44469 .08333 L
.44523 .08333 L
.44581 .08333 L
.44634 .08333 L
.44662 .08333 L
.44693 .08333 L
.44726 .08333 L
.44756 .08333 L
.44811 .08333 L
.44862 .08333 L
.44918 .08333 L
.44976 .08333 L
.45026 .08333 L
.45078 .08333 L
.45128 .08333 L
.45174 .08333 L
.45227 .08333 L
.45284 .08333 L
.45339 .08333 L
.45389 .08333 L
.45443 .08333 L
.455 .08333 L
.45554 .08333 L
.45604 .08333 L
.45662 .08333 L
.45695 .08333 L
.45725 .08333 L
Mistroke
.45781 .08333 L
.45812 .08333 L
.4584 .08333 L
.4587 .08333 L
.45902 .08333 L
.45958 .08333 L
.4599 .08333 L
.46019 .08333 L
.46052 .08333 L
.46086 .08333 L
.46116 .08333 L
.46148 .08333 L
.46179 .08333 L
.46207 .08333 L
.46261 .08333 L
.46317 .08333 L
.46371 .08333 L
.46429 .08333 L
.46484 .08333 L
.46535 .08333 L
.46586 .08333 L
.46632 .08333 L
.46685 .08333 L
.46735 .08333 L
.46789 .08333 L
.46847 .08333 L
.46896 .08333 L
.4695 .08333 L
.47009 .08333 L
.47041 .08333 L
.47071 .08333 L
.47129 .08333 L
.47184 .08333 L
.4723 .08333 L
.47282 .08333 L
.47335 .08333 L
.47386 .08333 L
.47433 .08333 L
.47476 .08333 L
.47523 .08333 L
.47573 .08333 L
.47623 .08333 L
.47677 .08333 L
.47728 .08333 L
.47775 .08333 L
.47829 .08333 L
.4786 .08333 L
.47888 .08333 L
.4794 .08333 L
.47996 .08333 L
Mistroke
.48049 .08333 L
.48108 .08333 L
.48163 .08333 L
.48214 .08333 L
.48265 .08333 L
.48311 .08333 L
.48364 .08333 L
.48414 .08333 L
.48469 .08333 L
.48527 .08333 L
.48576 .08333 L
.4863 .08333 L
.48689 .08333 L
.48721 .08333 L
.48751 .08333 L
.48809 .08333 L
.48864 .08333 L
.4891 .08333 L
.48962 .08333 L
.49016 .08333 L
.49066 .08333 L
.49113 .08333 L
.49156 .08333 L
.49203 .08333 L
.49253 .08333 L
.49304 .08333 L
.49358 .08333 L
.49409 .08333 L
.49455 .08333 L
.4951 .08333 L
.49541 .08333 L
.49569 .08333 L
.49621 .08333 L
.49676 .08333 L
.4973 .08333 L
.4976 .08333 L
.49789 .08333 L
.4984 .08333 L
.49895 .08333 L
.49944 .08333 L
.49991 .08333 L
.50041 .08333 L
.50096 .08333 L
.5015 .08333 L
.50181 .08333 L
.5021 .08333 L
.50268 .08333 L
.50301 .08333 L
.5033 .08333 L
.50384 .08333 L
Mistroke
.50441 .08333 L
.50496 .08333 L
.50546 .08333 L
.50593 .08333 L
.50643 .08333 L
.5069 .08333 L
.50734 .08333 L
.50784 .08333 L
.5084 .08333 L
.50892 .08333 L
.50941 .08333 L
.50995 .08333 L
.51047 .08333 L
.51093 .08333 L
.51143 .08333 L
.51198 .08333 L
.51255 .08333 L
.51305 .08333 L
.51359 .08333 L
.51398 .08333 L
.51434 .08333 L
.51474 .08333 L
.51516 .08333 L
.51553 .08333 L
.51587 .08333 L
.51624 .08333 L
.51665 .08333 L
.51699 .08333 L
.51736 .08333 L
.51775 .08333 L
.51811 .08333 L
.51844 .08333 L
.51875 .08333 L
.5191 .08333 L
.51944 .08333 L
.5198 .08333 L
.5202 .08333 L
.52062 .08333 L
.52101 .08333 L
.52137 .08333 L
.5217 .08333 L
.52208 .08333 L
.52245 .08333 L
.52284 .08333 L
.52326 .08333 L
.52365 .08333 L
.52401 .08333 L
.52443 .08333 L
.52489 .08333 L
.52531 .08333 L
Mistroke
.52571 .08333 L
Mfstroke
.52571 .08333 m
.52621 .08333 L
.52667 .08333 L
.5272 .08333 L
.5277 .08333 L
.52816 .08333 L
.52859 .08333 L
.52905 .08333 L
.52955 .08333 L
.53005 .08333 L
.53058 .08333 L
.53109 .08333 L
.53155 .08333 L
.53209 .08333 L
.5324 .08333 L
.53268 .08333 L
.5332 .08333 L
.53376 .08333 L
.53404 .08333 L
.53433 .08333 L
.53486 .08333 L
.53515 .08333 L
.53542 .08333 L
.53573 .08333 L
.53605 .08333 L
.53632 .08333 L
.53663 .08333 L
.53718 .08333 L
.53771 .08333 L
.53821 .08333 L
.53869 .08333 L
.53914 .08333 L
.53963 .08333 L
.54016 .08333 L
.54069 .08333 L
.54125 .08333 L
.54172 .08333 L
.54224 .08333 L
.54254 .08333 L
.54282 .08333 L
.54313 .08333 L
.54346 .08333 L
.544 .08333 L
.54431 .08333 L
.54461 .08333 L
.54515 .08333 L
.54564 .08333 L
.54591 .08333 L
.54621 .08333 L
.54675 .08333 L
Mistroke
.54708 .08333 L
.54739 .08333 L
.54767 .08333 L
.54797 .08333 L
.54829 .08333 L
.54864 .08333 L
.54893 .08333 L
.54926 .08333 L
.54956 .08333 L
.54984 .08333 L
.55016 .08333 L
.55046 .08333 L
.551 .08333 L
.5513 .08333 L
.55158 .08333 L
.55208 .08333 L
.55261 .08333 L
.55312 .08333 L
.55358 .08333 L
.5541 .08333 L
.55466 .08333 L
.55495 .08333 L
.55525 .08333 L
.55579 .08333 L
.5561 .08333 L
.55637 .08333 L
.55668 .08333 L
.557 .08333 L
.55754 .08333 L
.55785 .08333 L
.55814 .08333 L
.55868 .08333 L
.55917 .08333 L
.55973 .08333 L
.56027 .08333 L
.56075 .08333 L
.56128 .08333 L
.56177 .08333 L
.56223 .08333 L
.56273 .08333 L
.56328 .08333 L
.56356 .08333 L
.56385 .08333 L
.56439 .08333 L
.56468 .08333 L
.56496 .08333 L
.56525 .08333 L
.56557 .08333 L
.5661 .08333 L
.5664 .08333 L
Mistroke
.56669 .08333 L
.56721 .08333 L
.56769 .08333 L
.56825 .08333 L
.56877 .08333 L
.56927 .08333 L
.56972 .08333 L
.57024 .08333 L
.57073 .08333 L
.57118 .08333 L
.5716 .08333 L
.57206 .08333 L
.57254 .08333 L
.57303 .08333 L
.57356 .08333 L
.57405 .08333 L
.5745 .08333 L
.57503 .08333 L
.57533 .08333 L
.57561 .08333 L
.57611 .08333 L
.57665 .08333 L
.57714 .08333 L
.57767 .08333 L
.57823 .08333 L
.57875 .08333 L
.57923 .08333 L
.57967 .08333 L
.58018 .08333 L
.58067 .08333 L
.58119 .08333 L
.58175 .08333 L
.58222 .08333 L
.58274 .08333 L
.5833 .08333 L
.58362 .08333 L
.5839 .08333 L
.58446 .08333 L
.58499 .08333 L
.58548 .08333 L
.58593 .08333 L
.58645 .08333 L
.58693 .08333 L
.58738 .08333 L
.5878 .08333 L
.58825 .08333 L
.58873 .08333 L
.58922 .08333 L
.58974 .08333 L
.59023 .08333 L
Mistroke
.59068 .08333 L
.59121 .08333 L
.5915 .08333 L
.59178 .08333 L
.59228 .08333 L
.59281 .08333 L
.59333 .08333 L
.59389 .08333 L
.59442 .08333 L
.59491 .08333 L
.5954 .08333 L
.59584 .08333 L
.59635 .08333 L
.59684 .08333 L
.59736 .08333 L
.59792 .08333 L
.59839 .08333 L
.59892 .08333 L
.59948 .08333 L
.59979 .08333 L
.60008 .08333 L
.60064 .08333 L
.60117 .08333 L
.60161 .08333 L
.60211 .08333 L
.60263 .08333 L
.60311 .08333 L
.60357 .08333 L
.60398 .08333 L
.60444 .08333 L
.60492 .08333 L
.6054 .08333 L
.60592 .08333 L
.60642 .08333 L
.60686 .08333 L
.60739 .08333 L
.60769 .08333 L
.60796 .08333 L
.60846 .08333 L
.60899 .08333 L
.60951 .08333 L
.61008 .08333 L
.61061 .08333 L
.6111 .08333 L
.61159 .08333 L
.61204 .08333 L
.61255 .08333 L
.61303 .08333 L
.61356 .08333 L
.61412 .08333 L
Mistroke
.61459 .08333 L
.61511 .08333 L
.61568 .08333 L
.61599 .08333 L
.61628 .08333 L
.61684 .08333 L
.61737 .08333 L
.61782 .08333 L
.61831 .08333 L
.61883 .08333 L
.61932 .08333 L
.61977 .08333 L
.62018 .08333 L
.62064 .08333 L
.62112 .08333 L
.62161 .08333 L
.62213 .08333 L
.62262 .08333 L
.62307 .08333 L
.6236 .08333 L
.62389 .08333 L
.62417 .08333 L
.62467 .08333 L
.6252 .08333 L
.62572 .08333 L
.62629 .08333 L
.62682 .08333 L
.62731 .08333 L
.62776 .08333 L
.62825 .08333 L
.62876 .08333 L
.62925 .08333 L
.62978 .08333 L
.63033 .08333 L
.63081 .08333 L
.63133 .08333 L
.6319 .08333 L
.63221 .08333 L
.6325 .08333 L
.63306 .08333 L
.63359 .08333 L
.63404 .08333 L
.63454 .08333 L
.63506 .08333 L
.63554 .08333 L
.636 .08333 L
.63641 .08333 L
.63689 .08333 L
.63735 .08333 L
.63784 .08333 L
Mistroke
.63836 .08333 L
.63885 .08333 L
.6393 .08333 L
.63982 .08333 L
.64012 .08333 L
.64039 .08333 L
.6409 .08333 L
.64143 .08333 L
.64195 .08333 L
.64224 .08333 L
.64252 .08333 L
.64302 .08333 L
.64355 .08333 L
.64402 .08333 L
.64447 .08333 L
.64496 .08333 L
.64548 .08333 L
.64601 .08333 L
.64631 .08333 L
.64659 .08333 L
.64715 .08333 L
.64747 .08333 L
.64775 .08333 L
.64827 .08333 L
.64882 .08333 L
.64935 .08333 L
.64983 .08333 L
.65028 .08333 L
.65077 .08333 L
.65123 .08333 L
.65165 .08333 L
.65214 .08333 L
.65267 .08333 L
.65317 .08333 L
.65364 .08333 L
.65417 .08333 L
.65467 .08333 L
.65511 .08333 L
.6556 .08333 L
.65612 .08333 L
.65668 .08333 L
.65716 .08333 L
.65768 .08333 L
.65824 .08333 L
.65875 .08333 L
.65903 .08333 L
.65932 .08333 L
.65963 .08333 L
.65993 .08333 L
.66046 .08333 L
Mistroke
.66095 .08333 L
.66152 .08333 L
.66206 .08333 L
.66253 .08333 L
.66304 .08333 L
.66352 .08333 L
.66396 .08333 L
.66448 .08333 L
.66503 .08333 L
.66556 .08333 L
.66604 .08333 L
.66656 .08333 L
.66711 .08333 L
.66764 .08333 L
.66812 .08333 L
.66868 .08333 L
.66899 .08333 L
.66929 .08333 L
.66982 .08333 L
.6701 .08333 L
.6704 .08333 L
.67069 .08333 L
.67099 .08333 L
.67154 .08333 L
.67184 .08333 L
.67212 .08333 L
.67244 .08333 L
.67277 .08333 L
.67306 .08333 L
.67337 .08333 L
.67366 .08333 L
.67394 .08333 L
.67445 .08333 L
.675 .08333 L
.67551 .08333 L
.67608 .08333 L
.67661 .08333 L
.6771 .08333 L
.67759 .08333 L
.67804 .08333 L
.67855 .08333 L
.67903 .08333 L
.67956 .08333 L
.68011 .08333 L
.68059 .08333 L
.68111 .08333 L
.68167 .08333 L
.68199 .08333 L
.68228 .08333 L
.68284 .08333 L
Mistroke
.68336 .08333 L
.68381 .08333 L
.68431 .08333 L
.68483 .08333 L
.68531 .08333 L
.68577 .08333 L
.68618 .08333 L
.68664 .08333 L
.68712 .08333 L
.68761 .08333 L
.68813 .08333 L
.68862 .08333 L
.68907 .08333 L
.68959 .08333 L
.68989 .08333 L
.69016 .08333 L
.69066 .08333 L
.6912 .08333 L
.69172 .08333 L
.69228 .08333 L
.69282 .08333 L
.69331 .08333 L
.6938 .08333 L
.69424 .08333 L
.69476 .08333 L
.69524 .08333 L
.69577 .08333 L
.69633 .08333 L
.6968 .08333 L
.69733 .08333 L
.69789 .08333 L
.69821 .08333 L
.69849 .08333 L
.69905 .08333 L
.69958 .08333 L
.70003 .08333 L
.70053 .08333 L
.70105 .08333 L
.70153 .08333 L
.70199 .08333 L
.7024 .08333 L
.70288 .08333 L
.70334 .08333 L
.70383 .08333 L
.70435 .08333 L
.70484 .08333 L
.70529 .08333 L
.70582 .08333 L
.70611 .08333 L
.70639 .08333 L
Mistroke
.70689 .08333 L
.70742 .08333 L
.70794 .08333 L
.70823 .08333 L
.70851 .08333 L
.70901 .08333 L
.70954 .08333 L
.71001 .08333 L
.71046 .08333 L
.71095 .08333 L
.71147 .08333 L
.712 .08333 L
.7123 .08333 L
.71258 .08333 L
.71314 .08333 L
.71345 .08333 L
.71374 .08333 L
.71425 .08333 L
.71481 .08333 L
.71533 .08333 L
.71582 .08333 L
.71627 .08333 L
.71676 .08333 L
.71721 .08333 L
.71763 .08333 L
.71812 .08333 L
.71866 .08333 L
.71916 .08333 L
.71963 .08333 L
.72016 .08333 L
.72065 .08333 L
.7211 .08333 L
.72158 .08333 L
.72211 .08333 L
.72267 .08333 L
.72314 .08333 L
.72366 .08333 L
.72422 .08333 L
.72474 .08333 L
.72501 .08333 L
.72531 .08333 L
.72562 .08333 L
.72591 .08333 L
.72645 .08333 L
.72694 .08333 L
.72747 .08333 L
.72804 .08333 L
.72852 .08333 L
.72903 .08333 L
.72951 .08333 L
Mistroke
.72994 .08333 L
.73046 .08333 L
.73101 .08333 L
.73154 .08333 L
.73202 .08333 L
.73254 .08333 L
.7331 .08333 L
.73362 .08333 L
.7341 .08333 L
.73466 .08333 L
.73497 .08333 L
.73527 .08333 L
.73581 .08333 L
.73608 .08333 L
.73638 .08333 L
.73667 .08333 L
.73697 .08333 L
.73752 .08333 L
.73782 .08333 L
.73811 .08333 L
.73842 .08333 L
.73875 .08333 L
.73904 .08333 L
.73935 .08333 L
.73964 .08333 L
.73992 .08333 L
.74043 .08333 L
.74098 .08333 L
.74149 .08333 L
.74206 .08333 L
.74259 .08333 L
.74308 .08333 L
.74357 .08333 L
.74401 .08333 L
.74453 .08333 L
.74501 .08333 L
.74554 .08333 L
.74609 .08333 L
.74657 .08333 L
.74709 .08333 L
.74765 .08333 L
.74797 .08333 L
.74825 .08333 L
.74881 .08333 L
.74934 .08333 L
.74979 .08333 L
.75029 .08333 L
.7508 .08333 L
.75129 .08333 L
.75174 .08333 L
Mistroke
.75216 .08333 L
.75261 .08333 L
.75309 .08333 L
.75358 .08333 L
.7541 .08333 L
.75459 .08333 L
.75504 .08333 L
.75557 .08333 L
.75586 .08333 L
.75614 .08333 L
.75664 .08333 L
.75717 .08333 L
.75769 .08333 L
.75826 .08333 L
.75879 .08333 L
.75928 .08333 L
.75977 .08333 L
.76022 .08333 L
.76073 .08333 L
.76121 .08333 L
.76174 .08333 L
.7623 .08333 L
.76278 .08333 L
.7633 .08333 L
.76386 .08333 L
.76418 .08333 L
.76447 .08333 L
.76502 .08333 L
.76555 .08333 L
.766 .08333 L
.7665 .08333 L
.76702 .08333 L
.76751 .08333 L
.76796 .08333 L
.76837 .08333 L
.76885 .08333 L
.76931 .08333 L
.7698 .08333 L
.77032 .08333 L
.77081 .08333 L
.77126 .08333 L
.77179 .08333 L
.77208 .08333 L
.77236 .08333 L
.77286 .08333 L
.77339 .08333 L
.77391 .08333 L
.7742 .08333 L
.77448 .08333 L
.77498 .08333 L
Mistroke
.77551 .08333 L
.77598 .08333 L
.77643 .08333 L
.77691 .08333 L
.77744 .08333 L
.77797 .08333 L
.77827 .08333 L
.77854 .08333 L
.77911 .08333 L
.77942 .08333 L
.77971 .08333 L
.78022 .08333 L
.78078 .08333 L
.7813 .08333 L
.78179 .08333 L
.78224 .08333 L
.78272 .08333 L
.78318 .08333 L
.7836 .08333 L
.78409 .08333 L
.78462 .08333 L
.78513 .08333 L
.78559 .08333 L
.78612 .08333 L
.78662 .08333 L
.78707 .08333 L
.78755 .08333 L
.78807 .08333 L
.78863 .08333 L
.78911 .08333 L
.78963 .08333 L
.79019 .08333 L
.7907 .08333 L
.79097 .08333 L
.79127 .08333 L
.79158 .08333 L
.79187 .08333 L
.79241 .08333 L
.7929 .08333 L
.79344 .08333 L
.794 .08333 L
.79448 .08333 L
.79499 .08333 L
.79547 .08333 L
.79591 .08333 L
.79642 .08333 L
.79698 .08333 L
.7975 .08333 L
.79799 .08333 L
.7985 .08333 L
Mistroke
.79906 .08333 L
.79958 .08333 L
.80006 .08333 L
.80062 .08333 L
.80093 .08333 L
.80123 .08333 L
.80177 .08333 L
.80204 .08333 L
.80234 .08333 L
.80263 .08333 L
.80293 .08333 L
.80348 .08333 L
.80378 .08333 L
.80407 .08333 L
.80438 .08333 L
.80471 .08333 L
.805 .08333 L
.80531 .08333 L
.8056 .08333 L
.80588 .08333 L
.80639 .08333 L
.80694 .08333 L
.80745 .08333 L
.80802 .08333 L
.80855 .08333 L
.80904 .08333 L
.80953 .08333 L
.80997 .08333 L
.81048 .08333 L
.81097 .08333 L
.81149 .08333 L
.81205 .08333 L
.81252 .08333 L
.81305 .08333 L
.81361 .08333 L
.81392 .08333 L
.81421 .08333 L
.81477 .08333 L
.8153 .08333 L
.81575 .08333 L
.81624 .08333 L
.81676 .08333 L
.81725 .08333 L
.8177 .08333 L
.81811 .08333 L
.81857 .08333 L
.81905 .08333 L
.81954 .08333 L
.82006 .08333 L
.82055 .08333 L
Mistroke
.821 .08333 L
.82152 .08333 L
.82182 .08333 L
.82209 .08333 L
.8226 .08333 L
.82313 .08333 L
.82365 .08333 L
.82421 .08333 L
.82474 .08333 L
.82524 .08333 L
.82573 .08333 L
.82617 .08333 L
.82668 .08333 L
.82717 .08333 L
.82769 .08333 L
.82825 .08333 L
.82873 .08333 L
.82925 .08333 L
.82981 .08333 L
.83013 .08333 L
.83042 .08333 L
.83097 .08333 L
.8315 .08333 L
.83195 .08333 L
.83245 .08333 L
.83297 .08333 L
.83346 .08333 L
.83391 .08333 L
.83432 .08333 L
.83478 .08333 L
.83526 .08333 L
.83575 .08333 L
.83627 .08333 L
.83676 .08333 L
.83721 .08333 L
.83774 .08333 L
.83803 .08333 L
.83831 .08333 L
.83881 .08333 L
.83934 .08333 L
.83986 .08333 L
.84015 .08333 L
.84043 .08333 L
.84092 .08333 L
.84146 .08333 L
.84193 .08333 L
.84237 .08333 L
.84286 .08333 L
.84339 .08333 L
.84391 .08333 L
Mistroke
.84421 .08333 L
.84449 .08333 L
.84505 .08333 L
.84537 .08333 L
.84565 .08333 L
.84617 .08333 L
.84672 .08333 L
.84725 .08333 L
.84773 .08333 L
.84818 .08333 L
.84867 .08333 L
.84912 .08333 L
.84954 .08333 L
.85003 .08333 L
.85057 .08333 L
.85107 .08333 L
.85154 .08333 L
.85207 .08333 L
.85256 .08333 L
.85301 .08333 L
.85349 .08333 L
.85402 .08333 L
.85458 .08333 L
.85505 .08333 L
.85557 .08333 L
.85613 .08333 L
.85665 .08333 L
.85692 .08333 L
.85722 .08333 L
.85753 .08333 L
.85782 .08333 L
.85835 .08333 L
.85884 .08333 L
.85938 .08333 L
.85994 .08333 L
.86042 .08333 L
.86093 .08333 L
.86141 .08333 L
.86185 .08333 L
.86236 .08333 L
.86292 .08333 L
.86344 .08333 L
.86393 .08333 L
.86444 .08333 L
.865 .08333 L
.86552 .08333 L
.866 .08333 L
.86656 .08333 L
.86687 .08333 L
.86717 .08333 L
Mistroke
.8677 .08333 L
.868 .08333 L
.86828 .08333 L
.86857 .08333 L
.86887 .08333 L
.86942 .08333 L
.86972 .08333 L
.87 .08333 L
.87031 .08333 L
.87065 .08333 L
.87094 .08333 L
.87125 .08333 L
.87154 .08333 L
.87181 .08333 L
.87233 .08333 L
.87288 .08333 L
.87339 .08333 L
.87395 .08333 L
.87449 .08333 L
.87498 .08333 L
.87547 .08333 L
.87591 .08333 L
.87642 .08333 L
.8769 .08333 L
.87743 .08333 L
.87799 .08333 L
.87846 .08333 L
.87898 .08333 L
.87954 .08333 L
.87986 .08333 L
.88015 .08333 L
.8807 .08333 L
.88123 .08333 L
.88168 .08333 L
.88218 .08333 L
.88269 .08333 L
.88318 .08333 L
.88363 .08333 L
.88405 .08333 L
.8845 .08333 L
.88498 .08333 L
.88547 .08333 L
.88599 .08333 L
.88648 .08333 L
.88693 .08333 L
.88746 .08333 L
.88775 .08333 L
.88803 .08333 L
.88853 .08333 L
.88906 .08333 L
Mistroke
.88958 .08333 L
.89014 .08333 L
.89068 .08333 L
.89117 .08333 L
.89166 .08333 L
.8921 .08333 L
.89261 .08333 L
.8931 .08333 L
.89362 .08333 L
.89418 .08333 L
.89466 .08333 L
.89518 .08333 L
.89574 .08333 L
.89606 .08333 L
.89635 .08333 L
.8969 .08333 L
.89743 .08333 L
.89788 .08333 L
.89838 .08333 L
.8989 .08333 L
.89938 .08333 L
.89984 .08333 L
.90025 .08333 L
.90071 .08333 L
.90119 .08333 L
.90168 .08333 L
.9022 .08333 L
.90269 .08333 L
.90314 .08333 L
.90366 .08333 L
.90396 .08333 L
.90423 .08333 L
.90474 .08333 L
.90527 .08333 L
.90579 .08333 L
.90608 .08333 L
.90635 .08333 L
.90685 .08333 L
.90738 .08333 L
.90786 .08333 L
.9083 .08333 L
.90879 .08333 L
.90931 .08333 L
.90984 .08333 L
.91014 .08333 L
.91042 .08333 L
.91098 .08333 L
.91129 .08333 L
.91158 .08333 L
.91209 .08333 L
Mistroke
.91265 .08333 L
.91317 .08333 L
.91366 .08333 L
.91411 .08333 L
.91459 .08333 L
.91505 .08333 L
.91547 .08333 L
.91596 .08333 L
.91649 .08333 L
.91699 .08333 L
.91746 .08333 L
.91799 .08333 L
.91849 .08333 L
.91893 .08333 L
.91941 .08333 L
.91994 .08333 L
.9205 .08333 L
.92097 .08333 L
.9215 .08333 L
.92187 .08333 L
.92222 .08333 L
.9226 .08333 L
.92301 .08333 L
.92336 .08333 L
.92369 .08333 L
.92406 .08333 L
.92445 .08333 L
.92477 .08333 L
.92513 .08333 L
.9255 .08333 L
.92585 .08333 L
.92618 .08333 L
.92647 .08333 L
.92681 .08333 L
.92714 .08333 L
.92749 .08333 L
.92787 .08333 L
.92827 .08333 L
.92865 .08333 L
.929 .08333 L
.92932 .08333 L
.92969 .08333 L
.93004 .08333 L
.93042 .08333 L
.93082 .08333 L
.9312 .08333 L
.93154 .08333 L
.93195 .08333 L
.93239 .08333 L
.9328 .08333 L
Mistroke
.93318 .08333 L
Mfstroke
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{570, 95},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.10368 .08333 L
.10413 .08333 L
.10466 .08333 L
.10516 .08333 L
.10562 .08333 L
.10605 .08333 L
.10651 .08333 L
.10701 .08333 L
.1075 .08333 L
.10804 .08333 L
.10854 .08333 L
.109 .08333 L
.10954 .08333 L
.10985 .08333 L
.11013 .08333 L
.11065 .08333 L
.11121 .08333 L
.11148 .08333 L
.11178 .08333 L
.1123 .08333 L
.1126 .08333 L
.11287 .08333 L
.11317 .08333 L
.11349 .08333 L
.11377 .08333 L
.11407 .08333 L
.11462 .08333 L
.11515 .08333 L
.11565 .08333 L
.11612 .08333 L
.11657 .08333 L
.11707 .08333 L
.1176 .08333 L
.11812 .08333 L
.11868 .08333 L
.11915 .08333 L
.11967 .08333 L
.11997 .08333 L
.12025 .08333 L
.12056 .08333 L
.12089 .08333 L
.12143 .08333 L
.12174 .08333 L
.12203 .08333 L
.12257 .08333 L
.12307 .08333 L
.12334 .08333 L
.12364 .08333 L
.12418 .08333 L
Mistroke
.1245 .08333 L
.12481 .08333 L
.12509 .08333 L
.12539 .08333 L
.12571 .08333 L
.12606 .08333 L
.12635 .08333 L
.12667 .08333 L
.12698 .08333 L
.12725 .08333 L
.12757 .08333 L
.12787 .08333 L
.12841 .08333 L
.12871 .08333 L
.12899 .08333 L
.12949 .08333 L
.13002 .08333 L
.13053 .08333 L
.13099 .08333 L
.13151 .08333 L
.13207 .08333 L
.13235 .08333 L
.13265 .08333 L
.1332 .08333 L
.1335 .08333 L
.13378 .08333 L
.13408 .08333 L
.1344 .08333 L
.13494 .08333 L
.13525 .08333 L
.13554 .08333 L
.13607 .08333 L
.13656 .08333 L
.13713 .08333 L
.13766 .08333 L
.13815 .08333 L
.13867 .08333 L
.13916 .08333 L
.13962 .08333 L
.14012 .08333 L
.14067 .08333 L
.14095 .08333 L
.14124 .08333 L
.14178 .08333 L
.14207 .08333 L
.14234 .08333 L
.14264 .08333 L
.14296 .08333 L
.14348 .08333 L
.14379 .08333 L
Mistroke
.14407 .08333 L
.14459 .08333 L
.14507 .08333 L
.14563 .08333 L
.14615 .08333 L
.14665 .08333 L
.1471 .08333 L
.14761 .08333 L
.1481 .08333 L
.14856 .08333 L
.14897 .08333 L
.14943 .08333 L
.14991 .08333 L
.1504 .08333 L
.15092 .08333 L
.15142 .08333 L
.15187 .08333 L
.1524 .08333 L
.15269 .08333 L
.15297 .08333 L
.15348 .08333 L
.15401 .08333 L
.1545 .08333 L
.15503 .08333 L
.15559 .08333 L
.1561 .08333 L
.15659 .08333 L
.15703 .08333 L
.15754 .08333 L
.15802 .08333 L
.15854 .08333 L
.1591 .08333 L
.15957 .08333 L
.16009 .08333 L
.16065 .08333 L
.16096 .08333 L
.16125 .08333 L
.16181 .08333 L
.16233 .08333 L
.16283 .08333 L
.16327 .08333 L
.16379 .08333 L
.16427 .08333 L
.16472 .08333 L
.16514 .08333 L
.16559 .08333 L
.16607 .08333 L
.16656 .08333 L
.16708 .08333 L
.16757 .08333 L
Mistroke
.16801 .08333 L
.16854 .08333 L
.16883 .08333 L
.16911 .08333 L
.16961 .08333 L
.17014 .08333 L
.17065 .08333 L
.17122 .08333 L
.17175 .08333 L
.17224 .08333 L
.17272 .08333 L
.17317 .08333 L
.17368 .08333 L
.17416 .08333 L
.17468 .08333 L
.17524 .08333 L
.17571 .08333 L
.17623 .08333 L
.17679 .08333 L
.17711 .08333 L
.17739 .08333 L
.17795 .08333 L
.17848 .08333 L
.17893 .08333 L
.17942 .08333 L
.17994 .08333 L
.18042 .08333 L
.18087 .08333 L
.18129 .08333 L
.18174 .08333 L
.18222 .08333 L
.18271 .08333 L
.18323 .08333 L
.18372 .08333 L
.18416 .08333 L
.18469 .08333 L
.18498 .08333 L
.18526 .08333 L
.18576 .08333 L
.18629 .08333 L
.18681 .08333 L
.18737 .08333 L
.1879 .08333 L
.18839 .08333 L
.18888 .08333 L
.18933 .08333 L
.18984 .08333 L
.19032 .08333 L
.19084 .08333 L
.1914 .08333 L
Mistroke
.19188 .08333 L
.1924 .08333 L
.19296 .08333 L
.19327 .08333 L
.19356 .08333 L
.19412 .08333 L
.19464 .08333 L
.19509 .08333 L
.19559 .08333 L
.19611 .08333 L
.19659 .08333 L
.19704 .08333 L
.19746 .08333 L
.19791 .08333 L
.19839 .08333 L
.19888 .08333 L
.1994 .08333 L
.19989 .08333 L
.20034 .08333 L
.20086 .08333 L
.20116 .08333 L
.20143 .08333 L
.20193 .08333 L
.20246 .08333 L
.20298 .08333 L
.20355 .08333 L
.20408 .08333 L
.20457 .08333 L
.20502 .08333 L
.20551 .08333 L
.20602 .08333 L
.2065 .08333 L
.20703 .08333 L
.20759 .08333 L
.20806 .08333 L
.20858 .08333 L
.20915 .08333 L
.20946 .08333 L
.20975 .08333 L
.21031 .08333 L
.21083 .08333 L
.21128 .08333 L
.21178 .08333 L
.2123 .08333 L
.21278 .08333 L
.21324 .08333 L
.21365 .08333 L
.21413 .08333 L
.21458 .08333 L
.21507 .08333 L
Mistroke
.21559 .08333 L
.21609 .08333 L
.21653 .08333 L
.21706 .08333 L
.21735 .08333 L
.21763 .08333 L
.21813 .08333 L
.21866 .08333 L
.21918 .08333 L
.21947 .08333 L
.21974 .08333 L
.22024 .08333 L
.22077 .08333 L
.22125 .08333 L
.22169 .08333 L
.22218 .08333 L
.2227 .08333 L
.22323 .08333 L
.22353 .08333 L
.22381 .08333 L
.22437 .08333 L
.22468 .08333 L
.22497 .08333 L
.22548 .08333 L
.22604 .08333 L
.22656 .08333 L
.22704 .08333 L
.22749 .08333 L
.22798 .08333 L
.22844 .08333 L
.22885 .08333 L
.22934 .08333 L
.22988 .08333 L
.23038 .08333 L
.23085 .08333 L
.23137 .08333 L
.23187 .08333 L
.23232 .08333 L
.2328 .08333 L
.23332 .08333 L
.23388 .08333 L
.23435 .08333 L
.23487 .08333 L
.23543 .08333 L
.23595 .08333 L
.23622 .08333 L
.23652 .08333 L
.23683 .08333 L
.23712 .08333 L
.23765 .08333 L
Mistroke
.23814 .08333 L
.23871 .08333 L
.23924 .08333 L
.23972 .08333 L
.24023 .08333 L
.24071 .08333 L
.24114 .08333 L
.24166 .08333 L
.24221 .08333 L
.24274 .08333 L
.24322 .08333 L
.24374 .08333 L
.24429 .08333 L
.24482 .08333 L
.24529 .08333 L
.24585 .08333 L
.24617 .08333 L
.24646 .08333 L
.247 .08333 L
.24727 .08333 L
.24757 .08333 L
.24786 .08333 L
.24816 .08333 L
.24871 .08333 L
.24901 .08333 L
.24929 .08333 L
.2496 .08333 L
.24993 .08333 L
.25022 .08333 L
.25053 .08333 L
.25083 .08333 L
.2511 .08333 L
.25161 .08333 L
.25216 .08333 L
.25267 .08333 L
.25324 .08333 L
.25377 .08333 L
.25426 .08333 L
.25475 .08333 L
.25519 .08333 L
.2557 .08333 L
.25618 .08333 L
.25671 .08333 L
.25727 .08333 L
.25774 .08333 L
.25826 .08333 L
.25882 .08333 L
.25914 .08333 L
.25942 .08333 L
.25998 .08333 L
Mistroke
.26051 .08333 L
.26096 .08333 L
.26145 .08333 L
.26197 .08333 L
.26245 .08333 L
.26291 .08333 L
.26332 .08333 L
.26378 .08333 L
.26425 .08333 L
.26474 .08333 L
.26526 .08333 L
.26575 .08333 L
.2662 .08333 L
.26672 .08333 L
.26702 .08333 L
.26729 .08333 L
.26779 .08333 L
.26833 .08333 L
.26884 .08333 L
.26941 .08333 L
.26994 .08333 L
.27043 .08333 L
.27092 .08333 L
.27137 .08333 L
.27188 .08333 L
.27236 .08333 L
.27289 .08333 L
.27345 .08333 L
.27392 .08333 L
.27444 .08333 L
.27501 .08333 L
.27532 .08333 L
.27561 .08333 L
.27616 .08333 L
.27669 .08333 L
.27714 .08333 L
.27764 .08333 L
.27816 .08333 L
.27864 .08333 L
.27909 .08333 L
.27951 .08333 L
.27999 .08333 L
.28044 .08333 L
.28093 .08333 L
.28145 .08333 L
.28194 .08333 L
.28239 .08333 L
.28291 .08333 L
.28321 .08333 L
.28348 .08333 L
Mistroke
.28398 .08333 L
.28451 .08333 L
.28503 .08333 L
.28533 .08333 L
.2856 .08333 L
.2861 .08333 L
.28663 .08333 L
.2871 .08333 L
.28755 .08333 L
.28803 .08333 L
.28856 .08333 L
.28909 .08333 L
.28938 .08333 L
.28966 .08333 L
.29022 .08333 L
.29054 .08333 L
.29082 .08333 L
.29133 .08333 L
.29189 .08333 L
.29241 .08333 L
.2929 .08333 L
.29335 .08333 L
.29383 .08333 L
.29429 .08333 L
.29471 .08333 L
.2952 .08333 L
.29573 .08333 L
.29623 .08333 L
.2967 .08333 L
.29723 .08333 L
.29772 .08333 L
.29817 .08333 L
.29865 .08333 L
.29918 .08333 L
.29973 .08333 L
.3002 .08333 L
.30072 .08333 L
.30128 .08333 L
.3018 .08333 L
.30207 .08333 L
.30237 .08333 L
.30268 .08333 L
.30297 .08333 L
.3035 .08333 L
.30399 .08333 L
.30453 .08333 L
.30509 .08333 L
.30557 .08333 L
.30608 .08333 L
.30656 .08333 L
Mistroke
.30699 .08333 L
.30751 .08333 L
.30806 .08333 L
.30859 .08333 L
.30907 .08333 L
.30959 .08333 L
.31014 .08333 L
.31066 .08333 L
.31114 .08333 L
.3117 .08333 L
.31201 .08333 L
.31231 .08333 L
.31284 .08333 L
.31311 .08333 L
.31341 .08333 L
.3137 .08333 L
.31401 .08333 L
.31455 .08333 L
.31486 .08333 L
.31514 .08333 L
.31545 .08333 L
.31578 .08333 L
.31607 .08333 L
.31638 .08333 L
.31667 .08333 L
.31695 .08333 L
.31746 .08333 L
.31801 .08333 L
.31852 .08333 L
.31908 .08333 L
.31961 .08333 L
.32011 .08333 L
.32059 .08333 L
.32104 .08333 L
.32155 .08333 L
.32203 .08333 L
.32255 .08333 L
.32311 .08333 L
.32358 .08333 L
.3241 .08333 L
.32467 .08333 L
.32498 .08333 L
.32527 .08333 L
.32582 .08333 L
.32635 .08333 L
.3268 .08333 L
.32729 .08333 L
.32781 .08333 L
.3283 .08333 L
.32875 .08333 L
Mistroke
.32916 .08333 L
.32962 .08333 L
.3301 .08333 L
.33058 .08333 L
.3311 .08333 L
.33159 .08333 L
.33204 .08333 L
.33257 .08333 L
.33286 .08333 L
.33313 .08333 L
.33364 .08333 L
.33417 .08333 L
.33468 .08333 L
.33525 .08333 L
.33578 .08333 L
.33627 .08333 L
.33676 .08333 L
.33721 .08333 L
.33772 .08333 L
.3382 .08333 L
.33873 .08333 L
.33928 .08333 L
.33976 .08333 L
.34028 .08333 L
.34084 .08333 L
.34116 .08333 L
.34144 .08333 L
.342 .08333 L
.34253 .08333 L
.34298 .08333 L
.34348 .08333 L
.34399 .08333 L
.34448 .08333 L
.34493 .08333 L
.34535 .08333 L
.34582 .08333 L
.34628 .08333 L
.34677 .08333 L
.34729 .08333 L
.34778 .08333 L
.34822 .08333 L
.34875 .08333 L
.34905 .08333 L
.34932 .08333 L
.34982 .08333 L
.35035 .08333 L
.35087 .08333 L
.35116 .08333 L
.35144 .08333 L
.35193 .08333 L
Mistroke
.35246 .08333 L
.35294 .08333 L
.35338 .08333 L
.35387 .08333 L
.35439 .08333 L
.35492 .08333 L
.35522 .08333 L
.35549 .08333 L
.35606 .08333 L
.35637 .08333 L
.35666 .08333 L
.35717 .08333 L
.35772 .08333 L
.35825 .08333 L
.35873 .08333 L
.35918 .08333 L
.35966 .08333 L
.36012 .08333 L
.36054 .08333 L
.36103 .08333 L
.36156 .08333 L
.36206 .08333 L
.36253 .08333 L
.36306 .08333 L
.36355 .08333 L
.364 .08333 L
.36448 .08333 L
.36501 .08333 L
.36556 .08333 L
.36604 .08333 L
.36656 .08333 L
.36711 .08333 L
.36763 .08333 L
.3679 .08333 L
.3682 .08333 L
.36851 .08333 L
.3688 .08333 L
.36933 .08333 L
.36982 .08333 L
.37036 .08333 L
.37092 .08333 L
.3714 .08333 L
.37191 .08333 L
.37239 .08333 L
.37282 .08333 L
.37333 .08333 L
.37389 .08333 L
.37441 .08333 L
.3749 .08333 L
.37541 .08333 L
Mistroke
.37597 .08333 L
.37649 .08333 L
.37697 .08333 L
.37752 .08333 L
.37784 .08333 L
.37813 .08333 L
.37867 .08333 L
.37894 .08333 L
.37924 .08333 L
.37953 .08333 L
.37983 .08333 L
.38038 .08333 L
.38068 .08333 L
.38096 .08333 L
.38127 .08333 L
.38161 .08333 L
.38189 .08333 L
.38221 .08333 L
.3825 .08333 L
.38277 .08333 L
.38329 .08333 L
.38383 .08333 L
.38435 .08333 L
.38491 .08333 L
.38544 .08333 L
.38593 .08333 L
.38642 .08333 L
.38686 .08333 L
.38737 .08333 L
.38785 .08333 L
.38838 .08333 L
.38893 .08333 L
.38941 .08333 L
.38993 .08333 L
.39049 .08333 L
.3908 .08333 L
.39109 .08333 L
.39165 .08333 L
.39217 .08333 L
.39262 .08333 L
.39312 .08333 L
.39363 .08333 L
.39412 .08333 L
.39457 .08333 L
.39498 .08333 L
.39544 .08333 L
.39592 .08333 L
.3964 .08333 L
.39692 .08333 L
.39741 .08333 L
Mistroke
.39786 .08333 L
.39839 .08333 L
.39868 .08333 L
.39895 .08333 L
.39946 .08333 L
.39999 .08333 L
.4005 .08333 L
.40107 .08333 L
.4016 .08333 L
.40209 .08333 L
.40258 .08333 L
.40303 .08333 L
.40354 .08333 L
.40402 .08333 L
.40454 .08333 L
.4051 .08333 L
.40558 .08333 L
.4061 .08333 L
.40666 .08333 L
.40697 .08333 L
.40726 .08333 L
.40782 .08333 L
.40835 .08333 L
.4088 .08333 L
.40929 .08333 L
.40981 .08333 L
.41029 .08333 L
.41075 .08333 L
.41116 .08333 L
.41162 .08333 L
.41209 .08333 L
.41258 .08333 L
.4131 .08333 L
.41359 .08333 L
.41404 .08333 L
.41457 .08333 L
.41486 .08333 L
.41513 .08333 L
.41564 .08333 L
.41617 .08333 L
.41668 .08333 L
.41698 .08333 L
.41725 .08333 L
.41775 .08333 L
.41828 .08333 L
.41875 .08333 L
.41919 .08333 L
.41968 .08333 L
.42021 .08333 L
.42073 .08333 L
Mistroke
.42103 .08333 L
.42131 .08333 L
.42187 .08333 L
.42218 .08333 L
.42247 .08333 L
.42298 .08333 L
.42353 .08333 L
.42406 .08333 L
.42454 .08333 L
.42499 .08333 L
.42548 .08333 L
.42593 .08333 L
.42635 .08333 L
.42684 .08333 L
.42737 .08333 L
.42787 .08333 L
.42834 .08333 L
.42887 .08333 L
.42936 .08333 L
.42981 .08333 L
.43029 .08333 L
.43082 .08333 L
.43137 .08333 L
.43185 .08333 L
.43237 .08333 L
.43292 .08333 L
.43344 .08333 L
.43371 .08333 L
.43401 .08333 L
.43432 .08333 L
.43461 .08333 L
.43514 .08333 L
.43563 .08333 L
.43616 .08333 L
.43673 .08333 L
.4372 .08333 L
.43771 .08333 L
.43819 .08333 L
.43863 .08333 L
.43914 .08333 L
.4397 .08333 L
.44022 .08333 L
.4407 .08333 L
.44122 .08333 L
.44177 .08333 L
.44229 .08333 L
.44277 .08333 L
.44333 .08333 L
.44364 .08333 L
.44394 .08333 L
Mistroke
.44447 .08333 L
.44477 .08333 L
.44504 .08333 L
.44533 .08333 L
.44564 .08333 L
.44618 .08333 L
.44649 .08333 L
.44677 .08333 L
.44708 .08333 L
.44741 .08333 L
.4477 .08333 L
.44801 .08333 L
.4483 .08333 L
.44858 .08333 L
.44909 .08333 L
.44964 .08333 L
.45015 .08333 L
.45071 .08333 L
.45124 .08333 L
.45173 .08333 L
.45222 .08333 L
.45266 .08333 L
.45317 .08333 L
.45365 .08333 L
.45418 .08333 L
.45473 .08333 L
.45521 .08333 L
.45573 .08333 L
.45629 .08333 L
.4566 .08333 L
.45689 .08333 L
.45745 .08333 L
.45797 .08333 L
.45842 .08333 L
.45892 .08333 L
.45943 .08333 L
.45992 .08333 L
.46037 .08333 L
.46078 .08333 L
.46124 .08333 L
.46172 .08333 L
.4622 .08333 L
.46272 .08333 L
.46321 .08333 L
.46366 .08333 L
.46418 .08333 L
.46448 .08333 L
.46475 .08333 L
.46526 .08333 L
.46579 .08333 L
Mistroke
.4663 .08333 L
.46687 .08333 L
.4674 .08333 L
.46789 .08333 L
.46838 .08333 L
.46882 .08333 L
.46933 .08333 L
.46981 .08333 L
.47034 .08333 L
.4709 .08333 L
.47137 .08333 L
.47189 .08333 L
.47246 .08333 L
.47277 .08333 L
.47306 .08333 L
.47361 .08333 L
.47414 .08333 L
.47459 .08333 L
.47509 .08333 L
.4756 .08333 L
.47609 .08333 L
.47654 .08333 L
.47696 .08333 L
.47741 .08333 L
.47789 .08333 L
.47838 .08333 L
.4789 .08333 L
.47939 .08333 L
.47983 .08333 L
.48036 .08333 L
.48066 .08333 L
.48093 .08333 L
.48143 .08333 L
.48196 .08333 L
.48248 .08333 L
.48277 .08333 L
.48304 .08333 L
.48354 .08333 L
.48407 .08333 L
.48454 .08333 L
.48499 .08333 L
.48547 .08333 L
.486 .08333 L
.48652 .08333 L
.48682 .08333 L
.4871 .08333 L
.48766 .08333 L
.48797 .08333 L
.48826 .08333 L
.48877 .08333 L
Mistroke
.48932 .08333 L
.48985 .08333 L
.49033 .08333 L
.49078 .08333 L
.49126 .08333 L
.49172 .08333 L
.49214 .08333 L
.49263 .08333 L
.49316 .08333 L
.49366 .08333 L
.49413 .08333 L
.49466 .08333 L
.49515 .08333 L
.4956 .08333 L
.49608 .08333 L
.4966 .08333 L
.49716 .08333 L
.49763 .08333 L
.49816 .08333 L
.49853 .08333 L
.49888 .08333 L
.49926 .08333 L
.49967 .08333 L
.50002 .08333 L
.50035 .08333 L
.50071 .08333 L
.5011 .08333 L
.50143 .08333 L
.50178 .08333 L
.50216 .08333 L
.5025 .08333 L
.50283 .08333 L
.50312 .08333 L
.50346 .08333 L
.50379 .08333 L
.50413 .08333 L
.50452 .08333 L
.50492 .08333 L
.50529 .08333 L
.50564 .08333 L
.50596 .08333 L
.50633 .08333 L
.50668 .08333 L
.50706 .08333 L
.50746 .08333 L
.50784 .08333 L
.50818 .08333 L
.50859 .08333 L
.50903 .08333 L
.50944 .08333 L
Mistroke
.50982 .08333 L
Mfstroke
.50982 .08333 m
.51032 .08333 L
.51077 .08333 L
.51128 .08333 L
.51178 .08333 L
.51223 .08333 L
.51265 .08333 L
.51311 .08333 L
.5136 .08333 L
.51409 .08333 L
.51462 .08333 L
.51511 .08333 L
.51557 .08333 L
.5161 .08333 L
.5164 .08333 L
.51668 .08333 L
.51719 .08333 L
.51774 .08333 L
.51801 .08333 L
.5183 .08333 L
.51882 .08333 L
.51911 .08333 L
.51938 .08333 L
.51967 .08333 L
.51999 .08333 L
.52026 .08333 L
.52056 .08333 L
.5211 .08333 L
.52163 .08333 L
.52211 .08333 L
.52259 .08333 L
.52303 .08333 L
.52351 .08333 L
.52404 .08333 L
.52456 .08333 L
.52511 .08333 L
.52557 .08333 L
.52608 .08333 L
.52638 .08333 L
.52666 .08333 L
.52696 .08333 L
.52728 .08333 L
.52782 .08333 L
.52812 .08333 L
.52841 .08333 L
.52894 .08333 L
.52943 .08333 L
.5297 .08333 L
.52999 .08333 L
.53053 .08333 L
Mistroke
.53085 .08333 L
.53115 .08333 L
.53142 .08333 L
.53172 .08333 L
.53204 .08333 L
.53238 .08333 L
.53267 .08333 L
.53299 .08333 L
.53329 .08333 L
.53356 .08333 L
.53387 .08333 L
.53417 .08333 L
.5347 .08333 L
.535 .08333 L
.53527 .08333 L
.53576 .08333 L
.53629 .08333 L
.53679 .08333 L
.53724 .08333 L
.53775 .08333 L
.5383 .08333 L
.53858 .08333 L
.53888 .08333 L
.53942 .08333 L
.53972 .08333 L
.53999 .08333 L
.54029 .08333 L
.54061 .08333 L
.54114 .08333 L
.54144 .08333 L
.54173 .08333 L
.54225 .08333 L
.54274 .08333 L
.54329 .08333 L
.54382 .08333 L
.5443 .08333 L
.54481 .08333 L
.5453 .08333 L
.54575 .08333 L
.54624 .08333 L
.54678 .08333 L
.54706 .08333 L
.54735 .08333 L
.54788 .08333 L
.54817 .08333 L
.54843 .08333 L
.54873 .08333 L
.54904 .08333 L
.54956 .08333 L
.54986 .08333 L
Mistroke
.55014 .08333 L
.55065 .08333 L
.55113 .08333 L
.55167 .08333 L
.55219 .08333 L
.55268 .08333 L
.55312 .08333 L
.55363 .08333 L
.55411 .08333 L
.55456 .08333 L
.55497 .08333 L
.55542 .08333 L
.5559 .08333 L
.55638 .08333 L
.55689 .08333 L
.55738 .08333 L
.55782 .08333 L
.55835 .08333 L
.55864 .08333 L
.55891 .08333 L
.55941 .08333 L
.55994 .08333 L
.56042 .08333 L
.56094 .08333 L
.56149 .08333 L
.562 .08333 L
.56248 .08333 L
.56291 .08333 L
.56342 .08333 L
.56389 .08333 L
.5644 .08333 L
.56495 .08333 L
.56542 .08333 L
.56593 .08333 L
.56648 .08333 L
.56679 .08333 L
.56707 .08333 L
.56762 .08333 L
.56814 .08333 L
.56863 .08333 L
.56907 .08333 L
.56958 .08333 L
.57005 .08333 L
.5705 .08333 L
.57091 .08333 L
.57135 .08333 L
.57183 .08333 L
.5723 .08333 L
.57282 .08333 L
.5733 .08333 L
Mistroke
.57374 .08333 L
.57426 .08333 L
.57455 .08333 L
.57482 .08333 L
.57531 .08333 L
.57584 .08333 L
.57635 .08333 L
.5769 .08333 L
.57742 .08333 L
.57791 .08333 L
.57839 .08333 L
.57882 .08333 L
.57932 .08333 L
.5798 .08333 L
.58032 .08333 L
.58086 .08333 L
.58133 .08333 L
.58184 .08333 L
.5824 .08333 L
.58271 .08333 L
.58299 .08333 L
.58354 .08333 L
.58406 .08333 L
.5845 .08333 L
.58499 .08333 L
.5855 .08333 L
.58597 .08333 L
.58642 .08333 L
.58683 .08333 L
.58727 .08333 L
.58775 .08333 L
.58823 .08333 L
.58874 .08333 L
.58922 .08333 L
.58966 .08333 L
.59018 .08333 L
.59047 .08333 L
.59074 .08333 L
.59124 .08333 L
.59176 .08333 L
.59227 .08333 L
.59282 .08333 L
.59335 .08333 L
.59383 .08333 L
.59432 .08333 L
.59475 .08333 L
.59526 .08333 L
.59573 .08333 L
.59625 .08333 L
.5968 .08333 L
Mistroke
.59727 .08333 L
.59778 .08333 L
.59833 .08333 L
.59864 .08333 L
.59893 .08333 L
.59948 .08333 L
.6 .08333 L
.60044 .08333 L
.60093 .08333 L
.60144 .08333 L
.60192 .08333 L
.60236 .08333 L
.60277 .08333 L
.60322 .08333 L
.60369 .08333 L
.60417 .08333 L
.60468 .08333 L
.60517 .08333 L
.60561 .08333 L
.60613 .08333 L
.60642 .08333 L
.60669 .08333 L
.60718 .08333 L
.6077 .08333 L
.60821 .08333 L
.60877 .08333 L
.6093 .08333 L
.60978 .08333 L
.61022 .08333 L
.6107 .08333 L
.61121 .08333 L
.61168 .08333 L
.61221 .08333 L
.61275 .08333 L
.61322 .08333 L
.61374 .08333 L
.61429 .08333 L
.6146 .08333 L
.61489 .08333 L
.61544 .08333 L
.61596 .08333 L
.6164 .08333 L
.61689 .08333 L
.6174 .08333 L
.61788 .08333 L
.61833 .08333 L
.61873 .08333 L
.61921 .08333 L
.61965 .08333 L
.62014 .08333 L
Mistroke
.62065 .08333 L
.62113 .08333 L
.62157 .08333 L
.62209 .08333 L
.62238 .08333 L
.62265 .08333 L
.62315 .08333 L
.62367 .08333 L
.62418 .08333 L
.62447 .08333 L
.62474 .08333 L
.62523 .08333 L
.62576 .08333 L
.62622 .08333 L
.62666 .08333 L
.62714 .08333 L
.62766 .08333 L
.62818 .08333 L
.62847 .08333 L
.62875 .08333 L
.6293 .08333 L
.62961 .08333 L
.62989 .08333 L
.6304 .08333 L
.63094 .08333 L
.63146 .08333 L
.63194 .08333 L
.63238 .08333 L
.63286 .08333 L
.63331 .08333 L
.63372 .08333 L
.6342 .08333 L
.63473 .08333 L
.63523 .08333 L
.63569 .08333 L
.63621 .08333 L
.6367 .08333 L
.63713 .08333 L
.63761 .08333 L
.63813 .08333 L
.63868 .08333 L
.63914 .08333 L
.63966 .08333 L
.64021 .08333 L
.64072 .08333 L
.64098 .08333 L
.64128 .08333 L
.64158 .08333 L
.64187 .08333 L
.6424 .08333 L
Mistroke
.64288 .08333 L
.64343 .08333 L
.64396 .08333 L
.64443 .08333 L
.64494 .08333 L
.64541 .08333 L
.64584 .08333 L
.64634 .08333 L
.64689 .08333 L
.64741 .08333 L
.64789 .08333 L
.6484 .08333 L
.64894 .08333 L
.64946 .08333 L
.64993 .08333 L
.65048 .08333 L
.65079 .08333 L
.65108 .08333 L
.65161 .08333 L
.65187 .08333 L
.65217 .08333 L
.65245 .08333 L
.65275 .08333 L
.65329 .08333 L
.65359 .08333 L
.65387 .08333 L
.65418 .08333 L
.6545 .08333 L
.65479 .08333 L
.65509 .08333 L
.65538 .08333 L
.65565 .08333 L
.65616 .08333 L
.6567 .08333 L
.6572 .08333 L
.65776 .08333 L
.65828 .08333 L
.65877 .08333 L
.65925 .08333 L
.65969 .08333 L
.66019 .08333 L
.66066 .08333 L
.66118 .08333 L
.66173 .08333 L
.6622 .08333 L
.66271 .08333 L
.66327 .08333 L
.66358 .08333 L
.66386 .08333 L
.66441 .08333 L
Mistroke
.66493 .08333 L
.66537 .08333 L
.66586 .08333 L
.66637 .08333 L
.66685 .08333 L
.66729 .08333 L
.6677 .08333 L
.66815 .08333 L
.66862 .08333 L
.6691 .08333 L
.66961 .08333 L
.6701 .08333 L
.67054 .08333 L
.67106 .08333 L
.67135 .08333 L
.67162 .08333 L
.67211 .08333 L
.67263 .08333 L
.67314 .08333 L
.6737 .08333 L
.67423 .08333 L
.67471 .08333 L
.6752 .08333 L
.67563 .08333 L
.67614 .08333 L
.67661 .08333 L
.67713 .08333 L
.67768 .08333 L
.67815 .08333 L
.67867 .08333 L
.67922 .08333 L
.67953 .08333 L
.67981 .08333 L
.68036 .08333 L
.68088 .08333 L
.68133 .08333 L
.68182 .08333 L
.68233 .08333 L
.6828 .08333 L
.68325 .08333 L
.68366 .08333 L
.68413 .08333 L
.68458 .08333 L
.68506 .08333 L
.68558 .08333 L
.68606 .08333 L
.6865 .08333 L
.68702 .08333 L
.68731 .08333 L
.68758 .08333 L
Mistroke
.68807 .08333 L
.68859 .08333 L
.68911 .08333 L
.6894 .08333 L
.68967 .08333 L
.69016 .08333 L
.69068 .08333 L
.69115 .08333 L
.69158 .08333 L
.69206 .08333 L
.69258 .08333 L
.6931 .08333 L
.6934 .08333 L
.69367 .08333 L
.69422 .08333 L
.69453 .08333 L
.69481 .08333 L
.69532 .08333 L
.69587 .08333 L
.69638 .08333 L
.69686 .08333 L
.6973 .08333 L
.69778 .08333 L
.69823 .08333 L
.69864 .08333 L
.69913 .08333 L
.69965 .08333 L
.70015 .08333 L
.70061 .08333 L
.70113 .08333 L
.70162 .08333 L
.70205 .08333 L
.70253 .08333 L
.70305 .08333 L
.7036 .08333 L
.70406 .08333 L
.70458 .08333 L
.70513 .08333 L
.70564 .08333 L
.7059 .08333 L
.7062 .08333 L
.7065 .08333 L
.70679 .08333 L
.70731 .08333 L
.7078 .08333 L
.70833 .08333 L
.70888 .08333 L
.70935 .08333 L
.70985 .08333 L
.71033 .08333 L
Mistroke
.71076 .08333 L
.71126 .08333 L
.71181 .08333 L
.71233 .08333 L
.7128 .08333 L
.71331 .08333 L
.71386 .08333 L
.71437 .08333 L
.71484 .08333 L
.71539 .08333 L
.71571 .08333 L
.71599 .08333 L
.71652 .08333 L
.71679 .08333 L
.71708 .08333 L
.71737 .08333 L
.71767 .08333 L
.71821 .08333 L
.71851 .08333 L
.71879 .08333 L
.71909 .08333 L
.71942 .08333 L
.7197 .08333 L
.72001 .08333 L
.7203 .08333 L
.72057 .08333 L
.72107 .08333 L
.72161 .08333 L
.72212 .08333 L
.72267 .08333 L
.7232 .08333 L
.72368 .08333 L
.72416 .08333 L
.7246 .08333 L
.7251 .08333 L
.72558 .08333 L
.7261 .08333 L
.72664 .08333 L
.72711 .08333 L
.72762 .08333 L
.72818 .08333 L
.72849 .08333 L
.72877 .08333 L
.72932 .08333 L
.72984 .08333 L
.73028 .08333 L
.73077 .08333 L
.73128 .08333 L
.73176 .08333 L
.7322 .08333 L
Mistroke
.73261 .08333 L
.73306 .08333 L
.73353 .08333 L
.73401 .08333 L
.73452 .08333 L
.73501 .08333 L
.73545 .08333 L
.73597 .08333 L
.73626 .08333 L
.73653 .08333 L
.73702 .08333 L
.73754 .08333 L
.73805 .08333 L
.73861 .08333 L
.73914 .08333 L
.73962 .08333 L
.7401 .08333 L
.74054 .08333 L
.74105 .08333 L
.74152 .08333 L
.74204 .08333 L
.74259 .08333 L
.74306 .08333 L
.74357 .08333 L
.74413 .08333 L
.74444 .08333 L
.74472 .08333 L
.74527 .08333 L
.74579 .08333 L
.74623 .08333 L
.74672 .08333 L
.74723 .08333 L
.74771 .08333 L
.74816 .08333 L
.74857 .08333 L
.74904 .08333 L
.74949 .08333 L
.74997 .08333 L
.75048 .08333 L
.75096 .08333 L
.7514 .08333 L
.75192 .08333 L
.75221 .08333 L
.75248 .08333 L
.75298 .08333 L
.7535 .08333 L
.75401 .08333 L
.7543 .08333 L
.75457 .08333 L
.75506 .08333 L
Mistroke
.75558 .08333 L
.75605 .08333 L
.75649 .08333 L
.75697 .08333 L
.75749 .08333 L
.758 .08333 L
.7583 .08333 L
.75857 .08333 L
.75912 .08333 L
.75943 .08333 L
.75971 .08333 L
.76022 .08333 L
.76077 .08333 L
.76128 .08333 L
.76176 .08333 L
.7622 .08333 L
.76268 .08333 L
.76313 .08333 L
.76354 .08333 L
.76403 .08333 L
.76455 .08333 L
.76505 .08333 L
.76551 .08333 L
.76603 .08333 L
.76652 .08333 L
.76695 .08333 L
.76743 .08333 L
.76795 .08333 L
.7685 .08333 L
.76896 .08333 L
.76948 .08333 L
.77003 .08333 L
.77054 .08333 L
.7708 .08333 L
.77109 .08333 L
.7714 .08333 L
.77169 .08333 L
.77221 .08333 L
.77269 .08333 L
.77322 .08333 L
.77378 .08333 L
.77425 .08333 L
.77475 .08333 L
.77522 .08333 L
.77565 .08333 L
.77616 .08333 L
.77671 .08333 L
.77722 .08333 L
.7777 .08333 L
.77821 .08333 L
Mistroke
.77875 .08333 L
.77927 .08333 L
.77974 .08333 L
.78029 .08333 L
.7806 .08333 L
.78089 .08333 L
.78142 .08333 L
.78168 .08333 L
.78198 .08333 L
.78226 .08333 L
.78256 .08333 L
.7831 .08333 L
.7834 .08333 L
.78368 .08333 L
.78399 .08333 L
.78431 .08333 L
.7846 .08333 L
.7849 .08333 L
.78519 .08333 L
.78546 .08333 L
.78597 .08333 L
.78651 .08333 L
.78701 .08333 L
.78757 .08333 L
.78809 .08333 L
.78858 .08333 L
.78906 .08333 L
.78949 .08333 L
.78999 .08333 L
.79047 .08333 L
.79099 .08333 L
.79154 .08333 L
.792 .08333 L
.79252 .08333 L
.79307 .08333 L
.79338 .08333 L
.79366 .08333 L
.79421 .08333 L
.79473 .08333 L
.79517 .08333 L
.79566 .08333 L
.79617 .08333 L
.79665 .08333 L
.79709 .08333 L
.7975 .08333 L
.79795 .08333 L
.79842 .08333 L
.7989 .08333 L
.79941 .08333 L
.7999 .08333 L
Mistroke
.80034 .08333 L
.80085 .08333 L
.80115 .08333 L
.80142 .08333 L
.80191 .08333 L
.80243 .08333 L
.80294 .08333 L
.8035 .08333 L
.80402 .08333 L
.80451 .08333 L
.80499 .08333 L
.80543 .08333 L
.80593 .08333 L
.80641 .08333 L
.80693 .08333 L
.80748 .08333 L
.80794 .08333 L
.80846 .08333 L
.80901 .08333 L
.80932 .08333 L
.80961 .08333 L
.81015 .08333 L
.81067 .08333 L
.81112 .08333 L
.81161 .08333 L
.81212 .08333 L
.8126 .08333 L
.81304 .08333 L
.81345 .08333 L
.8139 .08333 L
.81437 .08333 L
.81485 .08333 L
.81536 .08333 L
.81585 .08333 L
.81629 .08333 L
.81681 .08333 L
.8171 .08333 L
.81737 .08333 L
.81786 .08333 L
.81838 .08333 L
.8189 .08333 L
.81918 .08333 L
.81945 .08333 L
.81994 .08333 L
.82047 .08333 L
.82093 .08333 L
.82137 .08333 L
.82185 .08333 L
.82237 .08333 L
.82289 .08333 L
Mistroke
.82318 .08333 L
.82345 .08333 L
.824 .08333 L
.82431 .08333 L
.8246 .08333 L
.8251 .08333 L
.82565 .08333 L
.82616 .08333 L
.82664 .08333 L
.82708 .08333 L
.82756 .08333 L
.82801 .08333 L
.82842 .08333 L
.8289 .08333 L
.82943 .08333 L
.82993 .08333 L
.83039 .08333 L
.83091 .08333 L
.83139 .08333 L
.83183 .08333 L
.83231 .08333 L
.83283 .08333 L
.83337 .08333 L
.83384 .08333 L
.83435 .08333 L
.8349 .08333 L
.83541 .08333 L
.83568 .08333 L
.83597 .08333 L
.83628 .08333 L
.83656 .08333 L
.83709 .08333 L
.83757 .08333 L
.8381 .08333 L
.83866 .08333 L
.83912 .08333 L
.83963 .08333 L
.8401 .08333 L
.84053 .08333 L
.84103 .08333 L
.84158 .08333 L
.8421 .08333 L
.84257 .08333 L
.84308 .08333 L
.84363 .08333 L
.84414 .08333 L
.84461 .08333 L
.84516 .08333 L
.84547 .08333 L
.84576 .08333 L
Mistroke
.84629 .08333 L
.84659 .08333 L
.84685 .08333 L
.84714 .08333 L
.84744 .08333 L
.84798 .08333 L
.84827 .08333 L
.84855 .08333 L
.84886 .08333 L
.84919 .08333 L
.84947 .08333 L
.84978 .08333 L
.85007 .08333 L
.85034 .08333 L
.85084 .08333 L
.85138 .08333 L
.85189 .08333 L
.85244 .08333 L
.85296 .08333 L
.85345 .08333 L
.85393 .08333 L
.85436 .08333 L
.85487 .08333 L
.85534 .08333 L
.85586 .08333 L
.85641 .08333 L
.85687 .08333 L
.85739 .08333 L
.85794 .08333 L
.85825 .08333 L
.85853 .08333 L
.85908 .08333 L
.8596 .08333 L
.86004 .08333 L
.86053 .08333 L
.86104 .08333 L
.86152 .08333 L
.86196 .08333 L
.86237 .08333 L
.86282 .08333 L
.86329 .08333 L
.86377 .08333 L
.86428 .08333 L
.86477 .08333 L
.86521 .08333 L
.86572 .08333 L
.86602 .08333 L
.86628 .08333 L
.86678 .08333 L
.8673 .08333 L
Mistroke
.86781 .08333 L
.86837 .08333 L
.86889 .08333 L
.86938 .08333 L
.86986 .08333 L
.8703 .08333 L
.8708 .08333 L
.87127 .08333 L
.87179 .08333 L
.87234 .08333 L
.87281 .08333 L
.87332 .08333 L
.87388 .08333 L
.87419 .08333 L
.87447 .08333 L
.87502 .08333 L
.87554 .08333 L
.87598 .08333 L
.87647 .08333 L
.87698 .08333 L
.87746 .08333 L
.8779 .08333 L
.87831 .08333 L
.87876 .08333 L
.87923 .08333 L
.87971 .08333 L
.88023 .08333 L
.88071 .08333 L
.88115 .08333 L
.88167 .08333 L
.88196 .08333 L
.88223 .08333 L
.88272 .08333 L
.88325 .08333 L
.88376 .08333 L
.88405 .08333 L
.88432 .08333 L
.88481 .08333 L
.88533 .08333 L
.88579 .08333 L
.88623 .08333 L
.88671 .08333 L
.88723 .08333 L
.88775 .08333 L
.88804 .08333 L
.88831 .08333 L
.88886 .08333 L
.88917 .08333 L
.88946 .08333 L
.88996 .08333 L
Mistroke
.89051 .08333 L
.89102 .08333 L
.8915 .08333 L
.89194 .08333 L
.89242 .08333 L
.89287 .08333 L
.89328 .08333 L
.89376 .08333 L
.89429 .08333 L
.89478 .08333 L
.89524 .08333 L
.89576 .08333 L
.89625 .08333 L
.89669 .08333 L
.89717 .08333 L
.89768 .08333 L
.89823 .08333 L
.8987 .08333 L
.89921 .08333 L
.89958 .08333 L
.89993 .08333 L
.9003 .08333 L
.9007 .08333 L
.90105 .08333 L
.90138 .08333 L
.90173 .08333 L
.90212 .08333 L
.90244 .08333 L
.90279 .08333 L
.90316 .08333 L
.9035 .08333 L
.90382 .08333 L
.90411 .08333 L
.90445 .08333 L
.90476 .08333 L
.90511 .08333 L
.90549 .08333 L
.90588 .08333 L
.90625 .08333 L
.90659 .08333 L
.90691 .08333 L
.90727 .08333 L
.90762 .08333 L
.90799 .08333 L
.90839 .08333 L
.90876 .08333 L
.9091 .08333 L
.9095 .08333 L
.90993 .08333 L
.91034 .08333 L
Mistroke
.91071 .08333 L
Mfstroke
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{570, 95},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.10365 .08333 L
.10409 .08333 L
.10459 .08333 L
.10506 .08333 L
.1055 .08333 L
.10591 .08333 L
.10635 .08333 L
.10682 .08333 L
.10729 .08333 L
.1078 .08333 L
.10828 .08333 L
.10872 .08333 L
.10924 .08333 L
.10953 .08333 L
.1098 .08333 L
.11029 .08333 L
.11082 .08333 L
.11108 .08333 L
.11136 .08333 L
.11186 .08333 L
.11214 .08333 L
.1124 .08333 L
.11269 .08333 L
.11299 .08333 L
.11326 .08333 L
.11354 .08333 L
.11407 .08333 L
.11457 .08333 L
.11504 .08333 L
.1155 .08333 L
.11593 .08333 L
.11639 .08333 L
.1169 .08333 L
.1174 .08333 L
.11793 .08333 L
.11838 .08333 L
.11887 .08333 L
.11916 .08333 L
.11943 .08333 L
.11972 .08333 L
.12003 .08333 L
.12055 .08333 L
.12084 .08333 L
.12112 .08333 L
.12164 .08333 L
.12211 .08333 L
.12236 .08333 L
.12265 .08333 L
.12316 .08333 L
Mistroke
.12347 .08333 L
.12377 .08333 L
.12403 .08333 L
.12431 .08333 L
.12462 .08333 L
.12495 .08333 L
.12523 .08333 L
.12554 .08333 L
.12583 .08333 L
.12609 .08333 L
.12639 .08333 L
.12668 .08333 L
.12719 .08333 L
.12748 .08333 L
.12774 .08333 L
.12822 .08333 L
.12873 .08333 L
.12921 .08333 L
.12965 .08333 L
.13014 .08333 L
.13067 .08333 L
.13094 .08333 L
.13123 .08333 L
.13175 .08333 L
.13203 .08333 L
.1323 .08333 L
.13259 .08333 L
.13289 .08333 L
.13341 .08333 L
.1337 .08333 L
.13398 .08333 L
.13448 .08333 L
.13495 .08333 L
.13549 .08333 L
.136 .08333 L
.13646 .08333 L
.13696 .08333 L
.13743 .08333 L
.13786 .08333 L
.13833 .08333 L
.13886 .08333 L
.13912 .08333 L
.1394 .08333 L
.13991 .08333 L
.14019 .08333 L
.14045 .08333 L
.14073 .08333 L
.14103 .08333 L
.14154 .08333 L
.14182 .08333 L
Mistroke
.14209 .08333 L
.14259 .08333 L
.14305 .08333 L
.14358 .08333 L
.14408 .08333 L
.14455 .08333 L
.14497 .08333 L
.14547 .08333 L
.14593 .08333 L
.14636 .08333 L
.14676 .08333 L
.1472 .08333 L
.14765 .08333 L
.14812 .08333 L
.14862 .08333 L
.14909 .08333 L
.14952 .08333 L
.15002 .08333 L
.1503 .08333 L
.15057 .08333 L
.15105 .08333 L
.15156 .08333 L
.15202 .08333 L
.15253 .08333 L
.15306 .08333 L
.15355 .08333 L
.15401 .08333 L
.15443 .08333 L
.15491 .08333 L
.15537 .08333 L
.15587 .08333 L
.1564 .08333 L
.15685 .08333 L
.15734 .08333 L
.15787 .08333 L
.15817 .08333 L
.15844 .08333 L
.15897 .08333 L
.15948 .08333 L
.15995 .08333 L
.16037 .08333 L
.16086 .08333 L
.16132 .08333 L
.16175 .08333 L
.16214 .08333 L
.16258 .08333 L
.16303 .08333 L
.16349 .08333 L
.16399 .08333 L
.16446 .08333 L
Mistroke
.16488 .08333 L
.16538 .08333 L
.16566 .08333 L
.16592 .08333 L
.1664 .08333 L
.16691 .08333 L
.1674 .08333 L
.16793 .08333 L
.16843 .08333 L
.1689 .08333 L
.16937 .08333 L
.16979 .08333 L
.17027 .08333 L
.17073 .08333 L
.17123 .08333 L
.17176 .08333 L
.17221 .08333 L
.1727 .08333 L
.17324 .08333 L
.17354 .08333 L
.17381 .08333 L
.17434 .08333 L
.17484 .08333 L
.17527 .08333 L
.17574 .08333 L
.17623 .08333 L
.17669 .08333 L
.17712 .08333 L
.17751 .08333 L
.17795 .08333 L
.1784 .08333 L
.17886 .08333 L
.17936 .08333 L
.17983 .08333 L
.18025 .08333 L
.18075 .08333 L
.18103 .08333 L
.18129 .08333 L
.18177 .08333 L
.18228 .08333 L
.18277 .08333 L
.1833 .08333 L
.18381 .08333 L
.18428 .08333 L
.18474 .08333 L
.18516 .08333 L
.18565 .08333 L
.18611 .08333 L
.18661 .08333 L
.18714 .08333 L
Mistroke
.18759 .08333 L
.18809 .08333 L
.18862 .08333 L
.18892 .08333 L
.18919 .08333 L
.18972 .08333 L
.19023 .08333 L
.19065 .08333 L
.19113 .08333 L
.19162 .08333 L
.19208 .08333 L
.19251 .08333 L
.1929 .08333 L
.19334 .08333 L
.19379 .08333 L
.19426 .08333 L
.19475 .08333 L
.19522 .08333 L
.19564 .08333 L
.19614 .08333 L
.19643 .08333 L
.19668 .08333 L
.19716 .08333 L
.19767 .08333 L
.19816 .08333 L
.1987 .08333 L
.19921 .08333 L
.19968 .08333 L
.2001 .08333 L
.20056 .08333 L
.20105 .08333 L
.20151 .08333 L
.20201 .08333 L
.20254 .08333 L
.203 .08333 L
.20349 .08333 L
.20403 .08333 L
.20433 .08333 L
.2046 .08333 L
.20513 .08333 L
.20563 .08333 L
.20606 .08333 L
.20653 .08333 L
.20703 .08333 L
.20749 .08333 L
.20792 .08333 L
.20832 .08333 L
.20877 .08333 L
.2092 .08333 L
.20967 .08333 L
Mistroke
.21016 .08333 L
.21063 .08333 L
.21106 .08333 L
.21156 .08333 L
.21184 .08333 L
.2121 .08333 L
.21257 .08333 L
.21308 .08333 L
.21357 .08333 L
.21385 .08333 L
.21411 .08333 L
.21459 .08333 L
.21509 .08333 L
.21554 .08333 L
.21597 .08333 L
.21643 .08333 L
.21693 .08333 L
.21743 .08333 L
.21772 .08333 L
.21798 .08333 L
.21852 .08333 L
.21881 .08333 L
.21909 .08333 L
.21957 .08333 L
.2201 .08333 L
.2206 .08333 L
.22106 .08333 L
.22149 .08333 L
.22195 .08333 L
.22239 .08333 L
.22278 .08333 L
.22325 .08333 L
.22376 .08333 L
.22424 .08333 L
.22468 .08333 L
.22518 .08333 L
.22565 .08333 L
.22608 .08333 L
.22654 .08333 L
.22704 .08333 L
.22757 .08333 L
.22802 .08333 L
.22851 .08333 L
.22904 .08333 L
.22954 .08333 L
.22979 .08333 L
.23008 .08333 L
.23037 .08333 L
.23065 .08333 L
.23116 .08333 L
Mistroke
.23162 .08333 L
.23216 .08333 L
.23267 .08333 L
.23313 .08333 L
.23361 .08333 L
.23407 .08333 L
.23448 .08333 L
.23497 .08333 L
.2355 .08333 L
.236 .08333 L
.23646 .08333 L
.23695 .08333 L
.23748 .08333 L
.23797 .08333 L
.23843 .08333 L
.23896 .08333 L
.23926 .08333 L
.23954 .08333 L
.24005 .08333 L
.24031 .08333 L
.24059 .08333 L
.24087 .08333 L
.24116 .08333 L
.24168 .08333 L
.24197 .08333 L
.24223 .08333 L
.24253 .08333 L
.24285 .08333 L
.24312 .08333 L
.24342 .08333 L
.2437 .08333 L
.24395 .08333 L
.24444 .08333 L
.24496 .08333 L
.24545 .08333 L
.24599 .08333 L
.24649 .08333 L
.24696 .08333 L
.24743 .08333 L
.24785 .08333 L
.24834 .08333 L
.24879 .08333 L
.24929 .08333 L
.24982 .08333 L
.25028 .08333 L
.25077 .08333 L
.2513 .08333 L
.2516 .08333 L
.25188 .08333 L
.25241 .08333 L
Mistroke
.25291 .08333 L
.25334 .08333 L
.25381 .08333 L
.2543 .08333 L
.25476 .08333 L
.25519 .08333 L
.25559 .08333 L
.25602 .08333 L
.25647 .08333 L
.25694 .08333 L
.25743 .08333 L
.2579 .08333 L
.25832 .08333 L
.25882 .08333 L
.25911 .08333 L
.25937 .08333 L
.25984 .08333 L
.26035 .08333 L
.26084 .08333 L
.26138 .08333 L
.26189 .08333 L
.26236 .08333 L
.26282 .08333 L
.26324 .08333 L
.26373 .08333 L
.26419 .08333 L
.26469 .08333 L
.26522 .08333 L
.26567 .08333 L
.26617 .08333 L
.26671 .08333 L
.26701 .08333 L
.26728 .08333 L
.26781 .08333 L
.26831 .08333 L
.26874 .08333 L
.26921 .08333 L
.2697 .08333 L
.27017 .08333 L
.2706 .08333 L
.27099 .08333 L
.27145 .08333 L
.27188 .08333 L
.27235 .08333 L
.27284 .08333 L
.27331 .08333 L
.27373 .08333 L
.27423 .08333 L
.27452 .08333 L
.27477 .08333 L
Mistroke
.27525 .08333 L
.27576 .08333 L
.27625 .08333 L
.27653 .08333 L
.27679 .08333 L
.27726 .08333 L
.27777 .08333 L
.27822 .08333 L
.27864 .08333 L
.27911 .08333 L
.27961 .08333 L
.28011 .08333 L
.28039 .08333 L
.28065 .08333 L
.28119 .08333 L
.28149 .08333 L
.28176 .08333 L
.28225 .08333 L
.28277 .08333 L
.28327 .08333 L
.28373 .08333 L
.28416 .08333 L
.28462 .08333 L
.28506 .08333 L
.28546 .08333 L
.28592 .08333 L
.28643 .08333 L
.28691 .08333 L
.28735 .08333 L
.28785 .08333 L
.28833 .08333 L
.28875 .08333 L
.28921 .08333 L
.28971 .08333 L
.29024 .08333 L
.29069 .08333 L
.29118 .08333 L
.29172 .08333 L
.29221 .08333 L
.29246 .08333 L
.29275 .08333 L
.29304 .08333 L
.29332 .08333 L
.29383 .08333 L
.29429 .08333 L
.2948 .08333 L
.29534 .08333 L
.29579 .08333 L
.29628 .08333 L
.29673 .08333 L
Mistroke
.29715 .08333 L
.29764 .08333 L
.29817 .08333 L
.29867 .08333 L
.29913 .08333 L
.29962 .08333 L
.30014 .08333 L
.30064 .08333 L
.3011 .08333 L
.30163 .08333 L
.30193 .08333 L
.30221 .08333 L
.30272 .08333 L
.30297 .08333 L
.30326 .08333 L
.30353 .08333 L
.30382 .08333 L
.30434 .08333 L
.30463 .08333 L
.3049 .08333 L
.3052 .08333 L
.30551 .08333 L
.30579 .08333 L
.30608 .08333 L
.30636 .08333 L
.30662 .08333 L
.30711 .08333 L
.30763 .08333 L
.30812 .08333 L
.30865 .08333 L
.30916 .08333 L
.30963 .08333 L
.31009 .08333 L
.31051 .08333 L
.311 .08333 L
.31146 .08333 L
.31196 .08333 L
.31249 .08333 L
.31294 .08333 L
.31343 .08333 L
.31397 .08333 L
.31427 .08333 L
.31454 .08333 L
.31507 .08333 L
.31557 .08333 L
.316 .08333 L
.31647 .08333 L
.31696 .08333 L
.31742 .08333 L
.31785 .08333 L
Mistroke
.31825 .08333 L
.31868 .08333 L
.31914 .08333 L
.3196 .08333 L
.32009 .08333 L
.32056 .08333 L
.32099 .08333 L
.32149 .08333 L
.32177 .08333 L
.32203 .08333 L
.3225 .08333 L
.32301 .08333 L
.3235 .08333 L
.32404 .08333 L
.32455 .08333 L
.32502 .08333 L
.32548 .08333 L
.3259 .08333 L
.32639 .08333 L
.32685 .08333 L
.32735 .08333 L
.32788 .08333 L
.32833 .08333 L
.32883 .08333 L
.32936 .08333 L
.32966 .08333 L
.32994 .08333 L
.33047 .08333 L
.33097 .08333 L
.3314 .08333 L
.33187 .08333 L
.33236 .08333 L
.33282 .08333 L
.33325 .08333 L
.33365 .08333 L
.3341 .08333 L
.33454 .08333 L
.335 .08333 L
.3355 .08333 L
.33597 .08333 L
.33639 .08333 L
.33689 .08333 L
.33717 .08333 L
.33743 .08333 L
.33791 .08333 L
.33841 .08333 L
.33891 .08333 L
.33919 .08333 L
.33945 .08333 L
.33992 .08333 L
Mistroke
.34042 .08333 L
.34087 .08333 L
.3413 .08333 L
.34176 .08333 L
.34226 .08333 L
.34276 .08333 L
.34304 .08333 L
.34331 .08333 L
.34384 .08333 L
.34414 .08333 L
.34441 .08333 L
.3449 .08333 L
.34543 .08333 L
.34593 .08333 L
.34639 .08333 L
.34682 .08333 L
.34728 .08333 L
.34771 .08333 L
.34811 .08333 L
.34857 .08333 L
.34908 .08333 L
.34956 .08333 L
.35 .08333 L
.35051 .08333 L
.35098 .08333 L
.3514 .08333 L
.35186 .08333 L
.35236 .08333 L
.35289 .08333 L
.35334 .08333 L
.35384 .08333 L
.35437 .08333 L
.35486 .08333 L
.35511 .08333 L
.3554 .08333 L
.35569 .08333 L
.35597 .08333 L
.35648 .08333 L
.35694 .08333 L
.35745 .08333 L
.35799 .08333 L
.35844 .08333 L
.35893 .08333 L
.35938 .08333 L
.3598 .08333 L
.36029 .08333 L
.36081 .08333 L
.36131 .08333 L
.36177 .08333 L
.36226 .08333 L
Mistroke
.36279 .08333 L
.36329 .08333 L
.36374 .08333 L
.36427 .08333 L
.36457 .08333 L
.36485 .08333 L
.36536 .08333 L
.36562 .08333 L
.36591 .08333 L
.36618 .08333 L
.36647 .08333 L
.36699 .08333 L
.36728 .08333 L
.36755 .08333 L
.36784 .08333 L
.36816 .08333 L
.36843 .08333 L
.36873 .08333 L
.36901 .08333 L
.36927 .08333 L
.36976 .08333 L
.37028 .08333 L
.37077 .08333 L
.3713 .08333 L
.3718 .08333 L
.37227 .08333 L
.37274 .08333 L
.37316 .08333 L
.37364 .08333 L
.3741 .08333 L
.3746 .08333 L
.37513 .08333 L
.37558 .08333 L
.37608 .08333 L
.37661 .08333 L
.37691 .08333 L
.37718 .08333 L
.37771 .08333 L
.37822 .08333 L
.37864 .08333 L
.37911 .08333 L
.3796 .08333 L
.38007 .08333 L
.3805 .08333 L
.38089 .08333 L
.38132 .08333 L
.38178 .08333 L
.38224 .08333 L
.38274 .08333 L
.3832 .08333 L
Mistroke
.38363 .08333 L
.38413 .08333 L
.38441 .08333 L
.38467 .08333 L
.38515 .08333 L
.38565 .08333 L
.38614 .08333 L
.38668 .08333 L
.38719 .08333 L
.38766 .08333 L
.38812 .08333 L
.38854 .08333 L
.38903 .08333 L
.38949 .08333 L
.38999 .08333 L
.39052 .08333 L
.39097 .08333 L
.39147 .08333 L
.392 .08333 L
.3923 .08333 L
.39257 .08333 L
.3931 .08333 L
.39361 .08333 L
.39403 .08333 L
.39451 .08333 L
.395 .08333 L
.39546 .08333 L
.39589 .08333 L
.39629 .08333 L
.39672 .08333 L
.39717 .08333 L
.39764 .08333 L
.39813 .08333 L
.3986 .08333 L
.39903 .08333 L
.39953 .08333 L
.39981 .08333 L
.40007 .08333 L
.40054 .08333 L
.40105 .08333 L
.40154 .08333 L
.40182 .08333 L
.40208 .08333 L
.40256 .08333 L
.40306 .08333 L
.40351 .08333 L
.40393 .08333 L
.40439 .08333 L
.40489 .08333 L
.40539 .08333 L
Mistroke
.40568 .08333 L
.40594 .08333 L
.40648 .08333 L
.40677 .08333 L
.40705 .08333 L
.40753 .08333 L
.40806 .08333 L
.40856 .08333 L
.40902 .08333 L
.40945 .08333 L
.40991 .08333 L
.41034 .08333 L
.41074 .08333 L
.41121 .08333 L
.41171 .08333 L
.41219 .08333 L
.41264 .08333 L
.41314 .08333 L
.41361 .08333 L
.41403 .08333 L
.41449 .08333 L
.41499 .08333 L
.41552 .08333 L
.41597 .08333 L
.41647 .08333 L
.417 .08333 L
.41749 .08333 L
.41774 .08333 L
.41803 .08333 L
.41832 .08333 L
.4186 .08333 L
.41911 .08333 L
.41957 .08333 L
.42008 .08333 L
.42062 .08333 L
.42107 .08333 L
.42155 .08333 L
.42201 .08333 L
.42243 .08333 L
.42291 .08333 L
.42344 .08333 L
.42394 .08333 L
.4244 .08333 L
.42489 .08333 L
.42542 .08333 L
.42592 .08333 L
.42637 .08333 L
.4269 .08333 L
.4272 .08333 L
.42748 .08333 L
Mistroke
.42799 .08333 L
.42827 .08333 L
.42853 .08333 L
.42881 .08333 L
.4291 .08333 L
.42962 .08333 L
.4299 .08333 L
.43017 .08333 L
.43047 .08333 L
.43078 .08333 L
.43106 .08333 L
.43135 .08333 L
.43163 .08333 L
.43189 .08333 L
.43238 .08333 L
.4329 .08333 L
.43339 .08333 L
.43393 .08333 L
.43443 .08333 L
.4349 .08333 L
.43536 .08333 L
.43578 .08333 L
.43627 .08333 L
.43673 .08333 L
.43723 .08333 L
.43775 .08333 L
.43821 .08333 L
.4387 .08333 L
.43923 .08333 L
.43953 .08333 L
.43981 .08333 L
.44034 .08333 L
.44084 .08333 L
.44126 .08333 L
.44173 .08333 L
.44223 .08333 L
.44269 .08333 L
.44312 .08333 L
.44351 .08333 L
.44394 .08333 L
.4444 .08333 L
.44486 .08333 L
.44536 .08333 L
.44582 .08333 L
.44625 .08333 L
.44675 .08333 L
.44703 .08333 L
.44729 .08333 L
.44777 .08333 L
.44827 .08333 L
Mistroke
.44876 .08333 L
.4493 .08333 L
.44981 .08333 L
.45028 .08333 L
.45074 .08333 L
.45116 .08333 L
.45165 .08333 L
.45211 .08333 L
.45261 .08333 L
.45314 .08333 L
.45359 .08333 L
.45409 .08333 L
.45462 .08333 L
.45492 .08333 L
.45519 .08333 L
.45572 .08333 L
.45622 .08333 L
.45665 .08333 L
.45712 .08333 L
.45762 .08333 L
.45808 .08333 L
.45851 .08333 L
.4589 .08333 L
.45934 .08333 L
.45979 .08333 L
.46025 .08333 L
.46075 .08333 L
.46122 .08333 L
.46164 .08333 L
.46214 .08333 L
.46242 .08333 L
.46268 .08333 L
.46316 .08333 L
.46367 .08333 L
.46416 .08333 L
.46444 .08333 L
.4647 .08333 L
.46517 .08333 L
.46567 .08333 L
.46612 .08333 L
.46655 .08333 L
.46701 .08333 L
.46751 .08333 L
.46801 .08333 L
.46829 .08333 L
.46856 .08333 L
.46909 .08333 L
.46939 .08333 L
.46966 .08333 L
.47015 .08333 L
Mistroke
.47067 .08333 L
.47117 .08333 L
.47163 .08333 L
.47206 .08333 L
.47252 .08333 L
.47296 .08333 L
.47335 .08333 L
.47382 .08333 L
.47432 .08333 L
.4748 .08333 L
.47525 .08333 L
.47575 .08333 L
.47622 .08333 L
.47664 .08333 L
.4771 .08333 L
.4776 .08333 L
.47813 .08333 L
.47858 .08333 L
.47908 .08333 L
.47944 .08333 L
.47977 .08333 L
.48013 .08333 L
.48052 .08333 L
.48085 .08333 L
.48117 .08333 L
.48151 .08333 L
.48188 .08333 L
.48219 .08333 L
.48253 .08333 L
.48289 .08333 L
.48321 .08333 L
.48352 .08333 L
.48381 .08333 L
.48413 .08333 L
.48444 .08333 L
.48477 .08333 L
.48513 .08333 L
.48551 .08333 L
.48587 .08333 L
.4862 .08333 L
.48651 .08333 L
.48686 .08333 L
.48719 .08333 L
.48755 .08333 L
.48793 .08333 L
.4883 .08333 L
.48862 .08333 L
.48901 .08333 L
.48942 .08333 L
.48982 .08333 L
Mistroke
.49018 .08333 L
Mfstroke
.49018 .08333 m
.49066 .08333 L
.49111 .08333 L
.49161 .08333 L
.4921 .08333 L
.49254 .08333 L
.49295 .08333 L
.4934 .08333 L
.49388 .08333 L
.49436 .08333 L
.49488 .08333 L
.49537 .08333 L
.49581 .08333 L
.49633 .08333 L
.49663 .08333 L
.4969 .08333 L
.4974 .08333 L
.49794 .08333 L
.4982 .08333 L
.49849 .08333 L
.499 .08333 L
.49928 .08333 L
.49954 .08333 L
.49983 .08333 L
.50014 .08333 L
.50041 .08333 L
.5007 .08333 L
.50123 .08333 L
.50175 .08333 L
.50222 .08333 L
.50269 .08333 L
.50312 .08333 L
.5036 .08333 L
.50411 .08333 L
.50462 .08333 L
.50515 .08333 L
.50561 .08333 L
.50611 .08333 L
.50641 .08333 L
.50668 .08333 L
.50697 .08333 L
.50729 .08333 L
.50781 .08333 L
.50811 .08333 L
.50839 .08333 L
.50892 .08333 L
.50939 .08333 L
.50966 .08333 L
.50994 .08333 L
.51046 .08333 L
Mistroke
.51078 .08333 L
.51108 .08333 L
.51135 .08333 L
.51163 .08333 L
.51195 .08333 L
.51228 .08333 L
.51257 .08333 L
.51288 .08333 L
.51317 .08333 L
.51344 .08333 L
.51374 .08333 L
.51404 .08333 L
.51455 .08333 L
.51484 .08333 L
.51511 .08333 L
.51559 .08333 L
.51611 .08333 L
.5166 .08333 L
.51705 .08333 L
.51754 .08333 L
.51809 .08333 L
.51836 .08333 L
.51865 .08333 L
.51918 .08333 L
.51947 .08333 L
.51974 .08333 L
.52003 .08333 L
.52034 .08333 L
.52086 .08333 L
.52116 .08333 L
.52144 .08333 L
.52196 .08333 L
.52243 .08333 L
.52297 .08333 L
.52349 .08333 L
.52396 .08333 L
.52446 .08333 L
.52494 .08333 L
.52538 .08333 L
.52586 .08333 L
.52639 .08333 L
.52666 .08333 L
.52695 .08333 L
.52746 .08333 L
.52775 .08333 L
.52801 .08333 L
.5283 .08333 L
.5286 .08333 L
.52911 .08333 L
.5294 .08333 L
Mistroke
.52968 .08333 L
.53018 .08333 L
.53065 .08333 L
.53118 .08333 L
.53169 .08333 L
.53217 .08333 L
.5326 .08333 L
.5331 .08333 L
.53357 .08333 L
.53401 .08333 L
.53441 .08333 L
.53485 .08333 L
.53532 .08333 L
.53579 .08333 L
.5363 .08333 L
.53678 .08333 L
.53721 .08333 L
.53772 .08333 L
.53801 .08333 L
.53827 .08333 L
.53876 .08333 L
.53928 .08333 L
.53975 .08333 L
.54027 .08333 L
.5408 .08333 L
.5413 .08333 L
.54177 .08333 L
.5422 .08333 L
.54269 .08333 L
.54315 .08333 L
.54366 .08333 L
.54419 .08333 L
.54465 .08333 L
.54515 .08333 L
.54569 .08333 L
.54599 .08333 L
.54627 .08333 L
.54681 .08333 L
.54732 .08333 L
.5478 .08333 L
.54823 .08333 L
.54872 .08333 L
.54919 .08333 L
.54963 .08333 L
.55003 .08333 L
.55046 .08333 L
.55093 .08333 L
.5514 .08333 L
.5519 .08333 L
.55237 .08333 L
Mistroke
.5528 .08333 L
.55331 .08333 L
.5536 .08333 L
.55386 .08333 L
.55435 .08333 L
.55486 .08333 L
.55536 .08333 L
.5559 .08333 L
.55641 .08333 L
.55688 .08333 L
.55735 .08333 L
.55778 .08333 L
.55827 .08333 L
.55874 .08333 L
.55925 .08333 L
.55978 .08333 L
.56024 .08333 L
.56074 .08333 L
.56128 .08333 L
.56159 .08333 L
.56186 .08333 L
.5624 .08333 L
.56291 .08333 L
.56334 .08333 L
.56382 .08333 L
.56432 .08333 L
.56479 .08333 L
.56522 .08333 L
.56562 .08333 L
.56606 .08333 L
.56653 .08333 L
.567 .08333 L
.5675 .08333 L
.56797 .08333 L
.5684 .08333 L
.56891 .08333 L
.5692 .08333 L
.56946 .08333 L
.56994 .08333 L
.57046 .08333 L
.57096 .08333 L
.5715 .08333 L
.57201 .08333 L
.57249 .08333 L
.57296 .08333 L
.57339 .08333 L
.57388 .08333 L
.57435 .08333 L
.57486 .08333 L
.57539 .08333 L
Mistroke
.57585 .08333 L
.57635 .08333 L
.5769 .08333 L
.5772 .08333 L
.57748 .08333 L
.57802 .08333 L
.57853 .08333 L
.57896 .08333 L
.57944 .08333 L
.57994 .08333 L
.58041 .08333 L
.58084 .08333 L
.58124 .08333 L
.58168 .08333 L
.58214 .08333 L
.58262 .08333 L
.58312 .08333 L
.58359 .08333 L
.58402 .08333 L
.58453 .08333 L
.58482 .08333 L
.58508 .08333 L
.58556 .08333 L
.58608 .08333 L
.58658 .08333 L
.58712 .08333 L
.58764 .08333 L
.58812 .08333 L
.58854 .08333 L
.58902 .08333 L
.58951 .08333 L
.58998 .08333 L
.59049 .08333 L
.59103 .08333 L
.59149 .08333 L
.59199 .08333 L
.59253 .08333 L
.59284 .08333 L
.59311 .08333 L
.59365 .08333 L
.59416 .08333 L
.5946 .08333 L
.59508 .08333 L
.59558 .08333 L
.59605 .08333 L
.59648 .08333 L
.59688 .08333 L
.59735 .08333 L
.59779 .08333 L
.59826 .08333 L
Mistroke
.59876 .08333 L
.59924 .08333 L
.59967 .08333 L
.60017 .08333 L
.60046 .08333 L
.60072 .08333 L
.60121 .08333 L
.60172 .08333 L
.60222 .08333 L
.60251 .08333 L
.60277 .08333 L
.60325 .08333 L
.60376 .08333 L
.60422 .08333 L
.60465 .08333 L
.60512 .08333 L
.60563 .08333 L
.60614 .08333 L
.60642 .08333 L
.60669 .08333 L
.60724 .08333 L
.60754 .08333 L
.60781 .08333 L
.60831 .08333 L
.60885 .08333 L
.60935 .08333 L
.60982 .08333 L
.61025 .08333 L
.61072 .08333 L
.61116 .08333 L
.61157 .08333 L
.61204 .08333 L
.61256 .08333 L
.61304 .08333 L
.61349 .08333 L
.614 .08333 L
.61448 .08333 L
.61491 .08333 L
.61538 .08333 L
.61588 .08333 L
.61642 .08333 L
.61688 .08333 L
.61738 .08333 L
.61792 .08333 L
.61842 .08333 L
.61868 .08333 L
.61897 .08333 L
.61927 .08333 L
.61955 .08333 L
.62007 .08333 L
Mistroke
.62054 .08333 L
.62108 .08333 L
.6216 .08333 L
.62206 .08333 L
.62255 .08333 L
.62302 .08333 L
.62344 .08333 L
.62393 .08333 L
.62447 .08333 L
.62498 .08333 L
.62544 .08333 L
.62594 .08333 L
.62648 .08333 L
.62698 .08333 L
.62744 .08333 L
.62798 .08333 L
.62829 .08333 L
.62857 .08333 L
.62909 .08333 L
.62935 .08333 L
.62964 .08333 L
.62992 .08333 L
.63021 .08333 L
.63074 .08333 L
.63103 .08333 L
.63131 .08333 L
.63161 .08333 L
.63193 .08333 L
.6322 .08333 L
.63251 .08333 L
.63279 .08333 L
.63305 .08333 L
.63355 .08333 L
.63408 .08333 L
.63457 .08333 L
.63512 .08333 L
.63563 .08333 L
.63611 .08333 L
.63658 .08333 L
.637 .08333 L
.6375 .08333 L
.63796 .08333 L
.63847 .08333 L
.63901 .08333 L
.63947 .08333 L
.63997 .08333 L
.64051 .08333 L
.64082 .08333 L
.64109 .08333 L
.64163 .08333 L
Mistroke
.64214 .08333 L
.64257 .08333 L
.64305 .08333 L
.64355 .08333 L
.64402 .08333 L
.64446 .08333 L
.64486 .08333 L
.6453 .08333 L
.64576 .08333 L
.64623 .08333 L
.64673 .08333 L
.64721 .08333 L
.64764 .08333 L
.64814 .08333 L
.64843 .08333 L
.64869 .08333 L
.64918 .08333 L
.64969 .08333 L
.65019 .08333 L
.65074 .08333 L
.65125 .08333 L
.65173 .08333 L
.6522 .08333 L
.65263 .08333 L
.65312 .08333 L
.65359 .08333 L
.6541 .08333 L
.65464 .08333 L
.6551 .08333 L
.6556 .08333 L
.65614 .08333 L
.65645 .08333 L
.65672 .08333 L
.65726 .08333 L
.65777 .08333 L
.65821 .08333 L
.65869 .08333 L
.65919 .08333 L
.65965 .08333 L
.66009 .08333 L
.66049 .08333 L
.66095 .08333 L
.66139 .08333 L
.66187 .08333 L
.66237 .08333 L
.66284 .08333 L
.66327 .08333 L
.66378 .08333 L
.66407 .08333 L
.66433 .08333 L
Mistroke
.66481 .08333 L
.66533 .08333 L
.66583 .08333 L
.66611 .08333 L
.66638 .08333 L
.66686 .08333 L
.66737 .08333 L
.66783 .08333 L
.66826 .08333 L
.66873 .08333 L
.66923 .08333 L
.66974 .08333 L
.67003 .08333 L
.6703 .08333 L
.67084 .08333 L
.67114 .08333 L
.67142 .08333 L
.67191 .08333 L
.67245 .08333 L
.67296 .08333 L
.67342 .08333 L
.67386 .08333 L
.67433 .08333 L
.67477 .08333 L
.67517 .08333 L
.67564 .08333 L
.67616 .08333 L
.67664 .08333 L
.6771 .08333 L
.6776 .08333 L
.67808 .08333 L
.67851 .08333 L
.67898 .08333 L
.67949 .08333 L
.68002 .08333 L
.68048 .08333 L
.68098 .08333 L
.68152 .08333 L
.68202 .08333 L
.68228 .08333 L
.68257 .08333 L
.68287 .08333 L
.68315 .08333 L
.68367 .08333 L
.68414 .08333 L
.68466 .08333 L
.6852 .08333 L
.68566 .08333 L
.68615 .08333 L
.68662 .08333 L
Mistroke
.68704 .08333 L
.68753 .08333 L
.68807 .08333 L
.68858 .08333 L
.68904 .08333 L
.68954 .08333 L
.69008 .08333 L
.69058 .08333 L
.69104 .08333 L
.69158 .08333 L
.69189 .08333 L
.69217 .08333 L
.69269 .08333 L
.69295 .08333 L
.69324 .08333 L
.69352 .08333 L
.69381 .08333 L
.69434 .08333 L
.69463 .08333 L
.6949 .08333 L
.6952 .08333 L
.69552 .08333 L
.6958 .08333 L
.6961 .08333 L
.69639 .08333 L
.69665 .08333 L
.69715 .08333 L
.69767 .08333 L
.69817 .08333 L
.69871 .08333 L
.69923 .08333 L
.6997 .08333 L
.70017 .08333 L
.7006 .08333 L
.70109 .08333 L
.70156 .08333 L
.70207 .08333 L
.7026 .08333 L
.70306 .08333 L
.70356 .08333 L
.70411 .08333 L
.70441 .08333 L
.70469 .08333 L
.70523 .08333 L
.70573 .08333 L
.70617 .08333 L
.70665 .08333 L
.70714 .08333 L
.70761 .08333 L
.70805 .08333 L
Mistroke
.70845 .08333 L
.70889 .08333 L
.70935 .08333 L
.70982 .08333 L
.71032 .08333 L
.7108 .08333 L
.71123 .08333 L
.71174 .08333 L
.71202 .08333 L
.71229 .08333 L
.71277 .08333 L
.71328 .08333 L
.71378 .08333 L
.71433 .08333 L
.71484 .08333 L
.71532 .08333 L
.71579 .08333 L
.71622 .08333 L
.71671 .08333 L
.71718 .08333 L
.71769 .08333 L
.71823 .08333 L
.71869 .08333 L
.71919 .08333 L
.71973 .08333 L
.72004 .08333 L
.72031 .08333 L
.72085 .08333 L
.72136 .08333 L
.72179 .08333 L
.72227 .08333 L
.72277 .08333 L
.72324 .08333 L
.72368 .08333 L
.72408 .08333 L
.72454 .08333 L
.72498 .08333 L
.72545 .08333 L
.72596 .08333 L
.72643 .08333 L
.72686 .08333 L
.72737 .08333 L
.72765 .08333 L
.72792 .08333 L
.7284 .08333 L
.72891 .08333 L
.72942 .08333 L
.7297 .08333 L
.72996 .08333 L
.73044 .08333 L
Mistroke
.73096 .08333 L
.73141 .08333 L
.73184 .08333 L
.73231 .08333 L
.73282 .08333 L
.73333 .08333 L
.73361 .08333 L
.73388 .08333 L
.73442 .08333 L
.73473 .08333 L
.735 .08333 L
.7355 .08333 L
.73603 .08333 L
.73654 .08333 L
.73701 .08333 L
.73744 .08333 L
.73791 .08333 L
.73835 .08333 L
.73875 .08333 L
.73923 .08333 L
.73974 .08333 L
.74023 .08333 L
.74068 .08333 L
.74119 .08333 L
.74167 .08333 L
.7421 .08333 L
.74256 .08333 L
.74307 .08333 L
.74361 .08333 L
.74406 .08333 L
.74457 .08333 L
.74511 .08333 L
.7456 .08333 L
.74586 .08333 L
.74615 .08333 L
.74645 .08333 L
.74673 .08333 L
.74725 .08333 L
.74772 .08333 L
.74824 .08333 L
.74878 .08333 L
.74924 .08333 L
.74973 .08333 L
.7502 .08333 L
.75062 .08333 L
.75111 .08333 L
.75165 .08333 L
.75216 .08333 L
.75262 .08333 L
.75312 .08333 L
Mistroke
.75366 .08333 L
.75416 .08333 L
.75462 .08333 L
.75516 .08333 L
.75546 .08333 L
.75575 .08333 L
.75627 .08333 L
.75653 .08333 L
.75682 .08333 L
.7571 .08333 L
.75739 .08333 L
.75792 .08333 L
.75821 .08333 L
.75848 .08333 L
.75878 .08333 L
.7591 .08333 L
.75938 .08333 L
.75968 .08333 L
.75997 .08333 L
.76023 .08333 L
.76072 .08333 L
.76125 .08333 L
.76175 .08333 L
.76229 .08333 L
.7628 .08333 L
.76328 .08333 L
.76375 .08333 L
.76418 .08333 L
.76467 .08333 L
.76513 .08333 L
.76564 .08333 L
.76618 .08333 L
.76664 .08333 L
.76714 .08333 L
.76768 .08333 L
.76798 .08333 L
.76826 .08333 L
.7688 .08333 L
.76931 .08333 L
.76974 .08333 L
.77022 .08333 L
.77072 .08333 L
.77119 .08333 L
.77162 .08333 L
.77202 .08333 L
.77246 .08333 L
.77292 .08333 L
.77339 .08333 L
.7739 .08333 L
.77437 .08333 L
Mistroke
.7748 .08333 L
.77531 .08333 L
.77559 .08333 L
.77586 .08333 L
.77634 .08333 L
.77686 .08333 L
.77736 .08333 L
.7779 .08333 L
.77841 .08333 L
.77889 .08333 L
.77936 .08333 L
.77979 .08333 L
.78028 .08333 L
.78075 .08333 L
.78126 .08333 L
.7818 .08333 L
.78225 .08333 L
.78276 .08333 L
.7833 .08333 L
.7836 .08333 L
.78388 .08333 L
.78442 .08333 L
.78493 .08333 L
.78536 .08333 L
.78584 .08333 L
.78634 .08333 L
.78681 .08333 L
.78725 .08333 L
.78765 .08333 L
.78809 .08333 L
.78855 .08333 L
.78902 .08333 L
.78952 .08333 L
.79 .08333 L
.79043 .08333 L
.79094 .08333 L
.79122 .08333 L
.79149 .08333 L
.79197 .08333 L
.79248 .08333 L
.79298 .08333 L
.79327 .08333 L
.79353 .08333 L
.79401 .08333 L
.79452 .08333 L
.79498 .08333 L
.79541 .08333 L
.79588 .08333 L
.79638 .08333 L
.79689 .08333 L
Mistroke
.79718 .08333 L
.79745 .08333 L
.79799 .08333 L
.79829 .08333 L
.79857 .08333 L
.79906 .08333 L
.7996 .08333 L
.8001 .08333 L
.80057 .08333 L
.80101 .08333 L
.80147 .08333 L
.80191 .08333 L
.80232 .08333 L
.80279 .08333 L
.8033 .08333 L
.80379 .08333 L
.80424 .08333 L
.80475 .08333 L
.80523 .08333 L
.80566 .08333 L
.80612 .08333 L
.80663 .08333 L
.80717 .08333 L
.80763 .08333 L
.80813 .08333 L
.80867 .08333 L
.80917 .08333 L
.80943 .08333 L
.80971 .08333 L
.81001 .08333 L
.81029 .08333 L
.81081 .08333 L
.81128 .08333 L
.8118 .08333 L
.81234 .08333 L
.8128 .08333 L
.81329 .08333 L
.81376 .08333 L
.81418 .08333 L
.81467 .08333 L
.81521 .08333 L
.81571 .08333 L
.81618 .08333 L
.81668 .08333 L
.81721 .08333 L
.81772 .08333 L
.81818 .08333 L
.81872 .08333 L
.81902 .08333 L
.8193 .08333 L
Mistroke
.81982 .08333 L
.82011 .08333 L
.82037 .08333 L
.82065 .08333 L
.82095 .08333 L
.82147 .08333 L
.82177 .08333 L
.82204 .08333 L
.82234 .08333 L
.82266 .08333 L
.82294 .08333 L
.82324 .08333 L
.82352 .08333 L
.82378 .08333 L
.82428 .08333 L
.82481 .08333 L
.82531 .08333 L
.82585 .08333 L
.82636 .08333 L
.82683 .08333 L
.82731 .08333 L
.82773 .08333 L
.82822 .08333 L
.82869 .08333 L
.8292 .08333 L
.82973 .08333 L
.83019 .08333 L
.83069 .08333 L
.83123 .08333 L
.83154 .08333 L
.83181 .08333 L
.83235 .08333 L
.83286 .08333 L
.83329 .08333 L
.83377 .08333 L
.83427 .08333 L
.83474 .08333 L
.83518 .08333 L
.83557 .08333 L
.83601 .08333 L
.83648 .08333 L
.83695 .08333 L
.83745 .08333 L
.83792 .08333 L
.83835 .08333 L
.83886 .08333 L
.83915 .08333 L
.83941 .08333 L
.8399 .08333 L
.84041 .08333 L
Mistroke
.84091 .08333 L
.84145 .08333 L
.84196 .08333 L
.84244 .08333 L
.84291 .08333 L
.84334 .08333 L
.84383 .08333 L
.8443 .08333 L
.84481 .08333 L
.84534 .08333 L
.8458 .08333 L
.84631 .08333 L
.84685 .08333 L
.84715 .08333 L
.84743 .08333 L
.84797 .08333 L
.84848 .08333 L
.84891 .08333 L
.84939 .08333 L
.84989 .08333 L
.85036 .08333 L
.8508 .08333 L
.8512 .08333 L
.85163 .08333 L
.8521 .08333 L
.85257 .08333 L
.85307 .08333 L
.85354 .08333 L
.85398 .08333 L
.85448 .08333 L
.85477 .08333 L
.85503 .08333 L
.85552 .08333 L
.85603 .08333 L
.85653 .08333 L
.85681 .08333 L
.85708 .08333 L
.85756 .08333 L
.85807 .08333 L
.85852 .08333 L
.85895 .08333 L
.85942 .08333 L
.85993 .08333 L
.86044 .08333 L
.86072 .08333 L
.86099 .08333 L
.86153 .08333 L
.86184 .08333 L
.86211 .08333 L
.86261 .08333 L
Mistroke
.86314 .08333 L
.86365 .08333 L
.86411 .08333 L
.86455 .08333 L
.86502 .08333 L
.86546 .08333 L
.86586 .08333 L
.86633 .08333 L
.86685 .08333 L
.86733 .08333 L
.86778 .08333 L
.86829 .08333 L
.86877 .08333 L
.8692 .08333 L
.86967 .08333 L
.87017 .08333 L
.87071 .08333 L
.87117 .08333 L
.87167 .08333 L
.87203 .08333 L
.87237 .08333 L
.87274 .08333 L
.87313 .08333 L
.87347 .08333 L
.87379 .08333 L
.87414 .08333 L
.87452 .08333 L
.87483 .08333 L
.87518 .08333 L
.87553 .08333 L
.87587 .08333 L
.87618 .08333 L
.87647 .08333 L
.8768 .08333 L
.87711 .08333 L
.87745 .08333 L
.87782 .08333 L
.8782 .08333 L
.87856 .08333 L
.8789 .08333 L
.87921 .08333 L
.87957 .08333 L
.87991 .08333 L
.88027 .08333 L
.88066 .08333 L
.88103 .08333 L
.88136 .08333 L
.88175 .08333 L
.88217 .08333 L
.88257 .08333 L
Mistroke
.88294 .08333 L
Mfstroke
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{570, 95},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.10363 .08333 L
.10405 .08333 L
.10453 .08333 L
.10499 .08333 L
.10541 .08333 L
.10579 .08333 L
.10622 .08333 L
.10667 .08333 L
.10713 .08333 L
.10761 .08333 L
.10807 .08333 L
.1085 .08333 L
.10899 .08333 L
.10927 .08333 L
.10952 .08333 L
.11 .08333 L
.1105 .08333 L
.11076 .08333 L
.11103 .08333 L
.11151 .08333 L
.11177 .08333 L
.11202 .08333 L
.1123 .08333 L
.11259 .08333 L
.11284 .08333 L
.11312 .08333 L
.11362 .08333 L
.11411 .08333 L
.11456 .08333 L
.11499 .08333 L
.1154 .08333 L
.11585 .08333 L
.11634 .08333 L
.11682 .08333 L
.11732 .08333 L
.11776 .08333 L
.11823 .08333 L
.11851 .08333 L
.11876 .08333 L
.11904 .08333 L
.11934 .08333 L
.11984 .08333 L
.12012 .08333 L
.12038 .08333 L
.12088 .08333 L
.12133 .08333 L
.12158 .08333 L
.12185 .08333 L
.12234 .08333 L
Mistroke
.12264 .08333 L
.12292 .08333 L
.12317 .08333 L
.12345 .08333 L
.12374 .08333 L
.12406 .08333 L
.12433 .08333 L
.12462 .08333 L
.1249 .08333 L
.12515 .08333 L
.12544 .08333 L
.12572 .08333 L
.1262 .08333 L
.12648 .08333 L
.12674 .08333 L
.12719 .08333 L
.12768 .08333 L
.12814 .08333 L
.12856 .08333 L
.12903 .08333 L
.12954 .08333 L
.1298 .08333 L
.13008 .08333 L
.13057 .08333 L
.13085 .08333 L
.1311 .08333 L
.13138 .08333 L
.13167 .08333 L
.13217 .08333 L
.13245 .08333 L
.13271 .08333 L
.1332 .08333 L
.13365 .08333 L
.13416 .08333 L
.13465 .08333 L
.13509 .08333 L
.13557 .08333 L
.13602 .08333 L
.13643 .08333 L
.13689 .08333 L
.13739 .08333 L
.13765 .08333 L
.13792 .08333 L
.1384 .08333 L
.13867 .08333 L
.13892 .08333 L
.13919 .08333 L
.13948 .08333 L
.13996 .08333 L
.14024 .08333 L
Mistroke
.1405 .08333 L
.14097 .08333 L
.14141 .08333 L
.14192 .08333 L
.1424 .08333 L
.14285 .08333 L
.14326 .08333 L
.14373 .08333 L
.14418 .08333 L
.14459 .08333 L
.14497 .08333 L
.14539 .08333 L
.14583 .08333 L
.14627 .08333 L
.14675 .08333 L
.1472 .08333 L
.14761 .08333 L
.1481 .08333 L
.14837 .08333 L
.14862 .08333 L
.14908 .08333 L
.14957 .08333 L
.15002 .08333 L
.1505 .08333 L
.15101 .08333 L
.15148 .08333 L
.15192 .08333 L
.15232 .08333 L
.15279 .08333 L
.15323 .08333 L
.1537 .08333 L
.15421 .08333 L
.15464 .08333 L
.15512 .08333 L
.15563 .08333 L
.15591 .08333 L
.15618 .08333 L
.15668 .08333 L
.15717 .08333 L
.15762 .08333 L
.15802 .08333 L
.15849 .08333 L
.15893 .08333 L
.15935 .08333 L
.15972 .08333 L
.16014 .08333 L
.16057 .08333 L
.16102 .08333 L
.16149 .08333 L
.16194 .08333 L
Mistroke
.16235 .08333 L
.16283 .08333 L
.1631 .08333 L
.16335 .08333 L
.1638 .08333 L
.16429 .08333 L
.16476 .08333 L
.16527 .08333 L
.16575 .08333 L
.1662 .08333 L
.16665 .08333 L
.16705 .08333 L
.16752 .08333 L
.16795 .08333 L
.16843 .08333 L
.16894 .08333 L
.16937 .08333 L
.16985 .08333 L
.17036 .08333 L
.17065 .08333 L
.17091 .08333 L
.17142 .08333 L
.1719 .08333 L
.17231 .08333 L
.17276 .08333 L
.17323 .08333 L
.17367 .08333 L
.17408 .08333 L
.17446 .08333 L
.17488 .08333 L
.17531 .08333 L
.17576 .08333 L
.17623 .08333 L
.17668 .08333 L
.17709 .08333 L
.17757 .08333 L
.17784 .08333 L
.17809 .08333 L
.17854 .08333 L
.17903 .08333 L
.1795 .08333 L
.18001 .08333 L
.1805 .08333 L
.18095 .08333 L
.18139 .08333 L
.1818 .08333 L
.18226 .08333 L
.1827 .08333 L
.18318 .08333 L
.18369 .08333 L
Mistroke
.18413 .08333 L
.1846 .08333 L
.18511 .08333 L
.1854 .08333 L
.18566 .08333 L
.18617 .08333 L
.18665 .08333 L
.18706 .08333 L
.18751 .08333 L
.18799 .08333 L
.18843 .08333 L
.18884 .08333 L
.18922 .08333 L
.18964 .08333 L
.19007 .08333 L
.19052 .08333 L
.19099 .08333 L
.19144 .08333 L
.19185 .08333 L
.19233 .08333 L
.1926 .08333 L
.19285 .08333 L
.1933 .08333 L
.19379 .08333 L
.19426 .08333 L
.19478 .08333 L
.19526 .08333 L
.19571 .08333 L
.19612 .08333 L
.19657 .08333 L
.19703 .08333 L
.19747 .08333 L
.19795 .08333 L
.19846 .08333 L
.1989 .08333 L
.19937 .08333 L
.19989 .08333 L
.20018 .08333 L
.20044 .08333 L
.20095 .08333 L
.20143 .08333 L
.20184 .08333 L
.20229 .08333 L
.20276 .08333 L
.20321 .08333 L
.20362 .08333 L
.204 .08333 L
.20444 .08333 L
.20485 .08333 L
.2053 .08333 L
Mistroke
.20577 .08333 L
.20622 .08333 L
.20663 .08333 L
.20711 .08333 L
.20738 .08333 L
.20763 .08333 L
.20808 .08333 L
.20857 .08333 L
.20904 .08333 L
.20931 .08333 L
.20956 .08333 L
.21001 .08333 L
.2105 .08333 L
.21093 .08333 L
.21134 .08333 L
.21178 .08333 L
.21226 .08333 L
.21274 .08333 L
.21301 .08333 L
.21327 .08333 L
.21378 .08333 L
.21407 .08333 L
.21433 .08333 L
.21479 .08333 L
.2153 .08333 L
.21578 .08333 L
.21622 .08333 L
.21663 .08333 L
.21708 .08333 L
.21749 .08333 L
.21787 .08333 L
.21832 .08333 L
.21881 .08333 L
.21927 .08333 L
.21969 .08333 L
.22017 .08333 L
.22063 .08333 L
.22103 .08333 L
.22147 .08333 L
.22195 .08333 L
.22246 .08333 L
.22289 .08333 L
.22337 .08333 L
.22388 .08333 L
.22435 .08333 L
.22459 .08333 L
.22487 .08333 L
.22515 .08333 L
.22542 .08333 L
.2259 .08333 L
Mistroke
.22635 .08333 L
.22686 .08333 L
.22735 .08333 L
.22779 .08333 L
.22825 .08333 L
.22869 .08333 L
.22909 .08333 L
.22956 .08333 L
.23007 .08333 L
.23054 .08333 L
.23099 .08333 L
.23146 .08333 L
.23196 .08333 L
.23244 .08333 L
.23287 .08333 L
.23339 .08333 L
.23367 .08333 L
.23394 .08333 L
.23443 .08333 L
.23468 .08333 L
.23495 .08333 L
.23521 .08333 L
.23549 .08333 L
.23599 .08333 L
.23627 .08333 L
.23653 .08333 L
.23681 .08333 L
.23711 .08333 L
.23737 .08333 L
.23766 .08333 L
.23793 .08333 L
.23817 .08333 L
.23864 .08333 L
.23914 .08333 L
.23961 .08333 L
.24013 .08333 L
.24061 .08333 L
.24106 .08333 L
.24151 .08333 L
.24191 .08333 L
.24238 .08333 L
.24281 .08333 L
.24329 .08333 L
.2438 .08333 L
.24424 .08333 L
.24471 .08333 L
.24522 .08333 L
.24551 .08333 L
.24577 .08333 L
.24628 .08333 L
Mistroke
.24676 .08333 L
.24717 .08333 L
.24762 .08333 L
.2481 .08333 L
.24854 .08333 L
.24895 .08333 L
.24933 .08333 L
.24974 .08333 L
.25018 .08333 L
.25062 .08333 L
.2511 .08333 L
.25155 .08333 L
.25195 .08333 L
.25243 .08333 L
.2527 .08333 L
.25295 .08333 L
.25341 .08333 L
.2539 .08333 L
.25437 .08333 L
.25488 .08333 L
.25537 .08333 L
.25582 .08333 L
.25627 .08333 L
.25667 .08333 L
.25714 .08333 L
.25758 .08333 L
.25806 .08333 L
.25857 .08333 L
.259 .08333 L
.25948 .08333 L
.25999 .08333 L
.26028 .08333 L
.26054 .08333 L
.26105 .08333 L
.26153 .08333 L
.26194 .08333 L
.26239 .08333 L
.26287 .08333 L
.26331 .08333 L
.26372 .08333 L
.2641 .08333 L
.26454 .08333 L
.26495 .08333 L
.2654 .08333 L
.26588 .08333 L
.26632 .08333 L
.26673 .08333 L
.26721 .08333 L
.26748 .08333 L
.26773 .08333 L
Mistroke
.26819 .08333 L
.26867 .08333 L
.26914 .08333 L
.26941 .08333 L
.26966 .08333 L
.27012 .08333 L
.2706 .08333 L
.27103 .08333 L
.27144 .08333 L
.27188 .08333 L
.27236 .08333 L
.27284 .08333 L
.27311 .08333 L
.27337 .08333 L
.27388 .08333 L
.27417 .08333 L
.27443 .08333 L
.27489 .08333 L
.2754 .08333 L
.27588 .08333 L
.27632 .08333 L
.27673 .08333 L
.27717 .08333 L
.27759 .08333 L
.27797 .08333 L
.27842 .08333 L
.27891 .08333 L
.27936 .08333 L
.27979 .08333 L
.28027 .08333 L
.28072 .08333 L
.28113 .08333 L
.28157 .08333 L
.28205 .08333 L
.28256 .08333 L
.28299 .08333 L
.28346 .08333 L
.28397 .08333 L
.28445 .08333 L
.28469 .08333 L
.28496 .08333 L
.28525 .08333 L
.28551 .08333 L
.286 .08333 L
.28645 .08333 L
.28694 .08333 L
.28745 .08333 L
.28789 .08333 L
.28835 .08333 L
.28879 .08333 L
Mistroke
.28919 .08333 L
.28965 .08333 L
.29016 .08333 L
.29064 .08333 L
.29108 .08333 L
.29155 .08333 L
.29206 .08333 L
.29253 .08333 L
.29297 .08333 L
.29348 .08333 L
.29377 .08333 L
.29403 .08333 L
.29452 .08333 L
.29477 .08333 L
.29504 .08333 L
.29531 .08333 L
.29559 .08333 L
.29608 .08333 L
.29636 .08333 L
.29662 .08333 L
.2969 .08333 L
.2972 .08333 L
.29747 .08333 L
.29775 .08333 L
.29802 .08333 L
.29827 .08333 L
.29874 .08333 L
.29924 .08333 L
.29971 .08333 L
.30022 .08333 L
.3007 .08333 L
.30115 .08333 L
.3016 .08333 L
.302 .08333 L
.30247 .08333 L
.30291 .08333 L
.30339 .08333 L
.30389 .08333 L
.30433 .08333 L
.3048 .08333 L
.30531 .08333 L
.3056 .08333 L
.30586 .08333 L
.30637 .08333 L
.30685 .08333 L
.30726 .08333 L
.30771 .08333 L
.30818 .08333 L
.30863 .08333 L
.30904 .08333 L
Mistroke
.30942 .08333 L
.30983 .08333 L
.31027 .08333 L
.31071 .08333 L
.31119 .08333 L
.31164 .08333 L
.31204 .08333 L
.31252 .08333 L
.31279 .08333 L
.31304 .08333 L
.3135 .08333 L
.31398 .08333 L
.31446 .08333 L
.31497 .08333 L
.31546 .08333 L
.31591 .08333 L
.31635 .08333 L
.31676 .08333 L
.31723 .08333 L
.31766 .08333 L
.31815 .08333 L
.31865 .08333 L
.31909 .08333 L
.31956 .08333 L
.32008 .08333 L
.32036 .08333 L
.32063 .08333 L
.32114 .08333 L
.32162 .08333 L
.32203 .08333 L
.32248 .08333 L
.32295 .08333 L
.3234 .08333 L
.32381 .08333 L
.32419 .08333 L
.32462 .08333 L
.32504 .08333 L
.32548 .08333 L
.32596 .08333 L
.32641 .08333 L
.32681 .08333 L
.32729 .08333 L
.32756 .08333 L
.32781 .08333 L
.32827 .08333 L
.32875 .08333 L
.32923 .08333 L
.3295 .08333 L
.32974 .08333 L
.3302 .08333 L
Mistroke
.33068 .08333 L
.33111 .08333 L
.33152 .08333 L
.33196 .08333 L
.33244 .08333 L
.33292 .08333 L
.3332 .08333 L
.33345 .08333 L
.33396 .08333 L
.33425 .08333 L
.33451 .08333 L
.33498 .08333 L
.33548 .08333 L
.33596 .08333 L
.3364 .08333 L
.33681 .08333 L
.33725 .08333 L
.33767 .08333 L
.33805 .08333 L
.3385 .08333 L
.33898 .08333 L
.33944 .08333 L
.33987 .08333 L
.34035 .08333 L
.3408 .08333 L
.34121 .08333 L
.34165 .08333 L
.34213 .08333 L
.34264 .08333 L
.34307 .08333 L
.34354 .08333 L
.34405 .08333 L
.34452 .08333 L
.34477 .08333 L
.34504 .08333 L
.34532 .08333 L
.34559 .08333 L
.34608 .08333 L
.34652 .08333 L
.34701 .08333 L
.34753 .08333 L
.34796 .08333 L
.34843 .08333 L
.34886 .08333 L
.34926 .08333 L
.34973 .08333 L
.35024 .08333 L
.35072 .08333 L
.35116 .08333 L
.35163 .08333 L
Mistroke
.35213 .08333 L
.35261 .08333 L
.35304 .08333 L
.35355 .08333 L
.35384 .08333 L
.35411 .08333 L
.3546 .08333 L
.35485 .08333 L
.35512 .08333 L
.35538 .08333 L
.35566 .08333 L
.35616 .08333 L
.35643 .08333 L
.35669 .08333 L
.35698 .08333 L
.35728 .08333 L
.35754 .08333 L
.35783 .08333 L
.35809 .08333 L
.35834 .08333 L
.35881 .08333 L
.35931 .08333 L
.35978 .08333 L
.36029 .08333 L
.36078 .08333 L
.36123 .08333 L
.36167 .08333 L
.36207 .08333 L
.36254 .08333 L
.36298 .08333 L
.36346 .08333 L
.36396 .08333 L
.3644 .08333 L
.36487 .08333 L
.36538 .08333 L
.36567 .08333 L
.36593 .08333 L
.36644 .08333 L
.36692 .08333 L
.36733 .08333 L
.36778 .08333 L
.36825 .08333 L
.3687 .08333 L
.36911 .08333 L
.36949 .08333 L
.3699 .08333 L
.37034 .08333 L
.37078 .08333 L
.37126 .08333 L
.37171 .08333 L
Mistroke
.37211 .08333 L
.37259 .08333 L
.37286 .08333 L
.37311 .08333 L
.37357 .08333 L
.37405 .08333 L
.37453 .08333 L
.37504 .08333 L
.37553 .08333 L
.37598 .08333 L
.37642 .08333 L
.37683 .08333 L
.37729 .08333 L
.37773 .08333 L
.37821 .08333 L
.37872 .08333 L
.37916 .08333 L
.37963 .08333 L
.38014 .08333 L
.38043 .08333 L
.38069 .08333 L
.3812 .08333 L
.38168 .08333 L
.38209 .08333 L
.38255 .08333 L
.38302 .08333 L
.38346 .08333 L
.38387 .08333 L
.38425 .08333 L
.38467 .08333 L
.3851 .08333 L
.38555 .08333 L
.38602 .08333 L
.38647 .08333 L
.38688 .08333 L
.38736 .08333 L
.38763 .08333 L
.38788 .08333 L
.38834 .08333 L
.38882 .08333 L
.38929 .08333 L
.38956 .08333 L
.38981 .08333 L
.39026 .08333 L
.39075 .08333 L
.39118 .08333 L
.39158 .08333 L
.39203 .08333 L
.39251 .08333 L
.39299 .08333 L
Mistroke
.39326 .08333 L
.39351 .08333 L
.39402 .08333 L
.39431 .08333 L
.39457 .08333 L
.39504 .08333 L
.39554 .08333 L
.39602 .08333 L
.39646 .08333 L
.39687 .08333 L
.39731 .08333 L
.39773 .08333 L
.39811 .08333 L
.39856 .08333 L
.39904 .08333 L
.3995 .08333 L
.39993 .08333 L
.40041 .08333 L
.40086 .08333 L
.40127 .08333 L
.40171 .08333 L
.40219 .08333 L
.4027 .08333 L
.40313 .08333 L
.4036 .08333 L
.40411 .08333 L
.40458 .08333 L
.40483 .08333 L
.4051 .08333 L
.40538 .08333 L
.40565 .08333 L
.40614 .08333 L
.40658 .08333 L
.40707 .08333 L
.40759 .08333 L
.40802 .08333 L
.40848 .08333 L
.40892 .08333 L
.40932 .08333 L
.40979 .08333 L
.41029 .08333 L
.41077 .08333 L
.41121 .08333 L
.41168 .08333 L
.41219 .08333 L
.41266 .08333 L
.4131 .08333 L
.41361 .08333 L
.4139 .08333 L
.41416 .08333 L
Mistroke
.41465 .08333 L
.41493 .08333 L
.41517 .08333 L
.41544 .08333 L
.41572 .08333 L
.41621 .08333 L
.41649 .08333 L
.41675 .08333 L
.41703 .08333 L
.41733 .08333 L
.4176 .08333 L
.41788 .08333 L
.41815 .08333 L
.4184 .08333 L
.41887 .08333 L
.41936 .08333 L
.41983 .08333 L
.42035 .08333 L
.42083 .08333 L
.42128 .08333 L
.42172 .08333 L
.42213 .08333 L
.42259 .08333 L
.42303 .08333 L
.42351 .08333 L
.42402 .08333 L
.42445 .08333 L
.42492 .08333 L
.42544 .08333 L
.42572 .08333 L
.42598 .08333 L
.42649 .08333 L
.42697 .08333 L
.42738 .08333 L
.42783 .08333 L
.42831 .08333 L
.42875 .08333 L
.42916 .08333 L
.42954 .08333 L
.42995 .08333 L
.43039 .08333 L
.43083 .08333 L
.43131 .08333 L
.43176 .08333 L
.43216 .08333 L
.43264 .08333 L
.43291 .08333 L
.43316 .08333 L
.43362 .08333 L
.4341 .08333 L
Mistroke
.43458 .08333 L
.43509 .08333 L
.43557 .08333 L
.43602 .08333 L
.43647 .08333 L
.43687 .08333 L
.43734 .08333 L
.43778 .08333 L
.43826 .08333 L
.43877 .08333 L
.4392 .08333 L
.43968 .08333 L
.44019 .08333 L
.44048 .08333 L
.44074 .08333 L
.44125 .08333 L
.44173 .08333 L
.44214 .08333 L
.44259 .08333 L
.44306 .08333 L
.44351 .08333 L
.44392 .08333 L
.4443 .08333 L
.44471 .08333 L
.44515 .08333 L
.44559 .08333 L
.44607 .08333 L
.44652 .08333 L
.44692 .08333 L
.4474 .08333 L
.44767 .08333 L
.44792 .08333 L
.44838 .08333 L
.44886 .08333 L
.44934 .08333 L
.44961 .08333 L
.44985 .08333 L
.45031 .08333 L
.45079 .08333 L
.45122 .08333 L
.45163 .08333 L
.45207 .08333 L
.45255 .08333 L
.45303 .08333 L
.4533 .08333 L
.45355 .08333 L
.45407 .08333 L
.45435 .08333 L
.45461 .08333 L
.45508 .08333 L
Mistroke
.45558 .08333 L
.45606 .08333 L
.4565 .08333 L
.45692 .08333 L
.45736 .08333 L
.45777 .08333 L
.45815 .08333 L
.4586 .08333 L
.45909 .08333 L
.45954 .08333 L
.45997 .08333 L
.46045 .08333 L
.4609 .08333 L
.46131 .08333 L
.46175 .08333 L
.46223 .08333 L
.46274 .08333 L
.46317 .08333 L
.46364 .08333 L
.46399 .08333 L
.46431 .08333 L
.46465 .08333 L
.46503 .08333 L
.46535 .08333 L
.46565 .08333 L
.46598 .08333 L
.46633 .08333 L
.46663 .08333 L
.46696 .08333 L
.4673 .08333 L
.46761 .08333 L
.46791 .08333 L
.46818 .08333 L
.46849 .08333 L
.46878 .08333 L
.4691 .08333 L
.46945 .08333 L
.46982 .08333 L
.47016 .08333 L
.47048 .08333 L
.47077 .08333 L
.47111 .08333 L
.47143 .08333 L
.47177 .08333 L
.47214 .08333 L
.47248 .08333 L
.4728 .08333 L
.47317 .08333 L
.47357 .08333 L
.47394 .08333 L
Mistroke
.47429 .08333 L
Mfstroke
.47429 .08333 m
.47477 .08333 L
.4752 .08333 L
.4757 .08333 L
.47617 .08333 L
.47661 .08333 L
.47702 .08333 L
.47746 .08333 L
.47793 .08333 L
.4784 .08333 L
.47891 .08333 L
.47939 .08333 L
.47983 .08333 L
.48034 .08333 L
.48063 .08333 L
.4809 .08333 L
.48139 .08333 L
.48192 .08333 L
.48218 .08333 L
.48246 .08333 L
.48296 .08333 L
.48324 .08333 L
.4835 .08333 L
.48378 .08333 L
.48409 .08333 L
.48435 .08333 L
.48464 .08333 L
.48516 .08333 L
.48566 .08333 L
.48613 .08333 L
.48659 .08333 L
.48701 .08333 L
.48748 .08333 L
.48799 .08333 L
.48849 .08333 L
.48901 .08333 L
.48946 .08333 L
.48996 .08333 L
.49024 .08333 L
.49051 .08333 L
.4908 .08333 L
.49111 .08333 L
.49163 .08333 L
.49192 .08333 L
.4922 .08333 L
.49271 .08333 L
.49318 .08333 L
.49344 .08333 L
.49372 .08333 L
.49424 .08333 L
Mistroke
.49455 .08333 L
.49484 .08333 L
.4951 .08333 L
.49538 .08333 L
.49569 .08333 L
.49602 .08333 L
.4963 .08333 L
.49661 .08333 L
.4969 .08333 L
.49716 .08333 L
.49746 .08333 L
.49775 .08333 L
.49825 .08333 L
.49854 .08333 L
.49881 .08333 L
.49928 .08333 L
.49979 .08333 L
.50027 .08333 L
.50071 .08333 L
.5012 .08333 L
.50173 .08333 L
.502 .08333 L
.50229 .08333 L
.5028 .08333 L
.50309 .08333 L
.50335 .08333 L
.50364 .08333 L
.50395 .08333 L
.50446 .08333 L
.50475 .08333 L
.50503 .08333 L
.50553 .08333 L
.506 .08333 L
.50653 .08333 L
.50704 .08333 L
.5075 .08333 L
.508 .08333 L
.50847 .08333 L
.5089 .08333 L
.50938 .08333 L
.5099 .08333 L
.51016 .08333 L
.51044 .08333 L
.51095 .08333 L
.51123 .08333 L
.51149 .08333 L
.51177 .08333 L
.51207 .08333 L
.51257 .08333 L
.51286 .08333 L
Mistroke
.51313 .08333 L
.51362 .08333 L
.51408 .08333 L
.51461 .08333 L
.5151 .08333 L
.51558 .08333 L
.516 .08333 L
.51649 .08333 L
.51696 .08333 L
.51739 .08333 L
.51778 .08333 L
.51822 .08333 L
.51868 .08333 L
.51914 .08333 L
.51964 .08333 L
.52011 .08333 L
.52053 .08333 L
.52103 .08333 L
.52132 .08333 L
.52158 .08333 L
.52206 .08333 L
.52257 .08333 L
.52303 .08333 L
.52354 .08333 L
.52406 .08333 L
.52456 .08333 L
.52502 .08333 L
.52543 .08333 L
.52592 .08333 L
.52637 .08333 L
.52687 .08333 L
.5274 .08333 L
.52785 .08333 L
.52834 .08333 L
.52887 .08333 L
.52917 .08333 L
.52944 .08333 L
.52997 .08333 L
.53047 .08333 L
.53094 .08333 L
.53136 .08333 L
.53185 .08333 L
.53231 .08333 L
.53274 .08333 L
.53313 .08333 L
.53357 .08333 L
.53402 .08333 L
.53448 .08333 L
.53497 .08333 L
.53544 .08333 L
Mistroke
.53586 .08333 L
.53636 .08333 L
.53664 .08333 L
.5369 .08333 L
.53738 .08333 L
.53789 .08333 L
.53837 .08333 L
.53891 .08333 L
.53941 .08333 L
.53988 .08333 L
.54034 .08333 L
.54076 .08333 L
.54124 .08333 L
.5417 .08333 L
.5422 .08333 L
.54273 .08333 L
.54318 .08333 L
.54367 .08333 L
.5442 .08333 L
.5445 .08333 L
.54477 .08333 L
.5453 .08333 L
.5458 .08333 L
.54623 .08333 L
.5467 .08333 L
.54719 .08333 L
.54765 .08333 L
.54808 .08333 L
.54847 .08333 L
.5489 .08333 L
.54936 .08333 L
.54982 .08333 L
.55031 .08333 L
.55078 .08333 L
.5512 .08333 L
.5517 .08333 L
.55198 .08333 L
.55224 .08333 L
.55272 .08333 L
.55322 .08333 L
.55371 .08333 L
.55425 .08333 L
.55475 .08333 L
.55522 .08333 L
.55568 .08333 L
.5561 .08333 L
.55659 .08333 L
.55705 .08333 L
.55755 .08333 L
.55808 .08333 L
Mistroke
.55853 .08333 L
.55902 .08333 L
.55955 .08333 L
.55985 .08333 L
.56013 .08333 L
.56066 .08333 L
.56116 .08333 L
.56158 .08333 L
.56205 .08333 L
.56254 .08333 L
.563 .08333 L
.56343 .08333 L
.56383 .08333 L
.56426 .08333 L
.56471 .08333 L
.56518 .08333 L
.56567 .08333 L
.56614 .08333 L
.56656 .08333 L
.56706 .08333 L
.56734 .08333 L
.5676 .08333 L
.56808 .08333 L
.56858 .08333 L
.56907 .08333 L
.56961 .08333 L
.57012 .08333 L
.57058 .08333 L
.57101 .08333 L
.57147 .08333 L
.57196 .08333 L
.57241 .08333 L
.57292 .08333 L
.57345 .08333 L
.5739 .08333 L
.57439 .08333 L
.57493 .08333 L
.57523 .08333 L
.5755 .08333 L
.57603 .08333 L
.57653 .08333 L
.57696 .08333 L
.57743 .08333 L
.57792 .08333 L
.57838 .08333 L
.57881 .08333 L
.57921 .08333 L
.57966 .08333 L
.58009 .08333 L
.58056 .08333 L
Mistroke
.58105 .08333 L
.58152 .08333 L
.58194 .08333 L
.58244 .08333 L
.58272 .08333 L
.58298 .08333 L
.58346 .08333 L
.58396 .08333 L
.58445 .08333 L
.58473 .08333 L
.58499 .08333 L
.58547 .08333 L
.58597 .08333 L
.58642 .08333 L
.58684 .08333 L
.5873 .08333 L
.5878 .08333 L
.5883 .08333 L
.58859 .08333 L
.58885 .08333 L
.58938 .08333 L
.58968 .08333 L
.58995 .08333 L
.59044 .08333 L
.59097 .08333 L
.59147 .08333 L
.59192 .08333 L
.59235 .08333 L
.59281 .08333 L
.59325 .08333 L
.59364 .08333 L
.59411 .08333 L
.59462 .08333 L
.59509 .08333 L
.59554 .08333 L
.59604 .08333 L
.59651 .08333 L
.59693 .08333 L
.59739 .08333 L
.59789 .08333 L
.59842 .08333 L
.59887 .08333 L
.59936 .08333 L
.59989 .08333 L
.60038 .08333 L
.60064 .08333 L
.60092 .08333 L
.60122 .08333 L
.60149 .08333 L
.602 .08333 L
Mistroke
.60246 .08333 L
.603 .08333 L
.60351 .08333 L
.60396 .08333 L
.60445 .08333 L
.6049 .08333 L
.60532 .08333 L
.6058 .08333 L
.60633 .08333 L
.60683 .08333 L
.60729 .08333 L
.60778 .08333 L
.6083 .08333 L
.6088 .08333 L
.60925 .08333 L
.60979 .08333 L
.61009 .08333 L
.61036 .08333 L
.61087 .08333 L
.61113 .08333 L
.61141 .08333 L
.61169 .08333 L
.61198 .08333 L
.6125 .08333 L
.61278 .08333 L
.61305 .08333 L
.61335 .08333 L
.61366 .08333 L
.61394 .08333 L
.61423 .08333 L
.61451 .08333 L
.61477 .08333 L
.61526 .08333 L
.61578 .08333 L
.61626 .08333 L
.6168 .08333 L
.6173 .08333 L
.61777 .08333 L
.61823 .08333 L
.61866 .08333 L
.61914 .08333 L
.6196 .08333 L
.6201 .08333 L
.62062 .08333 L
.62108 .08333 L
.62157 .08333 L
.6221 .08333 L
.6224 .08333 L
.62267 .08333 L
.6232 .08333 L
Mistroke
.6237 .08333 L
.62413 .08333 L
.6246 .08333 L
.62509 .08333 L
.62555 .08333 L
.62598 .08333 L
.62638 .08333 L
.62681 .08333 L
.62726 .08333 L
.62772 .08333 L
.62822 .08333 L
.62869 .08333 L
.62911 .08333 L
.62961 .08333 L
.62989 .08333 L
.63015 .08333 L
.63062 .08333 L
.63113 .08333 L
.63162 .08333 L
.63216 .08333 L
.63266 .08333 L
.63313 .08333 L
.6336 .08333 L
.63402 .08333 L
.6345 .08333 L
.63496 .08333 L
.63546 .08333 L
.63599 .08333 L
.63644 .08333 L
.63694 .08333 L
.63747 .08333 L
.63777 .08333 L
.63804 .08333 L
.63857 .08333 L
.63907 .08333 L
.6395 .08333 L
.63997 .08333 L
.64046 .08333 L
.64093 .08333 L
.64136 .08333 L
.64175 .08333 L
.6422 .08333 L
.64263 .08333 L
.6431 .08333 L
.64359 .08333 L
.64406 .08333 L
.64448 .08333 L
.64498 .08333 L
.64526 .08333 L
.64552 .08333 L
Mistroke
.646 .08333 L
.6465 .08333 L
.647 .08333 L
.64728 .08333 L
.64753 .08333 L
.64801 .08333 L
.64851 .08333 L
.64896 .08333 L
.64938 .08333 L
.64984 .08333 L
.65034 .08333 L
.65084 .08333 L
.65113 .08333 L
.65139 .08333 L
.65192 .08333 L
.65222 .08333 L
.65249 .08333 L
.65298 .08333 L
.65351 .08333 L
.654 .08333 L
.65446 .08333 L
.65489 .08333 L
.65535 .08333 L
.65579 .08333 L
.65618 .08333 L
.65665 .08333 L
.65715 .08333 L
.65763 .08333 L
.65807 .08333 L
.65857 .08333 L
.65905 .08333 L
.65947 .08333 L
.65993 .08333 L
.66043 .08333 L
.66095 .08333 L
.6614 .08333 L
.6619 .08333 L
.66243 .08333 L
.66292 .08333 L
.66317 .08333 L
.66346 .08333 L
.66375 .08333 L
.66403 .08333 L
.66453 .08333 L
.665 .08333 L
.66551 .08333 L
.66604 .08333 L
.6665 .08333 L
.66698 .08333 L
.66744 .08333 L
Mistroke
.66785 .08333 L
.66834 .08333 L
.66886 .08333 L
.66936 .08333 L
.66982 .08333 L
.67031 .08333 L
.67084 .08333 L
.67133 .08333 L
.67179 .08333 L
.67232 .08333 L
.67262 .08333 L
.6729 .08333 L
.6734 .08333 L
.67366 .08333 L
.67395 .08333 L
.67422 .08333 L
.67451 .08333 L
.67503 .08333 L
.67532 .08333 L
.67558 .08333 L
.67588 .08333 L
.67619 .08333 L
.67647 .08333 L
.67676 .08333 L
.67704 .08333 L
.6773 .08333 L
.67779 .08333 L
.67831 .08333 L
.6788 .08333 L
.67933 .08333 L
.67983 .08333 L
.6803 .08333 L
.68077 .08333 L
.68119 .08333 L
.68167 .08333 L
.68213 .08333 L
.68263 .08333 L
.68315 .08333 L
.68361 .08333 L
.6841 .08333 L
.68463 .08333 L
.68493 .08333 L
.6852 .08333 L
.68573 .08333 L
.68623 .08333 L
.68666 .08333 L
.68713 .08333 L
.68762 .08333 L
.68808 .08333 L
.68851 .08333 L
Mistroke
.6889 .08333 L
.68933 .08333 L
.68979 .08333 L
.69025 .08333 L
.69075 .08333 L
.69121 .08333 L
.69164 .08333 L
.69213 .08333 L
.69242 .08333 L
.69267 .08333 L
.69315 .08333 L
.69366 .08333 L
.69415 .08333 L
.69468 .08333 L
.69519 .08333 L
.69566 .08333 L
.69612 .08333 L
.69654 .08333 L
.69703 .08333 L
.69748 .08333 L
.69799 .08333 L
.69852 .08333 L
.69897 .08333 L
.69946 .08333 L
.7 .08333 L
.70029 .08333 L
.70057 .08333 L
.7011 .08333 L
.7016 .08333 L
.70202 .08333 L
.7025 .08333 L
.70299 .08333 L
.70345 .08333 L
.70388 .08333 L
.70427 .08333 L
.70473 .08333 L
.70516 .08333 L
.70562 .08333 L
.70612 .08333 L
.70658 .08333 L
.70701 .08333 L
.7075 .08333 L
.70779 .08333 L
.70804 .08333 L
.70852 .08333 L
.70902 .08333 L
.70952 .08333 L
.7098 .08333 L
.71006 .08333 L
.71053 .08333 L
Mistroke
.71103 .08333 L
.71148 .08333 L
.7119 .08333 L
.71237 .08333 L
.71286 .08333 L
.71336 .08333 L
.71365 .08333 L
.71391 .08333 L
.71444 .08333 L
.71474 .08333 L
.71501 .08333 L
.7155 .08333 L
.71602 .08333 L
.71652 .08333 L
.71698 .08333 L
.71741 .08333 L
.71787 .08333 L
.7183 .08333 L
.7187 .08333 L
.71916 .08333 L
.71967 .08333 L
.72015 .08333 L
.72059 .08333 L
.72109 .08333 L
.72156 .08333 L
.72199 .08333 L
.72244 .08333 L
.72294 .08333 L
.72347 .08333 L
.72392 .08333 L
.72441 .08333 L
.72494 .08333 L
.72543 .08333 L
.72569 .08333 L
.72597 .08333 L
.72627 .08333 L
.72654 .08333 L
.72705 .08333 L
.72751 .08333 L
.72802 .08333 L
.72856 .08333 L
.72901 .08333 L
.72949 .08333 L
.72995 .08333 L
.73036 .08333 L
.73085 .08333 L
.73138 .08333 L
.73188 .08333 L
.73234 .08333 L
.73283 .08333 L
Mistroke
.73335 .08333 L
.73385 .08333 L
.7343 .08333 L
.73483 .08333 L
.73513 .08333 L
.73541 .08333 L
.73592 .08333 L
.73617 .08333 L
.73646 .08333 L
.73673 .08333 L
.73702 .08333 L
.73754 .08333 L
.73783 .08333 L
.7381 .08333 L
.73839 .08333 L
.73871 .08333 L
.73898 .08333 L
.73928 .08333 L
.73956 .08333 L
.73981 .08333 L
.7403 .08333 L
.74082 .08333 L
.74131 .08333 L
.74184 .08333 L
.74235 .08333 L
.74281 .08333 L
.74328 .08333 L
.7437 .08333 L
.74418 .08333 L
.74464 .08333 L
.74514 .08333 L
.74566 .08333 L
.74611 .08333 L
.74661 .08333 L
.74714 .08333 L
.74744 .08333 L
.74771 .08333 L
.74824 .08333 L
.74874 .08333 L
.74917 .08333 L
.74964 .08333 L
.75013 .08333 L
.75059 .08333 L
.75102 .08333 L
.75141 .08333 L
.75184 .08333 L
.7523 .08333 L
.75276 .08333 L
.75325 .08333 L
.75372 .08333 L
Mistroke
.75414 .08333 L
.75464 .08333 L
.75492 .08333 L
.75518 .08333 L
.75566 .08333 L
.75616 .08333 L
.75665 .08333 L
.75719 .08333 L
.75769 .08333 L
.75816 .08333 L
.75863 .08333 L
.75905 .08333 L
.75953 .08333 L
.75999 .08333 L
.76049 .08333 L
.76102 .08333 L
.76147 .08333 L
.76197 .08333 L
.7625 .08333 L
.7628 .08333 L
.76307 .08333 L
.7636 .08333 L
.7641 .08333 L
.76453 .08333 L
.765 .08333 L
.76549 .08333 L
.76595 .08333 L
.76638 .08333 L
.76677 .08333 L
.76721 .08333 L
.76766 .08333 L
.76812 .08333 L
.76862 .08333 L
.76908 .08333 L
.76951 .08333 L
.77001 .08333 L
.77029 .08333 L
.77055 .08333 L
.77102 .08333 L
.77153 .08333 L
.77202 .08333 L
.7723 .08333 L
.77256 .08333 L
.77303 .08333 L
.77353 .08333 L
.77398 .08333 L
.7744 .08333 L
.77487 .08333 L
.77536 .08333 L
.77586 .08333 L
Mistroke
.77615 .08333 L
.77641 .08333 L
.77694 .08333 L
.77724 .08333 L
.77751 .08333 L
.778 .08333 L
.77852 .08333 L
.77902 .08333 L
.77948 .08333 L
.77991 .08333 L
.78037 .08333 L
.7808 .08333 L
.7812 .08333 L
.78166 .08333 L
.78217 .08333 L
.78265 .08333 L
.78309 .08333 L
.78359 .08333 L
.78406 .08333 L
.78448 .08333 L
.78494 .08333 L
.78544 .08333 L
.78597 .08333 L
.78642 .08333 L
.78691 .08333 L
.78744 .08333 L
.78793 .08333 L
.78819 .08333 L
.78847 .08333 L
.78876 .08333 L
.78904 .08333 L
.78955 .08333 L
.79001 .08333 L
.79052 .08333 L
.79105 .08333 L
.79151 .08333 L
.79199 .08333 L
.79244 .08333 L
.79286 .08333 L
.79334 .08333 L
.79387 .08333 L
.79437 .08333 L
.79483 .08333 L
.79532 .08333 L
.79584 .08333 L
.79634 .08333 L
.79679 .08333 L
.79732 .08333 L
.79762 .08333 L
.7979 .08333 L
Mistroke
.79841 .08333 L
.79869 .08333 L
.79895 .08333 L
.79923 .08333 L
.79951 .08333 L
.80003 .08333 L
.80032 .08333 L
.80059 .08333 L
.80088 .08333 L
.8012 .08333 L
.80147 .08333 L
.80177 .08333 L
.80205 .08333 L
.80231 .08333 L
.80279 .08333 L
.80331 .08333 L
.8038 .08333 L
.80433 .08333 L
.80484 .08333 L
.8053 .08333 L
.80577 .08333 L
.80619 .08333 L
.80667 .08333 L
.80713 .08333 L
.80763 .08333 L
.80815 .08333 L
.8086 .08333 L
.8091 .08333 L
.80963 .08333 L
.80993 .08333 L
.8102 .08333 L
.81073 .08333 L
.81123 .08333 L
.81166 .08333 L
.81213 .08333 L
.81262 .08333 L
.81308 .08333 L
.8135 .08333 L
.8139 .08333 L
.81433 .08333 L
.81478 .08333 L
.81525 .08333 L
.81574 .08333 L
.81621 .08333 L
.81663 .08333 L
.81713 .08333 L
.81741 .08333 L
.81767 .08333 L
.81815 .08333 L
.81865 .08333 L
Mistroke
.81914 .08333 L
.81967 .08333 L
.82018 .08333 L
.82065 .08333 L
.82111 .08333 L
.82153 .08333 L
.82202 .08333 L
.82247 .08333 L
.82298 .08333 L
.8235 .08333 L
.82395 .08333 L
.82445 .08333 L
.82498 .08333 L
.82528 .08333 L
.82555 .08333 L
.82608 .08333 L
.82658 .08333 L
.82701 .08333 L
.82748 .08333 L
.82797 .08333 L
.82843 .08333 L
.82886 .08333 L
.82926 .08333 L
.82969 .08333 L
.83014 .08333 L
.83061 .08333 L
.8311 .08333 L
.83157 .08333 L
.83199 .08333 L
.83249 .08333 L
.83277 .08333 L
.83303 .08333 L
.83351 .08333 L
.83401 .08333 L
.8345 .08333 L
.83478 .08333 L
.83504 .08333 L
.83551 .08333 L
.83601 .08333 L
.83646 .08333 L
.83688 .08333 L
.83735 .08333 L
.83784 .08333 L
.83834 .08333 L
.83863 .08333 L
.83889 .08333 L
.83942 .08333 L
.83972 .08333 L
.83999 .08333 L
.84048 .08333 L
Mistroke
.841 .08333 L
.8415 .08333 L
.84196 .08333 L
.84239 .08333 L
.84285 .08333 L
.84328 .08333 L
.84368 .08333 L
.84414 .08333 L
.84464 .08333 L
.84512 .08333 L
.84557 .08333 L
.84607 .08333 L
.84654 .08333 L
.84696 .08333 L
.84742 .08333 L
.84792 .08333 L
.84844 .08333 L
.84889 .08333 L
.84939 .08333 L
.84975 .08333 L
.85008 .08333 L
.85044 .08333 L
.85083 .08333 L
.85116 .08333 L
.85147 .08333 L
.85182 .08333 L
.85219 .08333 L
.8525 .08333 L
.85283 .08333 L
.85319 .08333 L
.85352 .08333 L
.85383 .08333 L
.85411 .08333 L
.85443 .08333 L
.85474 .08333 L
.85507 .08333 L
.85543 .08333 L
.85581 .08333 L
.85617 .08333 L
.8565 .08333 L
.8568 .08333 L
.85715 .08333 L
.85749 .08333 L
.85784 .08333 L
.85823 .08333 L
.85859 .08333 L
.85891 .08333 L
.8593 .08333 L
.85971 .08333 L
.86011 .08333 L
Mistroke
.86047 .08333 L
Mfstroke
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{570, 95},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.396825 0.0833333 0.396825 [
[.10317 -0.0125 -3 -9 ]
[.10317 -0.0125 3 0 ]
[.30159 -0.0125 -9 -9 ]
[.30159 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69841 -0.0125 -9 -9 ]
[.69841 -0.0125 9 0 ]
[.89683 -0.0125 -3 -9 ]
[.89683 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00397 -24 -4.5 ]
[-0.0125 .00397 0 4.5 ]
[-0.0125 .04365 -24 -4.5 ]
[-0.0125 .04365 0 4.5 ]
[-0.0125 .08333 -6 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .12302 -18 -4.5 ]
[-0.0125 .12302 0 4.5 ]
[-0.0125 .1627 -18 -4.5 ]
[-0.0125 .1627 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .16667 .125 0 ]
[ 1 0 .125 0 ]
[.5 .17917 -219.875 0 ]
[.5 .17917 219.875 12 ]
[.93651 .05688 -5 -6 ]
[.93651 .05688 5 6 ]
[.12963 .12302 -5 -6 ]
[.12963 .12302 5 6 ]
[.12963 .10979 -3 -4.5 ]
[.12963 .10979 3 4.5 ]
[.52646 .10979 -3 -4.5 ]
[.52646 .10979 3 4.5 ]
[.92328 .10979 -3 -4.5 ]
[.92328 .10979 3 4.5 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 0 m
.10317 .00625 L
s
[(0)] .10317 -0.0125 0 1 Mshowa
.30159 0 m
.30159 .00625 L
s
[(0.5)] .30159 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.69841 0 m
.69841 .00625 L
s
[(1.5)] .69841 -0.0125 0 1 Mshowa
.89683 0 m
.89683 .00625 L
s
[(2)] .89683 -0.0125 0 1 Mshowa
.125 Mabswid
.14286 0 m
.14286 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.06349 0 m
.06349 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00397 m
.00625 .00397 L
s
[(-0.2)] -0.0125 .00397 1 0 Mshowa
0 .04365 m
.00625 .04365 L
s
[(-0.1)] -0.0125 .04365 1 0 Mshowa
0 .08333 m
.00625 .08333 L
s
[(0)] -0.0125 .08333 1 0 Mshowa
0 .12302 m
.00625 .12302 L
s
[(0.1)] -0.0125 .12302 1 0 Mshowa
0 .1627 m
.00625 .1627 L
s
[(0.2)] -0.0125 .1627 1 0 Mshowa
.125 Mabswid
0 .0119 m
.00375 .0119 L
s
0 .01984 m
.00375 .01984 L
s
0 .02778 m
.00375 .02778 L
s
0 .03571 m
.00375 .03571 L
s
0 .05159 m
.00375 .05159 L
s
0 .05952 m
.00375 .05952 L
s
0 .06746 m
.00375 .06746 L
s
0 .0754 m
.00375 .0754 L
s
0 .09127 m
.00375 .09127 L
s
0 .09921 m
.00375 .09921 L
s
0 .10714 m
.00375 .10714 L
s
0 .11508 m
.00375 .11508 L
s
0 .13095 m
.00375 .13095 L
s
0 .13889 m
.00375 .13889 L
s
0 .14683 m
.00375 .14683 L
s
0 .15476 m
.00375 .15476 L
s
.25 Mabswid
0 0 m
0 .16667 L
s
.10317 .16042 m
.10317 .16667 L
s
.30159 .16042 m
.30159 .16667 L
s
.5 .16042 m
.5 .16667 L
s
.69841 .16042 m
.69841 .16667 L
s
.89683 .16042 m
.89683 .16667 L
s
.125 Mabswid
.14286 .16292 m
.14286 .16667 L
s
.18254 .16292 m
.18254 .16667 L
s
.22222 .16292 m
.22222 .16667 L
s
.2619 .16292 m
.2619 .16667 L
s
.34127 .16292 m
.34127 .16667 L
s
.38095 .16292 m
.38095 .16667 L
s
.42063 .16292 m
.42063 .16667 L
s
.46032 .16292 m
.46032 .16667 L
s
.53968 .16292 m
.53968 .16667 L
s
.57937 .16292 m
.57937 .16667 L
s
.61905 .16292 m
.61905 .16667 L
s
.65873 .16292 m
.65873 .16667 L
s
.7381 .16292 m
.7381 .16667 L
s
.77778 .16292 m
.77778 .16667 L
s
.81746 .16292 m
.81746 .16667 L
s
.85714 .16292 m
.85714 .16667 L
s
.06349 .16292 m
.06349 .16667 L
s
.02381 .16292 m
.02381 .16667 L
s
.93651 .16292 m
.93651 .16667 L
s
.97619 .16292 m
.97619 .16667 L
s
.25 Mabswid
0 .16667 m
1 .16667 L
s
.99375 .00397 m
1 .00397 L
s
.99375 .04365 m
1 .04365 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .12302 m
1 .12302 L
s
.99375 .1627 m
1 .1627 L
s
.125 Mabswid
.99625 .0119 m
1 .0119 L
s
.99625 .01984 m
1 .01984 L
s
.99625 .02778 m
1 .02778 L
s
.99625 .03571 m
1 .03571 L
s
.99625 .05159 m
1 .05159 L
s
.99625 .05952 m
1 .05952 L
s
.99625 .06746 m
1 .06746 L
s
.99625 .0754 m
1 .0754 L
s
.99625 .09127 m
1 .09127 L
s
.99625 .09921 m
1 .09921 L
s
.99625 .10714 m
1 .10714 L
s
.99625 .11508 m
1 .11508 L
s
.99625 .13095 m
1 .13095 L
s
.99625 .13889 m
1 .13889 L
s
.99625 .14683 m
1 .14683 L
s
.99625 .15476 m
1 .15476 L
s
.25 Mabswid
1 0 m
1 .16667 L
s
gsave
.5 .17917 -280.875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Eigen) show
105.000 13.000 moveto
(mode) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
129.000 13.000 moveto
(,) show
138.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
144.562 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
154.125 13.000 moveto
0.000 0.000 rmoveto
154.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
160.125 13.000 moveto
(D) show
172.125 13.000 moveto
(Balken) show
214.125 13.000 moveto
(2) show
226.125 13.000 moveto
(Elementen) show
280.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
292.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ow) show
304.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
316.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.01) show
346.125 13.000 moveto
(.2000) show
376.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
378.750 13.000 moveto
0.000 0.000 rmoveto
378.750 13.000 moveto
(:) show
390.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Einspannung) show
462.750 13.000 moveto
(in) show
480.750 13.000 moveto
(1) show
486.750 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
492.750 13.000 moveto
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
492.750 13.000 moveto
(<) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .08333 m
.97619 .08333 L
s
.10317 .00397 m
.10317 .1627 L
s
.10317 .08333 m
.10317 .08333 .00794 0 365.73 arc
F
gsave
.93651 .05688 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
gsave
.12963 .12302 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 g
[(1)] .12963 .10979 0 0 Mshowa
[(2)] .52646 .10979 0 0 Mshowa
[(3)] .92328 .10979 0 0 Mshowa
newpath
.10317 .08333 .00794 0 365.73 arc
s
newpath
.5 .08333 .00794 0 365.73 arc
s
newpath
.89683 .08333 .00794 0 365.73 arc
s
.10317 .08333 m
.5 .08333 L
s
.5 .08333 m
.89683 .08333 L
s
1 0 0 r
.10317 .08333 m
.10363 .08333 L
.10404 .08333 L
.10451 .08333 L
.10496 .08333 L
.10537 .08333 L
.10575 .08333 L
.10617 .08333 L
.10662 .08333 L
.10706 .08333 L
.10754 .08333 L
.10799 .08333 L
.10841 .08333 L
.10889 .08333 L
.10917 .08333 L
.10942 .08333 L
.10989 .08333 L
.11038 .08333 L
.11063 .08333 L
.1109 .08333 L
.11137 .08333 L
.11163 .08333 L
.11188 .08333 L
.11215 .08333 L
.11244 .08333 L
.11268 .08333 L
.11296 .08333 L
.11345 .08333 L
.11393 .08333 L
.11437 .08333 L
.1148 .08333 L
.1152 .08333 L
.11564 .08333 L
.11612 .08333 L
.11659 .08333 L
.11709 .08333 L
.11752 .08333 L
.11798 .08333 L
.11826 .08333 L
.11851 .08333 L
.11878 .08333 L
.11907 .08333 L
.11956 .08333 L
.11984 .08333 L
.1201 .08333 L
.12059 .08333 L
.12103 .08333 L
.12128 .08333 L
.12154 .08333 L
.12203 .08333 L
Mistroke
.12232 .08333 L
.1226 .08333 L
.12285 .08333 L
.12311 .08333 L
.12341 .08333 L
.12372 .08333 L
.12398 .08333 L
.12427 .08333 L
.12454 .08333 L
.12479 .08333 L
.12508 .08333 L
.12535 .08333 L
.12583 .08333 L
.1261 .08333 L
.12635 .08333 L
.1268 .08333 L
.12728 .08333 L
.12773 .08333 L
.12815 .08333 L
.12861 .08333 L
.12911 .08333 L
.12937 .08333 L
.12964 .08333 L
.13013 .08333 L
.1304 .08333 L
.13065 .08333 L
.13092 .08333 L
.13121 .08333 L
.13169 .08333 L
.13197 .08333 L
.13223 .08333 L
.13271 .08333 L
.13315 .08333 L
.13365 .08333 L
.13413 .08333 L
.13457 .08333 L
.13504 .08333 L
.13548 .08333 L
.13589 .08333 L
.13634 .08333 L
.13683 .08333 L
.13708 .08333 L
.13735 .08333 L
.13783 .08333 L
.13809 .08333 L
.13834 .08333 L
.1386 .08333 L
.13889 .08333 L
.13936 .08333 L
.13963 .08333 L
Mistroke
.13988 .08333 L
.14036 .08333 L
.14079 .08333 L
.14128 .08333 L
.14176 .08333 L
.1422 .08333 L
.1426 .08333 L
.14307 .08333 L
.14351 .08333 L
.14391 .08333 L
.14429 .08333 L
.1447 .08333 L
.14513 .08333 L
.14557 .08333 L
.14604 .08333 L
.14648 .08333 L
.14689 .08333 L
.14736 .08333 L
.14763 .08333 L
.14788 .08333 L
.14833 .08333 L
.14881 .08333 L
.14925 .08333 L
.14973 .08333 L
.15023 .08333 L
.15069 .08333 L
.15112 .08333 L
.15152 .08333 L
.15198 .08333 L
.15241 .08333 L
.15288 .08333 L
.15338 .08333 L
.1538 .08333 L
.15427 .08333 L
.15477 .08333 L
.15505 .08333 L
.15531 .08333 L
.15581 .08333 L
.15628 .08333 L
.15672 .08333 L
.15713 .08333 L
.15759 .08333 L
.15802 .08333 L
.15843 .08333 L
.1588 .08333 L
.15921 .08333 L
.15964 .08333 L
.16007 .08333 L
.16054 .08333 L
.16098 .08333 L
Mistroke
.16138 .08333 L
.16185 .08333 L
.16212 .08333 L
.16236 .08333 L
.16281 .08333 L
.16329 .08333 L
.16375 .08333 L
.16426 .08333 L
.16473 .08333 L
.16517 .08333 L
.16561 .08333 L
.16601 .08333 L
.16646 .08333 L
.1669 .08333 L
.16737 .08333 L
.16787 .08333 L
.16829 .08333 L
.16876 .08333 L
.16926 .08333 L
.16954 .08333 L
.1698 .08333 L
.1703 .08333 L
.17077 .08333 L
.17118 .08333 L
.17162 .08333 L
.17208 .08333 L
.17252 .08333 L
.17292 .08333 L
.1733 .08333 L
.1737 .08333 L
.17413 .08333 L
.17457 .08333 L
.17504 .08333 L
.17548 .08333 L
.17588 .08333 L
.17635 .08333 L
.17662 .08333 L
.17686 .08333 L
.17731 .08333 L
.17779 .08333 L
.17825 .08333 L
.17876 .08333 L
.17923 .08333 L
.17968 .08333 L
.18012 .08333 L
.18051 .08333 L
.18097 .08333 L
.1814 .08333 L
.18188 .08333 L
.18238 .08333 L
Mistroke
.1828 .08333 L
.18327 .08333 L
.18377 .08333 L
.18406 .08333 L
.18431 .08333 L
.18481 .08333 L
.18529 .08333 L
.18569 .08333 L
.18614 .08333 L
.1866 .08333 L
.18703 .08333 L
.18744 .08333 L
.18781 .08333 L
.18822 .08333 L
.18865 .08333 L
.18909 .08333 L
.18956 .08333 L
.19 .08333 L
.1904 .08333 L
.19087 .08333 L
.19113 .08333 L
.19138 .08333 L
.19183 .08333 L
.19231 .08333 L
.19277 .08333 L
.19328 .08333 L
.19376 .08333 L
.1942 .08333 L
.1946 .08333 L
.19504 .08333 L
.1955 .08333 L
.19593 .08333 L
.1964 .08333 L
.19691 .08333 L
.19733 .08333 L
.1978 .08333 L
.19831 .08333 L
.19859 .08333 L
.19885 .08333 L
.19935 .08333 L
.19982 .08333 L
.20022 .08333 L
.20067 .08333 L
.20114 .08333 L
.20157 .08333 L
.20198 .08333 L
.20235 .08333 L
.20278 .08333 L
.20319 .08333 L
.20363 .08333 L
Mistroke
.20409 .08333 L
.20454 .08333 L
.20494 .08333 L
.20541 .08333 L
.20567 .08333 L
.20592 .08333 L
.20637 .08333 L
.20684 .08333 L
.20731 .08333 L
.20757 .08333 L
.20782 .08333 L
.20827 .08333 L
.20874 .08333 L
.20917 .08333 L
.20957 .08333 L
.21001 .08333 L
.21048 .08333 L
.21095 .08333 L
.21122 .08333 L
.21147 .08333 L
.21197 .08333 L
.21225 .08333 L
.21251 .08333 L
.21297 .08333 L
.21347 .08333 L
.21394 .08333 L
.21437 .08333 L
.21478 .08333 L
.21521 .08333 L
.21562 .08333 L
.216 .08333 L
.21644 .08333 L
.21692 .08333 L
.21737 .08333 L
.21779 .08333 L
.21826 .08333 L
.21871 .08333 L
.21911 .08333 L
.21954 .08333 L
.22001 .08333 L
.22051 .08333 L
.22093 .08333 L
.2214 .08333 L
.2219 .08333 L
.22237 .08333 L
.22261 .08333 L
.22288 .08333 L
.22316 .08333 L
.22342 .08333 L
.2239 .08333 L
Mistroke
.22433 .08333 L
.22484 .08333 L
.22532 .08333 L
.22575 .08333 L
.22621 .08333 L
.22664 .08333 L
.22703 .08333 L
.22749 .08333 L
.22799 .08333 L
.22846 .08333 L
.2289 .08333 L
.22936 .08333 L
.22986 .08333 L
.23033 .08333 L
.23075 .08333 L
.23126 .08333 L
.23154 .08333 L
.2318 .08333 L
.23228 .08333 L
.23253 .08333 L
.2328 .08333 L
.23305 .08333 L
.23333 .08333 L
.23382 .08333 L
.23409 .08333 L
.23434 .08333 L
.23462 .08333 L
.23492 .08333 L
.23518 .08333 L
.23546 .08333 L
.23572 .08333 L
.23597 .08333 L
.23643 .08333 L
.23692 .08333 L
.23738 .08333 L
.23789 .08333 L
.23836 .08333 L
.2388 .08333 L
.23924 .08333 L
.23964 .08333 L
.2401 .08333 L
.24053 .08333 L
.241 .08333 L
.2415 .08333 L
.24193 .08333 L
.2424 .08333 L
.2429 .08333 L
.24318 .08333 L
.24344 .08333 L
.24394 .08333 L
Mistroke
.24441 .08333 L
.24482 .08333 L
.24526 .08333 L
.24572 .08333 L
.24616 .08333 L
.24657 .08333 L
.24694 .08333 L
.24735 .08333 L
.24778 .08333 L
.24821 .08333 L
.24868 .08333 L
.24912 .08333 L
.24952 .08333 L
.24999 .08333 L
.25026 .08333 L
.2505 .08333 L
.25095 .08333 L
.25143 .08333 L
.2519 .08333 L
.2524 .08333 L
.25288 .08333 L
.25332 .08333 L
.25376 .08333 L
.25416 .08333 L
.25462 .08333 L
.25505 .08333 L
.25553 .08333 L
.25603 .08333 L
.25645 .08333 L
.25692 .08333 L
.25743 .08333 L
.25771 .08333 L
.25797 .08333 L
.25847 .08333 L
.25894 .08333 L
.25935 .08333 L
.25979 .08333 L
.26026 .08333 L
.26069 .08333 L
.2611 .08333 L
.26147 .08333 L
.2619 .08333 L
.26231 .08333 L
.26275 .08333 L
.26321 .08333 L
.26366 .08333 L
.26406 .08333 L
.26453 .08333 L
.26479 .08333 L
.26504 .08333 L
Mistroke
.26549 .08333 L
.26596 .08333 L
.26643 .08333 L
.26669 .08333 L
.26694 .08333 L
.26739 .08333 L
.26786 .08333 L
.26829 .08333 L
.26869 .08333 L
.26912 .08333 L
.2696 .08333 L
.27007 .08333 L
.27034 .08333 L
.27058 .08333 L
.27109 .08333 L
.27137 .08333 L
.27163 .08333 L
.27209 .08333 L
.27258 .08333 L
.27306 .08333 L
.27349 .08333 L
.27389 .08333 L
.27433 .08333 L
.27474 .08333 L
.27511 .08333 L
.27555 .08333 L
.27603 .08333 L
.27648 .08333 L
.2769 .08333 L
.27738 .08333 L
.27782 .08333 L
.27822 .08333 L
.27865 .08333 L
.27912 .08333 L
.27962 .08333 L
.28005 .08333 L
.28052 .08333 L
.28102 .08333 L
.28148 .08333 L
.28172 .08333 L
.28199 .08333 L
.28227 .08333 L
.28253 .08333 L
.28301 .08333 L
.28345 .08333 L
.28393 .08333 L
.28444 .08333 L
.28486 .08333 L
.28532 .08333 L
.28575 .08333 L
Mistroke
.28614 .08333 L
.2866 .08333 L
.2871 .08333 L
.28757 .08333 L
.28801 .08333 L
.28847 .08333 L
.28897 .08333 L
.28944 .08333 L
.28987 .08333 L
.29037 .08333 L
.29065 .08333 L
.29091 .08333 L
.29139 .08333 L
.29164 .08333 L
.29191 .08333 L
.29217 .08333 L
.29244 .08333 L
.29293 .08333 L
.2932 .08333 L
.29346 .08333 L
.29373 .08333 L
.29403 .08333 L
.29429 .08333 L
.29457 .08333 L
.29483 .08333 L
.29508 .08333 L
.29554 .08333 L
.29603 .08333 L
.29649 .08333 L
.297 .08333 L
.29747 .08333 L
.29791 .08333 L
.29835 .08333 L
.29875 .08333 L
.29921 .08333 L
.29964 .08333 L
.30011 .08333 L
.30061 .08333 L
.30104 .08333 L
.3015 .08333 L
.30201 .08333 L
.30229 .08333 L
.30255 .08333 L
.30305 .08333 L
.30352 .08333 L
.30392 .08333 L
.30437 .08333 L
.30483 .08333 L
.30527 .08333 L
.30567 .08333 L
Mistroke
.30604 .08333 L
.30645 .08333 L
.30688 .08333 L
.30732 .08333 L
.30779 .08333 L
.30823 .08333 L
.30863 .08333 L
.3091 .08333 L
.30936 .08333 L
.30961 .08333 L
.31006 .08333 L
.31054 .08333 L
.311 .08333 L
.31151 .08333 L
.31199 .08333 L
.31243 .08333 L
.31287 .08333 L
.31327 .08333 L
.31372 .08333 L
.31416 .08333 L
.31463 .08333 L
.31513 .08333 L
.31556 .08333 L
.31603 .08333 L
.31653 .08333 L
.31681 .08333 L
.31707 .08333 L
.31757 .08333 L
.31804 .08333 L
.31845 .08333 L
.31889 .08333 L
.31936 .08333 L
.31979 .08333 L
.3202 .08333 L
.32057 .08333 L
.321 .08333 L
.32141 .08333 L
.32185 .08333 L
.32232 .08333 L
.32276 .08333 L
.32316 .08333 L
.32363 .08333 L
.32389 .08333 L
.32414 .08333 L
.32459 .08333 L
.32506 .08333 L
.32553 .08333 L
.3258 .08333 L
.32604 .08333 L
.32649 .08333 L
Mistroke
.32696 .08333 L
.32739 .08333 L
.32779 .08333 L
.32822 .08333 L
.32869 .08333 L
.32917 .08333 L
.32943 .08333 L
.32968 .08333 L
.33019 .08333 L
.33047 .08333 L
.33072 .08333 L
.33118 .08333 L
.33168 .08333 L
.33215 .08333 L
.33259 .08333 L
.33299 .08333 L
.33343 .08333 L
.33384 .08333 L
.33421 .08333 L
.33465 .08333 L
.33513 .08333 L
.33558 .08333 L
.336 .08333 L
.33647 .08333 L
.33692 .08333 L
.33732 .08333 L
.33775 .08333 L
.33822 .08333 L
.33872 .08333 L
.33915 .08333 L
.33961 .08333 L
.34011 .08333 L
.34058 .08333 L
.34082 .08333 L
.34109 .08333 L
.34136 .08333 L
.34163 .08333 L
.3421 .08333 L
.34254 .08333 L
.34302 .08333 L
.34353 .08333 L
.34396 .08333 L
.34442 .08333 L
.34485 .08333 L
.34524 .08333 L
.3457 .08333 L
.3462 .08333 L
.34667 .08333 L
.3471 .08333 L
.34756 .08333 L
Mistroke
.34806 .08333 L
.34853 .08333 L
.34896 .08333 L
.34946 .08333 L
.34974 .08333 L
.35 .08333 L
.35049 .08333 L
.35073 .08333 L
.351 .08333 L
.35126 .08333 L
.35153 .08333 L
.35202 .08333 L
.35229 .08333 L
.35255 .08333 L
.35283 .08333 L
.35312 .08333 L
.35338 .08333 L
.35366 .08333 L
.35393 .08333 L
.35417 .08333 L
.35463 .08333 L
.35512 .08333 L
.35558 .08333 L
.35609 .08333 L
.35656 .08333 L
.357 .08333 L
.35744 .08333 L
.35784 .08333 L
.3583 .08333 L
.35873 .08333 L
.3592 .08333 L
.3597 .08333 L
.36013 .08333 L
.36059 .08333 L
.3611 .08333 L
.36138 .08333 L
.36164 .08333 L
.36214 .08333 L
.36261 .08333 L
.36301 .08333 L
.36346 .08333 L
.36392 .08333 L
.36435 .08333 L
.36476 .08333 L
.36513 .08333 L
.36554 .08333 L
.36597 .08333 L
.36641 .08333 L
.36687 .08333 L
.36731 .08333 L
Mistroke
.36771 .08333 L
.36819 .08333 L
.36845 .08333 L
.3687 .08333 L
.36915 .08333 L
.36962 .08333 L
.37009 .08333 L
.37059 .08333 L
.37107 .08333 L
.37151 .08333 L
.37195 .08333 L
.37235 .08333 L
.37281 .08333 L
.37324 .08333 L
.37372 .08333 L
.37422 .08333 L
.37464 .08333 L
.37511 .08333 L
.37561 .08333 L
.3759 .08333 L
.37615 .08333 L
.37665 .08333 L
.37713 .08333 L
.37753 .08333 L
.37798 .08333 L
.37844 .08333 L
.37888 .08333 L
.37928 .08333 L
.37965 .08333 L
.38006 .08333 L
.38049 .08333 L
.38093 .08333 L
.3814 .08333 L
.38184 .08333 L
.38224 .08333 L
.38271 .08333 L
.38298 .08333 L
.38322 .08333 L
.38367 .08333 L
.38415 .08333 L
.38461 .08333 L
.38488 .08333 L
.38512 .08333 L
.38557 .08333 L
.38604 .08333 L
.38647 .08333 L
.38687 .08333 L
.3873 .08333 L
.38777 .08333 L
.38825 .08333 L
Mistroke
.38851 .08333 L
.38876 .08333 L
.38927 .08333 L
.38955 .08333 L
.3898 .08333 L
.39026 .08333 L
.39076 .08333 L
.39123 .08333 L
.39167 .08333 L
.39207 .08333 L
.3925 .08333 L
.39291 .08333 L
.39329 .08333 L
.39373 .08333 L
.39421 .08333 L
.39466 .08333 L
.39508 .08333 L
.39555 .08333 L
.39599 .08333 L
.39639 .08333 L
.39683 .08333 L
.3973 .08333 L
.3978 .08333 L
.39822 .08333 L
.39869 .08333 L
.39919 .08333 L
.39965 .08333 L
.3999 .08333 L
.40016 .08333 L
.40044 .08333 L
.4007 .08333 L
.40118 .08333 L
.40162 .08333 L
.4021 .08333 L
.40261 .08333 L
.40303 .08333 L
.40349 .08333 L
.40392 .08333 L
.40431 .08333 L
.40477 .08333 L
.40527 .08333 L
.40574 .08333 L
.40618 .08333 L
.40664 .08333 L
.40713 .08333 L
.4076 .08333 L
.40803 .08333 L
.40853 .08333 L
.40882 .08333 L
.40908 .08333 L
Mistroke
.40956 .08333 L
.40983 .08333 L
.41007 .08333 L
.41033 .08333 L
.4106 .08333 L
.41109 .08333 L
.41137 .08333 L
.41162 .08333 L
.4119 .08333 L
.4122 .08333 L
.41245 .08333 L
.41273 .08333 L
.413 .08333 L
.41324 .08333 L
.4137 .08333 L
.41419 .08333 L
.41466 .08333 L
.41516 .08333 L
.41563 .08333 L
.41608 .08333 L
.41651 .08333 L
.41691 .08333 L
.41737 .08333 L
.4178 .08333 L
.41827 .08333 L
.41877 .08333 L
.4192 .08333 L
.41966 .08333 L
.42017 .08333 L
.42045 .08333 L
.42071 .08333 L
.42121 .08333 L
.42168 .08333 L
.42208 .08333 L
.42252 .08333 L
.42299 .08333 L
.42342 .08333 L
.42383 .08333 L
.4242 .08333 L
.42461 .08333 L
.42504 .08333 L
.42547 .08333 L
.42594 .08333 L
.42638 .08333 L
.42678 .08333 L
.42725 .08333 L
.42752 .08333 L
.42777 .08333 L
.42822 .08333 L
.42869 .08333 L
Mistroke
.42916 .08333 L
.42966 .08333 L
.43014 .08333 L
.43058 .08333 L
.43102 .08333 L
.43142 .08333 L
.43188 .08333 L
.43231 .08333 L
.43278 .08333 L
.43328 .08333 L
.43371 .08333 L
.43418 .08333 L
.43468 .08333 L
.43496 .08333 L
.43522 .08333 L
.43572 .08333 L
.43619 .08333 L
.4366 .08333 L
.43704 .08333 L
.43751 .08333 L
.43794 .08333 L
.43835 .08333 L
.43872 .08333 L
.43913 .08333 L
.43956 .08333 L
.43999 .08333 L
.44046 .08333 L
.4409 .08333 L
.4413 .08333 L
.44177 .08333 L
.44204 .08333 L
.44228 .08333 L
.44274 .08333 L
.44321 .08333 L
.44368 .08333 L
.44394 .08333 L
.44418 .08333 L
.44463 .08333 L
.44511 .08333 L
.44553 .08333 L
.44593 .08333 L
.44636 .08333 L
.44684 .08333 L
.44731 .08333 L
.44757 .08333 L
.44782 .08333 L
.44833 .08333 L
.44861 .08333 L
.44886 .08333 L
.44932 .08333 L
Mistroke
.44982 .08333 L
.45029 .08333 L
.45073 .08333 L
.45113 .08333 L
.45156 .08333 L
.45197 .08333 L
.45235 .08333 L
.45279 .08333 L
.45327 .08333 L
.45372 .08333 L
.45414 .08333 L
.45461 .08333 L
.45505 .08333 L
.45545 .08333 L
.45589 .08333 L
.45636 .08333 L
.45686 .08333 L
.45728 .08333 L
.45775 .08333 L
.45809 .08333 L
.4584 .08333 L
.45874 .08333 L
.45911 .08333 L
.45942 .08333 L
.45972 .08333 L
.46004 .08333 L
.46039 .08333 L
.46069 .08333 L
.46101 .08333 L
.46134 .08333 L
.46165 .08333 L
.46194 .08333 L
.46221 .08333 L
.46252 .08333 L
.4628 .08333 L
.46312 .08333 L
.46346 .08333 L
.46382 .08333 L
.46416 .08333 L
.46447 .08333 L
.46476 .08333 L
.46509 .08333 L
.4654 .08333 L
.46574 .08333 L
.4661 .08333 L
.46644 .08333 L
.46675 .08333 L
.46712 .08333 L
.46751 .08333 L
.46788 .08333 L
Mistroke
.46822 .08333 L
Mfstroke
.46822 .08333 m
.46869 .08333 L
.46913 .08333 L
.46962 .08333 L
.47009 .08333 L
.47053 .08333 L
.47093 .08333 L
.47137 .08333 L
.47184 .08333 L
.47231 .08333 L
.47281 .08333 L
.47329 .08333 L
.47372 .08333 L
.47423 .08333 L
.47452 .08333 L
.47479 .08333 L
.47528 .08333 L
.4758 .08333 L
.47606 .08333 L
.47634 .08333 L
.47683 .08333 L
.47711 .08333 L
.47737 .08333 L
.47765 .08333 L
.47796 .08333 L
.47822 .08333 L
.4785 .08333 L
.47902 .08333 L
.47952 .08333 L
.47999 .08333 L
.48044 .08333 L
.48086 .08333 L
.48133 .08333 L
.48183 .08333 L
.48233 .08333 L
.48285 .08333 L
.4833 .08333 L
.48379 .08333 L
.48407 .08333 L
.48434 .08333 L
.48462 .08333 L
.48493 .08333 L
.48545 .08333 L
.48574 .08333 L
.48601 .08333 L
.48652 .08333 L
.48699 .08333 L
.48725 .08333 L
.48753 .08333 L
.48804 .08333 L
Mistroke
.48835 .08333 L
.48864 .08333 L
.4889 .08333 L
.48918 .08333 L
.48949 .08333 L
.48981 .08333 L
.49009 .08333 L
.49039 .08333 L
.49068 .08333 L
.49094 .08333 L
.49124 .08333 L
.49152 .08333 L
.49203 .08333 L
.49231 .08333 L
.49258 .08333 L
.49305 .08333 L
.49355 .08333 L
.49403 .08333 L
.49447 .08333 L
.49495 .08333 L
.49548 .08333 L
.49575 .08333 L
.49603 .08333 L
.49655 .08333 L
.49683 .08333 L
.49709 .08333 L
.49738 .08333 L
.49768 .08333 L
.49819 .08333 L
.49848 .08333 L
.49876 .08333 L
.49926 .08333 L
.49972 .08333 L
.50025 .08333 L
.50076 .08333 L
.50122 .08333 L
.50171 .08333 L
.50218 .08333 L
.5026 .08333 L
.50308 .08333 L
.5036 .08333 L
.50386 .08333 L
.50414 .08333 L
.50464 .08333 L
.50492 .08333 L
.50517 .08333 L
.50546 .08333 L
.50575 .08333 L
.50625 .08333 L
.50654 .08333 L
Mistroke
.5068 .08333 L
.5073 .08333 L
.50775 .08333 L
.50827 .08333 L
.50877 .08333 L
.50924 .08333 L
.50966 .08333 L
.51015 .08333 L
.51061 .08333 L
.51104 .08333 L
.51143 .08333 L
.51186 .08333 L
.51232 .08333 L
.51278 .08333 L
.51327 .08333 L
.51374 .08333 L
.51416 .08333 L
.51466 .08333 L
.51494 .08333 L
.5152 .08333 L
.51568 .08333 L
.51619 .08333 L
.51665 .08333 L
.51715 .08333 L
.51767 .08333 L
.51816 .08333 L
.51862 .08333 L
.51903 .08333 L
.51951 .08333 L
.51997 .08333 L
.52046 .08333 L
.52098 .08333 L
.52143 .08333 L
.52192 .08333 L
.52245 .08333 L
.52274 .08333 L
.52301 .08333 L
.52354 .08333 L
.52404 .08333 L
.5245 .08333 L
.52492 .08333 L
.52541 .08333 L
.52587 .08333 L
.52629 .08333 L
.52668 .08333 L
.52711 .08333 L
.52756 .08333 L
.52802 .08333 L
.52851 .08333 L
.52897 .08333 L
Mistroke
.52939 .08333 L
.52989 .08333 L
.53017 .08333 L
.53043 .08333 L
.5309 .08333 L
.5314 .08333 L
.53189 .08333 L
.53242 .08333 L
.53292 .08333 L
.53338 .08333 L
.53384 .08333 L
.53426 .08333 L
.53474 .08333 L
.53519 .08333 L
.53569 .08333 L
.53621 .08333 L
.53666 .08333 L
.53715 .08333 L
.53768 .08333 L
.53797 .08333 L
.53825 .08333 L
.53877 .08333 L
.53927 .08333 L
.53969 .08333 L
.54016 .08333 L
.54064 .08333 L
.5411 .08333 L
.54153 .08333 L
.54192 .08333 L
.54235 .08333 L
.5428 .08333 L
.54326 .08333 L
.54375 .08333 L
.54421 .08333 L
.54463 .08333 L
.54513 .08333 L
.54541 .08333 L
.54566 .08333 L
.54614 .08333 L
.54664 .08333 L
.54713 .08333 L
.54766 .08333 L
.54816 .08333 L
.54862 .08333 L
.54909 .08333 L
.5495 .08333 L
.54999 .08333 L
.55044 .08333 L
.55094 .08333 L
.55146 .08333 L
Mistroke
.55191 .08333 L
.5524 .08333 L
.55293 .08333 L
.55323 .08333 L
.5535 .08333 L
.55402 .08333 L
.55452 .08333 L
.55495 .08333 L
.55541 .08333 L
.5559 .08333 L
.55636 .08333 L
.55678 .08333 L
.55718 .08333 L
.5576 .08333 L
.55806 .08333 L
.55852 .08333 L
.55901 .08333 L
.55947 .08333 L
.55989 .08333 L
.56039 .08333 L
.56067 .08333 L
.56092 .08333 L
.5614 .08333 L
.5619 .08333 L
.56239 .08333 L
.56292 .08333 L
.56342 .08333 L
.56389 .08333 L
.56431 .08333 L
.56477 .08333 L
.56525 .08333 L
.56571 .08333 L
.56621 .08333 L
.56673 .08333 L
.56718 .08333 L
.56767 .08333 L
.5682 .08333 L
.5685 .08333 L
.56877 .08333 L
.5693 .08333 L
.56979 .08333 L
.57022 .08333 L
.57069 .08333 L
.57118 .08333 L
.57164 .08333 L
.57206 .08333 L
.57245 .08333 L
.57291 .08333 L
.57333 .08333 L
.5738 .08333 L
Mistroke
.57429 .08333 L
.57475 .08333 L
.57517 .08333 L
.57567 .08333 L
.57595 .08333 L
.5762 .08333 L
.57668 .08333 L
.57718 .08333 L
.57767 .08333 L
.57795 .08333 L
.5782 .08333 L
.57867 .08333 L
.57917 .08333 L
.57962 .08333 L
.58004 .08333 L
.5805 .08333 L
.581 .08333 L
.58149 .08333 L
.58177 .08333 L
.58204 .08333 L
.58257 .08333 L
.58286 .08333 L
.58313 .08333 L
.58361 .08333 L
.58414 .08333 L
.58463 .08333 L
.58509 .08333 L
.58552 .08333 L
.58597 .08333 L
.5864 .08333 L
.5868 .08333 L
.58726 .08333 L
.58776 .08333 L
.58824 .08333 L
.58868 .08333 L
.58918 .08333 L
.58964 .08333 L
.59006 .08333 L
.59052 .08333 L
.59101 .08333 L
.59154 .08333 L
.59199 .08333 L
.59248 .08333 L
.593 .08333 L
.59349 .08333 L
.59375 .08333 L
.59403 .08333 L
.59432 .08333 L
.59459 .08333 L
.5951 .08333 L
Mistroke
.59556 .08333 L
.59609 .08333 L
.5966 .08333 L
.59705 .08333 L
.59753 .08333 L
.59798 .08333 L
.59839 .08333 L
.59888 .08333 L
.5994 .08333 L
.5999 .08333 L
.60035 .08333 L
.60084 .08333 L
.60136 .08333 L
.60186 .08333 L
.60231 .08333 L
.60283 .08333 L
.60313 .08333 L
.60341 .08333 L
.60391 .08333 L
.60417 .08333 L
.60445 .08333 L
.60472 .08333 L
.60501 .08333 L
.60553 .08333 L
.60581 .08333 L
.60608 .08333 L
.60637 .08333 L
.60669 .08333 L
.60696 .08333 L
.60725 .08333 L
.60753 .08333 L
.60779 .08333 L
.60827 .08333 L
.60878 .08333 L
.60927 .08333 L
.6098 .08333 L
.6103 .08333 L
.61077 .08333 L
.61123 .08333 L
.61165 .08333 L
.61213 .08333 L
.61258 .08333 L
.61308 .08333 L
.6136 .08333 L
.61405 .08333 L
.61454 .08333 L
.61507 .08333 L
.61537 .08333 L
.61564 .08333 L
.61617 .08333 L
Mistroke
.61666 .08333 L
.61709 .08333 L
.61755 .08333 L
.61804 .08333 L
.6185 .08333 L
.61893 .08333 L
.61932 .08333 L
.61974 .08333 L
.6202 .08333 L
.62066 .08333 L
.62115 .08333 L
.62161 .08333 L
.62203 .08333 L
.62253 .08333 L
.62281 .08333 L
.62306 .08333 L
.62354 .08333 L
.62404 .08333 L
.62453 .08333 L
.62506 .08333 L
.62556 .08333 L
.62603 .08333 L
.62649 .08333 L
.62691 .08333 L
.62739 .08333 L
.62784 .08333 L
.62834 .08333 L
.62887 .08333 L
.62932 .08333 L
.62981 .08333 L
.63034 .08333 L
.63064 .08333 L
.63091 .08333 L
.63143 .08333 L
.63193 .08333 L
.63236 .08333 L
.63282 .08333 L
.63331 .08333 L
.63377 .08333 L
.6342 .08333 L
.63459 .08333 L
.63504 .08333 L
.63547 .08333 L
.63593 .08333 L
.63642 .08333 L
.63689 .08333 L
.63731 .08333 L
.6378 .08333 L
.63808 .08333 L
.63834 .08333 L
Mistroke
.63881 .08333 L
.63931 .08333 L
.6398 .08333 L
.64008 .08333 L
.64034 .08333 L
.64081 .08333 L
.64131 .08333 L
.64175 .08333 L
.64217 .08333 L
.64263 .08333 L
.64313 .08333 L
.64363 .08333 L
.64391 .08333 L
.64417 .08333 L
.6447 .08333 L
.64499 .08333 L
.64526 .08333 L
.64575 .08333 L
.64627 .08333 L
.64676 .08333 L
.64722 .08333 L
.64765 .08333 L
.6481 .08333 L
.64853 .08333 L
.64893 .08333 L
.64939 .08333 L
.64989 .08333 L
.65037 .08333 L
.65081 .08333 L
.65131 .08333 L
.65177 .08333 L
.65219 .08333 L
.65265 .08333 L
.65314 .08333 L
.65367 .08333 L
.65412 .08333 L
.65461 .08333 L
.65513 .08333 L
.65562 .08333 L
.65588 .08333 L
.65616 .08333 L
.65645 .08333 L
.65672 .08333 L
.65723 .08333 L
.65769 .08333 L
.65819 .08333 L
.65873 .08333 L
.65918 .08333 L
.65966 .08333 L
.66011 .08333 L
Mistroke
.66052 .08333 L
.661 .08333 L
.66153 .08333 L
.66202 .08333 L
.66248 .08333 L
.66297 .08333 L
.66349 .08333 L
.66398 .08333 L
.66443 .08333 L
.66496 .08333 L
.66526 .08333 L
.66553 .08333 L
.66604 .08333 L
.66629 .08333 L
.66658 .08333 L
.66685 .08333 L
.66714 .08333 L
.66765 .08333 L
.66794 .08333 L
.66821 .08333 L
.6685 .08333 L
.66881 .08333 L
.66908 .08333 L
.66938 .08333 L
.66965 .08333 L
.66991 .08333 L
.6704 .08333 L
.67091 .08333 L
.6714 .08333 L
.67193 .08333 L
.67243 .08333 L
.67289 .08333 L
.67335 .08333 L
.67377 .08333 L
.67425 .08333 L
.6747 .08333 L
.6752 .08333 L
.67573 .08333 L
.67617 .08333 L
.67666 .08333 L
.67719 .08333 L
.67749 .08333 L
.67776 .08333 L
.67829 .08333 L
.67878 .08333 L
.67921 .08333 L
.67967 .08333 L
.68016 .08333 L
.68062 .08333 L
.68105 .08333 L
Mistroke
.68144 .08333 L
.68187 .08333 L
.68232 .08333 L
.68278 .08333 L
.68327 .08333 L
.68373 .08333 L
.68415 .08333 L
.68465 .08333 L
.68493 .08333 L
.68518 .08333 L
.68566 .08333 L
.68616 .08333 L
.68665 .08333 L
.68718 .08333 L
.68768 .08333 L
.68815 .08333 L
.68861 .08333 L
.68903 .08333 L
.68951 .08333 L
.68996 .08333 L
.69046 .08333 L
.69099 .08333 L
.69143 .08333 L
.69193 .08333 L
.69246 .08333 L
.69275 .08333 L
.69302 .08333 L
.69355 .08333 L
.69405 .08333 L
.69447 .08333 L
.69494 .08333 L
.69543 .08333 L
.69589 .08333 L
.69631 .08333 L
.6967 .08333 L
.69716 .08333 L
.69759 .08333 L
.69805 .08333 L
.69854 .08333 L
.699 .08333 L
.69942 .08333 L
.69992 .08333 L
.7002 .08333 L
.70045 .08333 L
.70093 .08333 L
.70143 .08333 L
.70192 .08333 L
.70219 .08333 L
.70245 .08333 L
.70292 .08333 L
Mistroke
.70342 .08333 L
.70387 .08333 L
.70429 .08333 L
.70475 .08333 L
.70524 .08333 L
.70574 .08333 L
.70602 .08333 L
.70628 .08333 L
.70681 .08333 L
.70711 .08333 L
.70738 .08333 L
.70786 .08333 L
.70838 .08333 L
.70888 .08333 L
.70933 .08333 L
.70976 .08333 L
.71021 .08333 L
.71065 .08333 L
.71104 .08333 L
.7115 .08333 L
.712 .08333 L
.71248 .08333 L
.71292 .08333 L
.71342 .08333 L
.71388 .08333 L
.7143 .08333 L
.71476 .08333 L
.71525 .08333 L
.71578 .08333 L
.71623 .08333 L
.71672 .08333 L
.71724 .08333 L
.71773 .08333 L
.71798 .08333 L
.71827 .08333 L
.71856 .08333 L
.71883 .08333 L
.71934 .08333 L
.7198 .08333 L
.7203 .08333 L
.72083 .08333 L
.72128 .08333 L
.72176 .08333 L
.72222 .08333 L
.72263 .08333 L
.72311 .08333 L
.72364 .08333 L
.72413 .08333 L
.72459 .08333 L
.72507 .08333 L
Mistroke
.7256 .08333 L
.72609 .08333 L
.72654 .08333 L
.72706 .08333 L
.72736 .08333 L
.72764 .08333 L
.72814 .08333 L
.7284 .08333 L
.72868 .08333 L
.72896 .08333 L
.72924 .08333 L
.72976 .08333 L
.73004 .08333 L
.73031 .08333 L
.7306 .08333 L
.73092 .08333 L
.73119 .08333 L
.73148 .08333 L
.73176 .08333 L
.73202 .08333 L
.7325 .08333 L
.73302 .08333 L
.7335 .08333 L
.73403 .08333 L
.73453 .08333 L
.735 .08333 L
.73546 .08333 L
.73587 .08333 L
.73635 .08333 L
.73681 .08333 L
.7373 .08333 L
.73783 .08333 L
.73828 .08333 L
.73877 .08333 L
.7393 .08333 L
.73959 .08333 L
.73986 .08333 L
.74039 .08333 L
.74089 .08333 L
.74131 .08333 L
.74178 .08333 L
.74226 .08333 L
.74272 .08333 L
.74315 .08333 L
.74354 .08333 L
.74397 .08333 L
.74442 .08333 L
.74488 .08333 L
.74537 .08333 L
.74583 .08333 L
Mistroke
.74625 .08333 L
.74675 .08333 L
.74703 .08333 L
.74728 .08333 L
.74776 .08333 L
.74826 .08333 L
.74875 .08333 L
.74928 .08333 L
.74978 .08333 L
.75025 .08333 L
.75071 .08333 L
.75112 .08333 L
.75161 .08333 L
.75206 .08333 L
.75256 .08333 L
.75308 .08333 L
.75353 .08333 L
.75402 .08333 L
.75455 .08333 L
.75485 .08333 L
.75512 .08333 L
.75565 .08333 L
.75614 .08333 L
.75657 .08333 L
.75704 .08333 L
.75752 .08333 L
.75798 .08333 L
.75841 .08333 L
.7588 .08333 L
.75923 .08333 L
.75968 .08333 L
.76014 .08333 L
.76063 .08333 L
.7611 .08333 L
.76152 .08333 L
.76201 .08333 L
.76229 .08333 L
.76255 .08333 L
.76302 .08333 L
.76352 .08333 L
.76401 .08333 L
.76429 .08333 L
.76455 .08333 L
.76502 .08333 L
.76552 .08333 L
.76596 .08333 L
.76638 .08333 L
.76684 .08333 L
.76733 .08333 L
.76783 .08333 L
Mistroke
.76811 .08333 L
.76837 .08333 L
.7689 .08333 L
.7692 .08333 L
.76947 .08333 L
.76995 .08333 L
.77047 .08333 L
.77097 .08333 L
.77142 .08333 L
.77185 .08333 L
.77231 .08333 L
.77274 .08333 L
.77313 .08333 L
.77359 .08333 L
.77409 .08333 L
.77457 .08333 L
.77501 .08333 L
.77551 .08333 L
.77597 .08333 L
.77639 .08333 L
.77685 .08333 L
.77734 .08333 L
.77787 .08333 L
.77832 .08333 L
.77881 .08333 L
.77933 .08333 L
.77982 .08333 L
.78007 .08333 L
.78035 .08333 L
.78065 .08333 L
.78092 .08333 L
.78142 .08333 L
.78188 .08333 L
.78239 .08333 L
.78292 .08333 L
.78337 .08333 L
.78385 .08333 L
.7843 .08333 L
.78471 .08333 L
.7852 .08333 L
.78572 .08333 L
.78622 .08333 L
.78667 .08333 L
.78716 .08333 L
.78768 .08333 L
.78817 .08333 L
.78862 .08333 L
.78915 .08333 L
.78945 .08333 L
.78972 .08333 L
Mistroke
.79023 .08333 L
.79051 .08333 L
.79077 .08333 L
.79104 .08333 L
.79133 .08333 L
.79184 .08333 L
.79213 .08333 L
.7924 .08333 L
.79269 .08333 L
.793 .08333 L
.79327 .08333 L
.79357 .08333 L
.79384 .08333 L
.7941 .08333 L
.79459 .08333 L
.7951 .08333 L
.79559 .08333 L
.79612 .08333 L
.79662 .08333 L
.79708 .08333 L
.79754 .08333 L
.79796 .08333 L
.79844 .08333 L
.79889 .08333 L
.79939 .08333 L
.79991 .08333 L
.80036 .08333 L
.80085 .08333 L
.80138 .08333 L
.80167 .08333 L
.80194 .08333 L
.80247 .08333 L
.80297 .08333 L
.80339 .08333 L
.80386 .08333 L
.80434 .08333 L
.8048 .08333 L
.80523 .08333 L
.80562 .08333 L
.80605 .08333 L
.8065 .08333 L
.80696 .08333 L
.80745 .08333 L
.80791 .08333 L
.80833 .08333 L
.80883 .08333 L
.80911 .08333 L
.80936 .08333 L
.80984 .08333 L
.81034 .08333 L
Mistroke
.81083 .08333 L
.81136 .08333 L
.81186 .08333 L
.81232 .08333 L
.81279 .08333 L
.8132 .08333 L
.81369 .08333 L
.81414 .08333 L
.81464 .08333 L
.81516 .08333 L
.81561 .08333 L
.8161 .08333 L
.81663 .08333 L
.81693 .08333 L
.8172 .08333 L
.81772 .08333 L
.81822 .08333 L
.81865 .08333 L
.81911 .08333 L
.8196 .08333 L
.82006 .08333 L
.82049 .08333 L
.82088 .08333 L
.82131 .08333 L
.82176 .08333 L
.82222 .08333 L
.82271 .08333 L
.82317 .08333 L
.82359 .08333 L
.82409 .08333 L
.82437 .08333 L
.82462 .08333 L
.8251 .08333 L
.8256 .08333 L
.82609 .08333 L
.82636 .08333 L
.82662 .08333 L
.82709 .08333 L
.82759 .08333 L
.82804 .08333 L
.82845 .08333 L
.82891 .08333 L
.82941 .08333 L
.8299 .08333 L
.83018 .08333 L
.83045 .08333 L
.83097 .08333 L
.83127 .08333 L
.83154 .08333 L
.83202 .08333 L
Mistroke
.83255 .08333 L
.83304 .08333 L
.8335 .08333 L
.83392 .08333 L
.83438 .08333 L
.83481 .08333 L
.8352 .08333 L
.83566 .08333 L
.83616 .08333 L
.83664 .08333 L
.83708 .08333 L
.83758 .08333 L
.83804 .08333 L
.83846 .08333 L
.83892 .08333 L
.83941 .08333 L
.83994 .08333 L
.84039 .08333 L
.84088 .08333 L
.84123 .08333 L
.84156 .08333 L
.84192 .08333 L
.84231 .08333 L
.84264 .08333 L
.84295 .08333 L
.84329 .08333 L
.84366 .08333 L
.84396 .08333 L
.8443 .08333 L
.84465 .08333 L
.84498 .08333 L
.84529 .08333 L
.84556 .08333 L
.84589 .08333 L
.84619 .08333 L
.84652 .08333 L
.84688 .08333 L
.84726 .08333 L
.84761 .08333 L
.84794 .08333 L
.84824 .08333 L
.84859 .08333 L
.84892 .08333 L
.84928 .08333 L
.84966 .08333 L
.85002 .08333 L
.85034 .08333 L
.85072 .08333 L
.85114 .08333 L
.85153 .08333 L
Mistroke
.85188 .08333 L
Mfstroke
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{570, 95},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1680}, {0, 989}},
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{1008, 605},
WindowMargins->{{7, Automatic}, {33, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->False,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 159, 3, 97, "Title"],
Cell[1938, 58, 136, 4, 28, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2099, 66, 175, 5, 68, "Subtitle"],

Cell[CellGroupData[{
Cell[2299, 75, 71, 1, 27, "Input"],
Cell[2373, 78, 20466, 710, 56, 9138, 565, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[22854, 791, 42, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[22921, 795, 118, 2, 43, "Input"],
Cell[23042, 799, 98, 2, 27, "Output"]
}, Open  ]],
Cell[23155, 804, 295, 9, 47, "Text"],

Cell[CellGroupData[{
Cell[23475, 817, 149, 6, 73, "Input"],
Cell[23627, 825, 57, 1, 27, "Output"]
}, Open  ]],
Cell[23699, 829, 155, 3, 30, "Text"],
Cell[23857, 834, 106, 2, 43, "Input"],
Cell[23966, 838, 72, 0, 30, "Text"],
Cell[24041, 840, 121, 2, 43, "Input"],
Cell[24165, 844, 155, 3, 30, "Text"],
Cell[24323, 849, 106, 2, 43, "Input"],
Cell[24432, 853, 98, 3, 46, "Text"],
Cell[24533, 858, 309, 9, 47, "Text"],

Cell[CellGroupData[{
Cell[24867, 871, 156, 6, 73, "Input"],
Cell[25026, 879, 57, 1, 27, "Output"]
}, Open  ]],
Cell[25098, 883, 525, 13, 64, "Text"],

Cell[CellGroupData[{
Cell[25648, 900, 125, 2, 43, "Input"],
Cell[25776, 904, 61, 1, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[25886, 911, 155, 5, 52, "Subtitle"],

Cell[CellGroupData[{
Cell[26066, 920, 35, 1, 27, "Input"],
Cell[26104, 923, 35, 1, 27, "Output"]
}, Open  ]],
Cell[26154, 927, 69, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[26248, 931, 75, 1, 27, "Input"],
Cell[26326, 934, 207, 4, 23, "Print"]
}, Open  ]],
Cell[26548, 941, 70, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[26643, 945, 71, 1, 27, "Input"],
Cell[26717, 948, 237, 4, 23, "Print"]
}, Open  ]],
Cell[26969, 955, 64, 0, 30, "Text"],
Cell[27036, 957, 87, 1, 27, "Input"],
Cell[27126, 960, 203, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[27354, 968, 110, 2, 27, "Input"],
Cell[27467, 972, 304, 6, 23, "Print"]
}, Open  ]],
Cell[27786, 981, 203, 5, 30, "Text"],

Cell[CellGroupData[{
Cell[28014, 990, 138, 3, 27, "Input"],
Cell[28155, 995, 44, 1, 23, "Print"]
}, Open  ]],
Cell[28214, 999, 154, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[28393, 1007, 109, 2, 27, "Input"],
Cell[28505, 1011, 44, 1, 23, "Print"]
}, Open  ]],
Cell[28564, 1015, 107, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[28696, 1022, 207, 4, 43, "Input"],
Cell[28906, 1028, 44, 1, 23, "Print"]
}, Open  ]],
Cell[28965, 1032, 31, 0, 30, "Text"],
Cell[28999, 1034, 144, 6, 72, "Input"],
Cell[29146, 1042, 68, 0, 30, "Text"],
Cell[29217, 1044, 442, 10, 75, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29696, 1059, 185, 6, 52, "Subtitle"],
Cell[29884, 1067, 182, 4, 30, "Text"],
Cell[30069, 1073, 131, 3, 27, "Input"],
Cell[30203, 1078, 60, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[30288, 1082, 107, 2, 27, "Input"],
Cell[30398, 1086, 137, 2, 23, "Print"],
Cell[30538, 1090, 337, 7, 23, "Print"],
Cell[30878, 1099, 137, 2, 23, "Print"],
Cell[31018, 1103, 116, 2, 23, "Print"],
Cell[31137, 1107, 2170, 56, 39, "Print"],
Cell[33310, 1165, 1485, 38, 23, "Print"],
Cell[34798, 1205, 1515, 38, 23, "Print"],
Cell[36316, 1245, 1517, 38, 23, "Print"],
Cell[37836, 1285, 1515, 38, 23, "Print"],
Cell[39354, 1325, 1526, 38, 25, "Print"],
Cell[40883, 1365, 1528, 38, 25, "Print"]
}, Open  ]],
Cell[42426, 1406, 101, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[42552, 1413, 215, 3, 43, "Input"],
Cell[42770, 1418, 97392, 3735, 215, 49585, 3140, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[140177, 5156, 111, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[140313, 5163, 130, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[140468, 5169, 36778, 1008, 129, 11832, 696, "GraphicsData", \
"PostScript", "Graphics"],
Cell[177249, 6179, 36373, 998, 126, 11779, 690, "GraphicsData", "PostScript", \
"Graphics"],
Cell[213625, 7179, 36125, 995, 126, 11782, 690, "GraphicsData", "PostScript", \
"Graphics"],
Cell[249753, 8176, 36084, 995, 126, 11773, 690, "GraphicsData", "PostScript", \
"Graphics"],
Cell[285840, 9173, 36338, 998, 126, 11780, 690, "GraphicsData", "PostScript", \
"Graphics"],
Cell[322181, 10173, 36784, 1008, 129, 11838, 696, "GraphicsData", \
"PostScript", "Graphics"],
Cell[358968, 11183, 36338, 998, 126, 11780, 690, "GraphicsData", \
"PostScript", "Graphics"],
Cell[395309, 12183, 36084, 995, 126, 11773, 690, "GraphicsData", \
"PostScript", "Graphics"],
Cell[431396, 13180, 36125, 995, 126, 11782, 690, "GraphicsData", \
"PostScript", "Graphics"],
Cell[467524, 14177, 36373, 998, 126, 11779, 690, "GraphicsData", \
"PostScript", "Graphics"],
Cell[503900, 15177, 11959, 700, 129, 11832, 696, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[515908, 15883, 130, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[516063, 15889, 37419, 1034, 126, 12240, 719, "GraphicsData", \
"PostScript", "Graphics"],
Cell[553485, 16925, 37250, 1032, 126, 12245, 719, "GraphicsData", \
"PostScript", "Graphics"],
Cell[590738, 17959, 36741, 1026, 126, 12242, 719, "GraphicsData", \
"PostScript", "Graphics"],
Cell[627482, 18987, 12365, 723, 126, 12239, 719, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[639850, 19712, 12370, 723, 126, 12244, 719, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[652223, 20437, 12366, 723, 126, 12240, 719, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[664592, 21162, 12370, 723, 126, 12244, 719, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[676965, 21887, 12365, 723, 126, 12239, 719, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[689333, 22612, 12368, 723, 126, 12242, 719, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[701704, 23337, 12371, 723, 126, 12245, 719, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[714078, 24062, 12366, 723, 126, 12240, 719, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[726493, 24791, 128, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[726646, 24797, 38520, 1076, 126, 12792, 754, "GraphicsData", \
"PostScript", "Graphics"],
Cell[765169, 25875, 38197, 1072, 126, 12793, 754, "GraphicsData", \
"PostScript", "Graphics"],
Cell[803369, 26949, 37451, 1063, 126, 12788, 754, "GraphicsData", \
"PostScript", "Graphics"],
Cell[840823, 28014, 37433, 1063, 126, 12782, 754, "GraphicsData", \
"PostScript", "Graphics"],
Cell[878259, 29079, 12879, 758, 126, 12756, 754, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[891141, 29839, 12909, 758, 126, 12786, 754, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[904053, 30599, 12879, 758, 126, 12756, 754, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[916935, 31359, 12905, 758, 126, 12782, 754, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[929843, 32119, 12911, 758, 126, 12788, 754, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[942757, 32879, 12916, 758, 126, 12793, 754, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[955676, 33639, 12915, 758, 126, 12792, 754, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[968640, 34403, 128, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[968793, 34409, 61875, 2753, 103, 39961, 2478, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1030671, 37164, 61854, 2753, 103, 39940, 2478, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1092528, 39919, 61886, 2753, 103, 39972, 2478, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1154417, 42674, 61845, 2753, 103, 39967, 2478, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1216265, 45429, 40084, 2482, 103, 39966, 2478, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1256352, 47913, 40077, 2482, 103, 39959, 2478, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1296432, 50397, 40084, 2482, 103, 39966, 2478, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1336519, 52881, 40085, 2482, 103, 39967, 2478, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1376607, 55365, 40090, 2482, 103, 39972, 2478, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1416700, 57849, 40058, 2482, 103, 39940, 2478, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1456761, 60333, 40079, 2482, 103, 39961, 2478, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

